/* Generated by Cython 0.29.32 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "H5_USE_18_API",
                null
            ],
            [
                "NPY_NO_DEPRECATED_API",
                0
            ]
        ],
        "depends": [
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/arrayobject.h",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/arrayscalars.h",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/ndarrayobject.h",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/ndarraytypes.h",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/ufuncobject.h",
            "h5py/api_compat.h",
            "lzf/lzf_filter.h"
        ],
        "include_dirs": [
            "./h5py",
            "lzf",
            "lzf/lzf",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include"
        ],
        "libraries": [
            "hdf5",
            "hdf5_hl"
        ],
        "name": "h5py.h5t",
        "sources": [
            "h5py/h5t.pyx"
        ]
    },
    "module_name": "h5py.h5t"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_32"
#define CYTHON_HEX_VERSION 0x001D20F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_HEX >= 0x07030900)
  #endif
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #if PY_VERSION_HEX >= 0x030B00A4
    #undef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 0
  #elif !defined(CYTHON_FAST_THREAD_STATE)
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL (PY_VERSION_HEX < 0x030A0000)
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #if PY_VERSION_HEX >= 0x030B00A4
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if PY_VERSION_HEX >= 0x030B00A1
    static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *kwds=NULL, *argcount=NULL, *posonlyargcount=NULL, *kwonlyargcount=NULL;
        PyObject *nlocals=NULL, *stacksize=NULL, *flags=NULL, *replace=NULL, *call_result=NULL, *empty=NULL;
        const char *fn_cstr=NULL;
        const char *name_cstr=NULL;
        PyCodeObject* co=NULL;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        if (!(kwds=PyDict_New())) goto end;
        if (!(argcount=PyLong_FromLong(a))) goto end;
        if (PyDict_SetItemString(kwds, "co_argcount", argcount) != 0) goto end;
        if (!(posonlyargcount=PyLong_FromLong(0))) goto end;
        if (PyDict_SetItemString(kwds, "co_posonlyargcount", posonlyargcount) != 0) goto end;
        if (!(kwonlyargcount=PyLong_FromLong(k))) goto end;
        if (PyDict_SetItemString(kwds, "co_kwonlyargcount", kwonlyargcount) != 0) goto end;
        if (!(nlocals=PyLong_FromLong(l))) goto end;
        if (PyDict_SetItemString(kwds, "co_nlocals", nlocals) != 0) goto end;
        if (!(stacksize=PyLong_FromLong(s))) goto end;
        if (PyDict_SetItemString(kwds, "co_stacksize", stacksize) != 0) goto end;
        if (!(flags=PyLong_FromLong(f))) goto end;
        if (PyDict_SetItemString(kwds, "co_flags", flags) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_code", code) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_consts", c) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_names", n) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_varnames", v) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_freevars", fv) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_cellvars", cell) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_linetable", lnos) != 0) goto end;
        if (!(fn_cstr=PyUnicode_AsUTF8AndSize(fn, NULL))) goto end;
        if (!(name_cstr=PyUnicode_AsUTF8AndSize(name, NULL))) goto end;
        if (!(co = PyCode_NewEmpty(fn_cstr, name_cstr, fline))) goto end;
        if (!(replace = PyObject_GetAttrString((PyObject*)co, "replace"))) goto cleanup_code_too;
        if (!(empty = PyTuple_New(0))) goto cleanup_code_too; // unfortunately __pyx_empty_tuple isn't available here
        if (!(call_result = PyObject_Call(replace, empty, kwds))) goto cleanup_code_too;
        Py_XDECREF((PyObject*)co);
        co = (PyCodeObject*)call_result;
        call_result = NULL;
        if (0) {
            cleanup_code_too:
            Py_XDECREF((PyObject*)co);
            co = NULL;
        }
        end:
        Py_XDECREF(kwds);
        Py_XDECREF(argcount);
        Py_XDECREF(posonlyargcount);
        Py_XDECREF(kwonlyargcount);
        Py_XDECREF(nlocals);
        Py_XDECREF(stacksize);
        Py_XDECREF(replace);
        Py_XDECREF(call_result);
        Py_XDECREF(empty);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return co;
    }
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if defined(PyUnicode_IS_READY)
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #else
  #define __Pyx_PyUnicode_READY(op)       (0)
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #endif
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__h5py__h5t
#define __PYX_HAVE_API__h5py__h5t
/* Early includes */
#include <string.h>
#include <stdlib.h>
#include <stddef.h>
#include <time.h>
#include <stdio.h>
#include "numpy/arrayobject.h"
#include "numpy/ndarrayobject.h"
#include "numpy/ndarraytypes.h"
#include "numpy/arrayscalars.h"
#include "numpy/ufuncobject.h"

    /* NumPy API declarations from "numpy/__init__.pxd" */
    
#include "unistd.h"
#include "api_compat.h"
#include "lzf_filter.h"
#include "H5Cpublic.h"
#include "hdf5.h"
#include "hdf5_hl.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "h5py/h5t.pyx",
  "__init__.pxd",
  "type.pxd",
  "h5py/h5r.pxd",
  "h5py/h5p.pxd",
};

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":689
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":690
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":691
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":692
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":696
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":697
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":698
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":699
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":703
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":704
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":713
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":714
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":715
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":717
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":718
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":719
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":721
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":722
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":724
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":725
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":726
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;

/* "api_types_ext.pxd":20
 * from libc.string cimport strlen, strchr, strcpy, strncpy, strcmp,\
 *                          strdup, strdup, memcpy, memset
 * ctypedef long size_t             # <<<<<<<<<<<<<<
 * from libc.time cimport time_t
 * 
 */
typedef long __pyx_t_4h5py_13api_types_ext_size_t;
/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);


/*--- Type declarations ---*/
struct __pyx_obj_4h5py_8_objects_ObjectID;
struct __pyx_obj_4h5py_3h5r_Reference;
struct __pyx_obj_4h5py_3h5r_RegionReference;
struct __pyx_obj_4h5py_3h5p_PropID;
struct __pyx_obj_4h5py_3h5p_PropClassID;
struct __pyx_obj_4h5py_3h5p_PropInstanceID;
struct __pyx_obj_4h5py_3h5p_PropCreateID;
struct __pyx_obj_4h5py_3h5p_PropCopyID;
struct __pyx_obj_4h5py_3h5p_PropOCID;
struct __pyx_obj_4h5py_3h5p_PropDCID;
struct __pyx_obj_4h5py_3h5p_PropFCID;
struct __pyx_obj_4h5py_3h5p_PropFAID;
struct __pyx_obj_4h5py_3h5p_PropDXID;
struct __pyx_obj_4h5py_3h5p_PropDAID;
struct __pyx_obj_4h5py_3h5p_PropLCID;
struct __pyx_obj_4h5py_3h5p_PropLAID;
struct __pyx_obj_4h5py_3h5p_PropGCID;
struct __pyx_obj_4h5py_3h5t_TypeID;
struct __pyx_obj_4h5py_3h5t_TypeArrayID;
struct __pyx_obj_4h5py_3h5t_TypeOpaqueID;
struct __pyx_obj_4h5py_3h5t_TypeStringID;
struct __pyx_obj_4h5py_3h5t_TypeVlenID;
struct __pyx_obj_4h5py_3h5t_TypeTimeID;
struct __pyx_obj_4h5py_3h5t_TypeBitfieldID;
struct __pyx_obj_4h5py_3h5t_TypeReferenceID;
struct __pyx_obj_4h5py_3h5t_TypeAtomicID;
struct __pyx_obj_4h5py_3h5t_TypeIntegerID;
struct __pyx_obj_4h5py_3h5t_TypeFloatID;
struct __pyx_obj_4h5py_3h5t_TypeCompositeID;
struct __pyx_obj_4h5py_3h5t_TypeEnumID;
struct __pyx_obj_4h5py_3h5t_TypeCompoundID;
struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":728
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":729
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":730
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":732
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_t_4h5py_3h5r_hdset_reg_ref_t;
union __pyx_t_4h5py_3h5r_ref_u;

/* "h5r.pxd":18
 *   ctypedef haddr_t hobj_ref_t
 * IF HDF5_VERSION >= (1, 12, 0):
 *   cdef struct hdset_reg_ref_t:             # <<<<<<<<<<<<<<
 *     uint8_t data[12] # sizeof(haddr_t) + 4 == sizeof(signed long long) + 4
 * ELSE:
 */
struct __pyx_t_4h5py_3h5r_hdset_reg_ref_t {
  __pyx_t_5numpy_uint8_t data[12];
};

/* "h5r.pxd":23
 *   ctypedef unsigned char hdset_reg_ref_t[12]
 * 
 * cdef union ref_u:             # <<<<<<<<<<<<<<
 *     hobj_ref_t         obj_ref
 *     hdset_reg_ref_t    reg_ref
 */
union __pyx_t_4h5py_3h5r_ref_u {
  hobj_ref_t obj_ref;
  struct __pyx_t_4h5py_3h5r_hdset_reg_ref_t reg_ref;
};
struct __pyx_opt_args_4h5py_5utils_check_numpy_read;
struct __pyx_opt_args_4h5py_5utils_check_numpy_write;

/* "utils.pxd":16
 * cdef void efree(void* ptr)
 * 
 * cpdef int check_numpy_read(ndarray arr, hid_t space_id=*) except -1             # <<<<<<<<<<<<<<
 * cpdef int check_numpy_write(ndarray arr, hid_t space_id=*) except -1
 * 
 */
struct __pyx_opt_args_4h5py_5utils_check_numpy_read {
  int __pyx_n;
  hid_t space_id;
};

/* "utils.pxd":17
 * 
 * cpdef int check_numpy_read(ndarray arr, hid_t space_id=*) except -1
 * cpdef int check_numpy_write(ndarray arr, hid_t space_id=*) except -1             # <<<<<<<<<<<<<<
 * 
 * cdef int convert_tuple(object tuple, hsize_t *dims, hsize_t rank) except -1
 */
struct __pyx_opt_args_4h5py_5utils_check_numpy_write {
  int __pyx_n;
  hid_t space_id;
};
struct __pyx_opt_args_4h5py_3h5t_py_create;
struct __pyx_ctuple_int__and_int__and_int;
typedef struct __pyx_ctuple_int__and_int__and_int __pyx_ctuple_int__and_int__and_int;

/* "h5py/h5t.pxd":72
 * cdef hid_t H5PY_OBJ
 * cdef char* H5PY_PYTHON_OPAQUE_TAG
 * cpdef TypeID py_create(object dtype, bint logical=*, bint aligned=*)             # <<<<<<<<<<<<<<
 */
struct __pyx_opt_args_4h5py_3h5t_py_create {
  int __pyx_n;
  int logical;
  int aligned;
};

/* "h5py/h5t.pyx":281
 * 
 * 
 * cdef (int, int, int) _correct_float_info(ftype_, finfo):             # <<<<<<<<<<<<<<
 *     nmant = finfo.nmant
 *     maxexp = finfo.maxexp
 */
struct __pyx_ctuple_int__and_int__and_int {
  int f0;
  int f1;
  int f2;
};

/* "_objects.pxd":12
 * from .defs cimport *
 * 
 * cdef class ObjectID:             # <<<<<<<<<<<<<<
 * 
 *     cdef object __weakref__
 */
struct __pyx_obj_4h5py_8_objects_ObjectID {
  PyObject_HEAD
  PyObject *__weakref__;
  hid_t id;
  int locked;
  PyObject *_hash;
  size_t _pyid;
};


/* "h5r.pxd":27
 *     hdset_reg_ref_t    reg_ref
 * 
 * cdef class Reference:             # <<<<<<<<<<<<<<
 * 
 *     cdef ref_u ref
 */
struct __pyx_obj_4h5py_3h5r_Reference {
  PyObject_HEAD
  union __pyx_t_4h5py_3h5r_ref_u ref;
  int typecode;
  size_t typesize;
};


/* "h5r.pxd":33
 *     cdef readonly size_t typesize
 * 
 * cdef class RegionReference(Reference):             # <<<<<<<<<<<<<<
 *     pass
 */
struct __pyx_obj_4h5py_3h5r_RegionReference {
  struct __pyx_obj_4h5py_3h5r_Reference __pyx_base;
};


/* "h5p.pxd":17
 * # --- Base classes ---
 * 
 * cdef class PropID(ObjectID):             # <<<<<<<<<<<<<<
 *     """ Base class for all property lists """
 *     pass
 */
struct __pyx_obj_4h5py_3h5p_PropID {
  struct __pyx_obj_4h5py_8_objects_ObjectID __pyx_base;
};


/* "h5p.pxd":21
 *     pass
 * 
 * cdef class PropClassID(PropID):             # <<<<<<<<<<<<<<
 *     """ Represents an HDF5 property list class.  These can be either (locked)
 *         library-defined classes or user-created classes.
 */
struct __pyx_obj_4h5py_3h5p_PropClassID {
  struct __pyx_obj_4h5py_3h5p_PropID __pyx_base;
};


/* "h5p.pxd":27
 *     pass
 * 
 * cdef class PropInstanceID(PropID):             # <<<<<<<<<<<<<<
 *     """ Represents an instance of a property list class (i.e. an actual list
 *         which can be passed on to other API functions).
 */
struct __pyx_obj_4h5py_3h5p_PropInstanceID {
  struct __pyx_obj_4h5py_3h5p_PropID __pyx_base;
};


/* "h5p.pxd":33
 *     pass
 * 
 * cdef class PropCreateID(PropInstanceID):             # <<<<<<<<<<<<<<
 *     """ Base class for all object creation lists.
 * 
 */
struct __pyx_obj_4h5py_3h5p_PropCreateID {
  struct __pyx_obj_4h5py_3h5p_PropInstanceID __pyx_base;
};


/* "h5p.pxd":40
 *     pass
 * 
 * cdef class PropCopyID(PropInstanceID):             # <<<<<<<<<<<<<<
 *     """ Property list for copying objects (as in h5o.copy) """
 * 
 */
struct __pyx_obj_4h5py_3h5p_PropCopyID {
  struct __pyx_obj_4h5py_3h5p_PropInstanceID __pyx_base;
};


/* "h5p.pxd":45
 * # --- Object creation ---
 * 
 * cdef class PropOCID(PropCreateID):             # <<<<<<<<<<<<<<
 *     """ Object creation property list """
 *     pass
 */
struct __pyx_obj_4h5py_3h5p_PropOCID {
  struct __pyx_obj_4h5py_3h5p_PropCreateID __pyx_base;
};


/* "h5p.pxd":49
 *     pass
 * 
 * cdef class PropDCID(PropOCID):             # <<<<<<<<<<<<<<
 *     """ Dataset creation property list """
 *     pass
 */
struct __pyx_obj_4h5py_3h5p_PropDCID {
  struct __pyx_obj_4h5py_3h5p_PropOCID __pyx_base;
};


/* "h5p.pxd":53
 *     pass
 * 
 * cdef class PropFCID(PropOCID):             # <<<<<<<<<<<<<<
 *     """ File creation property list """
 *     pass
 */
struct __pyx_obj_4h5py_3h5p_PropFCID {
  struct __pyx_obj_4h5py_3h5p_PropOCID __pyx_base;
};


/* "h5p.pxd":60
 * # --- Object access ---
 * 
 * cdef class PropFAID(PropInstanceID):             # <<<<<<<<<<<<<<
 *     """ File access property list """
 *     pass
 */
struct __pyx_obj_4h5py_3h5p_PropFAID {
  struct __pyx_obj_4h5py_3h5p_PropInstanceID __pyx_base;
};


/* "h5p.pxd":64
 *     pass
 * 
 * cdef class PropDXID(PropInstanceID):             # <<<<<<<<<<<<<<
 *     """ Dataset transfer property list """
 *     pass
 */
struct __pyx_obj_4h5py_3h5p_PropDXID {
  struct __pyx_obj_4h5py_3h5p_PropInstanceID __pyx_base;
};


/* "h5p.pxd":68
 *     pass
 * 
 * cdef class PropDAID(PropInstanceID):             # <<<<<<<<<<<<<<
 *     """ Dataset access property list"""
 *     cdef char* _virtual_prefix_buf
 */
struct __pyx_obj_4h5py_3h5p_PropDAID {
  struct __pyx_obj_4h5py_3h5p_PropInstanceID __pyx_base;
  char *_virtual_prefix_buf;
  char *_efile_prefix_buf;
};


/* "h5p.pxd":75
 * # --- New in 1.8 ---
 * 
 * cdef class PropLCID(PropCreateID):             # <<<<<<<<<<<<<<
 *     """ Link creation property list """
 *     pass
 */
struct __pyx_obj_4h5py_3h5p_PropLCID {
  struct __pyx_obj_4h5py_3h5p_PropCreateID __pyx_base;
};


/* "h5p.pxd":79
 *     pass
 * 
 * cdef class PropLAID(PropInstanceID):             # <<<<<<<<<<<<<<
 *     """ Link access property list """
 *     cdef char* _buf
 */
struct __pyx_obj_4h5py_3h5p_PropLAID {
  struct __pyx_obj_4h5py_3h5p_PropInstanceID __pyx_base;
  char *_buf;
};


/* "h5p.pxd":83
 *     cdef char* _buf
 * 
 * cdef class PropGCID(PropOCID):             # <<<<<<<<<<<<<<
 *     """ Group creation property list """
 *     pass
 */
struct __pyx_obj_4h5py_3h5p_PropGCID {
  struct __pyx_obj_4h5py_3h5p_PropOCID __pyx_base;
};


/* "h5py/h5t.pxd":15
 * from ._objects cimport class ObjectID
 * 
 * cdef class TypeID(ObjectID):             # <<<<<<<<<<<<<<
 * 
 *     cdef object py_dtype(self)
 */
struct __pyx_obj_4h5py_3h5t_TypeID {
  struct __pyx_obj_4h5py_8_objects_ObjectID __pyx_base;
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID *__pyx_vtab;
};


/* "h5py/h5t.pxd":21
 * # --- Top-level classes ---
 * 
 * cdef class TypeArrayID(TypeID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeArrayID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":24
 *     pass
 * 
 * cdef class TypeOpaqueID(TypeID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeOpaqueID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":27
 *     pass
 * 
 * cdef class TypeStringID(TypeID):             # <<<<<<<<<<<<<<
 *     # Both vlen and fixed-len strings
 *     pass
 */
struct __pyx_obj_4h5py_3h5t_TypeStringID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":31
 *     pass
 * 
 * cdef class TypeVlenID(TypeID):             # <<<<<<<<<<<<<<
 *     # Non-string vlens
 *     pass
 */
struct __pyx_obj_4h5py_3h5t_TypeVlenID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":35
 *     pass
 * 
 * cdef class TypeTimeID(TypeID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeTimeID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":38
 *     pass
 * 
 * cdef class TypeBitfieldID(TypeID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeBitfieldID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":41
 *     pass
 * 
 * cdef class TypeReferenceID(TypeID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeReferenceID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":46
 * # --- Numeric atomic types ---
 * 
 * cdef class TypeAtomicID(TypeID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeAtomicID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":49
 *     pass
 * 
 * cdef class TypeIntegerID(TypeAtomicID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeIntegerID {
  struct __pyx_obj_4h5py_3h5t_TypeAtomicID __pyx_base;
};


/* "h5py/h5t.pxd":52
 *     pass
 * 
 * cdef class TypeFloatID(TypeAtomicID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeFloatID {
  struct __pyx_obj_4h5py_3h5t_TypeAtomicID __pyx_base;
};


/* "h5py/h5t.pxd":57
 * # --- Enums & compound types ---
 * 
 * cdef class TypeCompositeID(TypeID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeCompositeID {
  struct __pyx_obj_4h5py_3h5t_TypeID __pyx_base;
};


/* "h5py/h5t.pxd":60
 *     pass
 * 
 * cdef class TypeEnumID(TypeCompositeID):             # <<<<<<<<<<<<<<
 * 
 *     cdef int enum_convert(self, long long *buf, int reverse) except -1
 */
struct __pyx_obj_4h5py_3h5t_TypeEnumID {
  struct __pyx_obj_4h5py_3h5t_TypeCompositeID __pyx_base;
};


/* "h5py/h5t.pxd":64
 *     cdef int enum_convert(self, long long *buf, int reverse) except -1
 * 
 * cdef class TypeCompoundID(TypeCompositeID):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_4h5py_3h5t_TypeCompoundID {
  struct __pyx_obj_4h5py_3h5t_TypeCompositeID __pyx_base;
};


/* "h5py/h5t.pyx":1592
 *     return TypeCompoundID(tid)
 * 
 * cdef TypeCompoundID _c_compound(cnp.dtype dt, int logical, int aligned):             # <<<<<<<<<<<<<<
 *     # Compound datatypes
 *     cdef:
 */
struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound {
  PyObject_HEAD
  PyArray_Descr *__pyx_v_dt;
};



/* "h5py/h5t.pyx":385
 * # === Base type class =========================================================
 * 
 * cdef class TypeID(ObjectID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeID {
  PyObject *(*py_dtype)(struct __pyx_obj_4h5py_3h5t_TypeID *);
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeID *__pyx_vtabptr_4h5py_3h5t_TypeID;


/* "h5py/h5t.pyx":581
 * # === Top-level classes (inherit directly from TypeID) ========================
 * 
 * cdef class TypeArrayID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeArrayID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeArrayID *__pyx_vtabptr_4h5py_3h5t_TypeArrayID;


/* "h5py/h5t.pyx":626
 * 
 * 
 * cdef class TypeOpaqueID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeOpaqueID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeOpaqueID *__pyx_vtabptr_4h5py_3h5t_TypeOpaqueID;


/* "h5py/h5t.pyx":672
 * 
 * 
 * cdef class TypeStringID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeStringID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeStringID *__pyx_vtabptr_4h5py_3h5t_TypeStringID;


/* "h5py/h5t.pyx":758
 *         return string_dtype(encoding=encoding, length=length)
 * 
 * cdef class TypeVlenID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeVlenID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeVlenID *__pyx_vtabptr_4h5py_3h5t_TypeVlenID;


/* "h5py/h5t.pyx":772
 *         return vlen_dtype(base_type.dtype)
 * 
 * cdef class TypeTimeID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeTimeID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeTimeID *__pyx_vtabptr_4h5py_3h5t_TypeTimeID;


/* "h5py/h5t.pyx":779
 *     pass
 * 
 * cdef class TypeBitfieldID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeBitfieldID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeBitfieldID *__pyx_vtabptr_4h5py_3h5t_TypeBitfieldID;


/* "h5py/h5t.pyx":803
 * 
 * 
 * cdef class TypeReferenceID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeReferenceID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeReferenceID *__pyx_vtabptr_4h5py_3h5t_TypeReferenceID;


/* "h5py/h5t.pyx":820
 * # === Numeric classes (integers and floats) ===================================
 * 
 * cdef class TypeAtomicID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeAtomicID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeAtomicID *__pyx_vtabptr_4h5py_3h5t_TypeAtomicID;


/* "h5py/h5t.pyx":916
 * 
 * 
 * cdef class TypeIntegerID(TypeAtomicID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeIntegerID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeAtomicID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeIntegerID *__pyx_vtabptr_4h5py_3h5t_TypeIntegerID;


/* "h5py/h5t.pyx":958
 * 
 * 
 * cdef class TypeFloatID(TypeAtomicID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeFloatID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeAtomicID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeFloatID *__pyx_vtabptr_4h5py_3h5t_TypeFloatID;


/* "h5py/h5t.pyx":1087
 * # === Composite types (enums and compound) ====================================
 * 
 * cdef class TypeCompositeID(TypeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeCompositeID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeCompositeID *__pyx_vtabptr_4h5py_3h5t_TypeCompositeID;


/* "h5py/h5t.pyx":1244
 * 
 * 
 * cdef class TypeEnumID(TypeCompositeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeEnumID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeCompositeID __pyx_base;
  int (*enum_convert)(struct __pyx_obj_4h5py_3h5t_TypeEnumID *, PY_LONG_LONG *, int);
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeEnumID *__pyx_vtabptr_4h5py_3h5t_TypeEnumID;


/* "h5py/h5t.pyx":1138
 *         return H5Tget_member_index(self.id, name)
 * 
 * cdef class TypeCompoundID(TypeCompositeID):             # <<<<<<<<<<<<<<
 * 
 *     """
 */

struct __pyx_vtabstruct_4h5py_3h5t_TypeCompoundID {
  struct __pyx_vtabstruct_4h5py_3h5t_TypeCompositeID __pyx_base;
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeCompoundID *__pyx_vtabptr_4h5py_3h5t_TypeCompoundID;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if CYTHON_FAST_PYCALL
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif // CYTHON_FAST_PYCALL
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* unicode_iter.proto */
static CYTHON_INLINE int __Pyx_init_unicode_iteration(
    PyObject* ustring, Py_ssize_t *length, void** data, int *kind);

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return __Pyx_PyObject_GetAttrStr(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#else
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* bytes_tailmatch.proto */
static int __Pyx_PyBytes_SingleTailmatch(PyObject* self, PyObject* arg,
                                         Py_ssize_t start, Py_ssize_t end, int direction);
static int __Pyx_PyBytes_Tailmatch(PyObject* self, PyObject* substr,
                                   Py_ssize_t start, Py_ssize_t end, int direction);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PyNumberPow2.proto */
#define __Pyx_PyNumber_InPlacePowerOf2(a, b, c) __Pyx__PyNumber_PowerOf2(a, b, c, 1)
#define __Pyx_PyNumber_PowerOf2(a, b, c) __Pyx__PyNumber_PowerOf2(a, b, c, 0)
static PyObject* __Pyx__PyNumber_PowerOf2(PyObject *two, PyObject *exp, PyObject *none, int inplace);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractCObj(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* PyObject_Unicode.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))
#else
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Unicode(obj))
#endif

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_dealloc);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE hid_t __Pyx_PyInt_As_hid_t(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__H5T_class_t(enum H5T_class_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_sign_t(H5T_sign_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_order_t(H5T_order_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__H5T_direction_t(enum H5T_direction_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_str_t(H5T_str_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_norm_t(H5T_norm_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_cset_t(H5T_cset_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_pad_t(H5T_pad_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_bkg_t(H5T_bkg_t value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_As_PY_LONG_LONG(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_hid_t(hid_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_hsize_t(hsize_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_PY_LONG_LONG(PY_LONG_LONG value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_char(char value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* VoidPtrExport.proto */
static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_4h5py_3h5t_6TypeID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_11TypeArrayID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_12TypeOpaqueID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_12TypeStringID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_10TypeVlenID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeVlenID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_14TypeBitfieldID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeBitfieldID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_15TypeReferenceID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeReferenceID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_13TypeIntegerID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_11TypeFloatID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_14TypeCompoundID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self); /* proto*/
static int __pyx_f_4h5py_3h5t_10TypeEnumID_enum_convert(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, PY_LONG_LONG *__pyx_v_buf, int __pyx_v_reverse); /* proto*/
static PyObject *__pyx_f_4h5py_3h5t_10TypeEnumID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self); /* proto*/

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'libc.stddef' */

/* Module declarations from 'libc.time' */

/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_generic = 0;
static PyTypeObject *__pyx_ptype_5numpy_number = 0;
static PyTypeObject *__pyx_ptype_5numpy_integer = 0;
static PyTypeObject *__pyx_ptype_5numpy_signedinteger = 0;
static PyTypeObject *__pyx_ptype_5numpy_unsignedinteger = 0;
static PyTypeObject *__pyx_ptype_5numpy_inexact = 0;
static PyTypeObject *__pyx_ptype_5numpy_floating = 0;
static PyTypeObject *__pyx_ptype_5numpy_complexfloating = 0;
static PyTypeObject *__pyx_ptype_5numpy_flexible = 0;
static PyTypeObject *__pyx_ptype_5numpy_character = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;

/* Module declarations from 'h5py.api_types_ext' */

/* Module declarations from 'h5py.api_types_hdf5' */

/* Module declarations from 'h5py.defs' */
static herr_t (*__pyx_f_4h5py_4defs_H5free_memory)(void *); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tcreate)(enum H5T_class_t, size_t); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Topen)(hid_t, char *, hid_t); /*proto*/
static htri_t (*__pyx_f_4h5py_4defs_H5Tcommitted)(hid_t); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tcopy)(hid_t); /*proto*/
static htri_t (*__pyx_f_4h5py_4defs_H5Tequal)(hid_t, hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tlock)(hid_t); /*proto*/
static enum H5T_class_t (*__pyx_f_4h5py_4defs_H5Tget_class)(hid_t); /*proto*/
static size_t (*__pyx_f_4h5py_4defs_H5Tget_size)(hid_t); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tget_super)(hid_t); /*proto*/
static htri_t (*__pyx_f_4h5py_4defs_H5Tdetect_class)(hid_t, enum H5T_class_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tclose)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tcommit)(hid_t, char *, hid_t, hid_t, hid_t, hid_t); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tget_create_plist)(hid_t); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tdecode)(unsigned char *); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tencode)(hid_t, unsigned char *, size_t *); /*proto*/
static H5T_conv_t (*__pyx_f_4h5py_4defs_H5Tfind)(hid_t, hid_t, H5T_cdata_t **); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tconvert)(hid_t, hid_t, size_t, void *, void *, hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_size)(hid_t, size_t); /*proto*/
static H5T_order_t (*__pyx_f_4h5py_4defs_H5Tget_order)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_order)(hid_t, H5T_order_t); /*proto*/
static hsize_t (*__pyx_f_4h5py_4defs_H5Tget_precision)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_precision)(hid_t, size_t); /*proto*/
static int (*__pyx_f_4h5py_4defs_H5Tget_offset)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_offset)(hid_t, size_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tget_pad)(hid_t, H5T_pad_t *, H5T_pad_t *); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_pad)(hid_t, H5T_pad_t, H5T_pad_t); /*proto*/
static H5T_sign_t (*__pyx_f_4h5py_4defs_H5Tget_sign)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_sign)(hid_t, H5T_sign_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tget_fields)(hid_t, size_t *, size_t *, size_t *, size_t *, size_t *); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_fields)(hid_t, size_t, size_t, size_t, size_t, size_t); /*proto*/
static size_t (*__pyx_f_4h5py_4defs_H5Tget_ebias)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_ebias)(hid_t, size_t); /*proto*/
static H5T_norm_t (*__pyx_f_4h5py_4defs_H5Tget_norm)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_norm)(hid_t, H5T_norm_t); /*proto*/
static H5T_pad_t (*__pyx_f_4h5py_4defs_H5Tget_inpad)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_inpad)(hid_t, H5T_pad_t); /*proto*/
static H5T_cset_t (*__pyx_f_4h5py_4defs_H5Tget_cset)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_cset)(hid_t, H5T_cset_t); /*proto*/
static H5T_str_t (*__pyx_f_4h5py_4defs_H5Tget_strpad)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_strpad)(hid_t, H5T_str_t); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tvlen_create)(hid_t); /*proto*/
static htri_t (*__pyx_f_4h5py_4defs_H5Tis_variable_str)(hid_t); /*proto*/
static int (*__pyx_f_4h5py_4defs_H5Tget_nmembers)(hid_t); /*proto*/
static enum H5T_class_t (*__pyx_f_4h5py_4defs_H5Tget_member_class)(hid_t, int); /*proto*/
static char *(*__pyx_f_4h5py_4defs_H5Tget_member_name)(hid_t, unsigned int); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tget_member_type)(hid_t, unsigned int); /*proto*/
static int (*__pyx_f_4h5py_4defs_H5Tget_member_offset)(hid_t, int); /*proto*/
static int (*__pyx_f_4h5py_4defs_H5Tget_member_index)(hid_t, char *); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tinsert)(hid_t, char *, size_t, hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tpack)(hid_t); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tenum_create)(hid_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tenum_insert)(hid_t, char *, void *); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tenum_nameof)(hid_t, void *, char *, size_t); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tenum_valueof)(hid_t, char *, void *); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tget_member_value)(hid_t, unsigned int, void *); /*proto*/
static hid_t (*__pyx_f_4h5py_4defs_H5Tarray_create)(hid_t, int, hsize_t *); /*proto*/
static int (*__pyx_f_4h5py_4defs_H5Tget_array_ndims)(hid_t); /*proto*/
static int (*__pyx_f_4h5py_4defs_H5Tget_array_dims)(hid_t, hsize_t *); /*proto*/
static herr_t (*__pyx_f_4h5py_4defs_H5Tset_tag)(hid_t, char *); /*proto*/
static char *(*__pyx_f_4h5py_4defs_H5Tget_tag)(hid_t); /*proto*/

/* Module declarations from 'h5py._objects' */
static PyTypeObject *__pyx_ptype_4h5py_8_objects_ObjectID = 0;
static hid_t (*__pyx_f_4h5py_8_objects_pdefault)(struct __pyx_obj_4h5py_8_objects_ObjectID *); /*proto*/

/* Module declarations from 'h5py.h5r' */
static PyTypeObject *__pyx_ptype_4h5py_3h5r_Reference = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5r_RegionReference = 0;

/* Module declarations from 'h5py.h5p' */
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropClassID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropInstanceID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropCreateID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropCopyID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropOCID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropDCID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropFCID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropFAID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropDXID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropDAID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropLCID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropLAID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5p_PropGCID = 0;
static PyObject *(*__pyx_f_4h5py_3h5p_propwrap)(hid_t); /*proto*/

/* Module declarations from 'h5py.utils' */
static void *(*__pyx_f_4h5py_5utils_emalloc)(size_t); /*proto*/
static void (*__pyx_f_4h5py_5utils_efree)(void *); /*proto*/
static int (*__pyx_f_4h5py_5utils_convert_tuple)(PyObject *, hsize_t *, hsize_t); /*proto*/
static PyObject *(*__pyx_f_4h5py_5utils_convert_dims)(hsize_t *, hsize_t); /*proto*/
static int (*__pyx_f_4h5py_5utils_require_tuple)(PyObject *, int, int, char *); /*proto*/

/* Module declarations from 'h5py.h5t' */
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeArrayID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeOpaqueID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeStringID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeVlenID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeTimeID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeBitfieldID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeReferenceID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeAtomicID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeIntegerID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeFloatID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeCompositeID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeEnumID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t_TypeCompoundID = 0;
static PyTypeObject *__pyx_ptype_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound = 0;
static hid_t __pyx_v_4h5py_3h5t_H5PY_OBJ;
static char *__pyx_v_4h5py_3h5t_H5PY_PYTHON_OPAQUE_TAG;
static PyObject *__pyx_v_4h5py_3h5t__order_map = 0;
static PyObject *__pyx_v_4h5py_3h5t__sign_map = 0;
static PyObject *__pyx_v_4h5py_3h5t__available_ftypes = 0;
static PyObject *__pyx_v_4h5py_3h5t__float_le = 0;
static PyObject *__pyx_v_4h5py_3h5t__float_be = 0;
static PyObject *__pyx_v_4h5py_3h5t__float_nt = 0;
static PyObject *__pyx_v_4h5py_3h5t__int_le = 0;
static PyObject *__pyx_v_4h5py_3h5t__int_be = 0;
static PyObject *__pyx_v_4h5py_3h5t__int_nt = 0;
static PyObject *__pyx_v_4h5py_3h5t__uint_le = 0;
static PyObject *__pyx_v_4h5py_3h5t__uint_be = 0;
static PyObject *__pyx_v_4h5py_3h5t__uint_nt = 0;
static struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_f_4h5py_3h5t_typewrap(hid_t, int __pyx_skip_dispatch); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_f_4h5py_3h5t_py_create(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_4h5py_3h5t_py_create *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_4h5py_3h5t_lockid(hid_t); /*proto*/
static PyObject *__pyx_f_4h5py_3h5t__get_available_ftypes(void); /*proto*/
static __pyx_ctuple_int__and_int__and_int __pyx_f_4h5py_3h5t__correct_float_info(PyObject *, PyObject *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_f_4h5py_3h5t__c_float(PyArray_Descr *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_f_4h5py_3h5t__c_int(PyArray_Descr *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_f_4h5py_3h5t__c_enum(PyArray_Descr *, PyObject *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_f_4h5py_3h5t__c_bool(PyArray_Descr *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_f_4h5py_3h5t__c_array(PyArray_Descr *, int); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_f_4h5py_3h5t__c_opaque(PyArray_Descr *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_f_4h5py_3h5t__c_opaque_tagged(PyArray_Descr *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_f_4h5py_3h5t__c_string(PyArray_Descr *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_f_4h5py_3h5t__c_complex(PyArray_Descr *); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_f_4h5py_3h5t__c_compound(PyArray_Descr *, int, int); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_f_4h5py_3h5t__c_vlen_str(void); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_f_4h5py_3h5t__c_vlen_unicode(void); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeReferenceID *__pyx_f_4h5py_3h5t__c_ref(PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "h5py.h5t"
extern int __pyx_module_is_main_h5py__h5t;
int __pyx_module_is_main_h5py__h5t = 0;

/* Implementation of 'h5py.h5t' */
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_NotImplemented;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_UnicodeDecodeError;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_sorted;
static PyObject *__pyx_builtin_LookupError;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_ImportError;
static const char __pyx_k_O[] = "O";
static const char __pyx_k_S[] = "|S";
static const char __pyx_k_V[] = "|V";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_u[] = "u";
static const char __pyx_k_dt[] = "dt";
static const char __pyx_k_h5[] = "h5";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_S_2[] = "S";
static const char __pyx_k__38[] = "|";
static const char __pyx_k__39[] = "<";
static const char __pyx_k__40[] = ">";
static const char __pyx_k_bkg[] = "bkg";
static const char __pyx_k_buf[] = "buf";
static const char __pyx_k_cfg[] = "cfg";
static const char __pyx_k_dst[] = "dst";
static const char __pyx_k_enc[] = "enc";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_lsb[] = "lsb";
static const char __pyx_k_msb[] = "msb";
static const char __pyx_k_ref[] = "ref";
static const char __pyx_k_src[] = "src";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_val[] = "val";
static const char __pyx_k_C_S1[] = "C_S1";
static const char __pyx_k_ENUM[] = "ENUM";
static const char __pyx_k_TIME[] = "TIME";
static const char __pyx_k_VLEN[] = "VLEN";
static const char __pyx_k_base[] = "base";
static const char __pyx_k_bool[] = "bool";
static const char __pyx_k_copy[] = "__copy__";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_dims[] = "dims";
static const char __pyx_k_dxpl[] = "dxpl";
static const char __pyx_k_enum[] = "enum";
static const char __pyx_k_epos[] = "epos";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_hash[] = "__hash__";
static const char __pyx_k_iexp[] = "iexp";
static const char __pyx_k_kind[] = "kind";
static const char __pyx_k_kwds[] = "kwds";
static const char __pyx_k_lcpl[] = "lcpl";
static const char __pyx_k_lock[] = "lock";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mpos[] = "mpos";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_nexp[] = "nexp";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_pack[] = "pack";
static const char __pyx_k_phil[] = "phil";
static const char __pyx_k_rank[] = "rank";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_spos[] = "spos";
static const char __pyx_k_tapl[] = "tapl";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_type[] = "type";
static const char __pyx_k_utf8[] = "utf8";
static const char __pyx_k_vlen[] = "vlen";
static const char __pyx_k_ARRAY[] = "ARRAY";
static const char __pyx_k_FLOAT[] = "FLOAT";
static const char __pyx_k_Float[] = "Float";
static const char __pyx_k_NUMPY[] = "NUMPY:";
static const char __pyx_k_SGN_2[] = "SGN_2";
static const char __pyx_k_ascii[] = "ascii";
static const char __pyx_k_bkg_2[] = "bkg_";
static const char __pyx_k_buf_2[] = "buf_";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_descr[] = "descr";
static const char __pyx_k_dtype[] = "dtype";
static const char __pyx_k_ebias[] = "ebias";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_equal[] = "equal";
static const char __pyx_k_esize[] = "esize";
static const char __pyx_k_field[] = "field";
static const char __pyx_k_finfo[] = "finfo";
static const char __pyx_k_ftype[] = "ftype_";
static const char __pyx_k_group[] = "group";
static const char __pyx_k_msize[] = "msize";
static const char __pyx_k_names[] = "names";
static const char __pyx_k_nmant[] = "nmant";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_uint8[] = "uint8";
static const char __pyx_k_utf_8[] = "utf-8";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_BKG_NO[] = "BKG_NO";
static const char __pyx_k_OPAQUE[] = "OPAQUE";
static const char __pyx_k_STRING[] = "STRING";
static const char __pyx_k_TypeID[] = "TypeID";
static const char __pyx_k_codecs[] = "codecs";
static const char __pyx_k_commit[] = "commit";
static const char __pyx_k_copy_2[] = "copy";
static const char __pyx_k_create[] = "create";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_f_name[] = "_f_name";
static const char __pyx_k_h5type[] = "h5type";
static const char __pyx_k_i_name[] = "_i_name";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_insert[] = "insert";
static const char __pyx_k_length[] = "length";
static const char __pyx_k_little[] = "little";
static const char __pyx_k_lookup[] = "lookup";
static const char __pyx_k_maxexp[] = "maxexp";
static const char __pyx_k_minexp[] = "minexp";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_object[] = "object_";
static const char __pyx_k_offset[] = "offset";
static const char __pyx_k_r_name[] = "_r_name";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_sorted[] = "sorted";
static const char __pyx_k_t_name[] = "_t_name";
static const char __pyx_k_BKG_YES[] = "BKG_YES";
static const char __pyx_k_INTEGER[] = "INTEGER";
static const char __pyx_k_PAD_ONE[] = "PAD_ONE";
static const char __pyx_k_aligned[] = "aligned";
static const char __pyx_k_convert[] = "convert";
static const char __pyx_k_formats[] = "formats";
static const char __pyx_k_get_pad[] = "get_pad";
static const char __pyx_k_get_tag[] = "get_tag";
static const char __pyx_k_integer[] = "integer";
static const char __pyx_k_logical[] = "logical";
static const char __pyx_k_objects[] = "_objects";
static const char __pyx_k_offsets[] = "offsets";
static const char __pyx_k_popitem[] = "popitem";
static const char __pyx_k_set_pad[] = "set_pad";
static const char __pyx_k_set_tag[] = "set_tag";
static const char __pyx_k_BITFIELD[] = "BITFIELD";
static const char __pyx_k_BKG_TEMP[] = "BKG_TEMP";
static const char __pyx_k_COMPOUND[] = "COMPOUND";
static const char __pyx_k_H5PY_OBJ[] = "H5PY_OBJ";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_NO_CLASS[] = "NO_CLASS";
static const char __pyx_k_ORDER_BE[] = "ORDER_BE";
static const char __pyx_k_ORDER_LE[] = "ORDER_LE";
static const char __pyx_k_PAD_ZERO[] = "PAD_ZERO";
static const char __pyx_k_SGN_NONE[] = "SGN_NONE";
static const char __pyx_k_STD_B8BE[] = "STD_B8BE";
static const char __pyx_k_STD_B8LE[] = "STD_B8LE";
static const char __pyx_k_STD_I8BE[] = "STD_I8BE";
static const char __pyx_k_STD_I8LE[] = "STD_I8LE";
static const char __pyx_k_STD_U8BE[] = "STD_U8BE";
static const char __pyx_k_STD_U8LE[] = "STD_U8LE";
static const char __pyx_k_VARIABLE[] = "VARIABLE";
static const char __pyx_k_basetype[] = "basetype";
static const char __pyx_k_dims_tpl[] = "dims_tpl";
static const char __pyx_k_dtype_in[] = "dtype_in";
static const char __pyx_k_encoding[] = "encoding";
static const char __pyx_k_float_be[] = "float_be";
static const char __pyx_k_float_le[] = "float_le";
static const char __pyx_k_float_nt[] = "float_nt";
static const char __pyx_k_get_cset[] = "get_cset";
static const char __pyx_k_get_norm[] = "get_norm";
static const char __pyx_k_get_sign[] = "get_sign";
static const char __pyx_k_get_size[] = "get_size";
static const char __pyx_k_h5py_h5t[] = "h5py.h5t";
static const char __pyx_k_itemsize[] = "itemsize";
static const char __pyx_k_metadata[] = "metadata";
static const char __pyx_k_np_dtype[] = "np_dtype";
static const char __pyx_k_pyx_capi[] = "__pyx_capi__";
static const char __pyx_k_set_cset[] = "set_cset";
static const char __pyx_k_set_norm[] = "set_norm";
static const char __pyx_k_set_sign[] = "set_sign";
static const char __pyx_k_set_size[] = "set_size";
static const char __pyx_k_subdtype[] = "subdtype";
static const char __pyx_k_CSET_UTF8[] = "CSET_UTF8";
static const char __pyx_k_NATIVE_B8[] = "NATIVE_B8";
static const char __pyx_k_NORM_NONE[] = "NORM_NONE";
static const char __pyx_k_ORDER_VAX[] = "ORDER_VAX";
static const char __pyx_k_REFERENCE[] = "REFERENCE";
static const char __pyx_k_STD_B16BE[] = "STD_B16BE";
static const char __pyx_k_STD_B16LE[] = "STD_B16LE";
static const char __pyx_k_STD_B32BE[] = "STD_B32BE";
static const char __pyx_k_STD_B32LE[] = "STD_B32LE";
static const char __pyx_k_STD_B64BE[] = "STD_B64BE";
static const char __pyx_k_STD_B64LE[] = "STD_B64LE";
static const char __pyx_k_STD_I16BE[] = "STD_I16BE";
static const char __pyx_k_STD_I16LE[] = "STD_I16LE";
static const char __pyx_k_STD_I32BE[] = "STD_I32BE";
static const char __pyx_k_STD_I32LE[] = "STD_I32LE";
static const char __pyx_k_STD_I64BE[] = "STD_I64BE";
static const char __pyx_k_STD_I64LE[] = "STD_I64LE";
static const char __pyx_k_STD_U16BE[] = "STD_U16BE";
static const char __pyx_k_STD_U16LE[] = "STD_U16LE";
static const char __pyx_k_STD_U32BE[] = "STD_U32BE";
static const char __pyx_k_STD_U32LE[] = "STD_U32LE";
static const char __pyx_k_STD_U64BE[] = "STD_U64BE";
static const char __pyx_k_STD_U64LE[] = "STD_U64LE";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_byteorder[] = "byteorder";
static const char __pyx_k_classtype[] = "classtype";
static const char __pyx_k_committed[] = "committed";
static const char __pyx_k_enum_vals[] = "enum_vals";
static const char __pyx_k_get_class[] = "get_class";
static const char __pyx_k_get_ebias[] = "get_ebias";
static const char __pyx_k_get_inpad[] = "get_inpad";
static const char __pyx_k_get_order[] = "get_order";
static const char __pyx_k_get_super[] = "get_super";
static const char __pyx_k_iteritems[] = "iteritems";
static const char __pyx_k_ref_dtype[] = "ref_dtype";
static const char __pyx_k_set_ebias[] = "set_ebias";
static const char __pyx_k_set_inpad[] = "set_inpad";
static const char __pyx_k_set_order[] = "set_order";
static const char __pyx_k_typecodes[] = "typecodes";
static const char __pyx_k_vlen_kind[] = "vlen_kind";
static const char __pyx_k_with_phil[] = "with_phil";
static const char __pyx_k_CSET_ASCII[] = "CSET_ASCII";
static const char __pyx_k_DIR_ASCEND[] = "DIR_ASCEND";
static const char __pyx_k_FORTRAN_S1[] = "FORTRAN_S1";
static const char __pyx_k_IEEE_F16BE[] = "IEEE_F16BE";
static const char __pyx_k_IEEE_F16LE[] = "IEEE_F16LE";
static const char __pyx_k_IEEE_F32BE[] = "IEEE_F32BE";
static const char __pyx_k_IEEE_F32LE[] = "IEEE_F32LE";
static const char __pyx_k_IEEE_F64BE[] = "IEEE_F64BE";
static const char __pyx_k_IEEE_F64LE[] = "IEEE_F64LE";
static const char __pyx_k_LDOUBLE_BE[] = "LDOUBLE_BE";
static const char __pyx_k_LDOUBLE_LE[] = "LDOUBLE_LE";
static const char __pyx_k_NATIVE_B16[] = "NATIVE_B16";
static const char __pyx_k_NATIVE_B32[] = "NATIVE_B32";
static const char __pyx_k_NATIVE_B64[] = "NATIVE_B64";
static const char __pyx_k_ORDER_NONE[] = "ORDER_NONE";
static const char __pyx_k_TypeEnumID[] = "TypeEnumID";
static const char __pyx_k_TypeTimeID[] = "TypeTimeID";
static const char __pyx_k_TypeVlenID[] = "TypeVlenID";
static const char __pyx_k_UNIX_D32BE[] = "UNIX_D32BE";
static const char __pyx_k_UNIX_D32LE[] = "UNIX_D32LE";
static const char __pyx_k_UNIX_D64BE[] = "UNIX_D64BE";
static const char __pyx_k_UNIX_D64LE[] = "UNIX_D64LE";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_enum_dtype[] = "enum_dtype";
static const char __pyx_k_get_config[] = "get_config";
static const char __pyx_k_get_fields[] = "get_fields";
static const char __pyx_k_get_offset[] = "get_offset";
static const char __pyx_k_get_strpad[] = "get_strpad";
static const char __pyx_k_h5_be_list[] = "h5_be_list";
static const char __pyx_k_h5_le_list[] = "h5_le_list";
static const char __pyx_k_issubdtype[] = "issubdtype";
static const char __pyx_k_longdouble[] = "longdouble";
static const char __pyx_k_namedtuple[] = "namedtuple";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_set_fields[] = "set_fields";
static const char __pyx_k_set_offset[] = "set_offset";
static const char __pyx_k_set_strpad[] = "set_strpad";
static const char __pyx_k_vlen_dtype[] = "vlen_dtype";
static const char __pyx_k_DIR_DEFAULT[] = "DIR_DEFAULT";
static const char __pyx_k_DIR_DESCEND[] = "DIR_DESCEND";
static const char __pyx_k_IEEE_F128BE[] = "IEEE_F128BE";
static const char __pyx_k_IEEE_F128LE[] = "IEEE_F128LE";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_LookupError[] = "LookupError";
static const char __pyx_k_NATIVE_INT8[] = "NATIVE_INT8";
static const char __pyx_k_NORM_MSBSET[] = "NORM_MSBSET";
static const char __pyx_k_STD_REF_OBJ[] = "STD_REF_OBJ";
static const char __pyx_k_STR_NULLPAD[] = "STR_NULLPAD";
static const char __pyx_k_TypeArrayID[] = "TypeArrayID";
static const char __pyx_k_TypeFloatID[] = "TypeFloatID";
static const char __pyx_k_check_dtype[] = "check_dtype";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_enum_create[] = "enum_create";
static const char __pyx_k_enum_insert[] = "enum_insert";
static const char __pyx_k_enum_nameof[] = "enum_nameof";
static const char __pyx_k_h5py_opaque[] = "h5py_opaque";
static const char __pyx_k_string_info[] = "string_info";
static const char __pyx_k_values_dict[] = "values_dict";
static const char __pyx_k_vlen_create[] = "vlen_create";
static const char __pyx_k_NATIVE_FLOAT[] = "NATIVE_FLOAT";
static const char __pyx_k_NATIVE_INT16[] = "NATIVE_INT16";
static const char __pyx_k_NATIVE_INT32[] = "NATIVE_INT32";
static const char __pyx_k_NATIVE_INT64[] = "NATIVE_INT64";
static const char __pyx_k_NATIVE_UINT8[] = "NATIVE_UINT8";
static const char __pyx_k_NORM_IMPLIED[] = "NORM_IMPLIED";
static const char __pyx_k_ORDER_NATIVE[] = "ORDER_NATIVE";
static const char __pyx_k_Object_dtype[] = "Object dtype ";
static const char __pyx_k_STR_NULLTERM[] = "STR_NULLTERM";
static const char __pyx_k_STR_SPACEPAD[] = "STR_SPACEPAD";
static const char __pyx_k_TypeAtomicID[] = "TypeAtomicID";
static const char __pyx_k_TypeOpaqueID[] = "TypeOpaqueID";
static const char __pyx_k_TypeStringID[] = "TypeStringID";
static const char __pyx_k_array_create[] = "array_create";
static const char __pyx_k_detect_class[] = "detect_class";
static const char __pyx_k_enum_valueof[] = "enum_valueof";
static const char __pyx_k_get_nmembers[] = "get_nmembers";
static const char __pyx_k_h5py_h5t_pyx[] = "h5py/h5t.pyx";
static const char __pyx_k_newbyteorder[] = "newbyteorder";
static const char __pyx_k_opaque_dtype[] = "opaque_dtype";
static const char __pyx_k_string_dtype[] = "string_dtype";
static const char __pyx_k_NATIVE_DOUBLE[] = "NATIVE_DOUBLE";
static const char __pyx_k_NATIVE_UINT16[] = "NATIVE_UINT16";
static const char __pyx_k_NATIVE_UINT32[] = "NATIVE_UINT32";
static const char __pyx_k_NATIVE_UINT64[] = "NATIVE_UINT64";
static const char __pyx_k_PYTHON_OBJECT[] = "PYTHON_OBJECT";
static const char __pyx_k_TypeIntegerID[] = "TypeIntegerID";
static const char __pyx_k_get_precision[] = "get_precision";
static const char __pyx_k_h5py_encoding[] = "h5py_encoding";
static const char __pyx_k_set_precision[] = "set_precision";
static const char __pyx_k_special_dtype[] = "special_dtype";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_NATIVE_LDOUBLE[] = "NATIVE_LDOUBLE";
static const char __pyx_k_NotImplemented[] = "NotImplemented";
static const char __pyx_k_PAD_BACKGROUND[] = "PAD_BACKGROUND";
static const char __pyx_k_TypeBitfieldID[] = "TypeBitfieldID";
static const char __pyx_k_TypeCompoundID[] = "TypeCompoundID";
static const char __pyx_k_get_array_dims[] = "get_array_dims";
static const char __pyx_k_STD_REF_DSETREG[] = "STD_REF_DSETREG";
static const char __pyx_k_TypeCompositeID[] = "TypeCompositeID";
static const char __pyx_k_TypeReferenceID[] = "TypeReferenceID";
static const char __pyx_k_check_ref_dtype[] = "check_ref_dtype";
static const char __pyx_k_get_array_ndims[] = "get_array_ndims";
static const char __pyx_k_get_member_name[] = "get_member_name";
static const char __pyx_k_get_member_type[] = "get_member_type";
static const char __pyx_k_is_variable_str[] = "is_variable_str";
static const char __pyx_k_isalignedstruct[] = "isalignedstruct";
static const char __pyx_k_regionref_dtype[] = "regionref_dtype";
static const char __pyx_k_check_enum_dtype[] = "check_enum_dtype";
static const char __pyx_k_check_vlen_dtype[] = "check_vlen_dtype";
static const char __pyx_k_get_create_plist[] = "get_create_plist";
static const char __pyx_k_get_member_class[] = "get_member_class";
static const char __pyx_k_get_member_index[] = "get_member_index";
static const char __pyx_k_get_member_value[] = "get_member_value";
static const char __pyx_k_get_member_offset[] = "get_member_offset";
static const char __pyx_k_Illegal_int_kind_s[] = "Illegal int kind \"%s\"";
static const char __pyx_k_UnicodeDecodeError[] = "UnicodeDecodeError";
static const char __pyx_k_check_opaque_dtype[] = "check_opaque_dtype";
static const char __pyx_k_check_string_dtype[] = "check_string_dtype";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_H5PY_PYTHON_OPAQUE_TAG[] = "H5PY_PYTHON_OPAQUE_TAG";
static const char __pyx_k_Unknown_reference_type[] = "Unknown reference type";
static const char __pyx_k_Unknown_special_type_s[] = "Unknown special type \"%s\"";
static const char __pyx_k_get_float_dtype_to_hdf5[] = "_get_float_dtype_to_hdf5";
static const char __pyx_k_Unsupported_float_type_s[] = "Unsupported float type (%s)";
static const char __pyx_k_c_compound_locals_lambda[] = "_c_compound.<locals>.<lambda>";
static const char __pyx_k_Index_must_be_non_negative[] = "Index must be non-negative.";
static const char __pyx_k_Unsupported_integer_size_s[] = "Unsupported integer size (%s)";
static const char __pyx_k_Unrecognized_reference_code[] = "Unrecognized reference code";
static const char __pyx_k_has_no_native_HDF5_equivalent[] = " has no native HDF5 equivalent";
static const char __pyx_k_No_conversion_path_for_dtype_s[] = "No conversion path for dtype: %s";
static const char __pyx_k_Array_shape_for_dtype_must_be_a[] = "Array shape for dtype must be a sequence or integer";
static const char __pyx_k_HDF5_H5T_data_type_API_This_mod[] = "\n    HDF5 \"H5T\" data-type API\n\n    This module contains the datatype identifier class TypeID, and its\n    subclasses which represent things like integer/float/compound identifiers.\n    The majority of the H5T API is presented as methods on these identifiers.\n";
static const char __pyx_k_Unknown_string_encoding_value_d[] = "Unknown string encoding (value %d)";
static const char __pyx_k_dtype_for_opaque_data_must_have[] = "dtype for opaque data must have explicit size";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_Cannot_store_numpy_object_arrays[] = "Cannot store numpy object arrays as opaque data";
static const char __pyx_k_Cannot_store_numpy_structured_ar[] = "Cannot store numpy structured arrays as opaque data";
static const char __pyx_k_Cannot_store_numpy_sub_array_dty[] = "Cannot store numpy sub-array dtype as opaque data";
static const char __pyx_k_Class_must_be_COMPOUND_or_OPAQUE[] = "Class must be COMPOUND or OPAQUE.";
static const char __pyx_k_Enforced_alignment_not_compatibl[] = "Enforced alignment not compatible with HDF5 type";
static const char __pyx_k_Enums_must_be_created_from_a_2_t[] = "Enums must be created from a 2-tuple (basetype, values_dict)";
static const char __pyx_k_Exactly_one_keyword_may_be_provi[] = "Exactly one keyword may be provided";
static const char __pyx_k_Illegal_length_d_for_complex_dty[] = "Illegal length %d for complex dtype";
static const char __pyx_k_Insufficient_precision_in_availa[] = "Insufficient precision in available types to represent ";
static const char __pyx_k_Invalid_encoding_r_utf_8_or_asci[] = "Invalid encoding (%r); 'utf-8' or 'ascii' allowed";
static const char __pyx_k_Member_index_must_be_non_negativ[] = "Member index must be non-negative.";
static const char __pyx_k_No_NumPy_equivalent_for_s_exists[] = "No NumPy equivalent for %s exists";
static const char __pyx_k_Only_integer_types_can_be_used_a[] = "Only integer types can be used as enums";
static const char __pyx_k_Only_locked_or_committed_types_c[] = "Only locked or committed types can be hashed";
static const char __pyx_k_Ref_class_must_be_Reference_or_R[] = "Ref class must be Reference or RegionReference";
static const char __pyx_k_This_type_class_d_is_not_of_clas[] = "This type (class %d) is not of class ENUM";
static const char __pyx_k_length_must_be_integer_or_None_g[] = "length must be integer or None (got %r)";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static PyObject *__pyx_n_s_ARRAY;
static PyObject *__pyx_kp_u_Array_shape_for_dtype_must_be_a;
static PyObject *__pyx_n_s_AttributeError;
static PyObject *__pyx_n_s_BITFIELD;
static PyObject *__pyx_n_s_BKG_NO;
static PyObject *__pyx_n_s_BKG_TEMP;
static PyObject *__pyx_n_s_BKG_YES;
static PyObject *__pyx_n_s_COMPOUND;
static PyObject *__pyx_n_s_CSET_ASCII;
static PyObject *__pyx_n_s_CSET_UTF8;
static PyObject *__pyx_n_s_C_S1;
static PyObject *__pyx_kp_u_Cannot_store_numpy_object_arrays;
static PyObject *__pyx_kp_u_Cannot_store_numpy_structured_ar;
static PyObject *__pyx_kp_u_Cannot_store_numpy_sub_array_dty;
static PyObject *__pyx_kp_u_Class_must_be_COMPOUND_or_OPAQUE;
static PyObject *__pyx_n_s_DIR_ASCEND;
static PyObject *__pyx_n_s_DIR_DEFAULT;
static PyObject *__pyx_n_s_DIR_DESCEND;
static PyObject *__pyx_n_s_ENUM;
static PyObject *__pyx_kp_u_Enforced_alignment_not_compatibl;
static PyObject *__pyx_kp_u_Enums_must_be_created_from_a_2_t;
static PyObject *__pyx_kp_u_Exactly_one_keyword_may_be_provi;
static PyObject *__pyx_n_s_FLOAT;
static PyObject *__pyx_n_s_FORTRAN_S1;
static PyObject *__pyx_n_u_Float;
static PyObject *__pyx_n_s_H5PY_OBJ;
static PyObject *__pyx_n_s_H5PY_PYTHON_OPAQUE_TAG;
static PyObject *__pyx_n_s_IEEE_F128BE;
static PyObject *__pyx_n_s_IEEE_F128LE;
static PyObject *__pyx_n_s_IEEE_F16BE;
static PyObject *__pyx_n_s_IEEE_F16LE;
static PyObject *__pyx_n_s_IEEE_F32BE;
static PyObject *__pyx_n_s_IEEE_F32LE;
static PyObject *__pyx_n_s_IEEE_F64BE;
static PyObject *__pyx_n_s_IEEE_F64LE;
static PyObject *__pyx_n_s_INTEGER;
static PyObject *__pyx_kp_u_Illegal_int_kind_s;
static PyObject *__pyx_kp_u_Illegal_length_d_for_complex_dty;
static PyObject *__pyx_n_s_ImportError;
static PyObject *__pyx_kp_u_Index_must_be_non_negative;
static PyObject *__pyx_kp_u_Insufficient_precision_in_availa;
static PyObject *__pyx_kp_u_Invalid_encoding_r_utf_8_or_asci;
static PyObject *__pyx_n_s_KeyError;
static PyObject *__pyx_n_s_LDOUBLE_BE;
static PyObject *__pyx_n_s_LDOUBLE_LE;
static PyObject *__pyx_n_s_LookupError;
static PyObject *__pyx_kp_u_Member_index_must_be_non_negativ;
static PyObject *__pyx_n_s_NATIVE_B16;
static PyObject *__pyx_n_s_NATIVE_B32;
static PyObject *__pyx_n_s_NATIVE_B64;
static PyObject *__pyx_n_s_NATIVE_B8;
static PyObject *__pyx_n_s_NATIVE_DOUBLE;
static PyObject *__pyx_n_s_NATIVE_FLOAT;
static PyObject *__pyx_n_s_NATIVE_INT16;
static PyObject *__pyx_n_s_NATIVE_INT32;
static PyObject *__pyx_n_s_NATIVE_INT64;
static PyObject *__pyx_n_s_NATIVE_INT8;
static PyObject *__pyx_n_s_NATIVE_LDOUBLE;
static PyObject *__pyx_n_s_NATIVE_UINT16;
static PyObject *__pyx_n_s_NATIVE_UINT32;
static PyObject *__pyx_n_s_NATIVE_UINT64;
static PyObject *__pyx_n_s_NATIVE_UINT8;
static PyObject *__pyx_n_s_NORM_IMPLIED;
static PyObject *__pyx_n_s_NORM_MSBSET;
static PyObject *__pyx_n_s_NORM_NONE;
static PyObject *__pyx_n_s_NO_CLASS;
static PyObject *__pyx_kp_b_NUMPY;
static PyObject *__pyx_kp_u_No_NumPy_equivalent_for_s_exists;
static PyObject *__pyx_kp_u_No_conversion_path_for_dtype_s;
static PyObject *__pyx_n_s_NotImplemented;
static PyObject *__pyx_n_u_O;
static PyObject *__pyx_n_s_OPAQUE;
static PyObject *__pyx_n_s_ORDER_BE;
static PyObject *__pyx_n_s_ORDER_LE;
static PyObject *__pyx_n_s_ORDER_NATIVE;
static PyObject *__pyx_n_s_ORDER_NONE;
static PyObject *__pyx_n_s_ORDER_VAX;
static PyObject *__pyx_kp_u_Object_dtype;
static PyObject *__pyx_kp_u_Only_integer_types_can_be_used_a;
static PyObject *__pyx_kp_u_Only_locked_or_committed_types_c;
static PyObject *__pyx_n_s_PAD_BACKGROUND;
static PyObject *__pyx_n_s_PAD_ONE;
static PyObject *__pyx_n_s_PAD_ZERO;
static PyObject *__pyx_n_s_PYTHON_OBJECT;
static PyObject *__pyx_n_s_REFERENCE;
static PyObject *__pyx_kp_u_Ref_class_must_be_Reference_or_R;
static PyObject *__pyx_kp_u_S;
static PyObject *__pyx_n_s_SGN_2;
static PyObject *__pyx_n_s_SGN_NONE;
static PyObject *__pyx_n_s_STD_B16BE;
static PyObject *__pyx_n_s_STD_B16LE;
static PyObject *__pyx_n_s_STD_B32BE;
static PyObject *__pyx_n_s_STD_B32LE;
static PyObject *__pyx_n_s_STD_B64BE;
static PyObject *__pyx_n_s_STD_B64LE;
static PyObject *__pyx_n_s_STD_B8BE;
static PyObject *__pyx_n_s_STD_B8LE;
static PyObject *__pyx_n_s_STD_I16BE;
static PyObject *__pyx_n_s_STD_I16LE;
static PyObject *__pyx_n_s_STD_I32BE;
static PyObject *__pyx_n_s_STD_I32LE;
static PyObject *__pyx_n_s_STD_I64BE;
static PyObject *__pyx_n_s_STD_I64LE;
static PyObject *__pyx_n_s_STD_I8BE;
static PyObject *__pyx_n_s_STD_I8LE;
static PyObject *__pyx_n_s_STD_REF_DSETREG;
static PyObject *__pyx_n_s_STD_REF_OBJ;
static PyObject *__pyx_n_s_STD_U16BE;
static PyObject *__pyx_n_s_STD_U16LE;
static PyObject *__pyx_n_s_STD_U32BE;
static PyObject *__pyx_n_s_STD_U32LE;
static PyObject *__pyx_n_s_STD_U64BE;
static PyObject *__pyx_n_s_STD_U64LE;
static PyObject *__pyx_n_s_STD_U8BE;
static PyObject *__pyx_n_s_STD_U8LE;
static PyObject *__pyx_n_s_STRING;
static PyObject *__pyx_n_s_STR_NULLPAD;
static PyObject *__pyx_n_s_STR_NULLTERM;
static PyObject *__pyx_n_s_STR_SPACEPAD;
static PyObject *__pyx_n_u_S_2;
static PyObject *__pyx_n_s_TIME;
static PyObject *__pyx_kp_u_This_type_class_d_is_not_of_clas;
static PyObject *__pyx_n_s_TypeArrayID;
static PyObject *__pyx_n_s_TypeAtomicID;
static PyObject *__pyx_n_s_TypeBitfieldID;
static PyObject *__pyx_n_s_TypeCompositeID;
static PyObject *__pyx_n_s_TypeCompoundID;
static PyObject *__pyx_n_s_TypeEnumID;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_n_s_TypeFloatID;
static PyObject *__pyx_n_s_TypeID;
static PyObject *__pyx_n_s_TypeIntegerID;
static PyObject *__pyx_n_s_TypeOpaqueID;
static PyObject *__pyx_n_s_TypeReferenceID;
static PyObject *__pyx_n_s_TypeStringID;
static PyObject *__pyx_n_s_TypeTimeID;
static PyObject *__pyx_n_s_TypeVlenID;
static PyObject *__pyx_n_s_UNIX_D32BE;
static PyObject *__pyx_n_s_UNIX_D32LE;
static PyObject *__pyx_n_s_UNIX_D64BE;
static PyObject *__pyx_n_s_UNIX_D64LE;
static PyObject *__pyx_n_s_UnicodeDecodeError;
static PyObject *__pyx_kp_u_Unknown_reference_type;
static PyObject *__pyx_kp_u_Unknown_special_type_s;
static PyObject *__pyx_kp_u_Unknown_string_encoding_value_d;
static PyObject *__pyx_kp_u_Unrecognized_reference_code;
static PyObject *__pyx_kp_u_Unsupported_float_type_s;
static PyObject *__pyx_kp_u_Unsupported_integer_size_s;
static PyObject *__pyx_kp_u_V;
static PyObject *__pyx_n_s_VARIABLE;
static PyObject *__pyx_n_s_VLEN;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_kp_u__38;
static PyObject *__pyx_kp_u__39;
static PyObject *__pyx_kp_u__40;
static PyObject *__pyx_n_s_aligned;
static PyObject *__pyx_n_s_array_create;
static PyObject *__pyx_n_u_ascii;
static PyObject *__pyx_n_s_base;
static PyObject *__pyx_n_s_basetype;
static PyObject *__pyx_n_s_bkg;
static PyObject *__pyx_n_s_bkg_2;
static PyObject *__pyx_n_u_bool;
static PyObject *__pyx_n_s_buf;
static PyObject *__pyx_n_s_buf_2;
static PyObject *__pyx_n_s_byteorder;
static PyObject *__pyx_n_u_c;
static PyObject *__pyx_n_s_c_compound_locals_lambda;
static PyObject *__pyx_n_s_cfg;
static PyObject *__pyx_n_s_check_dtype;
static PyObject *__pyx_n_s_check_enum_dtype;
static PyObject *__pyx_n_s_check_opaque_dtype;
static PyObject *__pyx_n_s_check_ref_dtype;
static PyObject *__pyx_n_s_check_string_dtype;
static PyObject *__pyx_n_s_check_vlen_dtype;
static PyObject *__pyx_n_s_class;
static PyObject *__pyx_n_s_classtype;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_codecs;
static PyObject *__pyx_n_s_collections;
static PyObject *__pyx_n_s_commit;
static PyObject *__pyx_n_s_committed;
static PyObject *__pyx_n_s_convert;
static PyObject *__pyx_n_s_copy;
static PyObject *__pyx_n_s_copy_2;
static PyObject *__pyx_n_s_create;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_n_s_decode;
static PyObject *__pyx_n_s_descr;
static PyObject *__pyx_n_s_detect_class;
static PyObject *__pyx_n_s_dims;
static PyObject *__pyx_n_s_dims_tpl;
static PyObject *__pyx_n_s_dst;
static PyObject *__pyx_n_s_dt;
static PyObject *__pyx_n_s_dtype;
static PyObject *__pyx_kp_u_dtype_for_opaque_data_must_have;
static PyObject *__pyx_n_s_dtype_in;
static PyObject *__pyx_n_s_dxpl;
static PyObject *__pyx_n_s_ebias;
static PyObject *__pyx_n_s_enc;
static PyObject *__pyx_n_s_encode;
static PyObject *__pyx_n_s_encoding;
static PyObject *__pyx_n_u_encoding;
static PyObject *__pyx_n_s_enter;
static PyObject *__pyx_n_u_enum;
static PyObject *__pyx_n_s_enum_create;
static PyObject *__pyx_n_s_enum_dtype;
static PyObject *__pyx_n_s_enum_insert;
static PyObject *__pyx_n_s_enum_nameof;
static PyObject *__pyx_n_s_enum_vals;
static PyObject *__pyx_n_s_enum_valueof;
static PyObject *__pyx_n_s_epos;
static PyObject *__pyx_n_s_equal;
static PyObject *__pyx_n_s_esize;
static PyObject *__pyx_n_s_exit;
static PyObject *__pyx_n_u_f;
static PyObject *__pyx_n_s_f_name;
static PyObject *__pyx_n_s_field;
static PyObject *__pyx_n_s_find;
static PyObject *__pyx_n_s_finfo;
static PyObject *__pyx_n_s_float_be;
static PyObject *__pyx_n_s_float_le;
static PyObject *__pyx_n_s_float_nt;
static PyObject *__pyx_n_u_formats;
static PyObject *__pyx_n_s_ftype;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_get_array_dims;
static PyObject *__pyx_n_s_get_array_ndims;
static PyObject *__pyx_n_s_get_class;
static PyObject *__pyx_n_s_get_config;
static PyObject *__pyx_n_s_get_create_plist;
static PyObject *__pyx_n_s_get_cset;
static PyObject *__pyx_n_s_get_ebias;
static PyObject *__pyx_n_s_get_fields;
static PyObject *__pyx_n_s_get_float_dtype_to_hdf5;
static PyObject *__pyx_n_s_get_inpad;
static PyObject *__pyx_n_s_get_member_class;
static PyObject *__pyx_n_s_get_member_index;
static PyObject *__pyx_n_s_get_member_name;
static PyObject *__pyx_n_s_get_member_offset;
static PyObject *__pyx_n_s_get_member_type;
static PyObject *__pyx_n_s_get_member_value;
static PyObject *__pyx_n_s_get_nmembers;
static PyObject *__pyx_n_s_get_norm;
static PyObject *__pyx_n_s_get_offset;
static PyObject *__pyx_n_s_get_order;
static PyObject *__pyx_n_s_get_pad;
static PyObject *__pyx_n_s_get_precision;
static PyObject *__pyx_n_s_get_sign;
static PyObject *__pyx_n_s_get_size;
static PyObject *__pyx_n_s_get_strpad;
static PyObject *__pyx_n_s_get_super;
static PyObject *__pyx_n_s_get_tag;
static PyObject *__pyx_n_s_group;
static PyObject *__pyx_n_s_h5;
static PyObject *__pyx_n_s_h5_be_list;
static PyObject *__pyx_n_s_h5_le_list;
static PyObject *__pyx_n_u_h5py_encoding;
static PyObject *__pyx_n_s_h5py_h5t;
static PyObject *__pyx_kp_s_h5py_h5t_pyx;
static PyObject *__pyx_n_u_h5py_opaque;
static PyObject *__pyx_n_s_h5type;
static PyObject *__pyx_kp_u_has_no_native_HDF5_equivalent;
static PyObject *__pyx_n_s_hash;
static PyObject *__pyx_n_u_i;
static PyObject *__pyx_n_s_i_name;
static PyObject *__pyx_n_s_iexp;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_insert;
static PyObject *__pyx_n_s_integer;
static PyObject *__pyx_n_s_is_variable_str;
static PyObject *__pyx_n_u_isalignedstruct;
static PyObject *__pyx_n_s_issubdtype;
static PyObject *__pyx_n_s_itemsize;
static PyObject *__pyx_n_u_itemsize;
static PyObject *__pyx_n_s_iteritems;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_kind;
static PyObject *__pyx_n_s_kwds;
static PyObject *__pyx_n_s_lcpl;
static PyObject *__pyx_n_s_length;
static PyObject *__pyx_n_u_length;
static PyObject *__pyx_kp_u_length_must_be_integer_or_None_g;
static PyObject *__pyx_n_u_little;
static PyObject *__pyx_n_s_lock;
static PyObject *__pyx_n_s_logical;
static PyObject *__pyx_n_s_longdouble;
static PyObject *__pyx_n_s_lookup;
static PyObject *__pyx_n_s_lsb;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_maxexp;
static PyObject *__pyx_n_s_metadata;
static PyObject *__pyx_n_s_minexp;
static PyObject *__pyx_n_s_mpos;
static PyObject *__pyx_n_s_msb;
static PyObject *__pyx_n_s_msize;
static PyObject *__pyx_n_s_n;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_namedtuple;
static PyObject *__pyx_n_s_names;
static PyObject *__pyx_n_u_names;
static PyObject *__pyx_n_s_newbyteorder;
static PyObject *__pyx_n_s_nexp;
static PyObject *__pyx_n_s_nmant;
static PyObject *__pyx_n_s_np;
static PyObject *__pyx_n_s_np_dtype;
static PyObject *__pyx_n_s_numpy;
static PyObject *__pyx_kp_u_numpy_core_multiarray_failed_to;
static PyObject *__pyx_kp_u_numpy_core_umath_failed_to_impor;
static PyObject *__pyx_n_s_object;
static PyObject *__pyx_n_s_objects;
static PyObject *__pyx_n_s_offset;
static PyObject *__pyx_n_u_offsets;
static PyObject *__pyx_n_s_opaque_dtype;
static PyObject *__pyx_n_s_open;
static PyObject *__pyx_n_s_pack;
static PyObject *__pyx_n_s_phil;
static PyObject *__pyx_n_s_popitem;
static PyObject *__pyx_n_s_pyx_capi;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_r_name;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_rank;
static PyObject *__pyx_n_u_ref;
static PyObject *__pyx_n_s_ref_dtype;
static PyObject *__pyx_n_s_regionref_dtype;
static PyObject *__pyx_n_s_result;
static PyObject *__pyx_n_s_set_cset;
static PyObject *__pyx_n_s_set_ebias;
static PyObject *__pyx_n_s_set_fields;
static PyObject *__pyx_n_s_set_inpad;
static PyObject *__pyx_n_s_set_norm;
static PyObject *__pyx_n_s_set_offset;
static PyObject *__pyx_n_s_set_order;
static PyObject *__pyx_n_s_set_pad;
static PyObject *__pyx_n_s_set_precision;
static PyObject *__pyx_n_s_set_sign;
static PyObject *__pyx_n_s_set_size;
static PyObject *__pyx_n_s_set_strpad;
static PyObject *__pyx_n_s_set_tag;
static PyObject *__pyx_n_s_size;
static PyObject *__pyx_n_s_sorted;
static PyObject *__pyx_n_s_special_dtype;
static PyObject *__pyx_n_s_spos;
static PyObject *__pyx_n_s_src;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_n_s_string_dtype;
static PyObject *__pyx_n_s_string_info;
static PyObject *__pyx_n_u_string_info;
static PyObject *__pyx_n_s_subdtype;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_t_name;
static PyObject *__pyx_n_s_tapl;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_type;
static PyObject *__pyx_n_s_typecodes;
static PyObject *__pyx_n_u_u;
static PyObject *__pyx_n_s_uint8;
static PyObject *__pyx_n_u_utf8;
static PyObject *__pyx_kp_u_utf_8;
static PyObject *__pyx_n_s_val;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_values_dict;
static PyObject *__pyx_n_s_vlen;
static PyObject *__pyx_n_u_vlen;
static PyObject *__pyx_n_s_vlen_create;
static PyObject *__pyx_n_s_vlen_dtype;
static PyObject *__pyx_n_s_vlen_kind;
static PyObject *__pyx_n_s_with_phil;
static PyObject *__pyx_pf_4h5py_3h5t_typewrap(CYTHON_UNUSED PyObject *__pyx_self, hid_t __pyx_v_id_); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_2create(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_classtype, size_t __pyx_v_size); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_4open(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_group, char *__pyx_v_name, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_tapl); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6array_create(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_base, PyObject *__pyx_v_dims_tpl); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_8enum_create(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_base); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_10vlen_create(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_base); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12decode(CYTHON_UNUSED PyObject *__pyx_self, char *__pyx_v_buf); /* proto */
static Py_hash_t __pyx_pf_4h5py_3h5t_6TypeID___hash__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_2__richcmp__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_v_how); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_4__copy__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_5dtype___get__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_6commit(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_group, char *__pyx_v_name, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_lcpl); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_8committed(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_10copy(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_12equal(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_typeid); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_14lock(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_16get_class(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_18set_size(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, size_t __pyx_v_size); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_20get_size(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_22get_super(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_24detect_class(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, int __pyx_v_classtype); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_26encode(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_28get_create_plist(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_30__reduce__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_32__setstate__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, char *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeArrayID_get_array_ndims(struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeArrayID_2get_array_dims(struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeOpaqueID_set_tag(struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_v_self, char *__pyx_v_tag); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeOpaqueID_2get_tag(struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_is_variable_str(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_2get_cset(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_4set_cset(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self, int __pyx_v_cset); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_6get_strpad(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_8set_strpad(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self, int __pyx_v_pad); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_14TypeBitfieldID_get_order(struct __pyx_obj_4h5py_3h5t_TypeBitfieldID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_get_order(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_2set_order(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self, int __pyx_v_order); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_4get_precision(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_6set_precision(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self, size_t __pyx_v_precision); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_8get_offset(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_10set_offset(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self, size_t __pyx_v_offset); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_12get_pad(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_14set_pad(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self, int __pyx_v_lsb, int __pyx_v_msb); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_13TypeIntegerID_get_sign(struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_13TypeIntegerID_2set_sign(struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_v_self, int __pyx_v_sign); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_get_fields(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_2set_fields(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self, size_t __pyx_v_spos, size_t __pyx_v_epos, size_t __pyx_v_esize, size_t __pyx_v_mpos, size_t __pyx_v_msize); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_4get_ebias(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_6set_ebias(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self, size_t __pyx_v_ebias); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_8get_norm(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_10set_norm(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self, int __pyx_v_norm); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_12get_inpad(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_14set_inpad(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self, int __pyx_v_pad_code); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_15TypeCompositeID_get_nmembers(struct __pyx_obj_4h5py_3h5t_TypeCompositeID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_15TypeCompositeID_2get_member_name(struct __pyx_obj_4h5py_3h5t_TypeCompositeID *__pyx_v_self, int __pyx_v_member); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_15TypeCompositeID_4get_member_index(struct __pyx_obj_4h5py_3h5t_TypeCompositeID *__pyx_v_self, char *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_get_member_class(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self, int __pyx_v_member); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_2get_member_offset(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self, int __pyx_v_member); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_4get_member_type(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self, int __pyx_v_member); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_6insert(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self, char *__pyx_v_name, size_t __pyx_v_offset, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_8pack(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_10TypeEnumID_enum_insert(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, char *__pyx_v_name, PY_LONG_LONG __pyx_v_value); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_10TypeEnumID_2enum_nameof(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, PY_LONG_LONG __pyx_v_value); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_10TypeEnumID_4enum_valueof(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, char *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_10TypeEnumID_6get_member_value(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, int __pyx_v_idx); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_14_get_float_dtype_to_hdf5(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda(PyObject *__pyx_self, PyObject *__pyx_v_n); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_16py_create(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dtype_in, int __pyx_v_logical, int __pyx_v_aligned); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_18vlen_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_basetype); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_20string_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_encoding, PyObject *__pyx_v_length); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_22enum_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_values_dict, PyObject *__pyx_v_basetype); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_24opaque_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_np_dtype); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_26special_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_kwds); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_28check_vlen_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_30check_string_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_32check_enum_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_34check_opaque_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_36check_ref_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_38check_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_kwds); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_40convert(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_src, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_dst, size_t __pyx_v_n, PyArrayObject *__pyx_v_buf, PyArrayObject *__pyx_v_bkg, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_dxpl); /* proto */
static PyObject *__pyx_pf_4h5py_3h5t_42find(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_src, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_dst); /* proto */
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeArrayID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeOpaqueID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeStringID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeVlenID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeTimeID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeBitfieldID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeReferenceID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeAtomicID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeIntegerID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeFloatID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeCompositeID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeEnumID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t_TypeCompoundID(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_popitem = {0, &__pyx_n_s_popitem, 0, 0, 0};
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_10;
static PyObject *__pyx_int_15;
static PyObject *__pyx_int_16;
static PyObject *__pyx_int_52;
static PyObject *__pyx_int_63;
static PyObject *__pyx_int_112;
static PyObject *__pyx_int_116;
static PyObject *__pyx_int_127;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_1024;
static PyObject *__pyx_int_16383;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_int_neg_1022;
static PyObject *__pyx_k__13;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_slice__7;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_codeobj__42;
static PyObject *__pyx_codeobj__44;
static PyObject *__pyx_codeobj__46;
static PyObject *__pyx_codeobj__48;
static PyObject *__pyx_codeobj__50;
static PyObject *__pyx_codeobj__52;
static PyObject *__pyx_codeobj__54;
static PyObject *__pyx_codeobj__56;
static PyObject *__pyx_codeobj__58;
static PyObject *__pyx_codeobj__60;
static PyObject *__pyx_codeobj__62;
static PyObject *__pyx_codeobj__64;
static PyObject *__pyx_codeobj__66;
static PyObject *__pyx_codeobj__68;
static PyObject *__pyx_codeobj__70;
static PyObject *__pyx_codeobj__72;
static PyObject *__pyx_codeobj__74;
static PyObject *__pyx_codeobj__76;
static PyObject *__pyx_codeobj__78;
static PyObject *__pyx_codeobj__80;
/* Late includes */

/* "h5py/h5t.pyx":46
 * # === Custom C API ============================================================
 * 
 * cpdef TypeID typewrap(hid_t id_):             # <<<<<<<<<<<<<<
 * 
 *     cdef H5T_class_t cls
 */

static PyObject *__pyx_pw_4h5py_3h5t_1typewrap(PyObject *__pyx_self, PyObject *__pyx_arg_id_); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_f_4h5py_3h5t_typewrap(hid_t __pyx_v_id_, CYTHON_UNUSED int __pyx_skip_dispatch) {
  enum H5T_class_t __pyx_v_cls;
  PyTypeObject *__pyx_v_pcls = NULL;
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  enum H5T_class_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("typewrap", 0);

  /* "h5py/h5t.pyx":49
 * 
 *     cdef H5T_class_t cls
 *     cls = H5Tget_class(id_)             # <<<<<<<<<<<<<<
 * 
 *     if cls == H5T_INTEGER:
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_class(__pyx_v_id_); if (unlikely(__pyx_t_1 == ((enum H5T_class_t)((enum H5T_class_t)-1L)))) __PYX_ERR(0, 49, __pyx_L1_error)
  __pyx_v_cls = __pyx_t_1;

  /* "h5py/h5t.pyx":51
 *     cls = H5Tget_class(id_)
 * 
 *     if cls == H5T_INTEGER:             # <<<<<<<<<<<<<<
 *         pcls = TypeIntegerID
 *     elif cls == H5T_FLOAT:
 */
  switch (__pyx_v_cls) {
    case H5T_INTEGER:

    /* "h5py/h5t.pyx":52
 * 
 *     if cls == H5T_INTEGER:
 *         pcls = TypeIntegerID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_FLOAT:
 *         pcls = TypeFloatID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeIntegerID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeIntegerID;

    /* "h5py/h5t.pyx":51
 *     cls = H5Tget_class(id_)
 * 
 *     if cls == H5T_INTEGER:             # <<<<<<<<<<<<<<
 *         pcls = TypeIntegerID
 *     elif cls == H5T_FLOAT:
 */
    break;
    case H5T_FLOAT:

    /* "h5py/h5t.pyx":54
 *         pcls = TypeIntegerID
 *     elif cls == H5T_FLOAT:
 *         pcls = TypeFloatID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_TIME:
 *         pcls = TypeTimeID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeFloatID;

    /* "h5py/h5t.pyx":53
 *     if cls == H5T_INTEGER:
 *         pcls = TypeIntegerID
 *     elif cls == H5T_FLOAT:             # <<<<<<<<<<<<<<
 *         pcls = TypeFloatID
 *     elif cls == H5T_TIME:
 */
    break;
    case H5T_TIME:

    /* "h5py/h5t.pyx":56
 *         pcls = TypeFloatID
 *     elif cls == H5T_TIME:
 *         pcls = TypeTimeID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_STRING:
 *         pcls = TypeStringID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeTimeID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeTimeID;

    /* "h5py/h5t.pyx":55
 *     elif cls == H5T_FLOAT:
 *         pcls = TypeFloatID
 *     elif cls == H5T_TIME:             # <<<<<<<<<<<<<<
 *         pcls = TypeTimeID
 *     elif cls == H5T_STRING:
 */
    break;
    case H5T_STRING:

    /* "h5py/h5t.pyx":58
 *         pcls = TypeTimeID
 *     elif cls == H5T_STRING:
 *         pcls = TypeStringID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_BITFIELD:
 *         pcls = TypeBitfieldID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeStringID;

    /* "h5py/h5t.pyx":57
 *     elif cls == H5T_TIME:
 *         pcls = TypeTimeID
 *     elif cls == H5T_STRING:             # <<<<<<<<<<<<<<
 *         pcls = TypeStringID
 *     elif cls == H5T_BITFIELD:
 */
    break;
    case H5T_BITFIELD:

    /* "h5py/h5t.pyx":60
 *         pcls = TypeStringID
 *     elif cls == H5T_BITFIELD:
 *         pcls = TypeBitfieldID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_OPAQUE:
 *         pcls = TypeOpaqueID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeBitfieldID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeBitfieldID;

    /* "h5py/h5t.pyx":59
 *     elif cls == H5T_STRING:
 *         pcls = TypeStringID
 *     elif cls == H5T_BITFIELD:             # <<<<<<<<<<<<<<
 *         pcls = TypeBitfieldID
 *     elif cls == H5T_OPAQUE:
 */
    break;
    case H5T_OPAQUE:

    /* "h5py/h5t.pyx":62
 *         pcls = TypeBitfieldID
 *     elif cls == H5T_OPAQUE:
 *         pcls = TypeOpaqueID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_COMPOUND:
 *         pcls = TypeCompoundID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeOpaqueID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeOpaqueID;

    /* "h5py/h5t.pyx":61
 *     elif cls == H5T_BITFIELD:
 *         pcls = TypeBitfieldID
 *     elif cls == H5T_OPAQUE:             # <<<<<<<<<<<<<<
 *         pcls = TypeOpaqueID
 *     elif cls == H5T_COMPOUND:
 */
    break;
    case H5T_COMPOUND:

    /* "h5py/h5t.pyx":64
 *         pcls = TypeOpaqueID
 *     elif cls == H5T_COMPOUND:
 *         pcls = TypeCompoundID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_REFERENCE:
 *         pcls = TypeReferenceID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeCompoundID;

    /* "h5py/h5t.pyx":63
 *     elif cls == H5T_OPAQUE:
 *         pcls = TypeOpaqueID
 *     elif cls == H5T_COMPOUND:             # <<<<<<<<<<<<<<
 *         pcls = TypeCompoundID
 *     elif cls == H5T_REFERENCE:
 */
    break;
    case H5T_REFERENCE:

    /* "h5py/h5t.pyx":66
 *         pcls = TypeCompoundID
 *     elif cls == H5T_REFERENCE:
 *         pcls = TypeReferenceID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_ENUM:
 *         pcls = TypeEnumID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeReferenceID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeReferenceID;

    /* "h5py/h5t.pyx":65
 *     elif cls == H5T_COMPOUND:
 *         pcls = TypeCompoundID
 *     elif cls == H5T_REFERENCE:             # <<<<<<<<<<<<<<
 *         pcls = TypeReferenceID
 *     elif cls == H5T_ENUM:
 */
    break;
    case H5T_ENUM:

    /* "h5py/h5t.pyx":68
 *         pcls = TypeReferenceID
 *     elif cls == H5T_ENUM:
 *         pcls = TypeEnumID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_VLEN:
 *         pcls = TypeVlenID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeEnumID;

    /* "h5py/h5t.pyx":67
 *     elif cls == H5T_REFERENCE:
 *         pcls = TypeReferenceID
 *     elif cls == H5T_ENUM:             # <<<<<<<<<<<<<<
 *         pcls = TypeEnumID
 *     elif cls == H5T_VLEN:
 */
    break;
    case H5T_VLEN:

    /* "h5py/h5t.pyx":70
 *         pcls = TypeEnumID
 *     elif cls == H5T_VLEN:
 *         pcls = TypeVlenID             # <<<<<<<<<<<<<<
 *     elif cls == H5T_ARRAY:
 *         pcls = TypeArrayID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeVlenID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeVlenID;

    /* "h5py/h5t.pyx":69
 *     elif cls == H5T_ENUM:
 *         pcls = TypeEnumID
 *     elif cls == H5T_VLEN:             # <<<<<<<<<<<<<<
 *         pcls = TypeVlenID
 *     elif cls == H5T_ARRAY:
 */
    break;
    case H5T_ARRAY:

    /* "h5py/h5t.pyx":72
 *         pcls = TypeVlenID
 *     elif cls == H5T_ARRAY:
 *         pcls = TypeArrayID             # <<<<<<<<<<<<<<
 *     else:
 *         pcls = TypeID
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeArrayID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeArrayID;

    /* "h5py/h5t.pyx":71
 *     elif cls == H5T_VLEN:
 *         pcls = TypeVlenID
 *     elif cls == H5T_ARRAY:             # <<<<<<<<<<<<<<
 *         pcls = TypeArrayID
 *     else:
 */
    break;
    default:

    /* "h5py/h5t.pyx":74
 *         pcls = TypeArrayID
 *     else:
 *         pcls = TypeID             # <<<<<<<<<<<<<<
 * 
 *     return pcls(id_)
 */
    __Pyx_INCREF(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID));
    __pyx_v_pcls = __pyx_ptype_4h5py_3h5t_TypeID;
    break;
  }

  /* "h5py/h5t.pyx":76
 *         pcls = TypeID
 * 
 *     return pcls(id_)             # <<<<<<<<<<<<<<
 * 
 * cdef object lockid(hid_t id_in):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_2 = __Pyx_PyInt_From_hid_t(__pyx_v_id_); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_v_pcls), __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 76, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":46
 * # === Custom C API ============================================================
 * 
 * cpdef TypeID typewrap(hid_t id_):             # <<<<<<<<<<<<<<
 * 
 *     cdef H5T_class_t cls
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t.typewrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pcls);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_1typewrap(PyObject *__pyx_self, PyObject *__pyx_arg_id_); /*proto*/
static PyObject *__pyx_pw_4h5py_3h5t_1typewrap(PyObject *__pyx_self, PyObject *__pyx_arg_id_) {
  hid_t __pyx_v_id_;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("typewrap (wrapper)", 0);
  assert(__pyx_arg_id_); {
    __pyx_v_id_ = __Pyx_PyInt_As_hid_t(__pyx_arg_id_); if (unlikely((__pyx_v_id_ == ((hid_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 46, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.typewrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_typewrap(__pyx_self, ((hid_t)__pyx_v_id_));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_typewrap(CYTHON_UNUSED PyObject *__pyx_self, hid_t __pyx_v_id_) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("typewrap", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_v_id_, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5t.typewrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":78
 *     return pcls(id_)
 * 
 * cdef object lockid(hid_t id_in):             # <<<<<<<<<<<<<<
 *     cdef TypeID tid
 *     tid = typewrap(id_in)
 */

static PyObject *__pyx_f_4h5py_3h5t_lockid(hid_t __pyx_v_id_in) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_tid = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lockid", 0);

  /* "h5py/h5t.pyx":80
 * cdef object lockid(hid_t id_in):
 *     cdef TypeID tid
 *     tid = typewrap(id_in)             # <<<<<<<<<<<<<<
 *     tid.locked = 1
 *     return tid
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_v_id_in, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_tid = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":81
 *     cdef TypeID tid
 *     tid = typewrap(id_in)
 *     tid.locked = 1             # <<<<<<<<<<<<<<
 *     return tid
 * 
 */
  __pyx_v_tid->__pyx_base.locked = 1;

  /* "h5py/h5t.pyx":82
 *     tid = typewrap(id_in)
 *     tid.locked = 1
 *     return tid             # <<<<<<<<<<<<<<
 * 
 * # === Public constants and data structures ====================================
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_tid));
  __pyx_r = ((PyObject *)__pyx_v_tid);
  goto __pyx_L0;

  /* "h5py/h5t.pyx":78
 *     return pcls(id_)
 * 
 * cdef object lockid(hid_t id_in):             # <<<<<<<<<<<<<<
 *     cdef TypeID tid
 *     tid = typewrap(id_in)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5t.lockid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tid);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":263
 * 
 * # Available floating point types
 * cdef tuple _get_available_ftypes():             # <<<<<<<<<<<<<<
 *     cdef:
 *         str floating_typecodes = np.typecodes["Float"]
 */

static PyObject *__pyx_f_4h5py_3h5t__get_available_ftypes(void) {
  PyObject *__pyx_v_floating_typecodes = 0;
  PyObject *__pyx_v_ftc = 0;
  PyArray_Descr *__pyx_v_fdtype = 0;
  PyObject *__pyx_v_available_ftypes = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  void *__pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_available_ftypes", 0);

  /* "h5py/h5t.pyx":265
 * cdef tuple _get_available_ftypes():
 *     cdef:
 *         str floating_typecodes = np.typecodes["Float"]             # <<<<<<<<<<<<<<
 *         str ftc
 *         cnp.dtype fdtype
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_typecodes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_u_Float); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 265, __pyx_L1_error)
  __pyx_v_floating_typecodes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":268
 *         str ftc
 *         cnp.dtype fdtype
 *         list available_ftypes = []             # <<<<<<<<<<<<<<
 * 
 *     for ftc in floating_typecodes:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_available_ftypes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":270
 *         list available_ftypes = []
 * 
 *     for ftc in floating_typecodes:             # <<<<<<<<<<<<<<
 *         fdtype = np.dtype(ftc)
 *         available_ftypes.append(
 */
  if (unlikely(__pyx_v_floating_typecodes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' is not iterable");
    __PYX_ERR(0, 270, __pyx_L1_error)
  }
  __Pyx_INCREF(__pyx_v_floating_typecodes);
  __pyx_t_3 = __pyx_v_floating_typecodes;
  __pyx_t_8 = __Pyx_init_unicode_iteration(__pyx_t_3, (&__pyx_t_5), (&__pyx_t_6), (&__pyx_t_7)); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 270, __pyx_L1_error)
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_5; __pyx_t_9++) {
    __pyx_t_4 = __pyx_t_9;
    __pyx_t_1 = PyUnicode_FromOrdinal(__Pyx_PyUnicode_READ(__pyx_t_7, __pyx_t_6, __pyx_t_4)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 270, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 270, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_ftc, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":271
 * 
 *     for ftc in floating_typecodes:
 *         fdtype = np.dtype(ftc)             # <<<<<<<<<<<<<<
 *         available_ftypes.append(
 *             (<object>(fdtype.typeobj), np.finfo(fdtype), fdtype.itemsize)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dtype); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_2, __pyx_v_ftc) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_ftc);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 271, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_fdtype, ((PyArray_Descr *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":273
 *         fdtype = np.dtype(ftc)
 *         available_ftypes.append(
 *             (<object>(fdtype.typeobj), np.finfo(fdtype), fdtype.itemsize)             # <<<<<<<<<<<<<<
 *             )
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_np); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_finfo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_10, ((PyObject *)__pyx_v_fdtype)) : __Pyx_PyObject_CallOneArg(__pyx_t_2, ((PyObject *)__pyx_v_fdtype));
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_fdtype->elsize); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_INCREF(((PyObject *)__pyx_v_fdtype->typeobj));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_fdtype->typeobj));
    PyTuple_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_v_fdtype->typeobj));
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_2);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;

    /* "h5py/h5t.pyx":272
 *     for ftc in floating_typecodes:
 *         fdtype = np.dtype(ftc)
 *         available_ftypes.append(             # <<<<<<<<<<<<<<
 *             (<object>(fdtype.typeobj), np.finfo(fdtype), fdtype.itemsize)
 *             )
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_available_ftypes, __pyx_t_10); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 272, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "h5py/h5t.pyx":276
 *             )
 * 
 *     return tuple(available_ftypes)             # <<<<<<<<<<<<<<
 * 
 * cdef tuple _available_ftypes = _get_available_ftypes()
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_10 = PyList_AsTuple(__pyx_v_available_ftypes); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_r = ((PyObject*)__pyx_t_10);
  __pyx_t_10 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":263
 * 
 * # Available floating point types
 * cdef tuple _get_available_ftypes():             # <<<<<<<<<<<<<<
 *     cdef:
 *         str floating_typecodes = np.typecodes["Float"]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("h5py.h5t._get_available_ftypes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_floating_typecodes);
  __Pyx_XDECREF(__pyx_v_ftc);
  __Pyx_XDECREF((PyObject *)__pyx_v_fdtype);
  __Pyx_XDECREF(__pyx_v_available_ftypes);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":281
 * 
 * 
 * cdef (int, int, int) _correct_float_info(ftype_, finfo):             # <<<<<<<<<<<<<<
 *     nmant = finfo.nmant
 *     maxexp = finfo.maxexp
 */

static __pyx_ctuple_int__and_int__and_int __pyx_f_4h5py_3h5t__correct_float_info(PyObject *__pyx_v_ftype_, PyObject *__pyx_v_finfo) {
  PyObject *__pyx_v_nmant = NULL;
  PyObject *__pyx_v_maxexp = NULL;
  PyObject *__pyx_v_minexp = NULL;
  __pyx_ctuple_int__and_int__and_int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  __pyx_ctuple_int__and_int__and_int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_correct_float_info", 0);

  /* "h5py/h5t.pyx":282
 * 
 * cdef (int, int, int) _correct_float_info(ftype_, finfo):
 *     nmant = finfo.nmant             # <<<<<<<<<<<<<<
 *     maxexp = finfo.maxexp
 *     minexp = finfo.minexp
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_finfo, __pyx_n_s_nmant); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_nmant = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":283
 * cdef (int, int, int) _correct_float_info(ftype_, finfo):
 *     nmant = finfo.nmant
 *     maxexp = finfo.maxexp             # <<<<<<<<<<<<<<
 *     minexp = finfo.minexp
 *     # workaround for numpy's buggy finfo on float128 on ppc64 archs
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_finfo, __pyx_n_s_maxexp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_maxexp = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":284
 *     nmant = finfo.nmant
 *     maxexp = finfo.maxexp
 *     minexp = finfo.minexp             # <<<<<<<<<<<<<<
 *     # workaround for numpy's buggy finfo on float128 on ppc64 archs
 *     if ftype_ == np.longdouble and MACHINE == 'ppc64':
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_finfo, __pyx_n_s_minexp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_minexp = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":286
 *     minexp = finfo.minexp
 *     # workaround for numpy's buggy finfo on float128 on ppc64 archs
 *     if ftype_ == np.longdouble and MACHINE == 'ppc64':             # <<<<<<<<<<<<<<
 *         # values reported by hdf5
 *         nmant = 116
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_longdouble); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_ftype_, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = 0;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":288
 *     if ftype_ == np.longdouble and MACHINE == 'ppc64':
 *         # values reported by hdf5
 *         nmant = 116             # <<<<<<<<<<<<<<
 *         maxexp = 1024
 *         minexp = -1022
 */
    __Pyx_INCREF(__pyx_int_116);
    __Pyx_DECREF_SET(__pyx_v_nmant, __pyx_int_116);

    /* "h5py/h5t.pyx":289
 *         # values reported by hdf5
 *         nmant = 116
 *         maxexp = 1024             # <<<<<<<<<<<<<<
 *         minexp = -1022
 *     elif ftype_ == np.longdouble and MACHINE == 'ppc64le':
 */
    __Pyx_INCREF(__pyx_int_1024);
    __Pyx_DECREF_SET(__pyx_v_maxexp, __pyx_int_1024);

    /* "h5py/h5t.pyx":290
 *         nmant = 116
 *         maxexp = 1024
 *         minexp = -1022             # <<<<<<<<<<<<<<
 *     elif ftype_ == np.longdouble and MACHINE == 'ppc64le':
 *         # values reported by hdf5
 */
    __Pyx_INCREF(__pyx_int_neg_1022);
    __Pyx_DECREF_SET(__pyx_v_minexp, __pyx_int_neg_1022);

    /* "h5py/h5t.pyx":286
 *     minexp = finfo.minexp
 *     # workaround for numpy's buggy finfo on float128 on ppc64 archs
 *     if ftype_ == np.longdouble and MACHINE == 'ppc64':             # <<<<<<<<<<<<<<
 *         # values reported by hdf5
 *         nmant = 116
 */
    goto __pyx_L3;
  }

  /* "h5py/h5t.pyx":291
 *         maxexp = 1024
 *         minexp = -1022
 *     elif ftype_ == np.longdouble and MACHINE == 'ppc64le':             # <<<<<<<<<<<<<<
 *         # values reported by hdf5
 *         nmant = 52
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_longdouble); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_ftype_, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = 0;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":293
 *     elif ftype_ == np.longdouble and MACHINE == 'ppc64le':
 *         # values reported by hdf5
 *         nmant = 52             # <<<<<<<<<<<<<<
 *         maxexp = 1024
 *         minexp = -1022
 */
    __Pyx_INCREF(__pyx_int_52);
    __Pyx_DECREF_SET(__pyx_v_nmant, __pyx_int_52);

    /* "h5py/h5t.pyx":294
 *         # values reported by hdf5
 *         nmant = 52
 *         maxexp = 1024             # <<<<<<<<<<<<<<
 *         minexp = -1022
 *     elif nmant == 63 and finfo.nexp == 15:
 */
    __Pyx_INCREF(__pyx_int_1024);
    __Pyx_DECREF_SET(__pyx_v_maxexp, __pyx_int_1024);

    /* "h5py/h5t.pyx":295
 *         nmant = 52
 *         maxexp = 1024
 *         minexp = -1022             # <<<<<<<<<<<<<<
 *     elif nmant == 63 and finfo.nexp == 15:
 *         # This is an 80-bit float, correct mantissa size
 */
    __Pyx_INCREF(__pyx_int_neg_1022);
    __Pyx_DECREF_SET(__pyx_v_minexp, __pyx_int_neg_1022);

    /* "h5py/h5t.pyx":291
 *         maxexp = 1024
 *         minexp = -1022
 *     elif ftype_ == np.longdouble and MACHINE == 'ppc64le':             # <<<<<<<<<<<<<<
 *         # values reported by hdf5
 *         nmant = 52
 */
    goto __pyx_L3;
  }

  /* "h5py/h5t.pyx":296
 *         maxexp = 1024
 *         minexp = -1022
 *     elif nmant == 63 and finfo.nexp == 15:             # <<<<<<<<<<<<<<
 *         # This is an 80-bit float, correct mantissa size
 *         nmant += 1
 */
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_nmant, __pyx_int_63, 63, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_finfo, __pyx_n_s_nexp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_15, 15, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __pyx_t_4;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":298
 *     elif nmant == 63 and finfo.nexp == 15:
 *         # This is an 80-bit float, correct mantissa size
 *         nmant += 1             # <<<<<<<<<<<<<<
 * 
 *     return nmant, maxexp, minexp
 */
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_nmant, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_nmant, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "h5py/h5t.pyx":296
 *         maxexp = 1024
 *         minexp = -1022
 *     elif nmant == 63 and finfo.nexp == 15:             # <<<<<<<<<<<<<<
 *         # This is an 80-bit float, correct mantissa size
 *         nmant += 1
 */
  }
  __pyx_L3:;

  /* "h5py/h5t.pyx":300
 *         nmant += 1
 * 
 *     return nmant, maxexp, minexp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_nmant); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 300, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_maxexp); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 300, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_v_minexp); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 300, __pyx_L1_error)
  __pyx_t_8.f0 = __pyx_t_5;
  __pyx_t_8.f1 = __pyx_t_6;
  __pyx_t_8.f2 = __pyx_t_7;
  __pyx_r = __pyx_t_8;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":281
 * 
 * 
 * cdef (int, int, int) _correct_float_info(ftype_, finfo):             # <<<<<<<<<<<<<<
 *     nmant = finfo.nmant
 *     maxexp = finfo.maxexp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_WriteUnraisable("h5py.h5t._correct_float_info", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __Pyx_pretend_to_initialize(&__pyx_r);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_nmant);
  __Pyx_XDECREF(__pyx_v_maxexp);
  __Pyx_XDECREF(__pyx_v_minexp);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":306
 * 
 * @with_phil
 * def create(int classtype, size_t size):             # <<<<<<<<<<<<<<
 *     """(INT classtype, UINT size) => TypeID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_3create(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_2create[] = "(INT classtype, UINT size) => TypeID\n\n    Create a new HDF5 type object.  Legal class values are\n    COMPOUND and OPAQUE.  Use enum_create for enums.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_3create = {"create", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_3create, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_2create};
static PyObject *__pyx_pw_4h5py_3h5t_3create(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_classtype;
  size_t __pyx_v_size;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_classtype,&__pyx_n_s_size,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_classtype)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("create", 1, 2, 2, 1); __PYX_ERR(0, 306, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create") < 0)) __PYX_ERR(0, 306, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_classtype = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_classtype == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 306, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_size_t(values[1]); if (unlikely((__pyx_v_size == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 306, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 306, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_2create(__pyx_self, __pyx_v_classtype, __pyx_v_size);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_2create(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_classtype, size_t __pyx_v_size) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  hid_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "h5py/h5t.pyx":314
 * 
 *     # HDF5 versions 1.6.X segfault with anything else
 *     if classtype != H5T_COMPOUND and classtype != H5T_OPAQUE:             # <<<<<<<<<<<<<<
 *         raise ValueError("Class must be COMPOUND or OPAQUE.")
 * 
 */
  switch (__pyx_v_classtype) {
    case H5T_COMPOUND:
    case H5T_OPAQUE:
    __pyx_t_1 = 0;
    break;
    default:
    __pyx_t_1 = 1;
    break;
  }
  if (unlikely(__pyx_t_1)) {

    /* "h5py/h5t.pyx":315
 *     # HDF5 versions 1.6.X segfault with anything else
 *     if classtype != H5T_COMPOUND and classtype != H5T_OPAQUE:
 *         raise ValueError("Class must be COMPOUND or OPAQUE.")             # <<<<<<<<<<<<<<
 * 
 *     return typewrap(H5Tcreate(<H5T_class_t>classtype, size))
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 315, __pyx_L1_error)

    /* "h5py/h5t.pyx":314
 * 
 *     # HDF5 versions 1.6.X segfault with anything else
 *     if classtype != H5T_COMPOUND and classtype != H5T_OPAQUE:             # <<<<<<<<<<<<<<
 *         raise ValueError("Class must be COMPOUND or OPAQUE.")
 * 
 */
  }

  /* "h5py/h5t.pyx":317
 *         raise ValueError("Class must be COMPOUND or OPAQUE.")
 * 
 *     return typewrap(H5Tcreate(<H5T_class_t>classtype, size))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_f_4h5py_4defs_H5Tcreate(((enum H5T_class_t)__pyx_v_classtype), __pyx_v_size); if (unlikely(__pyx_t_3 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 317, __pyx_L1_error)
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_t_3, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":306
 * 
 * @with_phil
 * def create(int classtype, size_t size):             # <<<<<<<<<<<<<<
 *     """(INT classtype, UINT size) => TypeID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":321
 * 
 * @with_phil
 * def open(ObjectID group not None, char* name, ObjectID tapl=None):             # <<<<<<<<<<<<<<
 *     """(ObjectID group, STRING name) => TypeID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_5open(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_4open[] = "(ObjectID group, STRING name) => TypeID\n\n    Open a named datatype from a file.\n    If present, tapl must be a datatype access property list.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_5open = {"open", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_5open, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_4open};
static PyObject *__pyx_pw_4h5py_3h5t_5open(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_group = 0;
  char *__pyx_v_name;
  struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_tapl = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("open (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_group,&__pyx_n_s_name,&__pyx_n_s_tapl,0};
    PyObject* values[3] = {0,0,0};
    values[2] = (PyObject *)((struct __pyx_obj_4h5py_8_objects_ObjectID *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_group)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("open", 0, 2, 3, 1); __PYX_ERR(0, 321, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tapl);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "open") < 0)) __PYX_ERR(0, 321, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_group = ((struct __pyx_obj_4h5py_8_objects_ObjectID *)values[0]);
    __pyx_v_name = __Pyx_PyObject_AsWritableString(values[1]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) __PYX_ERR(0, 321, __pyx_L3_error)
    __pyx_v_tapl = ((struct __pyx_obj_4h5py_8_objects_ObjectID *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("open", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 321, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_group), __pyx_ptype_4h5py_8_objects_ObjectID, 0, "group", 0))) __PYX_ERR(0, 321, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tapl), __pyx_ptype_4h5py_8_objects_ObjectID, 1, "tapl", 0))) __PYX_ERR(0, 321, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_4open(__pyx_self, __pyx_v_group, __pyx_v_name, __pyx_v_tapl);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_4open(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_group, char *__pyx_v_name, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_tapl) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("open", 0);

  /* "h5py/h5t.pyx":327
 *     If present, tapl must be a datatype access property list.
 *     """
 *     return typewrap(H5Topen(group.id, name, pdefault(tapl)))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Topen(__pyx_v_group->id, __pyx_v_name, __pyx_f_4h5py_8_objects_pdefault(__pyx_v_tapl)); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 327, __pyx_L1_error)
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_t_1, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":321
 * 
 * @with_phil
 * def open(ObjectID group not None, char* name, ObjectID tapl=None):             # <<<<<<<<<<<<<<
 *     """(ObjectID group, STRING name) => TypeID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":331
 * 
 * @with_phil
 * def array_create(TypeID base not None, object dims_tpl):             # <<<<<<<<<<<<<<
 *     """(TypeID base, TUPLE dimensions) => TypeArrayID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_7array_create(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_6array_create[] = "(TypeID base, TUPLE dimensions) => TypeArrayID\n\n    Create a new array datatype, using and HDF5 parent type and\n    dimensions given via a tuple of positive integers.  \"Unlimited\"\n    dimensions are not allowed.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_7array_create = {"array_create", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_7array_create, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_6array_create};
static PyObject *__pyx_pw_4h5py_3h5t_7array_create(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_base = 0;
  PyObject *__pyx_v_dims_tpl = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("array_create (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_base,&__pyx_n_s_dims_tpl,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_base)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dims_tpl)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("array_create", 1, 2, 2, 1); __PYX_ERR(0, 331, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "array_create") < 0)) __PYX_ERR(0, 331, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_base = ((struct __pyx_obj_4h5py_3h5t_TypeID *)values[0]);
    __pyx_v_dims_tpl = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("array_create", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 331, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.array_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_base), __pyx_ptype_4h5py_3h5t_TypeID, 0, "base", 0))) __PYX_ERR(0, 331, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_6array_create(__pyx_self, __pyx_v_base, __pyx_v_dims_tpl);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6array_create(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_base, PyObject *__pyx_v_dims_tpl) {
  hsize_t __pyx_v_rank;
  hsize_t *__pyx_v_dims;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  void *__pyx_t_3;
  hid_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("array_create", 0);

  /* "h5py/h5t.pyx":339
 *     """
 *     cdef hsize_t rank
 *     cdef hsize_t *dims = NULL             # <<<<<<<<<<<<<<
 * 
 *     require_tuple(dims_tpl, 0, -1, b"dims_tpl")
 */
  __pyx_v_dims = NULL;

  /* "h5py/h5t.pyx":341
 *     cdef hsize_t *dims = NULL
 * 
 *     require_tuple(dims_tpl, 0, -1, b"dims_tpl")             # <<<<<<<<<<<<<<
 *     rank = len(dims_tpl)
 *     dims = <hsize_t*>emalloc(sizeof(hsize_t)*rank)
 */
  __pyx_t_1 = __pyx_f_4h5py_5utils_require_tuple(__pyx_v_dims_tpl, 0, -1, ((char *)"dims_tpl")); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 341, __pyx_L1_error)

  /* "h5py/h5t.pyx":342
 * 
 *     require_tuple(dims_tpl, 0, -1, b"dims_tpl")
 *     rank = len(dims_tpl)             # <<<<<<<<<<<<<<
 *     dims = <hsize_t*>emalloc(sizeof(hsize_t)*rank)
 * 
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_dims_tpl); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 342, __pyx_L1_error)
  __pyx_v_rank = __pyx_t_2;

  /* "h5py/h5t.pyx":343
 *     require_tuple(dims_tpl, 0, -1, b"dims_tpl")
 *     rank = len(dims_tpl)
 *     dims = <hsize_t*>emalloc(sizeof(hsize_t)*rank)             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __pyx_t_3 = __pyx_f_4h5py_5utils_emalloc(((sizeof(hsize_t)) * __pyx_v_rank)); if (unlikely(__pyx_t_3 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 343, __pyx_L1_error)
  __pyx_v_dims = ((hsize_t *)__pyx_t_3);

  /* "h5py/h5t.pyx":345
 *     dims = <hsize_t*>emalloc(sizeof(hsize_t)*rank)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         convert_tuple(dims_tpl, dims, rank)
 *         return TypeArrayID(H5Tarray_create(base.id, rank, dims))
 */
  /*try:*/ {

    /* "h5py/h5t.pyx":346
 * 
 *     try:
 *         convert_tuple(dims_tpl, dims, rank)             # <<<<<<<<<<<<<<
 *         return TypeArrayID(H5Tarray_create(base.id, rank, dims))
 *     finally:
 */
    __pyx_t_1 = __pyx_f_4h5py_5utils_convert_tuple(__pyx_v_dims_tpl, __pyx_v_dims, __pyx_v_rank); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 346, __pyx_L4_error)

    /* "h5py/h5t.pyx":347
 *     try:
 *         convert_tuple(dims_tpl, dims, rank)
 *         return TypeArrayID(H5Tarray_create(base.id, rank, dims))             # <<<<<<<<<<<<<<
 *     finally:
 *         efree(dims)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_4h5py_4defs_H5Tarray_create(__pyx_v_base->__pyx_base.id, __pyx_v_rank, __pyx_v_dims); if (unlikely(__pyx_t_4 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 347, __pyx_L4_error)
    __pyx_t_5 = __Pyx_PyInt_From_hid_t(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 347, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeArrayID), __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 347, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L3_return;
  }

  /* "h5py/h5t.pyx":349
 *         return TypeArrayID(H5Tarray_create(base.id, rank, dims))
 *     finally:
 *         efree(dims)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_1 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
      {
        __pyx_f_4h5py_5utils_efree(__pyx_v_dims);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_1; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_14 = __pyx_r;
      __pyx_r = 0;
      __pyx_f_4h5py_5utils_efree(__pyx_v_dims);
      __pyx_r = __pyx_t_14;
      __pyx_t_14 = 0;
      goto __pyx_L0;
    }
  }

  /* "h5py/h5t.pyx":331
 * 
 * @with_phil
 * def array_create(TypeID base not None, object dims_tpl):             # <<<<<<<<<<<<<<
 *     """(TypeID base, TUPLE dimensions) => TypeArrayID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("h5py.h5t.array_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":353
 * 
 * @with_phil
 * def enum_create(TypeID base not None):             # <<<<<<<<<<<<<<
 *     """(TypeID base) => TypeID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_9enum_create(PyObject *__pyx_self, PyObject *__pyx_v_base); /*proto*/
static char __pyx_doc_4h5py_3h5t_8enum_create[] = "(TypeID base) => TypeID\n\n    Create a new enumerated type based on an (integer) parent type.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_9enum_create = {"enum_create", (PyCFunction)__pyx_pw_4h5py_3h5t_9enum_create, METH_O, __pyx_doc_4h5py_3h5t_8enum_create};
static PyObject *__pyx_pw_4h5py_3h5t_9enum_create(PyObject *__pyx_self, PyObject *__pyx_v_base) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enum_create (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_base), __pyx_ptype_4h5py_3h5t_TypeID, 0, "base", 0))) __PYX_ERR(0, 353, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_8enum_create(__pyx_self, ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_base));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_8enum_create(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_base) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enum_create", 0);

  /* "h5py/h5t.pyx":358
 *     Create a new enumerated type based on an (integer) parent type.
 *     """
 *     return typewrap(H5Tenum_create(base.id))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tenum_create(__pyx_v_base->__pyx_base.id); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 358, __pyx_L1_error)
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_t_1, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":353
 * 
 * @with_phil
 * def enum_create(TypeID base not None):             # <<<<<<<<<<<<<<
 *     """(TypeID base) => TypeID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.enum_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":362
 * 
 * @with_phil
 * def vlen_create(TypeID base not None):             # <<<<<<<<<<<<<<
 *     """(TypeID base) => TypeID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11vlen_create(PyObject *__pyx_self, PyObject *__pyx_v_base); /*proto*/
static char __pyx_doc_4h5py_3h5t_10vlen_create[] = "(TypeID base) => TypeID\n\n    Create a new variable-length datatype, using any HDF5 type as a base.\n\n    Although the Python interface can manipulate these types, there is no\n    provision for reading/writing vlen data.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_11vlen_create = {"vlen_create", (PyCFunction)__pyx_pw_4h5py_3h5t_11vlen_create, METH_O, __pyx_doc_4h5py_3h5t_10vlen_create};
static PyObject *__pyx_pw_4h5py_3h5t_11vlen_create(PyObject *__pyx_self, PyObject *__pyx_v_base) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vlen_create (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_base), __pyx_ptype_4h5py_3h5t_TypeID, 0, "base", 0))) __PYX_ERR(0, 362, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_10vlen_create(__pyx_self, ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_base));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_10vlen_create(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_base) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vlen_create", 0);

  /* "h5py/h5t.pyx":370
 *     provision for reading/writing vlen data.
 *     """
 *     return typewrap(H5Tvlen_create(base.id))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tvlen_create(__pyx_v_base->__pyx_base.id); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 370, __pyx_L1_error)
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_t_1, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":362
 * 
 * @with_phil
 * def vlen_create(TypeID base not None):             # <<<<<<<<<<<<<<
 *     """(TypeID base) => TypeID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.vlen_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":374
 * 
 * @with_phil
 * def decode(char* buf):             # <<<<<<<<<<<<<<
 *     """(STRING buf) => TypeID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_13decode(PyObject *__pyx_self, PyObject *__pyx_arg_buf); /*proto*/
static char __pyx_doc_4h5py_3h5t_12decode[] = "(STRING buf) => TypeID\n\n    Deserialize an HDF5 type.  You can also do this with the native\n    Python pickling machinery.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_13decode = {"decode", (PyCFunction)__pyx_pw_4h5py_3h5t_13decode, METH_O, __pyx_doc_4h5py_3h5t_12decode};
static PyObject *__pyx_pw_4h5py_3h5t_13decode(PyObject *__pyx_self, PyObject *__pyx_arg_buf) {
  char *__pyx_v_buf;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("decode (wrapper)", 0);
  assert(__pyx_arg_buf); {
    __pyx_v_buf = __Pyx_PyObject_AsWritableString(__pyx_arg_buf); if (unlikely((!__pyx_v_buf) && PyErr_Occurred())) __PYX_ERR(0, 374, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.decode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_12decode(__pyx_self, ((char *)__pyx_v_buf));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12decode(CYTHON_UNUSED PyObject *__pyx_self, char *__pyx_v_buf) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("decode", 0);

  /* "h5py/h5t.pyx":380
 *     Python pickling machinery.
 *     """
 *     return typewrap(H5Tdecode(<unsigned char*>buf))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tdecode(((unsigned char *)__pyx_v_buf)); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 380, __pyx_L1_error)
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_t_1, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":374
 * 
 * @with_phil
 * def decode(char* buf):             # <<<<<<<<<<<<<<
 *     """(STRING buf) => TypeID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.decode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":394
 *     """
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         with phil:
 *             if self._hash is None:
 */

/* Python wrapper */
static Py_hash_t __pyx_pw_4h5py_3h5t_6TypeID_1__hash__(PyObject *__pyx_v_self); /*proto*/
static Py_hash_t __pyx_pw_4h5py_3h5t_6TypeID_1__hash__(PyObject *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID___hash__(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_hash_t __pyx_pf_4h5py_3h5t_6TypeID___hash__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  Py_hash_t __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "h5py/h5t.pyx":395
 * 
 *     def __hash__(self):
 *         with phil:             # <<<<<<<<<<<<<<
 *             if self._hash is None:
 *                 try:
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_exit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 395, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 395, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "h5py/h5t.pyx":396
 *     def __hash__(self):
 *         with phil:
 *             if self._hash is None:             # <<<<<<<<<<<<<<
 *                 try:
 *                     # Try to use object header first
 */
          __pyx_t_9 = (__pyx_v_self->__pyx_base._hash == Py_None);
          __pyx_t_10 = (__pyx_t_9 != 0);
          if (__pyx_t_10) {

            /* "h5py/h5t.pyx":397
 *         with phil:
 *             if self._hash is None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     # Try to use object header first
 *                     return ObjectID.__hash__(self)
 */
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_11);
              __Pyx_XGOTREF(__pyx_t_12);
              __Pyx_XGOTREF(__pyx_t_13);
              /*try:*/ {

                /* "h5py/h5t.pyx":399
 *                 try:
 *                     # Try to use object header first
 *                     return ObjectID.__hash__(self)             # <<<<<<<<<<<<<<
 *                 except TypeError:
 *                     # It's a transient type object
 */
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_4h5py_8_objects_ObjectID), __pyx_n_s_hash); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 399, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_4 = NULL;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
                  __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
                  if (likely(__pyx_t_4)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                    __Pyx_INCREF(__pyx_t_4);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_3, function);
                  }
                }
                __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_self)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_self));
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 399, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __pyx_t_14 = __Pyx_PyInt_AsHash_t(__pyx_t_1); if (unlikely((__pyx_t_14 == (Py_hash_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 399, __pyx_L14_error)
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __pyx_r = __pyx_t_14;
                goto __pyx_L18_try_return;

                /* "h5py/h5t.pyx":397
 *         with phil:
 *             if self._hash is None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     # Try to use object header first
 *                     return ObjectID.__hash__(self)
 */
              }
              __pyx_L14_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "h5py/h5t.pyx":400
 *                     # Try to use object header first
 *                     return ObjectID.__hash__(self)
 *                 except TypeError:             # <<<<<<<<<<<<<<
 *                     # It's a transient type object
 *                     if self.locked:
 */
              __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
              if (__pyx_t_15) {
                __Pyx_AddTraceback("h5py.h5t.TypeID.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 400, __pyx_L16_except_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_GOTREF(__pyx_t_3);
                __Pyx_GOTREF(__pyx_t_4);

                /* "h5py/h5t.pyx":402
 *                 except TypeError:
 *                     # It's a transient type object
 *                     if self.locked:             # <<<<<<<<<<<<<<
 *                         self._hash = hash(self.encode())
 *                     else:
 */
                __pyx_t_10 = (__pyx_v_self->__pyx_base.locked != 0);
                if (likely(__pyx_t_10)) {

                  /* "h5py/h5t.pyx":403
 *                     # It's a transient type object
 *                     if self.locked:
 *                         self._hash = hash(self.encode())             # <<<<<<<<<<<<<<
 *                     else:
 *                         raise TypeError("Only locked or committed types can be hashed")
 */
                  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_encode); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 403, __pyx_L16_except_error)
                  __Pyx_GOTREF(__pyx_t_16);
                  __pyx_t_17 = NULL;
                  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
                    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
                    if (likely(__pyx_t_17)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                      __Pyx_INCREF(__pyx_t_17);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_16, function);
                    }
                  }
                  __pyx_t_5 = (__pyx_t_17) ? __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_17) : __Pyx_PyObject_CallNoArg(__pyx_t_16);
                  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 403, __pyx_L16_except_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                  __pyx_t_14 = PyObject_Hash(__pyx_t_5); if (unlikely(__pyx_t_14 == ((Py_hash_t)-1))) __PYX_ERR(0, 403, __pyx_L16_except_error)
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  __pyx_t_5 = __Pyx_PyInt_FromHash_t(__pyx_t_14); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 403, __pyx_L16_except_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_GIVEREF(__pyx_t_5);
                  __Pyx_GOTREF(__pyx_v_self->__pyx_base._hash);
                  __Pyx_DECREF(__pyx_v_self->__pyx_base._hash);
                  __pyx_v_self->__pyx_base._hash = __pyx_t_5;
                  __pyx_t_5 = 0;

                  /* "h5py/h5t.pyx":402
 *                 except TypeError:
 *                     # It's a transient type object
 *                     if self.locked:             # <<<<<<<<<<<<<<
 *                         self._hash = hash(self.encode())
 *                     else:
 */
                  goto __pyx_L22;
                }

                /* "h5py/h5t.pyx":405
 *                         self._hash = hash(self.encode())
 *                     else:
 *                         raise TypeError("Only locked or committed types can be hashed")             # <<<<<<<<<<<<<<
 * 
 *             return self._hash
 */
                /*else*/ {
                  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 405, __pyx_L16_except_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_Raise(__pyx_t_5, 0, 0, 0);
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  __PYX_ERR(0, 405, __pyx_L16_except_error)
                }
                __pyx_L22:;
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                goto __pyx_L15_exception_handled;
              }
              goto __pyx_L16_except_error;
              __pyx_L16_except_error:;

              /* "h5py/h5t.pyx":397
 *         with phil:
 *             if self._hash is None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     # Try to use object header first
 *                     return ObjectID.__hash__(self)
 */
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
              goto __pyx_L7_error;
              __pyx_L18_try_return:;
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
              goto __pyx_L11_try_return;
              __pyx_L15_exception_handled:;
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
            }

            /* "h5py/h5t.pyx":396
 *     def __hash__(self):
 *         with phil:
 *             if self._hash is None:             # <<<<<<<<<<<<<<
 *                 try:
 *                     # Try to use object header first
 */
          }

          /* "h5py/h5t.pyx":407
 *                         raise TypeError("Only locked or committed types can be hashed")
 * 
 *             return self._hash             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __pyx_t_14 = __Pyx_PyInt_AsHash_t(__pyx_v_self->__pyx_base._hash); if (unlikely((__pyx_t_14 == (Py_hash_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 407, __pyx_L7_error)
          __pyx_r = __pyx_t_14;
          goto __pyx_L11_try_return;

          /* "h5py/h5t.pyx":395
 * 
 *     def __hash__(self):
 *         with phil:             # <<<<<<<<<<<<<<
 *             if self._hash is None:
 *                 try:
 */
        }
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("h5py.h5t.TypeID.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_1) < 0) __PYX_ERR(0, 395, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_5 = PyTuple_Pack(3, __pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 395, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 395, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (__pyx_t_10 < 0) __PYX_ERR(0, 395, __pyx_L9_except_error)
          __pyx_t_9 = ((!(__pyx_t_10 != 0)) != 0);
          if (__pyx_t_9) {
            __Pyx_GIVEREF(__pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_XGIVEREF(__pyx_t_1);
            __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_3, __pyx_t_1);
            __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_1 = 0; 
            __PYX_ERR(0, 395, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L11_try_return:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L4_return;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_2) {
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 395, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L4_return: {
        __pyx_t_14 = __pyx_r;
        if (__pyx_t_2) {
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 395, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_r = __pyx_t_14;
        goto __pyx_L0;
      }
      __pyx_L6:;
    }
    goto __pyx_L26;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L1_error;
    __pyx_L26:;
  }

  /* "h5py/h5t.pyx":394
 *     """
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         with phil:
 *             if self._hash is None:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("h5py.h5t.TypeID.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  if (unlikely(__pyx_r == -1) && !PyErr_Occurred()) __pyx_r = -2;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":410
 * 
 * 
 *     def __richcmp__(self, object other, int how):             # <<<<<<<<<<<<<<
 *         cdef bint truthval = 0
 *         with phil:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_3__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_v_how); /*proto*/
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_3__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_v_how) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__richcmp__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_2__richcmp__(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self), ((PyObject *)__pyx_v_other), ((int)__pyx_v_how));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_2__richcmp__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_v_how) {
  int __pyx_v_truthval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__richcmp__", 0);

  /* "h5py/h5t.pyx":411
 * 
 *     def __richcmp__(self, object other, int how):
 *         cdef bint truthval = 0             # <<<<<<<<<<<<<<
 *         with phil:
 *             if how != 2 and how != 3:
 */
  __pyx_v_truthval = 0;

  /* "h5py/h5t.pyx":412
 *     def __richcmp__(self, object other, int how):
 *         cdef bint truthval = 0
 *         with phil:             # <<<<<<<<<<<<<<
 *             if how != 2 and how != 3:
 *                 return NotImplemented
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_exit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 412, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 412, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "h5py/h5t.pyx":413
 *         cdef bint truthval = 0
 *         with phil:
 *             if how != 2 and how != 3:             # <<<<<<<<<<<<<<
 *                 return NotImplemented
 *             if isinstance(other, TypeID):
 */
          switch (__pyx_v_how) {
            case 2:
            case 3:
            __pyx_t_9 = 0;
            break;
            default:
            __pyx_t_9 = 1;
            break;
          }
          if (__pyx_t_9) {

            /* "h5py/h5t.pyx":414
 *         with phil:
 *             if how != 2 and how != 3:
 *                 return NotImplemented             # <<<<<<<<<<<<<<
 *             if isinstance(other, TypeID):
 *                 truthval = self.equal(other)
 */
            __Pyx_XDECREF(__pyx_r);
            __Pyx_INCREF(__pyx_builtin_NotImplemented);
            __pyx_r = __pyx_builtin_NotImplemented;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":413
 *         cdef bint truthval = 0
 *         with phil:
 *             if how != 2 and how != 3:             # <<<<<<<<<<<<<<
 *                 return NotImplemented
 *             if isinstance(other, TypeID):
 */
          }

          /* "h5py/h5t.pyx":415
 *             if how != 2 and how != 3:
 *                 return NotImplemented
 *             if isinstance(other, TypeID):             # <<<<<<<<<<<<<<
 *                 truthval = self.equal(other)
 * 
 */
          __pyx_t_9 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_4h5py_3h5t_TypeID); 
          __pyx_t_10 = (__pyx_t_9 != 0);
          if (__pyx_t_10) {

            /* "h5py/h5t.pyx":416
 *                 return NotImplemented
 *             if isinstance(other, TypeID):
 *                 truthval = self.equal(other)             # <<<<<<<<<<<<<<
 * 
 *             if how == 2:
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_equal); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 416, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_4 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
              }
            }
            __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_other) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_other);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 416, __pyx_L7_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_v_truthval = __pyx_t_10;

            /* "h5py/h5t.pyx":415
 *             if how != 2 and how != 3:
 *                 return NotImplemented
 *             if isinstance(other, TypeID):             # <<<<<<<<<<<<<<
 *                 truthval = self.equal(other)
 * 
 */
          }

          /* "h5py/h5t.pyx":418
 *                 truthval = self.equal(other)
 * 
 *             if how == 2:             # <<<<<<<<<<<<<<
 *                 return truthval
 *             return not truthval
 */
          __pyx_t_10 = ((__pyx_v_how == 2) != 0);
          if (__pyx_t_10) {

            /* "h5py/h5t.pyx":419
 * 
 *             if how == 2:
 *                 return truthval             # <<<<<<<<<<<<<<
 *             return not truthval
 * 
 */
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_truthval); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 419, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_r = __pyx_t_1;
            __pyx_t_1 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":418
 *                 truthval = self.equal(other)
 * 
 *             if how == 2:             # <<<<<<<<<<<<<<
 *                 return truthval
 *             return not truthval
 */
          }

          /* "h5py/h5t.pyx":420
 *             if how == 2:
 *                 return truthval
 *             return not truthval             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_1 = __Pyx_PyBool_FromLong((!(__pyx_v_truthval != 0))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 420, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_r = __pyx_t_1;
          __pyx_t_1 = 0;
          goto __pyx_L11_try_return;

          /* "h5py/h5t.pyx":412
 *     def __richcmp__(self, object other, int how):
 *         cdef bint truthval = 0
 *         with phil:             # <<<<<<<<<<<<<<
 *             if how != 2 and how != 3:
 *                 return NotImplemented
 */
        }
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("h5py.h5t.TypeID.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 412, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 412, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 412, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (__pyx_t_10 < 0) __PYX_ERR(0, 412, __pyx_L9_except_error)
          __pyx_t_9 = ((!(__pyx_t_10 != 0)) != 0);
          if (__pyx_t_9) {
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_XGIVEREF(__pyx_t_4);
            __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_3, __pyx_t_4);
            __pyx_t_1 = 0; __pyx_t_3 = 0; __pyx_t_4 = 0; 
            __PYX_ERR(0, 412, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L11_try_return:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L4_return;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_2) {
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L4_return: {
        __pyx_t_8 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_2) {
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __pyx_r = __pyx_t_8;
        __pyx_t_8 = 0;
        goto __pyx_L0;
      }
      __pyx_L6:;
    }
    goto __pyx_L19;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L1_error;
    __pyx_L19:;
  }

  /* "h5py/h5t.pyx":410
 * 
 * 
 *     def __richcmp__(self, object other, int how):             # <<<<<<<<<<<<<<
 *         cdef bint truthval = 0
 *         with phil:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("h5py.h5t.TypeID.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":423
 * 
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         cdef TypeID cpy
 *         with phil:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_5__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_5__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__copy__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_4__copy__(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_4__copy__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_cpy = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__copy__", 0);

  /* "h5py/h5t.pyx":425
 *     def __copy__(self):
 *         cdef TypeID cpy
 *         with phil:             # <<<<<<<<<<<<<<
 *             cpy = ObjectID.__copy__(self)
 *             return cpy
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_exit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 425, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 425, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "h5py/h5t.pyx":426
 *         cdef TypeID cpy
 *         with phil:
 *             cpy = ObjectID.__copy__(self)             # <<<<<<<<<<<<<<
 *             return cpy
 * 
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_4h5py_8_objects_ObjectID), __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 426, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_self)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_self));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 426, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 426, __pyx_L7_error)
          __pyx_v_cpy = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_1);
          __pyx_t_1 = 0;

          /* "h5py/h5t.pyx":427
 *         with phil:
 *             cpy = ObjectID.__copy__(self)
 *             return cpy             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __Pyx_XDECREF(__pyx_r);
          __Pyx_INCREF(((PyObject *)__pyx_v_cpy));
          __pyx_r = ((PyObject *)__pyx_v_cpy);
          goto __pyx_L11_try_return;

          /* "h5py/h5t.pyx":425
 *     def __copy__(self):
 *         cdef TypeID cpy
 *         with phil:             # <<<<<<<<<<<<<<
 *             cpy = ObjectID.__copy__(self)
 *             return cpy
 */
        }
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("h5py.h5t.TypeID.__copy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 425, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 425, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 425, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (__pyx_t_10 < 0) __PYX_ERR(0, 425, __pyx_L9_except_error)
          __pyx_t_11 = ((!(__pyx_t_10 != 0)) != 0);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_XGIVEREF(__pyx_t_4);
            __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_3, __pyx_t_4);
            __pyx_t_1 = 0; __pyx_t_3 = 0; __pyx_t_4 = 0; 
            __PYX_ERR(0, 425, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L11_try_return:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L4_return;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_2) {
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 425, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L4_return: {
        __pyx_t_8 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_2) {
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 425, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __pyx_r = __pyx_t_8;
        __pyx_t_8 = 0;
        goto __pyx_L0;
      }
      __pyx_L6:;
    }
    goto __pyx_L16;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L1_error;
    __pyx_L16:;
  }

  /* "h5py/h5t.pyx":423
 * 
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         cdef TypeID cpy
 *         with phil:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("h5py.h5t.TypeID.__copy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_cpy);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":433
 *         """ A Numpy-style dtype object representing this object.
 *         """
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             with phil:
 *                 return self.py_dtype()
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_5dtype_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_5dtype_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_5dtype___get__(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_5dtype___get__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5t.pyx":434
 *         """
 *         def __get__(self):
 *             with phil:             # <<<<<<<<<<<<<<
 *                 return self.py_dtype()
 * 
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_exit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 434, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 434, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "h5py/h5t.pyx":435
 *         def __get__(self):
 *             with phil:
 *                 return self.py_dtype()             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_1 = ((struct __pyx_vtabstruct_4h5py_3h5t_TypeID *)__pyx_v_self->__pyx_vtab)->py_dtype(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 435, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_r = __pyx_t_1;
          __pyx_t_1 = 0;
          goto __pyx_L11_try_return;

          /* "h5py/h5t.pyx":434
 *         """
 *         def __get__(self):
 *             with phil:             # <<<<<<<<<<<<<<
 *                 return self.py_dtype()
 * 
 */
        }
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("h5py.h5t.TypeID.dtype.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 434, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 434, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 434, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (__pyx_t_10 < 0) __PYX_ERR(0, 434, __pyx_L9_except_error)
          __pyx_t_11 = ((!(__pyx_t_10 != 0)) != 0);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_XGIVEREF(__pyx_t_4);
            __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_3, __pyx_t_4);
            __pyx_t_1 = 0; __pyx_t_3 = 0; __pyx_t_4 = 0; 
            __PYX_ERR(0, 434, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L11_try_return:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L4_return;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_2) {
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 434, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L4_return: {
        __pyx_t_8 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_2) {
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 434, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __pyx_r = __pyx_t_8;
        __pyx_t_8 = 0;
        goto __pyx_L0;
      }
      __pyx_L6:;
    }
    goto __pyx_L16;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L1_error;
    __pyx_L16:;
  }

  /* "h5py/h5t.pyx":433
 *         """ A Numpy-style dtype object representing this object.
 *         """
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             with phil:
 *                 return self.py_dtype()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("h5py.h5t.TypeID.dtype.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":438
 * 
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         raise TypeError("No NumPy equivalent for %s exists" % self.__class__.__name__)
 * 
 */

static PyObject *__pyx_f_4h5py_3h5t_6TypeID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":439
 * 
 *     cdef object py_dtype(self):
 *         raise TypeError("No NumPy equivalent for %s exists" % self.__class__.__name__)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_No_NumPy_equivalent_for_s_exists, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(0, 439, __pyx_L1_error)

  /* "h5py/h5t.pyx":438
 * 
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         raise TypeError("No NumPy equivalent for %s exists" % self.__class__.__name__)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":443
 * 
 *     @with_phil
 *     def commit(self, ObjectID group not None, char* name, ObjectID lcpl=None):             # <<<<<<<<<<<<<<
 *         """(ObjectID group, STRING name, PropID lcpl=None)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_7commit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_6commit[] = "(ObjectID group, STRING name, PropID lcpl=None)\n\n        Commit this (transient) datatype to a named datatype in a file.\n        If present, lcpl may be a link creation property list.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_7commit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_group = 0;
  char *__pyx_v_name;
  struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_lcpl = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("commit (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_group,&__pyx_n_s_name,&__pyx_n_s_lcpl,0};
    PyObject* values[3] = {0,0,0};
    values[2] = (PyObject *)((struct __pyx_obj_4h5py_8_objects_ObjectID *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_group)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("commit", 0, 2, 3, 1); __PYX_ERR(0, 443, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_lcpl);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "commit") < 0)) __PYX_ERR(0, 443, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_group = ((struct __pyx_obj_4h5py_8_objects_ObjectID *)values[0]);
    __pyx_v_name = __Pyx_PyObject_AsWritableString(values[1]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) __PYX_ERR(0, 443, __pyx_L3_error)
    __pyx_v_lcpl = ((struct __pyx_obj_4h5py_8_objects_ObjectID *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("commit", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 443, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeID.commit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_group), __pyx_ptype_4h5py_8_objects_ObjectID, 0, "group", 0))) __PYX_ERR(0, 443, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_lcpl), __pyx_ptype_4h5py_8_objects_ObjectID, 1, "lcpl", 0))) __PYX_ERR(0, 443, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_6commit(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self), __pyx_v_group, __pyx_v_name, __pyx_v_lcpl);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_6commit(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_group, char *__pyx_v_name, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_lcpl) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("commit", 0);

  /* "h5py/h5t.pyx":449
 *         If present, lcpl may be a link creation property list.
 *         """
 *         H5Tcommit(group.id, name, self.id, pdefault(lcpl),             # <<<<<<<<<<<<<<
 *             H5P_DEFAULT, H5P_DEFAULT)
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tcommit(__pyx_v_group->id, __pyx_v_name, __pyx_v_self->__pyx_base.id, __pyx_f_4h5py_8_objects_pdefault(__pyx_v_lcpl), H5P_DEFAULT, H5P_DEFAULT); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 449, __pyx_L1_error)

  /* "h5py/h5t.pyx":443
 * 
 *     @with_phil
 *     def commit(self, ObjectID group not None, char* name, ObjectID lcpl=None):             # <<<<<<<<<<<<<<
 *         """(ObjectID group, STRING name, PropID lcpl=None)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeID.commit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":454
 * 
 *     @with_phil
 *     def committed(self):             # <<<<<<<<<<<<<<
 *         """() => BOOL is_comitted
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_9committed(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_8committed[] = "() => BOOL is_comitted\n\n        Determine if a given type object is named (T) or transient (F).\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_9committed(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("committed (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_8committed(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_8committed(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  htri_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("committed", 0);

  /* "h5py/h5t.pyx":459
 *         Determine if a given type object is named (T) or transient (F).
 *         """
 *         return <bint>(H5Tcommitted(self.id))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tcommitted(__pyx_v_self->__pyx_base.id); if (unlikely(__pyx_t_1 == ((htri_t)((htri_t)-1L)))) __PYX_ERR(0, 459, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong((__pyx_t_1 != 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":454
 * 
 *     @with_phil
 *     def committed(self):             # <<<<<<<<<<<<<<
 *         """() => BOOL is_comitted
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.committed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":463
 * 
 *     @with_phil
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """() => TypeID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_11copy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_10copy[] = "() => TypeID\n\n        Create a copy of this type object.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_11copy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_10copy(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_10copy(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "h5py/h5t.pyx":468
 *         Create a copy of this type object.
 *         """
 *         return typewrap(H5Tcopy(self.id))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tcopy(__pyx_v_self->__pyx_base.id); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 468, __pyx_L1_error)
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_t_1, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":463
 * 
 *     @with_phil
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """() => TypeID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":472
 * 
 *     @with_phil
 *     def equal(self, TypeID typeid):             # <<<<<<<<<<<<<<
 *         """(TypeID typeid) => BOOL
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_13equal(PyObject *__pyx_v_self, PyObject *__pyx_v_typeid); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_12equal[] = "(TypeID typeid) => BOOL\n\n        Logical comparison between datatypes.  Also called by\n        Python's \"==\" operator.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_13equal(PyObject *__pyx_v_self, PyObject *__pyx_v_typeid) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("equal (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_typeid), __pyx_ptype_4h5py_3h5t_TypeID, 1, "typeid", 0))) __PYX_ERR(0, 472, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_12equal(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self), ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_typeid));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_12equal(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_typeid) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  htri_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("equal", 0);

  /* "h5py/h5t.pyx":478
 *         Python's "==" operator.
 *         """
 *         return <bint>(H5Tequal(self.id, typeid.id))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tequal(__pyx_v_self->__pyx_base.id, __pyx_v_typeid->__pyx_base.id); if (unlikely(__pyx_t_1 == ((htri_t)((htri_t)-1L)))) __PYX_ERR(0, 478, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong((__pyx_t_1 != 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":472
 * 
 *     @with_phil
 *     def equal(self, TypeID typeid):             # <<<<<<<<<<<<<<
 *         """(TypeID typeid) => BOOL
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.equal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":482
 * 
 *     @with_phil
 *     def lock(self):             # <<<<<<<<<<<<<<
 *         """()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_15lock(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_14lock[] = "()\n\n        Lock this datatype, which makes it immutable and indestructible.\n        Once locked, it can't be unlocked.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_15lock(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lock (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_14lock(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_14lock(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lock", 0);

  /* "h5py/h5t.pyx":488
 *         Once locked, it can't be unlocked.
 *         """
 *         H5Tlock(self.id)             # <<<<<<<<<<<<<<
 *         self.locked = 1
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tlock(__pyx_v_self->__pyx_base.id); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 488, __pyx_L1_error)

  /* "h5py/h5t.pyx":489
 *         """
 *         H5Tlock(self.id)
 *         self.locked = 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->__pyx_base.locked = 1;

  /* "h5py/h5t.pyx":482
 * 
 *     @with_phil
 *     def lock(self):             # <<<<<<<<<<<<<<
 *         """()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeID.lock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":493
 * 
 *     @with_phil
 *     def get_class(self):             # <<<<<<<<<<<<<<
 *         """() => INT classcode
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_17get_class(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_16get_class[] = "() => INT classcode\n\n        Determine the datatype's class code.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_17get_class(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_class (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_16get_class(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_16get_class(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  enum H5T_class_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_class", 0);

  /* "h5py/h5t.pyx":498
 *         Determine the datatype's class code.
 *         """
 *         return <int>H5Tget_class(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_class(__pyx_v_self->__pyx_base.id); if (unlikely(__pyx_t_1 == ((enum H5T_class_t)((enum H5T_class_t)-1L)))) __PYX_ERR(0, 498, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":493
 * 
 *     @with_phil
 *     def get_class(self):             # <<<<<<<<<<<<<<
 *         """() => INT classcode
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.get_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":502
 * 
 *     @with_phil
 *     def set_size(self, size_t size):             # <<<<<<<<<<<<<<
 *         """(UINT size)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_19set_size(PyObject *__pyx_v_self, PyObject *__pyx_arg_size); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_18set_size[] = "(UINT size)\n\n        Set the total size of the datatype, in bytes.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_19set_size(PyObject *__pyx_v_self, PyObject *__pyx_arg_size) {
  size_t __pyx_v_size;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_size (wrapper)", 0);
  assert(__pyx_arg_size); {
    __pyx_v_size = __Pyx_PyInt_As_size_t(__pyx_arg_size); if (unlikely((__pyx_v_size == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 502, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeID.set_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_18set_size(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self), ((size_t)__pyx_v_size));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_18set_size(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, size_t __pyx_v_size) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_size", 0);

  /* "h5py/h5t.pyx":507
 *         Set the total size of the datatype, in bytes.
 *         """
 *         H5Tset_size(self.id, size)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_size(__pyx_v_self->__pyx_base.id, __pyx_v_size); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 507, __pyx_L1_error)

  /* "h5py/h5t.pyx":502
 * 
 *     @with_phil
 *     def set_size(self, size_t size):             # <<<<<<<<<<<<<<
 *         """(UINT size)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeID.set_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":511
 * 
 *     @with_phil
 *     def get_size(self):             # <<<<<<<<<<<<<<
 *         """ () => INT size
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_21get_size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_20get_size[] = " () => INT size\n\n            Determine the total size of a datatype, in bytes.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_21get_size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_size (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_20get_size(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_20get_size(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  size_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_size", 0);

  /* "h5py/h5t.pyx":516
 *             Determine the total size of a datatype, in bytes.
 *         """
 *         return H5Tget_size(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_size(__pyx_v_self->__pyx_base.id); if (unlikely(__pyx_t_1 == ((size_t)((size_t)0)))) __PYX_ERR(0, 516, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":511
 * 
 *     @with_phil
 *     def get_size(self):             # <<<<<<<<<<<<<<
 *         """ () => INT size
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.get_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":520
 * 
 *     @with_phil
 *     def get_super(self):             # <<<<<<<<<<<<<<
 *         """() => TypeID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_23get_super(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_22get_super[] = "() => TypeID\n\n        Determine the parent type of an array, enumeration or vlen datatype.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_23get_super(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_super (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_22get_super(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_22get_super(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_super", 0);

  /* "h5py/h5t.pyx":525
 *         Determine the parent type of an array, enumeration or vlen datatype.
 *         """
 *         return typewrap(H5Tget_super(self.id))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_super(__pyx_v_self->__pyx_base.id); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 525, __pyx_L1_error)
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_t_1, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":520
 * 
 *     @with_phil
 *     def get_super(self):             # <<<<<<<<<<<<<<
 *         """() => TypeID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.get_super", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":529
 * 
 *     @with_phil
 *     def detect_class(self, int classtype):             # <<<<<<<<<<<<<<
 *         """(INT classtype) => BOOL class_is_present
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_25detect_class(PyObject *__pyx_v_self, PyObject *__pyx_arg_classtype); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_24detect_class[] = "(INT classtype) => BOOL class_is_present\n\n        Determine if a member of the given class exists in a compound\n        datatype.  The search is recursive.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_25detect_class(PyObject *__pyx_v_self, PyObject *__pyx_arg_classtype) {
  int __pyx_v_classtype;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("detect_class (wrapper)", 0);
  assert(__pyx_arg_classtype); {
    __pyx_v_classtype = __Pyx_PyInt_As_int(__pyx_arg_classtype); if (unlikely((__pyx_v_classtype == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 529, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeID.detect_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_24detect_class(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self), ((int)__pyx_v_classtype));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_24detect_class(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, int __pyx_v_classtype) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  htri_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("detect_class", 0);

  /* "h5py/h5t.pyx":535
 *         datatype.  The search is recursive.
 *         """
 *         return <bint>(H5Tdetect_class(self.id, <H5T_class_t>classtype))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tdetect_class(__pyx_v_self->__pyx_base.id, ((enum H5T_class_t)__pyx_v_classtype)); if (unlikely(__pyx_t_1 == ((htri_t)((htri_t)-1L)))) __PYX_ERR(0, 535, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong((__pyx_t_1 != 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":529
 * 
 *     @with_phil
 *     def detect_class(self, int classtype):             # <<<<<<<<<<<<<<
 *         """(INT classtype) => BOOL class_is_present
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.detect_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":539
 * 
 *     @with_phil
 *     def encode(self):             # <<<<<<<<<<<<<<
 *         """() => STRING
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_27encode(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_26encode[] = "() => STRING\n\n        Serialize an HDF5 type.  Bear in mind you can also use the\n        native Python pickle/unpickle machinery to do this.  The\n        returned string may contain binary values, including NULLs.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_27encode(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("encode (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_26encode(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_26encode(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  size_t __pyx_v_nalloc;
  char *__pyx_v_buf;
  PyObject *__pyx_v_pystr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  void *__pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  char const *__pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("encode", 0);

  /* "h5py/h5t.pyx":546
 *         returned string may contain binary values, including NULLs.
 *         """
 *         cdef size_t nalloc = 0             # <<<<<<<<<<<<<<
 *         cdef char* buf = NULL
 * 
 */
  __pyx_v_nalloc = 0;

  /* "h5py/h5t.pyx":547
 *         """
 *         cdef size_t nalloc = 0
 *         cdef char* buf = NULL             # <<<<<<<<<<<<<<
 * 
 *         H5Tencode(self.id, NULL, &nalloc)
 */
  __pyx_v_buf = NULL;

  /* "h5py/h5t.pyx":549
 *         cdef char* buf = NULL
 * 
 *         H5Tencode(self.id, NULL, &nalloc)             # <<<<<<<<<<<<<<
 *         buf = <char*>emalloc(sizeof(char)*nalloc)
 *         try:
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tencode(__pyx_v_self->__pyx_base.id, NULL, (&__pyx_v_nalloc)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 549, __pyx_L1_error)

  /* "h5py/h5t.pyx":550
 * 
 *         H5Tencode(self.id, NULL, &nalloc)
 *         buf = <char*>emalloc(sizeof(char)*nalloc)             # <<<<<<<<<<<<<<
 *         try:
 *             H5Tencode(self.id, <unsigned char*>buf, &nalloc)
 */
  __pyx_t_2 = __pyx_f_4h5py_5utils_emalloc(((sizeof(char)) * __pyx_v_nalloc)); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 550, __pyx_L1_error)
  __pyx_v_buf = ((char *)__pyx_t_2);

  /* "h5py/h5t.pyx":551
 *         H5Tencode(self.id, NULL, &nalloc)
 *         buf = <char*>emalloc(sizeof(char)*nalloc)
 *         try:             # <<<<<<<<<<<<<<
 *             H5Tencode(self.id, <unsigned char*>buf, &nalloc)
 *             pystr = PyBytes_FromStringAndSize(buf, nalloc)
 */
  /*try:*/ {

    /* "h5py/h5t.pyx":552
 *         buf = <char*>emalloc(sizeof(char)*nalloc)
 *         try:
 *             H5Tencode(self.id, <unsigned char*>buf, &nalloc)             # <<<<<<<<<<<<<<
 *             pystr = PyBytes_FromStringAndSize(buf, nalloc)
 *         finally:
 */
    __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tencode(__pyx_v_self->__pyx_base.id, ((unsigned char *)__pyx_v_buf), (&__pyx_v_nalloc)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 552, __pyx_L4_error)

    /* "h5py/h5t.pyx":553
 *         try:
 *             H5Tencode(self.id, <unsigned char*>buf, &nalloc)
 *             pystr = PyBytes_FromStringAndSize(buf, nalloc)             # <<<<<<<<<<<<<<
 *         finally:
 *             efree(buf)
 */
    __pyx_t_3 = PyBytes_FromStringAndSize(__pyx_v_buf, __pyx_v_nalloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 553, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_pystr = __pyx_t_3;
    __pyx_t_3 = 0;
  }

  /* "h5py/h5t.pyx":555
 *             pystr = PyBytes_FromStringAndSize(buf, nalloc)
 *         finally:
 *             efree(buf)             # <<<<<<<<<<<<<<
 * 
 *         return pystr
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_f_4h5py_5utils_efree(__pyx_v_buf);
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __pyx_t_4 = __pyx_lineno; __pyx_t_5 = __pyx_clineno; __pyx_t_6 = __pyx_filename;
      {
        __pyx_f_4h5py_5utils_efree(__pyx_v_buf);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_5; __pyx_filename = __pyx_t_6;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "h5py/h5t.pyx":557
 *             efree(buf)
 * 
 *         return pystr             # <<<<<<<<<<<<<<
 * 
 *     @with_phil
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pystr);
  __pyx_r = __pyx_v_pystr;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":539
 * 
 *     @with_phil
 *     def encode(self):             # <<<<<<<<<<<<<<
 *         """() => STRING
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t.TypeID.encode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pystr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":560
 * 
 *     @with_phil
 *     def get_create_plist(self):             # <<<<<<<<<<<<<<
 *         """ () => PropTCID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_29get_create_plist(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_6TypeID_28get_create_plist[] = " () => PropTCID\n\n            Create and return a new copy of the datatype creation property list\n            used when this datatype was created.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_29get_create_plist(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_create_plist (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_28get_create_plist(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_28get_create_plist(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_create_plist", 0);

  /* "h5py/h5t.pyx":566
 *             used when this datatype was created.
 *         """
 *         return propwrap(H5Tget_create_plist(self.id))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_create_plist(__pyx_v_self->__pyx_base.id); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 566, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_4h5py_3h5p_propwrap(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":560
 * 
 *     @with_phil
 *     def get_create_plist(self):             # <<<<<<<<<<<<<<
 *         """ () => PropTCID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeID.get_create_plist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":569
 * 
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         with phil:
 *             return (type(self), (-1,), self.encode())
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_31__reduce__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_31__reduce__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_30__reduce__(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_30__reduce__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce__", 0);

  /* "h5py/h5t.pyx":570
 * 
 *     def __reduce__(self):
 *         with phil:             # <<<<<<<<<<<<<<
 *             return (type(self), (-1,), self.encode())
 * 
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_exit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 570, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 570, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "h5py/h5t.pyx":571
 *     def __reduce__(self):
 *         with phil:
 *             return (type(self), (-1,), self.encode())             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_encode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 571, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 571, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 571, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
          __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
          PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
          __Pyx_INCREF(__pyx_tuple__4);
          __Pyx_GIVEREF(__pyx_tuple__4);
          PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_tuple__4);
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_r = __pyx_t_3;
          __pyx_t_3 = 0;
          goto __pyx_L11_try_return;

          /* "h5py/h5t.pyx":570
 * 
 *     def __reduce__(self):
 *         with phil:             # <<<<<<<<<<<<<<
 *             return (type(self), (-1,), self.encode())
 * 
 */
        }
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("h5py.h5t.TypeID.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_4) < 0) __PYX_ERR(0, 570, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = PyTuple_Pack(3, __pyx_t_3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 570, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 570, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (__pyx_t_10 < 0) __PYX_ERR(0, 570, __pyx_L9_except_error)
          __pyx_t_11 = ((!(__pyx_t_10 != 0)) != 0);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_XGIVEREF(__pyx_t_4);
            __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_1, __pyx_t_4);
            __pyx_t_3 = 0; __pyx_t_1 = 0; __pyx_t_4 = 0; 
            __PYX_ERR(0, 570, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L11_try_return:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L4_return;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_2) {
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 570, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L4_return: {
        __pyx_t_8 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_2) {
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 570, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __pyx_r = __pyx_t_8;
        __pyx_t_8 = 0;
        goto __pyx_L0;
      }
      __pyx_L6:;
    }
    goto __pyx_L16;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L1_error;
    __pyx_L16:;
  }

  /* "h5py/h5t.pyx":569
 * 
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         with phil:
 *             return (type(self), (-1,), self.encode())
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("h5py.h5t.TypeID.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":574
 * 
 * 
 *     def __setstate__(self, char* state):             # <<<<<<<<<<<<<<
 *         with phil:
 *             self.id = H5Tdecode(<unsigned char*>state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_33__setstate__(PyObject *__pyx_v_self, PyObject *__pyx_arg_state); /*proto*/
static PyObject *__pyx_pw_4h5py_3h5t_6TypeID_33__setstate__(PyObject *__pyx_v_self, PyObject *__pyx_arg_state) {
  char *__pyx_v_state;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  assert(__pyx_arg_state); {
    __pyx_v_state = __Pyx_PyObject_AsWritableString(__pyx_arg_state); if (unlikely((!__pyx_v_state) && PyErr_Occurred())) __PYX_ERR(0, 574, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeID.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_6TypeID_32__setstate__(((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_v_self), ((char *)__pyx_v_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_6TypeID_32__setstate__(struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_self, char *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  hid_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 0);

  /* "h5py/h5t.pyx":575
 * 
 *     def __setstate__(self, char* state):
 *         with phil:             # <<<<<<<<<<<<<<
 *             self.id = H5Tdecode(<unsigned char*>state)
 * 
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_exit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 575, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 575, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "h5py/h5t.pyx":576
 *     def __setstate__(self, char* state):
 *         with phil:
 *             self.id = H5Tdecode(<unsigned char*>state)             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __pyx_t_9 = __pyx_f_4h5py_4defs_H5Tdecode(((unsigned char *)__pyx_v_state)); if (unlikely(__pyx_t_9 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 576, __pyx_L7_error)
          __pyx_v_self->__pyx_base.id = __pyx_t_9;

          /* "h5py/h5t.pyx":575
 * 
 *     def __setstate__(self, char* state):
 *         with phil:             # <<<<<<<<<<<<<<
 *             self.id = H5Tdecode(<unsigned char*>state)
 * 
 */
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L12_try_end;
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("h5py.h5t.TypeID.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 575, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 575, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 575, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (__pyx_t_11 < 0) __PYX_ERR(0, 575, __pyx_L9_except_error)
          __pyx_t_12 = ((!(__pyx_t_11 != 0)) != 0);
          if (__pyx_t_12) {
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_XGIVEREF(__pyx_t_4);
            __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_3, __pyx_t_4);
            __pyx_t_1 = 0; __pyx_t_3 = 0; __pyx_t_4 = 0; 
            __PYX_ERR(0, 575, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        __pyx_L12_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_2) {
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 575, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L6:;
    }
    goto __pyx_L16;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L1_error;
    __pyx_L16:;
  }

  /* "h5py/h5t.pyx":574
 * 
 * 
 *     def __setstate__(self, char* state):             # <<<<<<<<<<<<<<
 *         with phil:
 *             self.id = H5Tdecode(<unsigned char*>state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("h5py.h5t.TypeID.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":589
 * 
 *     @with_phil
 *     def get_array_ndims(self):             # <<<<<<<<<<<<<<
 *         """() => INT rank
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeArrayID_1get_array_ndims(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeArrayID_get_array_ndims[] = "() => INT rank\n\n        Get the rank of the given array datatype.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeArrayID_1get_array_ndims(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_array_ndims (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeArrayID_get_array_ndims(((struct __pyx_obj_4h5py_3h5t_TypeArrayID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeArrayID_get_array_ndims(struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_array_ndims", 0);

  /* "h5py/h5t.pyx":594
 *         Get the rank of the given array datatype.
 *         """
 *         return H5Tget_array_ndims(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_array_ndims(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((int)((int)-1L)))) __PYX_ERR(0, 594, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":589
 * 
 *     @with_phil
 *     def get_array_ndims(self):             # <<<<<<<<<<<<<<
 *         """() => INT rank
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeArrayID.get_array_ndims", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":598
 * 
 *     @with_phil
 *     def get_array_dims(self):             # <<<<<<<<<<<<<<
 *         """() => TUPLE dimensions
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeArrayID_3get_array_dims(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeArrayID_2get_array_dims[] = "() => TUPLE dimensions\n\n        Get the dimensions of the given array datatype as\n        a tuple of integers.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeArrayID_3get_array_dims(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_array_dims (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeArrayID_2get_array_dims(((struct __pyx_obj_4h5py_3h5t_TypeArrayID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeArrayID_2get_array_dims(struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_v_self) {
  hsize_t __pyx_v_rank;
  hsize_t *__pyx_v_dims;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  void *__pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  char const *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_array_dims", 0);

  /* "h5py/h5t.pyx":605
 *         """
 *         cdef hsize_t rank
 *         cdef hsize_t* dims = NULL             # <<<<<<<<<<<<<<
 * 
 *         rank = H5Tget_array_dims(self.id, NULL)
 */
  __pyx_v_dims = NULL;

  /* "h5py/h5t.pyx":607
 *         cdef hsize_t* dims = NULL
 * 
 *         rank = H5Tget_array_dims(self.id, NULL)             # <<<<<<<<<<<<<<
 *         dims = <hsize_t*>emalloc(sizeof(hsize_t)*rank)
 *         try:
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_array_dims(__pyx_v_self->__pyx_base.__pyx_base.id, NULL); if (unlikely(__pyx_t_1 == ((int)((int)-1L)))) __PYX_ERR(0, 607, __pyx_L1_error)
  __pyx_v_rank = __pyx_t_1;

  /* "h5py/h5t.pyx":608
 * 
 *         rank = H5Tget_array_dims(self.id, NULL)
 *         dims = <hsize_t*>emalloc(sizeof(hsize_t)*rank)             # <<<<<<<<<<<<<<
 *         try:
 *             H5Tget_array_dims(self.id, dims)
 */
  __pyx_t_2 = __pyx_f_4h5py_5utils_emalloc(((sizeof(hsize_t)) * __pyx_v_rank)); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 608, __pyx_L1_error)
  __pyx_v_dims = ((hsize_t *)__pyx_t_2);

  /* "h5py/h5t.pyx":609
 *         rank = H5Tget_array_dims(self.id, NULL)
 *         dims = <hsize_t*>emalloc(sizeof(hsize_t)*rank)
 *         try:             # <<<<<<<<<<<<<<
 *             H5Tget_array_dims(self.id, dims)
 *             return convert_dims(dims, rank)
 */
  /*try:*/ {

    /* "h5py/h5t.pyx":610
 *         dims = <hsize_t*>emalloc(sizeof(hsize_t)*rank)
 *         try:
 *             H5Tget_array_dims(self.id, dims)             # <<<<<<<<<<<<<<
 *             return convert_dims(dims, rank)
 *         finally:
 */
    __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_array_dims(__pyx_v_self->__pyx_base.__pyx_base.id, __pyx_v_dims); if (unlikely(__pyx_t_1 == ((int)((int)-1L)))) __PYX_ERR(0, 610, __pyx_L4_error)

    /* "h5py/h5t.pyx":611
 *         try:
 *             H5Tget_array_dims(self.id, dims)
 *             return convert_dims(dims, rank)             # <<<<<<<<<<<<<<
 *         finally:
 *             efree(dims)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4h5py_5utils_convert_dims(__pyx_v_dims, __pyx_v_rank); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 611, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3_return;
  }

  /* "h5py/h5t.pyx":613
 *             return convert_dims(dims, rank)
 *         finally:
 *             efree(dims)             # <<<<<<<<<<<<<<
 * 
 *     cdef object py_dtype(self):
 */
  /*finally:*/ {
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __pyx_t_1 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_5 = __pyx_filename;
      {
        __pyx_f_4h5py_5utils_efree(__pyx_v_dims);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      }
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      __pyx_lineno = __pyx_t_1; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_5;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_11 = __pyx_r;
      __pyx_r = 0;
      __pyx_f_4h5py_5utils_efree(__pyx_v_dims);
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;
    }
  }

  /* "h5py/h5t.pyx":598
 * 
 *     @with_phil
 *     def get_array_dims(self):             # <<<<<<<<<<<<<<
 *         """() => TUPLE dimensions
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t.TypeArrayID.get_array_dims", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":615
 *             efree(dims)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Numpy translation function for array types
 *         cdef TypeID tmp_type
 */

static PyObject *__pyx_f_4h5py_3h5t_11TypeArrayID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_v_self) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_tmp_type = 0;
  PyObject *__pyx_v_base_dtype = NULL;
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":618
 *         # Numpy translation function for array types
 *         cdef TypeID tmp_type
 *         tmp_type = self.get_super()             # <<<<<<<<<<<<<<
 * 
 *         base_dtype = tmp_type.py_dtype()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_super); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 618, __pyx_L1_error)
  __pyx_v_tmp_type = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":620
 *         tmp_type = self.get_super()
 * 
 *         base_dtype = tmp_type.py_dtype()             # <<<<<<<<<<<<<<
 * 
 *         shape = self.get_array_dims()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4h5py_3h5t_TypeID *)__pyx_v_tmp_type->__pyx_vtab)->py_dtype(__pyx_v_tmp_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_base_dtype = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":622
 *         base_dtype = tmp_type.py_dtype()
 * 
 *         shape = self.get_array_dims()             # <<<<<<<<<<<<<<
 *         return np.dtype( (base_dtype, shape) )
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_array_dims); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":623
 * 
 *         shape = self.get_array_dims()
 *         return np.dtype( (base_dtype, shape) )             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_base_dtype);
  __Pyx_GIVEREF(__pyx_v_base_dtype);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_base_dtype);
  __Pyx_INCREF(__pyx_v_shape);
  __Pyx_GIVEREF(__pyx_v_shape);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_shape);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":615
 *             efree(dims)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Numpy translation function for array types
 *         cdef TypeID tmp_type
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("h5py.h5t.TypeArrayID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tmp_type);
  __Pyx_XDECREF(__pyx_v_base_dtype);
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":634
 * 
 *     @with_phil
 *     def set_tag(self, char* tag):             # <<<<<<<<<<<<<<
 *         """(STRING tag)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeOpaqueID_1set_tag(PyObject *__pyx_v_self, PyObject *__pyx_arg_tag); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeOpaqueID_set_tag[] = "(STRING tag)\n\n        Set a string describing the contents of an opaque datatype.\n        Limited to 256 characters.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeOpaqueID_1set_tag(PyObject *__pyx_v_self, PyObject *__pyx_arg_tag) {
  char *__pyx_v_tag;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_tag (wrapper)", 0);
  assert(__pyx_arg_tag); {
    __pyx_v_tag = __Pyx_PyObject_AsWritableString(__pyx_arg_tag); if (unlikely((!__pyx_v_tag) && PyErr_Occurred())) __PYX_ERR(0, 634, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeOpaqueID.set_tag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeOpaqueID_set_tag(((struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *)__pyx_v_self), ((char *)__pyx_v_tag));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeOpaqueID_set_tag(struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_v_self, char *__pyx_v_tag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_tag", 0);

  /* "h5py/h5t.pyx":640
 *         Limited to 256 characters.
 *         """
 *         H5Tset_tag(self.id, tag)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_tag(__pyx_v_self->__pyx_base.__pyx_base.id, __pyx_v_tag); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 640, __pyx_L1_error)

  /* "h5py/h5t.pyx":634
 * 
 *     @with_phil
 *     def set_tag(self, char* tag):             # <<<<<<<<<<<<<<
 *         """(STRING tag)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeOpaqueID.set_tag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":644
 * 
 *     @with_phil
 *     def get_tag(self):             # <<<<<<<<<<<<<<
 *         """() => STRING tag
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeOpaqueID_3get_tag(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeOpaqueID_2get_tag[] = "() => STRING tag\n\n        Get the tag associated with an opaque datatype.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeOpaqueID_3get_tag(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_tag (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeOpaqueID_2get_tag(((struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeOpaqueID_2get_tag(struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_v_self) {
  char *__pyx_v_buf;
  char *__pyx_v_tag;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  char const *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  herr_t __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_tag", 0);

  /* "h5py/h5t.pyx":649
 *         Get the tag associated with an opaque datatype.
 *         """
 *         cdef char* buf = NULL             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_v_buf = NULL;

  /* "h5py/h5t.pyx":651
 *         cdef char* buf = NULL
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             buf = H5Tget_tag(self.id)
 *             assert buf != NULL
 */
  /*try:*/ {

    /* "h5py/h5t.pyx":652
 * 
 *         try:
 *             buf = H5Tget_tag(self.id)             # <<<<<<<<<<<<<<
 *             assert buf != NULL
 *             tag = buf
 */
    __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_tag(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((char *)((char *)NULL)))) __PYX_ERR(0, 652, __pyx_L4_error)
    __pyx_v_buf = __pyx_t_1;

    /* "h5py/h5t.pyx":653
 *         try:
 *             buf = H5Tget_tag(self.id)
 *             assert buf != NULL             # <<<<<<<<<<<<<<
 *             tag = buf
 *             return tag
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_buf != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 653, __pyx_L4_error)
      }
    }
    #endif

    /* "h5py/h5t.pyx":654
 *             buf = H5Tget_tag(self.id)
 *             assert buf != NULL
 *             tag = buf             # <<<<<<<<<<<<<<
 *             return tag
 *         finally:
 */
    __pyx_v_tag = __pyx_v_buf;

    /* "h5py/h5t.pyx":655
 *             assert buf != NULL
 *             tag = buf
 *             return tag             # <<<<<<<<<<<<<<
 *         finally:
 *             IF HDF5_VERSION >= (1, 8, 13):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_tag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 655, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3_return;
  }

  /* "h5py/h5t.pyx":658
 *         finally:
 *             IF HDF5_VERSION >= (1, 8, 13):
 *                 H5free_memory(buf)             # <<<<<<<<<<<<<<
 *             ELSE:
 *                 free(buf)
 */
  /*finally:*/ {
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __pyx_t_3 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_5 = __pyx_filename;
      {
        __pyx_t_12 = __pyx_f_4h5py_4defs_H5free_memory(__pyx_v_buf); if (unlikely(__pyx_t_12 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 658, __pyx_L7_error)
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      }
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      __pyx_lineno = __pyx_t_3; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_5;
      goto __pyx_L1_error;
      __pyx_L7_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_11 = __pyx_r;
      __pyx_r = 0;
      __pyx_t_12 = __pyx_f_4h5py_4defs_H5free_memory(__pyx_v_buf); if (unlikely(__pyx_t_12 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 658, __pyx_L1_error)
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;
    }
  }

  /* "h5py/h5t.pyx":644
 * 
 *     @with_phil
 *     def get_tag(self):             # <<<<<<<<<<<<<<
 *         """() => STRING tag
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeOpaqueID.get_tag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":662
 *                 free(buf)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         cdef bytes tag = self.get_tag()
 *         if tag.startswith(b"NUMPY:"):
 */

static PyObject *__pyx_f_4h5py_3h5t_12TypeOpaqueID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_v_self) {
  PyObject *__pyx_v_tag = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":663
 * 
 *     cdef object py_dtype(self):
 *         cdef bytes tag = self.get_tag()             # <<<<<<<<<<<<<<
 *         if tag.startswith(b"NUMPY:"):
 *             # 6 = len("NUMPY:")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_tag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(PyBytes_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 663, __pyx_L1_error)
  __pyx_v_tag = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":664
 *     cdef object py_dtype(self):
 *         cdef bytes tag = self.get_tag()
 *         if tag.startswith(b"NUMPY:"):             # <<<<<<<<<<<<<<
 *             # 6 = len("NUMPY:")
 *             return np.dtype(tag[6:], metadata={'h5py_opaque': True})
 */
  if (unlikely(__pyx_v_tag == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "startswith");
    __PYX_ERR(0, 664, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_Tailmatch(__pyx_v_tag, __pyx_kp_b_NUMPY, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 664, __pyx_L1_error)
  if ((__pyx_t_4 != 0)) {

    /* "h5py/h5t.pyx":666
 *         if tag.startswith(b"NUMPY:"):
 *             # 6 = len("NUMPY:")
 *             return np.dtype(tag[6:], metadata={'h5py_opaque': True})             # <<<<<<<<<<<<<<
 * 
 *         # Numpy translation function for opaque types
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__pyx_v_tag == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 666, __pyx_L1_error)
    }
    __pyx_t_1 = PySequence_GetSlice(__pyx_v_tag, 6, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_u_h5py_opaque, Py_True) < 0) __PYX_ERR(0, 666, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_metadata, __pyx_t_5) < 0) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":664
 *     cdef object py_dtype(self):
 *         cdef bytes tag = self.get_tag()
 *         if tag.startswith(b"NUMPY:"):             # <<<<<<<<<<<<<<
 *             # 6 = len("NUMPY:")
 *             return np.dtype(tag[6:], metadata={'h5py_opaque': True})
 */
  }

  /* "h5py/h5t.pyx":669
 * 
 *         # Numpy translation function for opaque types
 *         return np.dtype("|V" + str(self.get_size()))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_kp_u_V, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":662
 *                 free(buf)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         cdef bytes tag = self.get_tag()
 *         if tag.startswith(b"NUMPY:"):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("h5py.h5t.TypeOpaqueID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tag);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":680
 * 
 *     @with_phil
 *     def is_variable_str(self):             # <<<<<<<<<<<<<<
 *         """() => BOOL is_variable
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_1is_variable_str(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeStringID_is_variable_str[] = "() => BOOL is_variable\n\n        Determine if the given string datatype is a variable-length string.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_1is_variable_str(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_variable_str (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeStringID_is_variable_str(((struct __pyx_obj_4h5py_3h5t_TypeStringID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_is_variable_str(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  htri_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_variable_str", 0);

  /* "h5py/h5t.pyx":685
 *         Determine if the given string datatype is a variable-length string.
 *         """
 *         return <bint>(H5Tis_variable_str(self.id))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tis_variable_str(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((htri_t)((htri_t)-1L)))) __PYX_ERR(0, 685, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong((__pyx_t_1 != 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":680
 * 
 *     @with_phil
 *     def is_variable_str(self):             # <<<<<<<<<<<<<<
 *         """() => BOOL is_variable
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeStringID.is_variable_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":689
 * 
 *     @with_phil
 *     def get_cset(self):             # <<<<<<<<<<<<<<
 *         """() => INT character_set
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_3get_cset(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeStringID_2get_cset[] = "() => INT character_set\n\n        Retrieve the character set used for a string.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_3get_cset(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_cset (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeStringID_2get_cset(((struct __pyx_obj_4h5py_3h5t_TypeStringID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_2get_cset(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  H5T_cset_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_cset", 0);

  /* "h5py/h5t.pyx":694
 *         Retrieve the character set used for a string.
 *         """
 *         return <int>H5Tget_cset(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_cset(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((H5T_cset_t)((H5T_cset_t)-1L)))) __PYX_ERR(0, 694, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":689
 * 
 *     @with_phil
 *     def get_cset(self):             # <<<<<<<<<<<<<<
 *         """() => INT character_set
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeStringID.get_cset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":698
 * 
 *     @with_phil
 *     def set_cset(self, int cset):             # <<<<<<<<<<<<<<
 *         """(INT character_set)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_5set_cset(PyObject *__pyx_v_self, PyObject *__pyx_arg_cset); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeStringID_4set_cset[] = "(INT character_set)\n\n        Set the character set used for a string.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_5set_cset(PyObject *__pyx_v_self, PyObject *__pyx_arg_cset) {
  int __pyx_v_cset;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_cset (wrapper)", 0);
  assert(__pyx_arg_cset); {
    __pyx_v_cset = __Pyx_PyInt_As_int(__pyx_arg_cset); if (unlikely((__pyx_v_cset == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 698, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeStringID.set_cset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeStringID_4set_cset(((struct __pyx_obj_4h5py_3h5t_TypeStringID *)__pyx_v_self), ((int)__pyx_v_cset));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_4set_cset(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self, int __pyx_v_cset) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_cset", 0);

  /* "h5py/h5t.pyx":703
 *         Set the character set used for a string.
 *         """
 *         H5Tset_cset(self.id, <H5T_cset_t>cset)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_cset(__pyx_v_self->__pyx_base.__pyx_base.id, ((H5T_cset_t)__pyx_v_cset)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 703, __pyx_L1_error)

  /* "h5py/h5t.pyx":698
 * 
 *     @with_phil
 *     def set_cset(self, int cset):             # <<<<<<<<<<<<<<
 *         """(INT character_set)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeStringID.set_cset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":707
 * 
 *     @with_phil
 *     def get_strpad(self):             # <<<<<<<<<<<<<<
 *         """() => INT padding_type
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_7get_strpad(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeStringID_6get_strpad[] = "() => INT padding_type\n\n        Get the padding type.  Legal values are:\n\n        STR_NULLTERM\n            NULL termination only (C style)\n\n        STR_NULLPAD\n            Pad buffer with NULLs\n\n        STR_SPACEPAD\n            Pad buffer with spaces (FORTRAN style)\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_7get_strpad(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_strpad (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeStringID_6get_strpad(((struct __pyx_obj_4h5py_3h5t_TypeStringID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_6get_strpad(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  H5T_str_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_strpad", 0);

  /* "h5py/h5t.pyx":721
 *             Pad buffer with spaces (FORTRAN style)
 *         """
 *         return <int>H5Tget_strpad(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_strpad(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((H5T_str_t)((H5T_str_t)-1L)))) __PYX_ERR(0, 721, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":707
 * 
 *     @with_phil
 *     def get_strpad(self):             # <<<<<<<<<<<<<<
 *         """() => INT padding_type
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeStringID.get_strpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":725
 * 
 *     @with_phil
 *     def set_strpad(self, int pad):             # <<<<<<<<<<<<<<
 *         """(INT pad)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_9set_strpad(PyObject *__pyx_v_self, PyObject *__pyx_arg_pad); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeStringID_8set_strpad[] = "(INT pad)\n\n        Set the padding type.  Legal values are:\n\n        STR_NULLTERM\n            NULL termination only (C style)\n\n        STR_NULLPAD\n            Pad buffer with NULLs\n\n        STR_SPACEPAD\n            Pad buffer with spaces (FORTRAN style)\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeStringID_9set_strpad(PyObject *__pyx_v_self, PyObject *__pyx_arg_pad) {
  int __pyx_v_pad;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_strpad (wrapper)", 0);
  assert(__pyx_arg_pad); {
    __pyx_v_pad = __Pyx_PyInt_As_int(__pyx_arg_pad); if (unlikely((__pyx_v_pad == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 725, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeStringID.set_strpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeStringID_8set_strpad(((struct __pyx_obj_4h5py_3h5t_TypeStringID *)__pyx_v_self), ((int)__pyx_v_pad));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeStringID_8set_strpad(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self, int __pyx_v_pad) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_strpad", 0);

  /* "h5py/h5t.pyx":739
 *             Pad buffer with spaces (FORTRAN style)
 *         """
 *         H5Tset_strpad(self.id, <H5T_str_t>pad)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_strpad(__pyx_v_self->__pyx_base.__pyx_base.id, ((H5T_str_t)__pyx_v_pad)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 739, __pyx_L1_error)

  /* "h5py/h5t.pyx":725
 * 
 *     @with_phil
 *     def set_strpad(self, int pad):             # <<<<<<<<<<<<<<
 *         """(INT pad)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeStringID.set_strpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":742
 * 
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Numpy translation function for string types
 *         if self.get_cset() == H5T_CSET_ASCII:
 */

static PyObject *__pyx_f_4h5py_3h5t_12TypeStringID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_v_self) {
  PyObject *__pyx_v_encoding = NULL;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":744
 *     cdef object py_dtype(self):
 *         # Numpy translation function for string types
 *         if self.get_cset() == H5T_CSET_ASCII:             # <<<<<<<<<<<<<<
 *             encoding = 'ascii'
 *         elif self.get_cset() == H5T_CSET_UTF8:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_cset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_H5T_cset_t(H5T_CSET_ASCII); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "h5py/h5t.pyx":745
 *         # Numpy translation function for string types
 *         if self.get_cset() == H5T_CSET_ASCII:
 *             encoding = 'ascii'             # <<<<<<<<<<<<<<
 *         elif self.get_cset() == H5T_CSET_UTF8:
 *             encoding = 'utf-8'
 */
    __Pyx_INCREF(__pyx_n_u_ascii);
    __pyx_v_encoding = __pyx_n_u_ascii;

    /* "h5py/h5t.pyx":744
 *     cdef object py_dtype(self):
 *         # Numpy translation function for string types
 *         if self.get_cset() == H5T_CSET_ASCII:             # <<<<<<<<<<<<<<
 *             encoding = 'ascii'
 *         elif self.get_cset() == H5T_CSET_UTF8:
 */
    goto __pyx_L3;
  }

  /* "h5py/h5t.pyx":746
 *         if self.get_cset() == H5T_CSET_ASCII:
 *             encoding = 'ascii'
 *         elif self.get_cset() == H5T_CSET_UTF8:             # <<<<<<<<<<<<<<
 *             encoding = 'utf-8'
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_cset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_H5T_cset_t(H5T_CSET_UTF8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_3, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_4)) {

    /* "h5py/h5t.pyx":747
 *             encoding = 'ascii'
 *         elif self.get_cset() == H5T_CSET_UTF8:
 *             encoding = 'utf-8'             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError("Unknown string encoding (value %d)" % self.get_cset())
 */
    __Pyx_INCREF(__pyx_kp_u_utf_8);
    __pyx_v_encoding = __pyx_kp_u_utf_8;

    /* "h5py/h5t.pyx":746
 *         if self.get_cset() == H5T_CSET_ASCII:
 *             encoding = 'ascii'
 *         elif self.get_cset() == H5T_CSET_UTF8:             # <<<<<<<<<<<<<<
 *             encoding = 'utf-8'
 *         else:
 */
    goto __pyx_L3;
  }

  /* "h5py/h5t.pyx":749
 *             encoding = 'utf-8'
 *         else:
 *             raise TypeError("Unknown string encoding (value %d)" % self.get_cset())             # <<<<<<<<<<<<<<
 * 
 *         if self.is_variable_str():
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_cset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Unknown_string_encoding_value_d, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 749, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "h5py/h5t.pyx":751
 *             raise TypeError("Unknown string encoding (value %d)" % self.get_cset())
 * 
 *         if self.is_variable_str():             # <<<<<<<<<<<<<<
 *             length = None
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_variable_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "h5py/h5t.pyx":752
 * 
 *         if self.is_variable_str():
 *             length = None             # <<<<<<<<<<<<<<
 *         else:
 *             length = self.get_size()
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_length = Py_None;

    /* "h5py/h5t.pyx":751
 *             raise TypeError("Unknown string encoding (value %d)" % self.get_cset())
 * 
 *         if self.is_variable_str():             # <<<<<<<<<<<<<<
 *             length = None
 *         else:
 */
    goto __pyx_L4;
  }

  /* "h5py/h5t.pyx":754
 *             length = None
 *         else:
 *             length = self.get_size()             # <<<<<<<<<<<<<<
 * 
 *         return string_dtype(encoding=encoding, length=length)
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_length = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "h5py/h5t.pyx":756
 *             length = self.get_size()
 * 
 *         return string_dtype(encoding=encoding, length=length)             # <<<<<<<<<<<<<<
 * 
 * cdef class TypeVlenID(TypeID):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_string_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_encoding, __pyx_v_encoding) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_length, __pyx_v_length) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":742
 * 
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Numpy translation function for string types
 *         if self.get_cset() == H5T_CSET_ASCII:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t.TypeStringID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_encoding);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":764
 *     """
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 * 
 *         # get base type id
 */

static PyObject *__pyx_f_4h5py_3h5t_10TypeVlenID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeVlenID *__pyx_v_self) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_base_type = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":768
 *         # get base type id
 *         cdef TypeID base_type
 *         base_type = self.get_super()             # <<<<<<<<<<<<<<
 * 
 *         return vlen_dtype(base_type.dtype)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_super); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 768, __pyx_L1_error)
  __pyx_v_base_type = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":770
 *         base_type = self.get_super()
 * 
 *         return vlen_dtype(base_type.dtype)             # <<<<<<<<<<<<<<
 * 
 * cdef class TypeTimeID(TypeID):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_vlen_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_base_type), __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":764
 *     """
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 * 
 *         # get base type id
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("h5py.h5t.TypeVlenID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_base_type);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":786
 * 
 *     @with_phil
 *     def get_order(self):             # <<<<<<<<<<<<<<
 *         """() => INT order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_14TypeBitfieldID_1get_order(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_14TypeBitfieldID_get_order[] = "() => INT order\n\n        Obtain the byte order of the datatype; one of:\n\n        - ORDER_LE\n        - ORDER_BE\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_14TypeBitfieldID_1get_order(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_order (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_14TypeBitfieldID_get_order(((struct __pyx_obj_4h5py_3h5t_TypeBitfieldID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_14TypeBitfieldID_get_order(struct __pyx_obj_4h5py_3h5t_TypeBitfieldID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  H5T_order_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_order", 0);

  /* "h5py/h5t.pyx":794
 *         - ORDER_BE
 *         """
 *         return <int>H5Tget_order(self.id)             # <<<<<<<<<<<<<<
 * 
 *     cdef object py_dtype(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_order(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((H5T_order_t)((H5T_order_t)-1L)))) __PYX_ERR(0, 794, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":786
 * 
 *     @with_phil
 *     def get_order(self):             # <<<<<<<<<<<<<<
 *         """() => INT order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeBitfieldID.get_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":796
 *         return <int>H5Tget_order(self.id)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 * 
 *         # Translation function for bitfield types
 */

static PyObject *__pyx_f_4h5py_3h5t_14TypeBitfieldID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeBitfieldID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":799
 * 
 *         # Translation function for bitfield types
 *         return np.dtype( _order_map[self.get_order()] +             # <<<<<<<<<<<<<<
 *                          'u' + str(self.get_size()) )
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_v_4h5py_3h5t__order_map == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 799, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_order); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__order_map, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_n_u_u); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":800
 *         # Translation function for bitfield types
 *         return np.dtype( _order_map[self.get_order()] +
 *                          'u' + str(self.get_size()) )             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_size); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":796
 *         return <int>H5Tget_order(self.id)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 * 
 *         # Translation function for bitfield types
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("h5py.h5t.TypeBitfieldID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":809
 *     """
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         if H5Tequal(self.id, H5T_STD_REF_OBJ):
 *             return ref_dtype
 */

static PyObject *__pyx_f_4h5py_3h5t_15TypeReferenceID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeReferenceID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  htri_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":810
 * 
 *     cdef object py_dtype(self):
 *         if H5Tequal(self.id, H5T_STD_REF_OBJ):             # <<<<<<<<<<<<<<
 *             return ref_dtype
 *         elif H5Tequal(self.id, H5T_STD_REF_DSETREG):
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tequal(__pyx_v_self->__pyx_base.__pyx_base.id, H5T_STD_REF_OBJ); if (unlikely(__pyx_t_1 == ((htri_t)((htri_t)-1L)))) __PYX_ERR(0, 810, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":811
 *     cdef object py_dtype(self):
 *         if H5Tequal(self.id, H5T_STD_REF_OBJ):
 *             return ref_dtype             # <<<<<<<<<<<<<<
 *         elif H5Tequal(self.id, H5T_STD_REF_DSETREG):
 *             return regionref_dtype
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ref_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":810
 * 
 *     cdef object py_dtype(self):
 *         if H5Tequal(self.id, H5T_STD_REF_OBJ):             # <<<<<<<<<<<<<<
 *             return ref_dtype
 *         elif H5Tequal(self.id, H5T_STD_REF_DSETREG):
 */
  }

  /* "h5py/h5t.pyx":812
 *         if H5Tequal(self.id, H5T_STD_REF_OBJ):
 *             return ref_dtype
 *         elif H5Tequal(self.id, H5T_STD_REF_DSETREG):             # <<<<<<<<<<<<<<
 *             return regionref_dtype
 *         else:
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tequal(__pyx_v_self->__pyx_base.__pyx_base.id, H5T_STD_REF_DSETREG); if (unlikely(__pyx_t_1 == ((htri_t)((htri_t)-1L)))) __PYX_ERR(0, 812, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (likely(__pyx_t_2)) {

    /* "h5py/h5t.pyx":813
 *             return ref_dtype
 *         elif H5Tequal(self.id, H5T_STD_REF_DSETREG):
 *             return regionref_dtype             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError("Unknown reference type")
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_regionref_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":812
 *         if H5Tequal(self.id, H5T_STD_REF_OBJ):
 *             return ref_dtype
 *         elif H5Tequal(self.id, H5T_STD_REF_DSETREG):             # <<<<<<<<<<<<<<
 *             return regionref_dtype
 *         else:
 */
  }

  /* "h5py/h5t.pyx":815
 *             return regionref_dtype
 *         else:
 *             raise TypeError("Unknown reference type")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 815, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 815, __pyx_L1_error)
  }

  /* "h5py/h5t.pyx":809
 *     """
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         if H5Tequal(self.id, H5T_STD_REF_OBJ):
 *             return ref_dtype
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t.TypeReferenceID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":828
 * 
 *     @with_phil
 *     def get_order(self):             # <<<<<<<<<<<<<<
 *         """() => INT order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_1get_order(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeAtomicID_get_order[] = "() => INT order\n\n        Obtain the byte order of the datatype; one of:\n\n        - ORDER_LE\n        - ORDER_BE\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_1get_order(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_order (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeAtomicID_get_order(((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_get_order(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  H5T_order_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_order", 0);

  /* "h5py/h5t.pyx":836
 *         - ORDER_BE
 *         """
 *         return <int>H5Tget_order(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_order(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((H5T_order_t)((H5T_order_t)-1L)))) __PYX_ERR(0, 836, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":828
 * 
 *     @with_phil
 *     def get_order(self):             # <<<<<<<<<<<<<<
 *         """() => INT order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.get_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":840
 * 
 *     @with_phil
 *     def set_order(self, int order):             # <<<<<<<<<<<<<<
 *         """(INT order)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_3set_order(PyObject *__pyx_v_self, PyObject *__pyx_arg_order); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeAtomicID_2set_order[] = "(INT order)\n\n        Set the byte order of the datatype; one of:\n\n        - ORDER_LE\n        - ORDER_BE\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_3set_order(PyObject *__pyx_v_self, PyObject *__pyx_arg_order) {
  int __pyx_v_order;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_order (wrapper)", 0);
  assert(__pyx_arg_order); {
    __pyx_v_order = __Pyx_PyInt_As_int(__pyx_arg_order); if (unlikely((__pyx_v_order == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 840, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.set_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeAtomicID_2set_order(((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)__pyx_v_self), ((int)__pyx_v_order));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_2set_order(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self, int __pyx_v_order) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_order", 0);

  /* "h5py/h5t.pyx":848
 *         - ORDER_BE
 *         """
 *         H5Tset_order(self.id, <H5T_order_t>order)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_order(__pyx_v_self->__pyx_base.__pyx_base.id, ((H5T_order_t)__pyx_v_order)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 848, __pyx_L1_error)

  /* "h5py/h5t.pyx":840
 * 
 *     @with_phil
 *     def set_order(self, int order):             # <<<<<<<<<<<<<<
 *         """(INT order)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.set_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":852
 * 
 *     @with_phil
 *     def get_precision(self):             # <<<<<<<<<<<<<<
 *         """() => UINT precision
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_5get_precision(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeAtomicID_4get_precision[] = "() => UINT precision\n\n        Get the number of significant bits (excludes padding).\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_5get_precision(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_precision (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeAtomicID_4get_precision(((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_4get_precision(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hsize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_precision", 0);

  /* "h5py/h5t.pyx":857
 *         Get the number of significant bits (excludes padding).
 *         """
 *         return H5Tget_precision(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_precision(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((hsize_t)((hsize_t)0)))) __PYX_ERR(0, 857, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_hsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":852
 * 
 *     @with_phil
 *     def get_precision(self):             # <<<<<<<<<<<<<<
 *         """() => UINT precision
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.get_precision", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":861
 * 
 *     @with_phil
 *     def set_precision(self, size_t precision):             # <<<<<<<<<<<<<<
 *         """(UINT precision)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_7set_precision(PyObject *__pyx_v_self, PyObject *__pyx_arg_precision); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeAtomicID_6set_precision[] = "(UINT precision)\n\n        Set the number of significant bits (excludes padding).\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_7set_precision(PyObject *__pyx_v_self, PyObject *__pyx_arg_precision) {
  size_t __pyx_v_precision;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_precision (wrapper)", 0);
  assert(__pyx_arg_precision); {
    __pyx_v_precision = __Pyx_PyInt_As_size_t(__pyx_arg_precision); if (unlikely((__pyx_v_precision == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 861, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.set_precision", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeAtomicID_6set_precision(((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)__pyx_v_self), ((size_t)__pyx_v_precision));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_6set_precision(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self, size_t __pyx_v_precision) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_precision", 0);

  /* "h5py/h5t.pyx":866
 *         Set the number of significant bits (excludes padding).
 *         """
 *         H5Tset_precision(self.id, precision)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_precision(__pyx_v_self->__pyx_base.__pyx_base.id, __pyx_v_precision); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 866, __pyx_L1_error)

  /* "h5py/h5t.pyx":861
 * 
 *     @with_phil
 *     def set_precision(self, size_t precision):             # <<<<<<<<<<<<<<
 *         """(UINT precision)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.set_precision", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":870
 * 
 *     @with_phil
 *     def get_offset(self):             # <<<<<<<<<<<<<<
 *         """() => INT offset
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_9get_offset(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeAtomicID_8get_offset[] = "() => INT offset\n\n        Get the offset of the first significant bit.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_9get_offset(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_offset (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeAtomicID_8get_offset(((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_8get_offset(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_offset", 0);

  /* "h5py/h5t.pyx":875
 *         Get the offset of the first significant bit.
 *         """
 *         return H5Tget_offset(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_offset(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((int)((int)-1L)))) __PYX_ERR(0, 875, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":870
 * 
 *     @with_phil
 *     def get_offset(self):             # <<<<<<<<<<<<<<
 *         """() => INT offset
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.get_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":879
 * 
 *     @with_phil
 *     def set_offset(self, size_t offset):             # <<<<<<<<<<<<<<
 *         """(UINT offset)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_11set_offset(PyObject *__pyx_v_self, PyObject *__pyx_arg_offset); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeAtomicID_10set_offset[] = "(UINT offset)\n\n        Set the offset of the first significant bit.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_11set_offset(PyObject *__pyx_v_self, PyObject *__pyx_arg_offset) {
  size_t __pyx_v_offset;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_offset (wrapper)", 0);
  assert(__pyx_arg_offset); {
    __pyx_v_offset = __Pyx_PyInt_As_size_t(__pyx_arg_offset); if (unlikely((__pyx_v_offset == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 879, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.set_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeAtomicID_10set_offset(((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)__pyx_v_self), ((size_t)__pyx_v_offset));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_10set_offset(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self, size_t __pyx_v_offset) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_offset", 0);

  /* "h5py/h5t.pyx":884
 *         Set the offset of the first significant bit.
 *         """
 *         H5Tset_offset(self.id, offset)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_offset(__pyx_v_self->__pyx_base.__pyx_base.id, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 884, __pyx_L1_error)

  /* "h5py/h5t.pyx":879
 * 
 *     @with_phil
 *     def set_offset(self, size_t offset):             # <<<<<<<<<<<<<<
 *         """(UINT offset)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.set_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":888
 * 
 *     @with_phil
 *     def get_pad(self):             # <<<<<<<<<<<<<<
 *         """() => (INT lsb_pad_code, INT msb_pad_code)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_13get_pad(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeAtomicID_12get_pad[] = "() => (INT lsb_pad_code, INT msb_pad_code)\n\n        Determine the padding type.  Possible values are:\n\n        - PAD_ZERO\n        - PAD_ONE\n        - PAD_BACKGROUND\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_13get_pad(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pad (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeAtomicID_12get_pad(((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_12get_pad(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self) {
  H5T_pad_t __pyx_v_lsb;
  H5T_pad_t __pyx_v_msb;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pad", 0);

  /* "h5py/h5t.pyx":899
 *         cdef H5T_pad_t lsb
 *         cdef H5T_pad_t msb
 *         H5Tget_pad(self.id, &lsb, &msb)             # <<<<<<<<<<<<<<
 *         return (<int>lsb, <int>msb)
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_pad(__pyx_v_self->__pyx_base.__pyx_base.id, (&__pyx_v_lsb), (&__pyx_v_msb)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 899, __pyx_L1_error)

  /* "h5py/h5t.pyx":900
 *         cdef H5T_pad_t msb
 *         H5Tget_pad(self.id, &lsb, &msb)
 *         return (<int>lsb, <int>msb)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_v_lsb)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(((int)__pyx_v_msb)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":888
 * 
 *     @with_phil
 *     def get_pad(self):             # <<<<<<<<<<<<<<
 *         """() => (INT lsb_pad_code, INT msb_pad_code)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.get_pad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":904
 * 
 *     @with_phil
 *     def set_pad(self, int lsb, int msb):             # <<<<<<<<<<<<<<
 *         """(INT lsb_pad_code, INT msb_pad_code)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_15set_pad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_12TypeAtomicID_14set_pad[] = "(INT lsb_pad_code, INT msb_pad_code)\n\n        Set the padding type.  Possible values are:\n\n        - PAD_ZERO\n        - PAD_ONE\n        - PAD_BACKGROUND\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_12TypeAtomicID_15set_pad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_lsb;
  int __pyx_v_msb;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_pad (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_lsb,&__pyx_n_s_msb,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_lsb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_msb)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_pad", 1, 2, 2, 1); __PYX_ERR(0, 904, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_pad") < 0)) __PYX_ERR(0, 904, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_lsb = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_lsb == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 904, __pyx_L3_error)
    __pyx_v_msb = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_msb == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 904, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_pad", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 904, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.set_pad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_12TypeAtomicID_14set_pad(((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)__pyx_v_self), __pyx_v_lsb, __pyx_v_msb);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_12TypeAtomicID_14set_pad(struct __pyx_obj_4h5py_3h5t_TypeAtomicID *__pyx_v_self, int __pyx_v_lsb, int __pyx_v_msb) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_pad", 0);

  /* "h5py/h5t.pyx":913
 *         - PAD_BACKGROUND
 *         """
 *         H5Tset_pad(self.id, <H5T_pad_t>lsb, <H5T_pad_t>msb)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_pad(__pyx_v_self->__pyx_base.__pyx_base.id, ((H5T_pad_t)__pyx_v_lsb), ((H5T_pad_t)__pyx_v_msb)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 913, __pyx_L1_error)

  /* "h5py/h5t.pyx":904
 * 
 *     @with_phil
 *     def set_pad(self, int lsb, int msb):             # <<<<<<<<<<<<<<
 *         """(INT lsb_pad_code, INT msb_pad_code)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeAtomicID.set_pad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":924
 * 
 *     @with_phil
 *     def get_sign(self):             # <<<<<<<<<<<<<<
 *         """() => INT sign
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_13TypeIntegerID_1get_sign(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_13TypeIntegerID_get_sign[] = "() => INT sign\n\n        Get the \"signedness\" of the datatype; one of:\n\n        SGN_NONE\n            Unsigned\n\n        SGN_2\n            Signed 2's complement\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_13TypeIntegerID_1get_sign(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sign (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_13TypeIntegerID_get_sign(((struct __pyx_obj_4h5py_3h5t_TypeIntegerID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_13TypeIntegerID_get_sign(struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  H5T_sign_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sign", 0);

  /* "h5py/h5t.pyx":935
 *             Signed 2's complement
 *         """
 *         return <int>H5Tget_sign(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_sign(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((H5T_sign_t)((H5T_sign_t)-1L)))) __PYX_ERR(0, 935, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":924
 * 
 *     @with_phil
 *     def get_sign(self):             # <<<<<<<<<<<<<<
 *         """() => INT sign
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeIntegerID.get_sign", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":939
 * 
 *     @with_phil
 *     def set_sign(self, int sign):             # <<<<<<<<<<<<<<
 *         """(INT sign)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_13TypeIntegerID_3set_sign(PyObject *__pyx_v_self, PyObject *__pyx_arg_sign); /*proto*/
static char __pyx_doc_4h5py_3h5t_13TypeIntegerID_2set_sign[] = "(INT sign)\n\n        Set the \"signedness\" of the datatype; one of:\n\n        SGN_NONE\n            Unsigned\n\n        SGN_2\n            Signed 2's complement\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_13TypeIntegerID_3set_sign(PyObject *__pyx_v_self, PyObject *__pyx_arg_sign) {
  int __pyx_v_sign;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_sign (wrapper)", 0);
  assert(__pyx_arg_sign); {
    __pyx_v_sign = __Pyx_PyInt_As_int(__pyx_arg_sign); if (unlikely((__pyx_v_sign == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 939, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeIntegerID.set_sign", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_13TypeIntegerID_2set_sign(((struct __pyx_obj_4h5py_3h5t_TypeIntegerID *)__pyx_v_self), ((int)__pyx_v_sign));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_13TypeIntegerID_2set_sign(struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_v_self, int __pyx_v_sign) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_sign", 0);

  /* "h5py/h5t.pyx":950
 *             Signed 2's complement
 *         """
 *         H5Tset_sign(self.id, <H5T_sign_t>sign)             # <<<<<<<<<<<<<<
 * 
 *     cdef object py_dtype(self):
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_sign(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, ((H5T_sign_t)__pyx_v_sign)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 950, __pyx_L1_error)

  /* "h5py/h5t.pyx":939
 * 
 *     @with_phil
 *     def set_sign(self, int sign):             # <<<<<<<<<<<<<<
 *         """(INT sign)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeIntegerID.set_sign", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":952
 *         H5Tset_sign(self.id, <H5T_sign_t>sign)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Translation function for integer types
 *         return np.dtype( _order_map[self.get_order()] +
 */

static PyObject *__pyx_f_4h5py_3h5t_13TypeIntegerID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":954
 *     cdef object py_dtype(self):
 *         # Translation function for integer types
 *         return np.dtype( _order_map[self.get_order()] +             # <<<<<<<<<<<<<<
 *                          _sign_map[self.get_sign()] + str(self.get_size()) )
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_v_4h5py_3h5t__order_map == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 954, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_order); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__order_map, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":955
 *         # Translation function for integer types
 *         return np.dtype( _order_map[self.get_order()] +
 *                          _sign_map[self.get_sign()] + str(self.get_size()) )             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (unlikely(__pyx_v_4h5py_3h5t__sign_map == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 955, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_sign); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_2 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__sign_map, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":954
 *     cdef object py_dtype(self):
 *         # Translation function for integer types
 *         return np.dtype( _order_map[self.get_order()] +             # <<<<<<<<<<<<<<
 *                          _sign_map[self.get_sign()] + str(self.get_size()) )
 * 
 */
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "h5py/h5t.pyx":955
 *         # Translation function for integer types
 *         return np.dtype( _order_map[self.get_order()] +
 *                          _sign_map[self.get_sign()] + str(self.get_size()) )             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":952
 *         H5Tset_sign(self.id, <H5T_sign_t>sign)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Translation function for integer types
 *         return np.dtype( _order_map[self.get_order()] +
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("h5py.h5t.TypeIntegerID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":966
 * 
 *     @with_phil
 *     def get_fields(self):             # <<<<<<<<<<<<<<
 *         """() => TUPLE field_info
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_1get_fields(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeFloatID_get_fields[] = "() => TUPLE field_info\n\n        Get information about floating-point bit fields.  See the HDF5\n        docs for a full description.  Tuple has the following members:\n\n        0. UINT spos\n        1. UINT epos\n        2. UINT esize\n        3. UINT mpos\n        4. UINT msize\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_1get_fields(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_fields (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeFloatID_get_fields(((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_get_fields(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self) {
  size_t __pyx_v_spos;
  size_t __pyx_v_epos;
  size_t __pyx_v_esize;
  size_t __pyx_v_mpos;
  size_t __pyx_v_msize;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_fields", 0);

  /* "h5py/h5t.pyx":979
 *         """
 *         cdef size_t spos, epos, esize, mpos, msize
 *         H5Tget_fields(self.id, &spos, &epos, &esize, &mpos, &msize)             # <<<<<<<<<<<<<<
 *         return (spos, epos, esize, mpos, msize)
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_fields(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, (&__pyx_v_spos), (&__pyx_v_epos), (&__pyx_v_esize), (&__pyx_v_mpos), (&__pyx_v_msize)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 979, __pyx_L1_error)

  /* "h5py/h5t.pyx":980
 *         cdef size_t spos, epos, esize, mpos, msize
 *         H5Tget_fields(self.id, &spos, &epos, &esize, &mpos, &msize)
 *         return (spos, epos, esize, mpos, msize)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_spos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_epos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_esize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_FromSize_t(__pyx_v_mpos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyInt_FromSize_t(__pyx_v_msize); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 4, __pyx_t_6);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":966
 * 
 *     @with_phil
 *     def get_fields(self):             # <<<<<<<<<<<<<<
 *         """() => TUPLE field_info
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.get_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":984
 * 
 *     @with_phil
 *     def set_fields(self, size_t spos, size_t epos, size_t esize,             # <<<<<<<<<<<<<<
 *                           size_t mpos, size_t msize):
 *         """(UINT spos, UINT epos, UINT esize, UINT mpos, UINT msize)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_3set_fields(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeFloatID_2set_fields[] = "(UINT spos, UINT epos, UINT esize, UINT mpos, UINT msize)\n\n        Set floating-point bit fields.  Refer to the HDF5 docs for\n        argument definitions.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_3set_fields(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  size_t __pyx_v_spos;
  size_t __pyx_v_epos;
  size_t __pyx_v_esize;
  size_t __pyx_v_mpos;
  size_t __pyx_v_msize;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_fields (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_spos,&__pyx_n_s_epos,&__pyx_n_s_esize,&__pyx_n_s_mpos,&__pyx_n_s_msize,0};
    PyObject* values[5] = {0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_spos)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_epos)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_fields", 1, 5, 5, 1); __PYX_ERR(0, 984, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_esize)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_fields", 1, 5, 5, 2); __PYX_ERR(0, 984, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_mpos)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_fields", 1, 5, 5, 3); __PYX_ERR(0, 984, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_msize)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_fields", 1, 5, 5, 4); __PYX_ERR(0, 984, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_fields") < 0)) __PYX_ERR(0, 984, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 5) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
    }
    __pyx_v_spos = __Pyx_PyInt_As_size_t(values[0]); if (unlikely((__pyx_v_spos == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 984, __pyx_L3_error)
    __pyx_v_epos = __Pyx_PyInt_As_size_t(values[1]); if (unlikely((__pyx_v_epos == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 984, __pyx_L3_error)
    __pyx_v_esize = __Pyx_PyInt_As_size_t(values[2]); if (unlikely((__pyx_v_esize == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 984, __pyx_L3_error)
    __pyx_v_mpos = __Pyx_PyInt_As_size_t(values[3]); if (unlikely((__pyx_v_mpos == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 985, __pyx_L3_error)
    __pyx_v_msize = __Pyx_PyInt_As_size_t(values[4]); if (unlikely((__pyx_v_msize == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 985, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_fields", 1, 5, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 984, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.set_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeFloatID_2set_fields(((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_v_self), __pyx_v_spos, __pyx_v_epos, __pyx_v_esize, __pyx_v_mpos, __pyx_v_msize);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_2set_fields(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self, size_t __pyx_v_spos, size_t __pyx_v_epos, size_t __pyx_v_esize, size_t __pyx_v_mpos, size_t __pyx_v_msize) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_fields", 0);

  /* "h5py/h5t.pyx":991
 *         argument definitions.
 *         """
 *         H5Tset_fields(self.id, spos, epos, esize, mpos, msize)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_fields(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_spos, __pyx_v_epos, __pyx_v_esize, __pyx_v_mpos, __pyx_v_msize); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 991, __pyx_L1_error)

  /* "h5py/h5t.pyx":984
 * 
 *     @with_phil
 *     def set_fields(self, size_t spos, size_t epos, size_t esize,             # <<<<<<<<<<<<<<
 *                           size_t mpos, size_t msize):
 *         """(UINT spos, UINT epos, UINT esize, UINT mpos, UINT msize)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.set_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":995
 * 
 *     @with_phil
 *     def get_ebias(self):             # <<<<<<<<<<<<<<
 *         """() => UINT ebias
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_5get_ebias(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeFloatID_4get_ebias[] = "() => UINT ebias\n\n        Get the exponent bias.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_5get_ebias(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_ebias (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeFloatID_4get_ebias(((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_4get_ebias(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  size_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_ebias", 0);

  /* "h5py/h5t.pyx":1000
 *         Get the exponent bias.
 *         """
 *         return H5Tget_ebias(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_ebias(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((size_t)((size_t)0)))) __PYX_ERR(0, 1000, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":995
 * 
 *     @with_phil
 *     def get_ebias(self):             # <<<<<<<<<<<<<<
 *         """() => UINT ebias
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.get_ebias", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1004
 * 
 *     @with_phil
 *     def set_ebias(self, size_t ebias):             # <<<<<<<<<<<<<<
 *         """(UINT ebias)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_7set_ebias(PyObject *__pyx_v_self, PyObject *__pyx_arg_ebias); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeFloatID_6set_ebias[] = "(UINT ebias)\n\n        Set the exponent bias.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_7set_ebias(PyObject *__pyx_v_self, PyObject *__pyx_arg_ebias) {
  size_t __pyx_v_ebias;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_ebias (wrapper)", 0);
  assert(__pyx_arg_ebias); {
    __pyx_v_ebias = __Pyx_PyInt_As_size_t(__pyx_arg_ebias); if (unlikely((__pyx_v_ebias == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1004, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.set_ebias", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeFloatID_6set_ebias(((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_v_self), ((size_t)__pyx_v_ebias));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_6set_ebias(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self, size_t __pyx_v_ebias) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_ebias", 0);

  /* "h5py/h5t.pyx":1009
 *         Set the exponent bias.
 *         """
 *         H5Tset_ebias(self.id, ebias)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_ebias(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_ebias); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1009, __pyx_L1_error)

  /* "h5py/h5t.pyx":1004
 * 
 *     @with_phil
 *     def set_ebias(self, size_t ebias):             # <<<<<<<<<<<<<<
 *         """(UINT ebias)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.set_ebias", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1013
 * 
 *     @with_phil
 *     def get_norm(self):             # <<<<<<<<<<<<<<
 *         """() => INT normalization_code
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_9get_norm(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeFloatID_8get_norm[] = "() => INT normalization_code\n\n        Get the normalization strategy.  Legal values are:\n\n        - NORM_IMPLIED\n        - NORM_MSBSET\n        - NORM_NONE\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_9get_norm(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_norm (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeFloatID_8get_norm(((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_8get_norm(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  H5T_norm_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_norm", 0);

  /* "h5py/h5t.pyx":1022
 *         - NORM_NONE
 *         """
 *         return <int>H5Tget_norm(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_norm(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((H5T_norm_t)((H5T_norm_t)-1L)))) __PYX_ERR(0, 1022, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1013
 * 
 *     @with_phil
 *     def get_norm(self):             # <<<<<<<<<<<<<<
 *         """() => INT normalization_code
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.get_norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1026
 * 
 *     @with_phil
 *     def set_norm(self, int norm):             # <<<<<<<<<<<<<<
 *         """(INT normalization_code)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_11set_norm(PyObject *__pyx_v_self, PyObject *__pyx_arg_norm); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeFloatID_10set_norm[] = "(INT normalization_code)\n\n        Set the normalization strategy.  Legal values are:\n\n        - NORM_IMPLIED\n        - NORM_MSBSET\n        - NORM_NONE\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_11set_norm(PyObject *__pyx_v_self, PyObject *__pyx_arg_norm) {
  int __pyx_v_norm;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_norm (wrapper)", 0);
  assert(__pyx_arg_norm); {
    __pyx_v_norm = __Pyx_PyInt_As_int(__pyx_arg_norm); if (unlikely((__pyx_v_norm == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1026, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.set_norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeFloatID_10set_norm(((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_v_self), ((int)__pyx_v_norm));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_10set_norm(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self, int __pyx_v_norm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_norm", 0);

  /* "h5py/h5t.pyx":1035
 *         - NORM_NONE
 *         """
 *         H5Tset_norm(self.id, <H5T_norm_t>norm)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_norm(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, ((H5T_norm_t)__pyx_v_norm)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1035, __pyx_L1_error)

  /* "h5py/h5t.pyx":1026
 * 
 *     @with_phil
 *     def set_norm(self, int norm):             # <<<<<<<<<<<<<<
 *         """(INT normalization_code)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.set_norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1039
 * 
 *     @with_phil
 *     def get_inpad(self):             # <<<<<<<<<<<<<<
 *         """() => INT pad_code
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_13get_inpad(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeFloatID_12get_inpad[] = "() => INT pad_code\n\n        Determine the internal padding strategy.  Legal values are:\n\n        - PAD_ZERO\n        - PAD_ONE\n        - PAD_BACKGROUND\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_13get_inpad(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_inpad (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeFloatID_12get_inpad(((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_12get_inpad(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  H5T_pad_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_inpad", 0);

  /* "h5py/h5t.pyx":1048
 *         - PAD_BACKGROUND
 *         """
 *         return <int>H5Tget_inpad(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_inpad(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((H5T_pad_t)((H5T_pad_t)-1L)))) __PYX_ERR(0, 1048, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(((int)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1039
 * 
 *     @with_phil
 *     def get_inpad(self):             # <<<<<<<<<<<<<<
 *         """() => INT pad_code
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.get_inpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1052
 * 
 *     @with_phil
 *     def set_inpad(self, int pad_code):             # <<<<<<<<<<<<<<
 *         """(INT pad_code)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_15set_inpad(PyObject *__pyx_v_self, PyObject *__pyx_arg_pad_code); /*proto*/
static char __pyx_doc_4h5py_3h5t_11TypeFloatID_14set_inpad[] = "(INT pad_code)\n\n        Set the internal padding strategy.  Legal values are:\n\n        - PAD_ZERO\n        - PAD_ONE\n        - PAD_BACKGROUND\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_11TypeFloatID_15set_inpad(PyObject *__pyx_v_self, PyObject *__pyx_arg_pad_code) {
  int __pyx_v_pad_code;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_inpad (wrapper)", 0);
  assert(__pyx_arg_pad_code); {
    __pyx_v_pad_code = __Pyx_PyInt_As_int(__pyx_arg_pad_code); if (unlikely((__pyx_v_pad_code == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1052, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.set_inpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_11TypeFloatID_14set_inpad(((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_v_self), ((int)__pyx_v_pad_code));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_11TypeFloatID_14set_inpad(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self, int __pyx_v_pad_code) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_inpad", 0);

  /* "h5py/h5t.pyx":1061
 *         - PAD_BACKGROUND
 *         """
 *         H5Tset_inpad(self.id, <H5T_pad_t>pad_code)             # <<<<<<<<<<<<<<
 * 
 *     cdef object py_dtype(self):
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tset_inpad(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, ((H5T_pad_t)__pyx_v_pad_code)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1061, __pyx_L1_error)

  /* "h5py/h5t.pyx":1052
 * 
 *     @with_phil
 *     def set_inpad(self, int pad_code):             # <<<<<<<<<<<<<<
 *         """(INT pad_code)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.set_inpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1063
 *         H5Tset_inpad(self.id, <H5T_pad_t>pad_code)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Translation function for floating-point types
 * 
 */

static PyObject *__pyx_f_4h5py_3h5t_11TypeFloatID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_self) {
  PyObject *__pyx_v_order = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_s_offset = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_e_offset = NULL;
  PyObject *__pyx_v_e_size = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_m_offset = NULL;
  PyObject *__pyx_v_m_size = NULL;
  PyObject *__pyx_v_e_bias = NULL;
  PyObject *__pyx_v_ftype_ = NULL;
  PyObject *__pyx_v_finfo = NULL;
  PyObject *__pyx_v_size = NULL;
  int __pyx_v_nmant;
  int __pyx_v_maxexp;
  int __pyx_v_minexp;
  PyObject *__pyx_v_new_dtype = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  Py_ssize_t __pyx_t_9;
  __pyx_ctuple_int__and_int__and_int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":1066
 *         # Translation function for floating-point types
 * 
 *         order = _order_map[self.get_order()]    # string with '<' or '>'             # <<<<<<<<<<<<<<
 * 
 *         s_offset, e_offset, e_size, m_offset, m_size = self.get_fields()
 */
  if (unlikely(__pyx_v_4h5py_3h5t__order_map == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1066, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_order); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__order_map, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_order = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1068
 *         order = _order_map[self.get_order()]    # string with '<' or '>'
 * 
 *         s_offset, e_offset, e_size, m_offset, m_size = self.get_fields()             # <<<<<<<<<<<<<<
 *         e_bias = self.get_ebias()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_fields); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 5)) {
      if (size > 5) __Pyx_RaiseTooManyValuesError(5);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1068, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 3); 
      __pyx_t_6 = PyTuple_GET_ITEM(sequence, 4); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 2); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 3); 
      __pyx_t_6 = PyList_GET_ITEM(sequence, 4); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_6);
    #else
    {
      Py_ssize_t i;
      PyObject** temps[5] = {&__pyx_t_1,&__pyx_t_3,&__pyx_t_4,&__pyx_t_5,&__pyx_t_6};
      for (i=0; i < 5; i++) {
        PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 1068, __pyx_L1_error)
        __Pyx_GOTREF(item);
        *(temps[i]) = item;
      }
    }
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    PyObject** temps[5] = {&__pyx_t_1,&__pyx_t_3,&__pyx_t_4,&__pyx_t_5,&__pyx_t_6};
    __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
    for (index=0; index < 5; index++) {
      PyObject* item = __pyx_t_8(__pyx_t_7); if (unlikely(!item)) goto __pyx_L3_unpacking_failed;
      __Pyx_GOTREF(item);
      *(temps[index]) = item;
    }
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 5) < 0) __PYX_ERR(0, 1068, __pyx_L1_error)
    __pyx_t_8 = NULL;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1068, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_s_offset = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_e_offset = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_e_size = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_m_offset = __pyx_t_5;
  __pyx_t_5 = 0;
  __pyx_v_m_size = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "h5py/h5t.pyx":1069
 * 
 *         s_offset, e_offset, e_size, m_offset, m_size = self.get_fields()
 *         e_bias = self.get_ebias()             # <<<<<<<<<<<<<<
 * 
 *         # Handle non-standard exponent and mantissa sizes.
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_ebias); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_e_bias = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1072
 * 
 *         # Handle non-standard exponent and mantissa sizes.
 *         for ftype_, finfo, size in _available_ftypes:             # <<<<<<<<<<<<<<
 *             nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *             if (size >= self.get_size() and m_size <= nmant and
 */
  if (unlikely(__pyx_v_4h5py_3h5t__available_ftypes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1072, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_v_4h5py_3h5t__available_ftypes; __Pyx_INCREF(__pyx_t_2); __pyx_t_9 = 0;
  for (;;) {
    if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_6); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 1072, __pyx_L1_error)
    #else
    __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1072, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
      PyObject* sequence = __pyx_t_6;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1072, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1072, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1072, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1072, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_1 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1072, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_1)->tp_iternext;
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_4)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 2; __pyx_t_3 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_1), 3) < 0) __PYX_ERR(0, 1072, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L8_unpacking_done;
      __pyx_L7_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1072, __pyx_L1_error)
      __pyx_L8_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_ftype_, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_finfo, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_size, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "h5py/h5t.pyx":1073
 *         # Handle non-standard exponent and mantissa sizes.
 *         for ftype_, finfo, size in _available_ftypes:
 *             nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)             # <<<<<<<<<<<<<<
 *             if (size >= self.get_size() and m_size <= nmant and
 *                 (2**e_size - e_bias - 1) <= maxexp and (1 - e_bias) >= minexp):
 */
    __pyx_t_10 = __pyx_f_4h5py_3h5t__correct_float_info(__pyx_v_ftype_, __pyx_v_finfo);
    __pyx_t_11 = __pyx_t_10.f0;
    __pyx_t_12 = __pyx_t_10.f1;
    __pyx_t_13 = __pyx_t_10.f2;
    __pyx_v_nmant = __pyx_t_11;
    __pyx_v_maxexp = __pyx_t_12;
    __pyx_v_minexp = __pyx_t_13;

    /* "h5py/h5t.pyx":1074
 *         for ftype_, finfo, size in _available_ftypes:
 *             nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *             if (size >= self.get_size() and m_size <= nmant and             # <<<<<<<<<<<<<<
 *                 (2**e_size - e_bias - 1) <= maxexp and (1 - e_bias) >= minexp):
 *                 new_dtype = np.dtype(ftype_).newbyteorder(order)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_size, __pyx_t_6, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_15) {
    } else {
      __pyx_t_14 = __pyx_t_15;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_nmant); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyObject_RichCompare(__pyx_v_m_size, __pyx_t_3, Py_LE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_15) {
    } else {
      __pyx_t_14 = __pyx_t_15;
      goto __pyx_L10_bool_binop_done;
    }

    /* "h5py/h5t.pyx":1075
 *             nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *             if (size >= self.get_size() and m_size <= nmant and
 *                 (2**e_size - e_bias - 1) <= maxexp and (1 - e_bias) >= minexp):             # <<<<<<<<<<<<<<
 *                 new_dtype = np.dtype(ftype_).newbyteorder(order)
 *                 break
 */
    __pyx_t_6 = __Pyx_PyNumber_PowerOf2(__pyx_int_2, __pyx_v_e_size, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = PyNumber_Subtract(__pyx_t_6, __pyx_v_e_bias); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_maxexp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_6, __pyx_t_3, Py_LE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_15) {
    } else {
      __pyx_t_14 = __pyx_t_15;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyInt_SubtractCObj(__pyx_int_1, __pyx_v_e_bias, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_minexp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_t_3, Py_GE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 1075, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_14 = __pyx_t_15;
    __pyx_L10_bool_binop_done:;

    /* "h5py/h5t.pyx":1074
 *         for ftype_, finfo, size in _available_ftypes:
 *             nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *             if (size >= self.get_size() and m_size <= nmant and             # <<<<<<<<<<<<<<
 *                 (2**e_size - e_bias - 1) <= maxexp and (1 - e_bias) >= minexp):
 *                 new_dtype = np.dtype(ftype_).newbyteorder(order)
 */
    if (__pyx_t_14) {

      /* "h5py/h5t.pyx":1076
 *             if (size >= self.get_size() and m_size <= nmant and
 *                 (2**e_size - e_bias - 1) <= maxexp and (1 - e_bias) >= minexp):
 *                 new_dtype = np.dtype(ftype_).newbyteorder(order)             # <<<<<<<<<<<<<<
 *                 break
 *         else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1076, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1076, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_v_ftype_) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_ftype_);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1076, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_newbyteorder); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1076, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_6 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_3, __pyx_v_order) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_order);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1076, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_new_dtype = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "h5py/h5t.pyx":1077
 *                 (2**e_size - e_bias - 1) <= maxexp and (1 - e_bias) >= minexp):
 *                 new_dtype = np.dtype(ftype_).newbyteorder(order)
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError('Insufficient precision in available types to ' +
 */
      goto __pyx_L6_break;

      /* "h5py/h5t.pyx":1074
 *         for ftype_, finfo, size in _available_ftypes:
 *             nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *             if (size >= self.get_size() and m_size <= nmant and             # <<<<<<<<<<<<<<
 *                 (2**e_size - e_bias - 1) <= maxexp and (1 - e_bias) >= minexp):
 *                 new_dtype = np.dtype(ftype_).newbyteorder(order)
 */
    }

    /* "h5py/h5t.pyx":1072
 * 
 *         # Handle non-standard exponent and mantissa sizes.
 *         for ftype_, finfo, size in _available_ftypes:             # <<<<<<<<<<<<<<
 *             nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *             if (size >= self.get_size() and m_size <= nmant and
 */
  }
  /*else*/ {

    /* "h5py/h5t.pyx":1080
 *         else:
 *             raise ValueError('Insufficient precision in available types to ' +
 *                              'represent ' + str(self.get_fields()))             # <<<<<<<<<<<<<<
 * 
 *         return new_dtype
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_fields); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_6 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Insufficient_precision_in_availa, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "h5py/h5t.pyx":1079
 *                 break
 *         else:
 *             raise ValueError('Insufficient precision in available types to ' +             # <<<<<<<<<<<<<<
 *                              'represent ' + str(self.get_fields()))
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1079, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 1079, __pyx_L1_error)
  }

  /* "h5py/h5t.pyx":1072
 * 
 *         # Handle non-standard exponent and mantissa sizes.
 *         for ftype_, finfo, size in _available_ftypes:             # <<<<<<<<<<<<<<
 *             nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *             if (size >= self.get_size() and m_size <= nmant and
 */
  __pyx_L6_break:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1082
 *                              'represent ' + str(self.get_fields()))
 * 
 *         return new_dtype             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_new_dtype);
  __pyx_r = __pyx_v_new_dtype;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1063
 *         H5Tset_inpad(self.id, <H5T_pad_t>pad_code)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Translation function for floating-point types
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t.TypeFloatID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_order);
  __Pyx_XDECREF(__pyx_v_s_offset);
  __Pyx_XDECREF(__pyx_v_e_offset);
  __Pyx_XDECREF(__pyx_v_e_size);
  __Pyx_XDECREF(__pyx_v_m_offset);
  __Pyx_XDECREF(__pyx_v_m_size);
  __Pyx_XDECREF(__pyx_v_e_bias);
  __Pyx_XDECREF(__pyx_v_ftype_);
  __Pyx_XDECREF(__pyx_v_finfo);
  __Pyx_XDECREF(__pyx_v_size);
  __Pyx_XDECREF(__pyx_v_new_dtype);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1095
 * 
 *     @with_phil
 *     def get_nmembers(self):             # <<<<<<<<<<<<<<
 *         """() => INT number_of_members
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_15TypeCompositeID_1get_nmembers(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_15TypeCompositeID_get_nmembers[] = "() => INT number_of_members\n\n        Determine the number of members in a compound or enumerated type.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_15TypeCompositeID_1get_nmembers(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_nmembers (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_15TypeCompositeID_get_nmembers(((struct __pyx_obj_4h5py_3h5t_TypeCompositeID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_15TypeCompositeID_get_nmembers(struct __pyx_obj_4h5py_3h5t_TypeCompositeID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_nmembers", 0);

  /* "h5py/h5t.pyx":1100
 *         Determine the number of members in a compound or enumerated type.
 *         """
 *         return H5Tget_nmembers(self.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_nmembers(__pyx_v_self->__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((int)((int)-1L)))) __PYX_ERR(0, 1100, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1095
 * 
 *     @with_phil
 *     def get_nmembers(self):             # <<<<<<<<<<<<<<
 *         """() => INT number_of_members
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeCompositeID.get_nmembers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1104
 * 
 *     @with_phil
 *     def get_member_name(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => STRING name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_15TypeCompositeID_3get_member_name(PyObject *__pyx_v_self, PyObject *__pyx_arg_member); /*proto*/
static char __pyx_doc_4h5py_3h5t_15TypeCompositeID_2get_member_name[] = "(INT member) => STRING name\n\n        Determine the name of a member of a compound or enumerated type,\n        identified by its index (0 <= member < nmembers).\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_15TypeCompositeID_3get_member_name(PyObject *__pyx_v_self, PyObject *__pyx_arg_member) {
  int __pyx_v_member;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_member_name (wrapper)", 0);
  assert(__pyx_arg_member); {
    __pyx_v_member = __Pyx_PyInt_As_int(__pyx_arg_member); if (unlikely((__pyx_v_member == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1104, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeCompositeID.get_member_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_15TypeCompositeID_2get_member_name(((struct __pyx_obj_4h5py_3h5t_TypeCompositeID *)__pyx_v_self), ((int)__pyx_v_member));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_15TypeCompositeID_2get_member_name(struct __pyx_obj_4h5py_3h5t_TypeCompositeID *__pyx_v_self, int __pyx_v_member) {
  char *__pyx_v_name;
  PyObject *__pyx_v_pyname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  herr_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_member_name", 0);

  /* "h5py/h5t.pyx":1111
 *         """
 *         cdef char* name
 *         name = NULL             # <<<<<<<<<<<<<<
 * 
 *         if member < 0:
 */
  __pyx_v_name = NULL;

  /* "h5py/h5t.pyx":1113
 *         name = NULL
 * 
 *         if member < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Member index must be non-negative.")
 * 
 */
  __pyx_t_1 = ((__pyx_v_member < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "h5py/h5t.pyx":1114
 * 
 *         if member < 0:
 *             raise ValueError("Member index must be non-negative.")             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1114, __pyx_L1_error)

    /* "h5py/h5t.pyx":1113
 *         name = NULL
 * 
 *         if member < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Member index must be non-negative.")
 * 
 */
  }

  /* "h5py/h5t.pyx":1116
 *             raise ValueError("Member index must be non-negative.")
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             name = H5Tget_member_name(self.id, member)
 *             assert name != NULL
 */
  /*try:*/ {

    /* "h5py/h5t.pyx":1117
 * 
 *         try:
 *             name = H5Tget_member_name(self.id, member)             # <<<<<<<<<<<<<<
 *             assert name != NULL
 *             pyname = <bytes>name
 */
    __pyx_t_3 = __pyx_f_4h5py_4defs_H5Tget_member_name(__pyx_v_self->__pyx_base.__pyx_base.id, __pyx_v_member); if (unlikely(__pyx_t_3 == ((char *)((char *)NULL)))) __PYX_ERR(0, 1117, __pyx_L5_error)
    __pyx_v_name = __pyx_t_3;

    /* "h5py/h5t.pyx":1118
 *         try:
 *             name = H5Tget_member_name(self.id, member)
 *             assert name != NULL             # <<<<<<<<<<<<<<
 *             pyname = <bytes>name
 *         finally:
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_name != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 1118, __pyx_L5_error)
      }
    }
    #endif

    /* "h5py/h5t.pyx":1119
 *             name = H5Tget_member_name(self.id, member)
 *             assert name != NULL
 *             pyname = <bytes>name             # <<<<<<<<<<<<<<
 *         finally:
 *             IF HDF5_VERSION >= (1, 8, 13):
 */
    __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1119, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __pyx_t_2;
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_pyname = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
  }

  /* "h5py/h5t.pyx":1122
 *         finally:
 *             IF HDF5_VERSION >= (1, 8, 13):
 *                 H5free_memory(name)             # <<<<<<<<<<<<<<
 *             ELSE:
 *                 free(name)
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_5 = __pyx_f_4h5py_4defs_H5free_memory(__pyx_v_name); if (unlikely(__pyx_t_5 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1122, __pyx_L1_error)
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
      {
        __pyx_t_5 = __pyx_f_4h5py_4defs_H5free_memory(__pyx_v_name); if (unlikely(__pyx_t_5 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1122, __pyx_L8_error)
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "h5py/h5t.pyx":1126
 *                 free(name)
 * 
 *         return pyname             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pyname);
  __pyx_r = __pyx_v_pyname;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1104
 * 
 *     @with_phil
 *     def get_member_name(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => STRING name
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("h5py.h5t.TypeCompositeID.get_member_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pyname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1130
 * 
 *     @with_phil
 *     def get_member_index(self, char* name):             # <<<<<<<<<<<<<<
 *         """(STRING name) => INT index
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_15TypeCompositeID_5get_member_index(PyObject *__pyx_v_self, PyObject *__pyx_arg_name); /*proto*/
static char __pyx_doc_4h5py_3h5t_15TypeCompositeID_4get_member_index[] = "(STRING name) => INT index\n\n        Determine the index of a member of a compound or enumerated datatype\n        identified by a string name.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_15TypeCompositeID_5get_member_index(PyObject *__pyx_v_self, PyObject *__pyx_arg_name) {
  char *__pyx_v_name;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_member_index (wrapper)", 0);
  assert(__pyx_arg_name); {
    __pyx_v_name = __Pyx_PyObject_AsWritableString(__pyx_arg_name); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) __PYX_ERR(0, 1130, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeCompositeID.get_member_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_15TypeCompositeID_4get_member_index(((struct __pyx_obj_4h5py_3h5t_TypeCompositeID *)__pyx_v_self), ((char *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_15TypeCompositeID_4get_member_index(struct __pyx_obj_4h5py_3h5t_TypeCompositeID *__pyx_v_self, char *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_member_index", 0);

  /* "h5py/h5t.pyx":1136
 *         identified by a string name.
 *         """
 *         return H5Tget_member_index(self.id, name)             # <<<<<<<<<<<<<<
 * 
 * cdef class TypeCompoundID(TypeCompositeID):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_member_index(__pyx_v_self->__pyx_base.__pyx_base.id, __pyx_v_name); if (unlikely(__pyx_t_1 == ((int)((int)-1L)))) __PYX_ERR(0, 1136, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1130
 * 
 *     @with_phil
 *     def get_member_index(self, char* name):             # <<<<<<<<<<<<<<
 *         """(STRING name) => INT index
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeCompositeID.get_member_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1146
 * 
 *     @with_phil
 *     def get_member_class(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => INT class
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_1get_member_class(PyObject *__pyx_v_self, PyObject *__pyx_arg_member); /*proto*/
static char __pyx_doc_4h5py_3h5t_14TypeCompoundID_get_member_class[] = "(INT member) => INT class\n\n        Determine the datatype class of the member of a compound type,\n        identified by its index (0 <= member < nmembers).\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_1get_member_class(PyObject *__pyx_v_self, PyObject *__pyx_arg_member) {
  int __pyx_v_member;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_member_class (wrapper)", 0);
  assert(__pyx_arg_member); {
    __pyx_v_member = __Pyx_PyInt_As_int(__pyx_arg_member); if (unlikely((__pyx_v_member == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1146, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.get_member_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_14TypeCompoundID_get_member_class(((struct __pyx_obj_4h5py_3h5t_TypeCompoundID *)__pyx_v_self), ((int)__pyx_v_member));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_get_member_class(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self, int __pyx_v_member) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  enum H5T_class_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_member_class", 0);

  /* "h5py/h5t.pyx":1152
 *         identified by its index (0 <= member < nmembers).
 *         """
 *         if member < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Member index must be non-negative.")
 *         return H5Tget_member_class(self.id, member)
 */
  __pyx_t_1 = ((__pyx_v_member < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "h5py/h5t.pyx":1153
 *         """
 *         if member < 0:
 *             raise ValueError("Member index must be non-negative.")             # <<<<<<<<<<<<<<
 *         return H5Tget_member_class(self.id, member)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1153, __pyx_L1_error)

    /* "h5py/h5t.pyx":1152
 *         identified by its index (0 <= member < nmembers).
 *         """
 *         if member < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Member index must be non-negative.")
 *         return H5Tget_member_class(self.id, member)
 */
  }

  /* "h5py/h5t.pyx":1154
 *         if member < 0:
 *             raise ValueError("Member index must be non-negative.")
 *         return H5Tget_member_class(self.id, member)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_f_4h5py_4defs_H5Tget_member_class(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_member); if (unlikely(__pyx_t_3 == ((enum H5T_class_t)((enum H5T_class_t)-1L)))) __PYX_ERR(0, 1154, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_enum__H5T_class_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1146
 * 
 *     @with_phil
 *     def get_member_class(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => INT class
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.get_member_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1158
 * 
 *     @with_phil
 *     def get_member_offset(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => INT offset
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_3get_member_offset(PyObject *__pyx_v_self, PyObject *__pyx_arg_member); /*proto*/
static char __pyx_doc_4h5py_3h5t_14TypeCompoundID_2get_member_offset[] = "(INT member) => INT offset\n\n        Determine the offset, in bytes, of the beginning of the specified\n        member of a compound datatype.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_3get_member_offset(PyObject *__pyx_v_self, PyObject *__pyx_arg_member) {
  int __pyx_v_member;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_member_offset (wrapper)", 0);
  assert(__pyx_arg_member); {
    __pyx_v_member = __Pyx_PyInt_As_int(__pyx_arg_member); if (unlikely((__pyx_v_member == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1158, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.get_member_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_14TypeCompoundID_2get_member_offset(((struct __pyx_obj_4h5py_3h5t_TypeCompoundID *)__pyx_v_self), ((int)__pyx_v_member));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_2get_member_offset(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self, int __pyx_v_member) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_member_offset", 0);

  /* "h5py/h5t.pyx":1164
 *         member of a compound datatype.
 *         """
 *         if member < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Member index must be non-negative.")
 *         return H5Tget_member_offset(self.id, member)
 */
  __pyx_t_1 = ((__pyx_v_member < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "h5py/h5t.pyx":1165
 *         """
 *         if member < 0:
 *             raise ValueError("Member index must be non-negative.")             # <<<<<<<<<<<<<<
 *         return H5Tget_member_offset(self.id, member)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1165, __pyx_L1_error)

    /* "h5py/h5t.pyx":1164
 *         member of a compound datatype.
 *         """
 *         if member < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Member index must be non-negative.")
 *         return H5Tget_member_offset(self.id, member)
 */
  }

  /* "h5py/h5t.pyx":1166
 *         if member < 0:
 *             raise ValueError("Member index must be non-negative.")
 *         return H5Tget_member_offset(self.id, member)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_f_4h5py_4defs_H5Tget_member_offset(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_member); if (unlikely(__pyx_t_3 == ((int)((int)-1L)))) __PYX_ERR(0, 1166, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1158
 * 
 *     @with_phil
 *     def get_member_offset(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => INT offset
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.get_member_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1170
 * 
 *     @with_phil
 *     def get_member_type(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => TypeID
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_5get_member_type(PyObject *__pyx_v_self, PyObject *__pyx_arg_member); /*proto*/
static char __pyx_doc_4h5py_3h5t_14TypeCompoundID_4get_member_type[] = "(INT member) => TypeID\n\n        Create a copy of a member of a compound datatype, identified by its\n        index.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_5get_member_type(PyObject *__pyx_v_self, PyObject *__pyx_arg_member) {
  int __pyx_v_member;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_member_type (wrapper)", 0);
  assert(__pyx_arg_member); {
    __pyx_v_member = __Pyx_PyInt_As_int(__pyx_arg_member); if (unlikely((__pyx_v_member == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1170, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.get_member_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_14TypeCompoundID_4get_member_type(((struct __pyx_obj_4h5py_3h5t_TypeCompoundID *)__pyx_v_self), ((int)__pyx_v_member));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_4get_member_type(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self, int __pyx_v_member) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  hid_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_member_type", 0);

  /* "h5py/h5t.pyx":1176
 *         index.
 *         """
 *         if member < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Member index must be non-negative.")
 *         return typewrap(H5Tget_member_type(self.id, member))
 */
  __pyx_t_1 = ((__pyx_v_member < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "h5py/h5t.pyx":1177
 *         """
 *         if member < 0:
 *             raise ValueError("Member index must be non-negative.")             # <<<<<<<<<<<<<<
 *         return typewrap(H5Tget_member_type(self.id, member))
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1177, __pyx_L1_error)

    /* "h5py/h5t.pyx":1176
 *         index.
 *         """
 *         if member < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Member index must be non-negative.")
 *         return typewrap(H5Tget_member_type(self.id, member))
 */
  }

  /* "h5py/h5t.pyx":1178
 *         if member < 0:
 *             raise ValueError("Member index must be non-negative.")
 *         return typewrap(H5Tget_member_type(self.id, member))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_f_4h5py_4defs_H5Tget_member_type(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_member); if (unlikely(__pyx_t_3 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1178, __pyx_L1_error)
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_typewrap(__pyx_t_3, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1170
 * 
 *     @with_phil
 *     def get_member_type(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => TypeID
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.get_member_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1182
 * 
 *     @with_phil
 *     def insert(self, char* name, size_t offset, TypeID field not None):             # <<<<<<<<<<<<<<
 *         """(STRING name, UINT offset, TypeID field)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_7insert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_14TypeCompoundID_6insert[] = "(STRING name, UINT offset, TypeID field)\n\n        Add a named member datatype to a compound datatype.  The parameter\n        offset indicates the offset from the start of the compound datatype,\n        in bytes.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_7insert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  char *__pyx_v_name;
  size_t __pyx_v_offset;
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_field = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("insert (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_offset,&__pyx_n_s_field,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_offset)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, 1); __PYX_ERR(0, 1182, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, 2); __PYX_ERR(0, 1182, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "insert") < 0)) __PYX_ERR(0, 1182, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = __Pyx_PyObject_AsWritableString(values[0]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) __PYX_ERR(0, 1182, __pyx_L3_error)
    __pyx_v_offset = __Pyx_PyInt_As_size_t(values[1]); if (unlikely((__pyx_v_offset == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1182, __pyx_L3_error)
    __pyx_v_field = ((struct __pyx_obj_4h5py_3h5t_TypeID *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1182, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_4h5py_3h5t_TypeID, 0, "field", 0))) __PYX_ERR(0, 1182, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_14TypeCompoundID_6insert(((struct __pyx_obj_4h5py_3h5t_TypeCompoundID *)__pyx_v_self), __pyx_v_name, __pyx_v_offset, __pyx_v_field);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_6insert(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self, char *__pyx_v_name, size_t __pyx_v_offset, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("insert", 0);

  /* "h5py/h5t.pyx":1189
 *         in bytes.
 *         """
 *         H5Tinsert(self.id, name, offset, field.id)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tinsert(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_name, __pyx_v_offset, __pyx_v_field->__pyx_base.id); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1189, __pyx_L1_error)

  /* "h5py/h5t.pyx":1182
 * 
 *     @with_phil
 *     def insert(self, char* name, size_t offset, TypeID field not None):             # <<<<<<<<<<<<<<
 *         """(STRING name, UINT offset, TypeID field)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1193
 * 
 *     @with_phil
 *     def pack(self):             # <<<<<<<<<<<<<<
 *         """()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_9pack(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4h5py_3h5t_14TypeCompoundID_8pack[] = "()\n\n        Recursively removes padding (introduced on account of e.g. compiler\n        alignment rules) from a compound datatype.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_14TypeCompoundID_9pack(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pack (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_14TypeCompoundID_8pack(((struct __pyx_obj_4h5py_3h5t_TypeCompoundID *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_14TypeCompoundID_8pack(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pack", 0);

  /* "h5py/h5t.pyx":1199
 *         alignment rules) from a compound datatype.
 *         """
 *         H5Tpack(self.id)             # <<<<<<<<<<<<<<
 * 
 *     cdef object py_dtype(self):
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tpack(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1199, __pyx_L1_error)

  /* "h5py/h5t.pyx":1193
 * 
 *     @with_phil
 *     def pack(self):             # <<<<<<<<<<<<<<
 *         """()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.pack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1201
 *         H5Tpack(self.id)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             TypeID tmp_type
 */

static PyObject *__pyx_f_4h5py_3h5t_14TypeCompoundID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_v_self) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_tmp_type = 0;
  PyObject *__pyx_v_field_names = 0;
  PyObject *__pyx_v_field_types = 0;
  int __pyx_v_i;
  int __pyx_v_nfields;
  PyObject *__pyx_v_field_offsets = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_bstring = NULL;
  PyObject *__pyx_v_blen = NULL;
  PyObject *__pyx_v_nstring = NULL;
  PyObject *__pyx_v_typeobj = NULL;
  PyObject *__pyx_7genexpr__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":1207
 *             list field_types
 *             int i, nfields
 *         field_names = []             # <<<<<<<<<<<<<<
 *         field_types = []
 *         field_offsets = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_field_names = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1208
 *             int i, nfields
 *         field_names = []
 *         field_types = []             # <<<<<<<<<<<<<<
 *         field_offsets = []
 *         nfields = self.get_nmembers()
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_field_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1209
 *         field_names = []
 *         field_types = []
 *         field_offsets = []             # <<<<<<<<<<<<<<
 *         nfields = self.get_nmembers()
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_field_offsets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1210
 *         field_types = []
 *         field_offsets = []
 *         nfields = self.get_nmembers()             # <<<<<<<<<<<<<<
 * 
 *         # First step: read field names and their Numpy dtypes into
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_nmembers); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_nfields = __pyx_t_4;

  /* "h5py/h5t.pyx":1214
 *         # First step: read field names and their Numpy dtypes into
 *         # two separate arrays.
 *         for i in range(nfields):             # <<<<<<<<<<<<<<
 *             tmp_type = self.get_member_type(i)
 *             name = self.get_member_name(i)
 */
  __pyx_t_4 = __pyx_v_nfields;
  __pyx_t_5 = __pyx_t_4;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "h5py/h5t.pyx":1215
 *         # two separate arrays.
 *         for i in range(nfields):
 *             tmp_type = self.get_member_type(i)             # <<<<<<<<<<<<<<
 *             name = self.get_member_name(i)
 *             field_names.append(name)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_member_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 1215, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_tmp_type, ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1216
 *         for i in range(nfields):
 *             tmp_type = self.get_member_type(i)
 *             name = self.get_member_name(i)             # <<<<<<<<<<<<<<
 *             field_names.append(name)
 *             field_types.append(tmp_type.py_dtype())
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_member_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1217
 *             tmp_type = self.get_member_type(i)
 *             name = self.get_member_name(i)
 *             field_names.append(name)             # <<<<<<<<<<<<<<
 *             field_types.append(tmp_type.py_dtype())
 *             field_offsets.append(self.get_member_offset(i))
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_field_names, __pyx_v_name); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1217, __pyx_L1_error)

    /* "h5py/h5t.pyx":1218
 *             name = self.get_member_name(i)
 *             field_names.append(name)
 *             field_types.append(tmp_type.py_dtype())             # <<<<<<<<<<<<<<
 *             field_offsets.append(self.get_member_offset(i))
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_4h5py_3h5t_TypeID *)__pyx_v_tmp_type->__pyx_vtab)->py_dtype(__pyx_v_tmp_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_field_types, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1219
 *             field_names.append(name)
 *             field_types.append(tmp_type.py_dtype())
 *             field_offsets.append(self.get_member_offset(i))             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_member_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_field_offsets, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1219, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "h5py/h5t.pyx":1223
 * 
 *         # 1. Check if it should be converted to a complex number
 *         if len(field_names) == 2                                and \             # <<<<<<<<<<<<<<
 *             tuple(field_names) == (cfg._r_name, cfg._i_name)    and \
 *             field_types[0] == field_types[1]                    and \
 */
  __pyx_t_10 = PyList_GET_SIZE(__pyx_v_field_names); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1223, __pyx_L1_error)
  __pyx_t_11 = ((__pyx_t_10 == 2) != 0);
  if (__pyx_t_11) {
  } else {
    __pyx_t_9 = __pyx_t_11;
    goto __pyx_L6_bool_binop_done;
  }

  /* "h5py/h5t.pyx":1224
 *         # 1. Check if it should be converted to a complex number
 *         if len(field_names) == 2                                and \
 *             tuple(field_names) == (cfg._r_name, cfg._i_name)    and \             # <<<<<<<<<<<<<<
 *             field_types[0] == field_types[1]                    and \
 *             field_types[0].kind == 'f':
 */
  __pyx_t_1 = PyList_AsTuple(__pyx_v_field_names); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cfg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_r_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cfg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_i_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_7);
  __pyx_t_3 = 0;
  __pyx_t_7 = 0;
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1224, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 1224, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_11) {
  } else {
    __pyx_t_9 = __pyx_t_11;
    goto __pyx_L6_bool_binop_done;
  }

  /* "h5py/h5t.pyx":1225
 *         if len(field_names) == 2                                and \
 *             tuple(field_names) == (cfg._r_name, cfg._i_name)    and \
 *             field_types[0] == field_types[1]                    and \             # <<<<<<<<<<<<<<
 *             field_types[0].kind == 'f':
 * 
 */
  __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_field_types, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_field_types, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_7, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 1225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_11) {
  } else {
    __pyx_t_9 = __pyx_t_11;
    goto __pyx_L6_bool_binop_done;
  }

  /* "h5py/h5t.pyx":1226
 *             tuple(field_names) == (cfg._r_name, cfg._i_name)    and \
 *             field_types[0] == field_types[1]                    and \
 *             field_types[0].kind == 'f':             # <<<<<<<<<<<<<<
 * 
 *             bstring = field_types[0].str
 */
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_field_types, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_kind); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_f, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 1226, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_11;
  __pyx_L6_bool_binop_done:;

  /* "h5py/h5t.pyx":1223
 * 
 *         # 1. Check if it should be converted to a complex number
 *         if len(field_names) == 2                                and \             # <<<<<<<<<<<<<<
 *             tuple(field_names) == (cfg._r_name, cfg._i_name)    and \
 *             field_types[0] == field_types[1]                    and \
 */
  if (__pyx_t_9) {

    /* "h5py/h5t.pyx":1228
 *             field_types[0].kind == 'f':
 * 
 *             bstring = field_types[0].str             # <<<<<<<<<<<<<<
 *             blen = int(bstring[2:])
 *             nstring = bstring[0] + "c" + str(2*blen)
 */
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_field_types, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_bstring = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1229
 * 
 *             bstring = field_types[0].str
 *             blen = int(bstring[2:])             # <<<<<<<<<<<<<<
 *             nstring = bstring[0] + "c" + str(2*blen)
 *             typeobj = np.dtype(nstring)
 */
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_bstring, 2, 0, NULL, NULL, &__pyx_slice__7, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_blen = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "h5py/h5t.pyx":1230
 *             bstring = field_types[0].str
 *             blen = int(bstring[2:])
 *             nstring = bstring[0] + "c" + str(2*blen)             # <<<<<<<<<<<<<<
 *             typeobj = np.dtype(nstring)
 * 
 */
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_bstring, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_n_u_c); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Multiply(__pyx_int_2, __pyx_v_blen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_nstring = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "h5py/h5t.pyx":1231
 *             blen = int(bstring[2:])
 *             nstring = bstring[0] + "c" + str(2*blen)
 *             typeobj = np.dtype(nstring)             # <<<<<<<<<<<<<<
 * 
 *         # 2. Otherwise, read all fields of the compound type, in HDF5 order.
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, __pyx_v_nstring) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_nstring);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_typeobj = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "h5py/h5t.pyx":1223
 * 
 *         # 1. Check if it should be converted to a complex number
 *         if len(field_names) == 2                                and \             # <<<<<<<<<<<<<<
 *             tuple(field_names) == (cfg._r_name, cfg._i_name)    and \
 *             field_types[0] == field_types[1]                    and \
 */
    goto __pyx_L5;
  }

  /* "h5py/h5t.pyx":1235
 *         # 2. Otherwise, read all fields of the compound type, in HDF5 order.
 *         else:
 *             field_names = [x.decode('utf8') for x in field_names]             # <<<<<<<<<<<<<<
 *             typeobj = np.dtype({'names': field_names,
 *                                 'formats': field_types,
 */
  /*else*/ {
    { /* enter inner scope */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1235, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __pyx_v_field_names; __Pyx_INCREF(__pyx_t_1); __pyx_t_10 = 0;
      for (;;) {
        if (__pyx_t_10 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_10); __Pyx_INCREF(__pyx_t_7); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 1235, __pyx_L12_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1235, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_x, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_x, __pyx_n_s_decode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1235, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_7 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_12, __pyx_n_u_utf8) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_utf8);
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1235, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_7))) __PYX_ERR(0, 1235, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x); __pyx_7genexpr__pyx_v_x = 0;
      goto __pyx_L15_exit_scope;
      __pyx_L12_error:;
      __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x); __pyx_7genexpr__pyx_v_x = 0;
      goto __pyx_L1_error;
      __pyx_L15_exit_scope:;
    } /* exit inner scope */
    __Pyx_DECREF_SET(__pyx_v_field_names, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "h5py/h5t.pyx":1236
 *         else:
 *             field_names = [x.decode('utf8') for x in field_names]
 *             typeobj = np.dtype({'names': field_names,             # <<<<<<<<<<<<<<
 *                                 'formats': field_types,
 *                                 'offsets': field_offsets,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dtype); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_names, __pyx_v_field_names) < 0) __PYX_ERR(0, 1236, __pyx_L1_error)

    /* "h5py/h5t.pyx":1237
 *             field_names = [x.decode('utf8') for x in field_names]
 *             typeobj = np.dtype({'names': field_names,
 *                                 'formats': field_types,             # <<<<<<<<<<<<<<
 *                                 'offsets': field_offsets,
 *                                 'itemsize': self.get_size()})
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_formats, __pyx_v_field_types) < 0) __PYX_ERR(0, 1236, __pyx_L1_error)

    /* "h5py/h5t.pyx":1238
 *             typeobj = np.dtype({'names': field_names,
 *                                 'formats': field_types,
 *                                 'offsets': field_offsets,             # <<<<<<<<<<<<<<
 *                                 'itemsize': self.get_size()})
 * 
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_offsets, __pyx_v_field_offsets) < 0) __PYX_ERR(0, 1236, __pyx_L1_error)

    /* "h5py/h5t.pyx":1239
 *                                 'formats': field_types,
 *                                 'offsets': field_offsets,
 *                                 'itemsize': self.get_size()})             # <<<<<<<<<<<<<<
 * 
 *         return typeobj
 */
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_size); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
      }
    }
    __pyx_t_3 = (__pyx_t_13) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_13) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_itemsize, __pyx_t_3) < 0) __PYX_ERR(0, 1236, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_3, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_1);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_typeobj = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "h5py/h5t.pyx":1241
 *                                 'itemsize': self.get_size()})
 * 
 *         return typeobj             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_typeobj);
  __pyx_r = __pyx_v_typeobj;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1201
 *         H5Tpack(self.id)
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             TypeID tmp_type
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("h5py.h5t.TypeCompoundID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tmp_type);
  __Pyx_XDECREF(__pyx_v_field_names);
  __Pyx_XDECREF(__pyx_v_field_types);
  __Pyx_XDECREF(__pyx_v_field_offsets);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_bstring);
  __Pyx_XDECREF(__pyx_v_blen);
  __Pyx_XDECREF(__pyx_v_nstring);
  __Pyx_XDECREF(__pyx_v_typeobj);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1250
 *     """
 * 
 *     cdef int enum_convert(self, long long *buf, int reverse) except -1:             # <<<<<<<<<<<<<<
 *         # Convert the long long value in "buf" to the native representation
 *         # of this (enumerated) type.  Conversion performed in-place.
 */

static int __pyx_f_4h5py_3h5t_10TypeEnumID_enum_convert(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, PY_LONG_LONG *__pyx_v_buf, int __pyx_v_reverse) {
  hid_t __pyx_v_basetype;
  enum H5T_class_t __pyx_v_class_code;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  enum H5T_class_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  hid_t __pyx_t_5;
  herr_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enum_convert", 0);

  /* "h5py/h5t.pyx":1258
 *         cdef H5T_class_t class_code
 * 
 *         class_code = H5Tget_class(self.id)             # <<<<<<<<<<<<<<
 *         if class_code != H5T_ENUM:
 *             raise ValueError("This type (class %d) is not of class ENUM" % class_code)
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tget_class(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_1 == ((enum H5T_class_t)((enum H5T_class_t)-1L)))) __PYX_ERR(0, 1258, __pyx_L1_error)
  __pyx_v_class_code = __pyx_t_1;

  /* "h5py/h5t.pyx":1259
 * 
 *         class_code = H5Tget_class(self.id)
 *         if class_code != H5T_ENUM:             # <<<<<<<<<<<<<<
 *             raise ValueError("This type (class %d) is not of class ENUM" % class_code)
 * 
 */
  __pyx_t_2 = ((__pyx_v_class_code != H5T_ENUM) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "h5py/h5t.pyx":1260
 *         class_code = H5Tget_class(self.id)
 *         if class_code != H5T_ENUM:
 *             raise ValueError("This type (class %d) is not of class ENUM" % class_code)             # <<<<<<<<<<<<<<
 * 
 *         basetype = H5Tget_super(self.id)
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum__H5T_class_t(__pyx_v_class_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_This_type_class_d_is_not_of_clas, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1260, __pyx_L1_error)

    /* "h5py/h5t.pyx":1259
 * 
 *         class_code = H5Tget_class(self.id)
 *         if class_code != H5T_ENUM:             # <<<<<<<<<<<<<<
 *             raise ValueError("This type (class %d) is not of class ENUM" % class_code)
 * 
 */
  }

  /* "h5py/h5t.pyx":1262
 *             raise ValueError("This type (class %d) is not of class ENUM" % class_code)
 * 
 *         basetype = H5Tget_super(self.id)             # <<<<<<<<<<<<<<
 *         assert basetype > 0
 * 
 */
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tget_super(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1262, __pyx_L1_error)
  __pyx_v_basetype = __pyx_t_5;

  /* "h5py/h5t.pyx":1263
 * 
 *         basetype = H5Tget_super(self.id)
 *         assert basetype > 0             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(!((__pyx_v_basetype > 0) != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 1263, __pyx_L1_error)
    }
  }
  #endif

  /* "h5py/h5t.pyx":1265
 *         assert basetype > 0
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if not reverse:
 *                 H5Tconvert(H5T_NATIVE_LLONG, basetype, 1, buf, NULL, H5P_DEFAULT)
 */
  /*try:*/ {

    /* "h5py/h5t.pyx":1266
 * 
 *         try:
 *             if not reverse:             # <<<<<<<<<<<<<<
 *                 H5Tconvert(H5T_NATIVE_LLONG, basetype, 1, buf, NULL, H5P_DEFAULT)
 *             else:
 */
    __pyx_t_2 = ((!(__pyx_v_reverse != 0)) != 0);
    if (__pyx_t_2) {

      /* "h5py/h5t.pyx":1267
 *         try:
 *             if not reverse:
 *                 H5Tconvert(H5T_NATIVE_LLONG, basetype, 1, buf, NULL, H5P_DEFAULT)             # <<<<<<<<<<<<<<
 *             else:
 *                 H5Tconvert(basetype, H5T_NATIVE_LLONG, 1, buf, NULL, H5P_DEFAULT)
 */
      __pyx_t_6 = __pyx_f_4h5py_4defs_H5Tconvert(H5T_NATIVE_LLONG, __pyx_v_basetype, 1, __pyx_v_buf, NULL, H5P_DEFAULT); if (unlikely(__pyx_t_6 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1267, __pyx_L5_error)

      /* "h5py/h5t.pyx":1266
 * 
 *         try:
 *             if not reverse:             # <<<<<<<<<<<<<<
 *                 H5Tconvert(H5T_NATIVE_LLONG, basetype, 1, buf, NULL, H5P_DEFAULT)
 *             else:
 */
      goto __pyx_L7;
    }

    /* "h5py/h5t.pyx":1269
 *                 H5Tconvert(H5T_NATIVE_LLONG, basetype, 1, buf, NULL, H5P_DEFAULT)
 *             else:
 *                 H5Tconvert(basetype, H5T_NATIVE_LLONG, 1, buf, NULL, H5P_DEFAULT)             # <<<<<<<<<<<<<<
 *         finally:
 *             H5Tclose(basetype)
 */
    /*else*/ {
      __pyx_t_6 = __pyx_f_4h5py_4defs_H5Tconvert(__pyx_v_basetype, H5T_NATIVE_LLONG, 1, __pyx_v_buf, NULL, H5P_DEFAULT); if (unlikely(__pyx_t_6 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1269, __pyx_L5_error)
    }
    __pyx_L7:;
  }

  /* "h5py/h5t.pyx":1271
 *                 H5Tconvert(basetype, H5T_NATIVE_LLONG, 1, buf, NULL, H5P_DEFAULT)
 *         finally:
 *             H5Tclose(basetype)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_6 = __pyx_f_4h5py_4defs_H5Tclose(__pyx_v_basetype); if (unlikely(__pyx_t_6 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1271, __pyx_L1_error)
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_7 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
      {
        __pyx_t_6 = __pyx_f_4h5py_4defs_H5Tclose(__pyx_v_basetype); if (unlikely(__pyx_t_6 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1271, __pyx_L9_error)
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_9;
      goto __pyx_L1_error;
      __pyx_L9_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "h5py/h5t.pyx":1250
 *     """
 * 
 *     cdef int enum_convert(self, long long *buf, int reverse) except -1:             # <<<<<<<<<<<<<<
 *         # Convert the long long value in "buf" to the native representation
 *         # of this (enumerated) type.  Conversion performed in-place.
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.enum_convert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1275
 * 
 *     @with_phil
 *     def enum_insert(self, char* name, long long value):             # <<<<<<<<<<<<<<
 *         """(STRING name, INT/LONG value)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_10TypeEnumID_1enum_insert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_10TypeEnumID_enum_insert[] = "(STRING name, INT/LONG value)\n\n        Define a new member of an enumerated type.  The value will be\n        automatically converted to the base type defined for this enum.  If\n        the conversion results in overflow, the value will be silently\n        clipped.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_10TypeEnumID_1enum_insert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  char *__pyx_v_name;
  PY_LONG_LONG __pyx_v_value;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enum_insert (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("enum_insert", 1, 2, 2, 1); __PYX_ERR(0, 1275, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "enum_insert") < 0)) __PYX_ERR(0, 1275, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_name = __Pyx_PyObject_AsWritableString(values[0]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) __PYX_ERR(0, 1275, __pyx_L3_error)
    __pyx_v_value = __Pyx_PyInt_As_PY_LONG_LONG(values[1]); if (unlikely((__pyx_v_value == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 1275, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enum_insert", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1275, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.enum_insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_10TypeEnumID_enum_insert(((struct __pyx_obj_4h5py_3h5t_TypeEnumID *)__pyx_v_self), __pyx_v_name, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_10TypeEnumID_enum_insert(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, char *__pyx_v_name, PY_LONG_LONG __pyx_v_value) {
  PY_LONG_LONG __pyx_v_buf;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  herr_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enum_insert", 0);

  /* "h5py/h5t.pyx":1285
 *         cdef long long buf
 * 
 *         buf = value             # <<<<<<<<<<<<<<
 *         self.enum_convert(&buf, 0)
 *         H5Tenum_insert(self.id, name, &buf)
 */
  __pyx_v_buf = __pyx_v_value;

  /* "h5py/h5t.pyx":1286
 * 
 *         buf = value
 *         self.enum_convert(&buf, 0)             # <<<<<<<<<<<<<<
 *         H5Tenum_insert(self.id, name, &buf)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4h5py_3h5t_TypeEnumID *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->enum_convert(__pyx_v_self, (&__pyx_v_buf), 0); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1286, __pyx_L1_error)

  /* "h5py/h5t.pyx":1287
 *         buf = value
 *         self.enum_convert(&buf, 0)
 *         H5Tenum_insert(self.id, name, &buf)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tenum_insert(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_name, (&__pyx_v_buf)); if (unlikely(__pyx_t_2 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1287, __pyx_L1_error)

  /* "h5py/h5t.pyx":1275
 * 
 *     @with_phil
 *     def enum_insert(self, char* name, long long value):             # <<<<<<<<<<<<<<
 *         """(STRING name, INT/LONG value)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.enum_insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1291
 * 
 *     @with_phil
 *     def enum_nameof(self, long long value):             # <<<<<<<<<<<<<<
 *         """(LONG value) => STRING name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_10TypeEnumID_3enum_nameof(PyObject *__pyx_v_self, PyObject *__pyx_arg_value); /*proto*/
static char __pyx_doc_4h5py_3h5t_10TypeEnumID_2enum_nameof[] = "(LONG value) => STRING name\n\n        Determine the name associated with the given value.  Due to a\n        limitation of the HDF5 library, this can only retrieve names up to\n        1023 characters in length.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_10TypeEnumID_3enum_nameof(PyObject *__pyx_v_self, PyObject *__pyx_arg_value) {
  PY_LONG_LONG __pyx_v_value;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enum_nameof (wrapper)", 0);
  assert(__pyx_arg_value); {
    __pyx_v_value = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_arg_value); if (unlikely((__pyx_v_value == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 1291, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.enum_nameof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_10TypeEnumID_2enum_nameof(((struct __pyx_obj_4h5py_3h5t_TypeEnumID *)__pyx_v_self), ((PY_LONG_LONG)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_10TypeEnumID_2enum_nameof(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, PY_LONG_LONG __pyx_v_value) {
  herr_t __pyx_v_retval;
  char __pyx_v_name[0x400];
  PY_LONG_LONG __pyx_v_buf;
  char *__pyx_v_retstring;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  herr_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enum_nameof", 0);

  /* "h5py/h5t.pyx":1302
 *         cdef long long buf
 * 
 *         buf = value             # <<<<<<<<<<<<<<
 *         self.enum_convert(&buf, 0)
 *         retval = H5Tenum_nameof(self.id, &buf, name, 1024)
 */
  __pyx_v_buf = __pyx_v_value;

  /* "h5py/h5t.pyx":1303
 * 
 *         buf = value
 *         self.enum_convert(&buf, 0)             # <<<<<<<<<<<<<<
 *         retval = H5Tenum_nameof(self.id, &buf, name, 1024)
 *         assert retval >= 0
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4h5py_3h5t_TypeEnumID *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->enum_convert(__pyx_v_self, (&__pyx_v_buf), 0); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1303, __pyx_L1_error)

  /* "h5py/h5t.pyx":1304
 *         buf = value
 *         self.enum_convert(&buf, 0)
 *         retval = H5Tenum_nameof(self.id, &buf, name, 1024)             # <<<<<<<<<<<<<<
 *         assert retval >= 0
 *         retstring = name
 */
  __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tenum_nameof(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, (&__pyx_v_buf), __pyx_v_name, 0x400); if (unlikely(__pyx_t_2 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1304, __pyx_L1_error)
  __pyx_v_retval = __pyx_t_2;

  /* "h5py/h5t.pyx":1305
 *         self.enum_convert(&buf, 0)
 *         retval = H5Tenum_nameof(self.id, &buf, name, 1024)
 *         assert retval >= 0             # <<<<<<<<<<<<<<
 *         retstring = name
 *         return retstring
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(!((__pyx_v_retval >= 0) != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 1305, __pyx_L1_error)
    }
  }
  #endif

  /* "h5py/h5t.pyx":1306
 *         retval = H5Tenum_nameof(self.id, &buf, name, 1024)
 *         assert retval >= 0
 *         retstring = name             # <<<<<<<<<<<<<<
 *         return retstring
 * 
 */
  __pyx_v_retstring = __pyx_v_name;

  /* "h5py/h5t.pyx":1307
 *         assert retval >= 0
 *         retstring = name
 *         return retstring             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_retstring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1291
 * 
 *     @with_phil
 *     def enum_nameof(self, long long value):             # <<<<<<<<<<<<<<
 *         """(LONG value) => STRING name
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.enum_nameof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1311
 * 
 *     @with_phil
 *     def enum_valueof(self, char* name):             # <<<<<<<<<<<<<<
 *         """(STRING name) => LONG value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_10TypeEnumID_5enum_valueof(PyObject *__pyx_v_self, PyObject *__pyx_arg_name); /*proto*/
static char __pyx_doc_4h5py_3h5t_10TypeEnumID_4enum_valueof[] = "(STRING name) => LONG value\n\n        Get the value associated with an enum name.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_10TypeEnumID_5enum_valueof(PyObject *__pyx_v_self, PyObject *__pyx_arg_name) {
  char *__pyx_v_name;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enum_valueof (wrapper)", 0);
  assert(__pyx_arg_name); {
    __pyx_v_name = __Pyx_PyObject_AsWritableString(__pyx_arg_name); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) __PYX_ERR(0, 1311, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.enum_valueof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_10TypeEnumID_4enum_valueof(((struct __pyx_obj_4h5py_3h5t_TypeEnumID *)__pyx_v_self), ((char *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_10TypeEnumID_4enum_valueof(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, char *__pyx_v_name) {
  PY_LONG_LONG __pyx_v_buf;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  herr_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enum_valueof", 0);

  /* "h5py/h5t.pyx":1318
 *         cdef long long buf
 * 
 *         H5Tenum_valueof(self.id, name, &buf)             # <<<<<<<<<<<<<<
 *         self.enum_convert(&buf, 1)
 *         return buf
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tenum_valueof(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_name, (&__pyx_v_buf)); if (unlikely(__pyx_t_1 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1318, __pyx_L1_error)

  /* "h5py/h5t.pyx":1319
 * 
 *         H5Tenum_valueof(self.id, name, &buf)
 *         self.enum_convert(&buf, 1)             # <<<<<<<<<<<<<<
 *         return buf
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_4h5py_3h5t_TypeEnumID *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->enum_convert(__pyx_v_self, (&__pyx_v_buf), 1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1319, __pyx_L1_error)

  /* "h5py/h5t.pyx":1320
 *         H5Tenum_valueof(self.id, name, &buf)
 *         self.enum_convert(&buf, 1)
 *         return buf             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyInt_From_PY_LONG_LONG(__pyx_v_buf); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1311
 * 
 *     @with_phil
 *     def enum_valueof(self, char* name):             # <<<<<<<<<<<<<<
 *         """(STRING name) => LONG value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.enum_valueof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1324
 * 
 *     @with_phil
 *     def get_member_value(self, int idx):             # <<<<<<<<<<<<<<
 *         """(UINT index) => LONG value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_10TypeEnumID_7get_member_value(PyObject *__pyx_v_self, PyObject *__pyx_arg_idx); /*proto*/
static char __pyx_doc_4h5py_3h5t_10TypeEnumID_6get_member_value[] = "(UINT index) => LONG value\n\n        Determine the value for the member at the given zero-based index.\n        ";
static PyObject *__pyx_pw_4h5py_3h5t_10TypeEnumID_7get_member_value(PyObject *__pyx_v_self, PyObject *__pyx_arg_idx) {
  int __pyx_v_idx;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_member_value (wrapper)", 0);
  assert(__pyx_arg_idx); {
    __pyx_v_idx = __Pyx_PyInt_As_int(__pyx_arg_idx); if (unlikely((__pyx_v_idx == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1324, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.get_member_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_10TypeEnumID_6get_member_value(((struct __pyx_obj_4h5py_3h5t_TypeEnumID *)__pyx_v_self), ((int)__pyx_v_idx));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_10TypeEnumID_6get_member_value(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self, int __pyx_v_idx) {
  CYTHON_UNUSED hid_t __pyx_v_ptype;
  PY_LONG_LONG __pyx_v_val;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  herr_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_member_value", 0);

  /* "h5py/h5t.pyx":1332
 *         cdef hid_t ptype
 *         cdef long long val
 *         ptype = 0             # <<<<<<<<<<<<<<
 * 
 *         if idx < 0:
 */
  __pyx_v_ptype = 0;

  /* "h5py/h5t.pyx":1334
 *         ptype = 0
 * 
 *         if idx < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Index must be non-negative.")
 * 
 */
  __pyx_t_1 = ((__pyx_v_idx < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "h5py/h5t.pyx":1335
 * 
 *         if idx < 0:
 *             raise ValueError("Index must be non-negative.")             # <<<<<<<<<<<<<<
 * 
 *         H5Tget_member_value(self.id, idx, &val)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1335, __pyx_L1_error)

    /* "h5py/h5t.pyx":1334
 *         ptype = 0
 * 
 *         if idx < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Index must be non-negative.")
 * 
 */
  }

  /* "h5py/h5t.pyx":1337
 *             raise ValueError("Index must be non-negative.")
 * 
 *         H5Tget_member_value(self.id, idx, &val)             # <<<<<<<<<<<<<<
 *         self.enum_convert(&val, 1)
 *         return val
 */
  __pyx_t_3 = __pyx_f_4h5py_4defs_H5Tget_member_value(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.id, __pyx_v_idx, (&__pyx_v_val)); if (unlikely(__pyx_t_3 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1337, __pyx_L1_error)

  /* "h5py/h5t.pyx":1338
 * 
 *         H5Tget_member_value(self.id, idx, &val)
 *         self.enum_convert(&val, 1)             # <<<<<<<<<<<<<<
 *         return val
 * 
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_4h5py_3h5t_TypeEnumID *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->enum_convert(__pyx_v_self, (&__pyx_v_val), 1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1338, __pyx_L1_error)

  /* "h5py/h5t.pyx":1339
 *         H5Tget_member_value(self.id, idx, &val)
 *         self.enum_convert(&val, 1)
 *         return val             # <<<<<<<<<<<<<<
 * 
 *     cdef object py_dtype(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_PY_LONG_LONG(__pyx_v_val); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1324
 * 
 *     @with_phil
 *     def get_member_value(self, int idx):             # <<<<<<<<<<<<<<
 *         """(UINT index) => LONG value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.get_member_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1341
 *         return val
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Translation function for enum types
 * 
 */

static PyObject *__pyx_f_4h5py_3h5t_10TypeEnumID_py_dtype(struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_self) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_basetype = 0;
  PyObject *__pyx_v_nmembers = NULL;
  PyObject *__pyx_v_members = NULL;
  PyObject *__pyx_v_idx = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_v_ref = NULL;
  PyObject *__pyx_v_members_conv = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_dtype", 0);

  /* "h5py/h5t.pyx":1344
 *         # Translation function for enum types
 * 
 *         cdef TypeID basetype = self.get_super()             # <<<<<<<<<<<<<<
 * 
 *         nmembers = self.get_nmembers()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_super); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 1344, __pyx_L1_error)
  __pyx_v_basetype = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1346
 *         cdef TypeID basetype = self.get_super()
 * 
 *         nmembers = self.get_nmembers()             # <<<<<<<<<<<<<<
 *         members = {}
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_nmembers); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_nmembers = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1347
 * 
 *         nmembers = self.get_nmembers()
 *         members = {}             # <<<<<<<<<<<<<<
 * 
 *         for idx in range(nmembers):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_members = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1349
 *         members = {}
 * 
 *         for idx in range(nmembers):             # <<<<<<<<<<<<<<
 *             name = self.get_member_name(idx)
 *             val = self.get_member_value(idx)
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_nmembers); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1349, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1349, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1349, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1349, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1349, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1349, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1349, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_idx, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1350
 * 
 *         for idx in range(nmembers):
 *             name = self.get_member_name(idx)             # <<<<<<<<<<<<<<
 *             val = self.get_member_value(idx)
 *             members[name] = val
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_member_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_v_idx) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_idx);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1351
 *         for idx in range(nmembers):
 *             name = self.get_member_name(idx)
 *             val = self.get_member_value(idx)             # <<<<<<<<<<<<<<
 *             members[name] = val
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_member_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_v_idx) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_idx);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1352
 *             name = self.get_member_name(idx)
 *             val = self.get_member_value(idx)
 *             members[name] = val             # <<<<<<<<<<<<<<
 * 
 *         ref = {cfg._f_name: 0, cfg._t_name: 1}
 */
    if (unlikely(PyDict_SetItem(__pyx_v_members, __pyx_v_name, __pyx_v_val) < 0)) __PYX_ERR(0, 1352, __pyx_L1_error)

    /* "h5py/h5t.pyx":1349
 *         members = {}
 * 
 *         for idx in range(nmembers):             # <<<<<<<<<<<<<<
 *             name = self.get_member_name(idx)
 *             val = self.get_member_value(idx)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1354
 *             members[name] = val
 * 
 *         ref = {cfg._f_name: 0, cfg._t_name: 1}             # <<<<<<<<<<<<<<
 * 
 *         # Boolean types have priority over standard enums
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_cfg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_f_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_t_3, __pyx_int_0) < 0) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_cfg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_t_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_t_1, __pyx_int_1) < 0) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_ref = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1357
 * 
 *         # Boolean types have priority over standard enums
 *         if members == ref:             # <<<<<<<<<<<<<<
 *             return np.dtype('bool')
 * 
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_members, __pyx_v_ref, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "h5py/h5t.pyx":1358
 *         # Boolean types have priority over standard enums
 *         if members == ref:
 *             return np.dtype('bool')             # <<<<<<<<<<<<<<
 * 
 *         # Convert strings to appropriate representation
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_1, __pyx_n_u_bool) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_bool);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1357
 * 
 *         # Boolean types have priority over standard enums
 *         if members == ref:             # <<<<<<<<<<<<<<
 *             return np.dtype('bool')
 * 
 */
  }

  /* "h5py/h5t.pyx":1361
 * 
 *         # Convert strings to appropriate representation
 *         members_conv = {}             # <<<<<<<<<<<<<<
 *         for name, val in members.iteritems():
 *             try:    # ASCII;
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_members_conv = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1362
 *         # Convert strings to appropriate representation
 *         members_conv = {}
 *         for name, val in members.iteritems():             # <<<<<<<<<<<<<<
 *             try:    # ASCII;
 *                 name = name.decode('ascii')
 */
  __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_members, 1, __pyx_n_s_iteritems, (&__pyx_t_8), (&__pyx_t_9)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2);
  __pyx_t_2 = __pyx_t_3;
  __pyx_t_3 = 0;
  while (1) {
    __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_8, &__pyx_t_4, &__pyx_t_3, &__pyx_t_1, NULL, __pyx_t_9);
    if (unlikely(__pyx_t_10 == 0)) break;
    if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 1362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1363
 *         members_conv = {}
 *         for name, val in members.iteritems():
 *             try:    # ASCII;             # <<<<<<<<<<<<<<
 *                 name = name.decode('ascii')
 *             except UnicodeDecodeError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      /*try:*/ {

        /* "h5py/h5t.pyx":1364
 *         for name, val in members.iteritems():
 *             try:    # ASCII;
 *                 name = name.decode('ascii')             # <<<<<<<<<<<<<<
 *             except UnicodeDecodeError:
 *                 try:    # Non-ascii; all platforms try unicode
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_decode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1364, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_n_u_ascii) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_ascii);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1364, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "h5py/h5t.pyx":1363
 *         members_conv = {}
 *         for name, val in members.iteritems():
 *             try:    # ASCII;             # <<<<<<<<<<<<<<
 *                 name = name.decode('ascii')
 *             except UnicodeDecodeError:
 */
      }
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L15_try_end;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "h5py/h5t.pyx":1365
 *             try:    # ASCII;
 *                 name = name.decode('ascii')
 *             except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *                 try:    # Non-ascii; all platforms try unicode
 *                     name = name.decode('utf8')
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
      if (__pyx_t_10) {
        __Pyx_AddTraceback("h5py.h5t.TypeEnumID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_6) < 0) __PYX_ERR(0, 1365, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_6);

        /* "h5py/h5t.pyx":1366
 *                 name = name.decode('ascii')
 *             except UnicodeDecodeError:
 *                 try:    # Non-ascii; all platforms try unicode             # <<<<<<<<<<<<<<
 *                     name = name.decode('utf8')
 *                 except UnicodeDecodeError:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          /*try:*/ {

            /* "h5py/h5t.pyx":1367
 *             except UnicodeDecodeError:
 *                 try:    # Non-ascii; all platforms try unicode
 *                     name = name.decode('utf8')             # <<<<<<<<<<<<<<
 *                 except UnicodeDecodeError:
 *                     pass    # Last resort: return byte string
 */
            __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_decode); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1367, __pyx_L18_error)
            __Pyx_GOTREF(__pyx_t_18);
            __pyx_t_19 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_18))) {
              __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_18);
              if (likely(__pyx_t_19)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
                __Pyx_INCREF(__pyx_t_19);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_18, function);
              }
            }
            __pyx_t_17 = (__pyx_t_19) ? __Pyx_PyObject_Call2Args(__pyx_t_18, __pyx_t_19, __pyx_n_u_utf8) : __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_n_u_utf8);
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1367, __pyx_L18_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_17);
            __pyx_t_17 = 0;

            /* "h5py/h5t.pyx":1366
 *                 name = name.decode('ascii')
 *             except UnicodeDecodeError:
 *                 try:    # Non-ascii; all platforms try unicode             # <<<<<<<<<<<<<<
 *                     name = name.decode('utf8')
 *                 except UnicodeDecodeError:
 */
          }
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          goto __pyx_L25_try_end;
          __pyx_L18_error:;
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;

          /* "h5py/h5t.pyx":1368
 *                 try:    # Non-ascii; all platforms try unicode
 *                     name = name.decode('utf8')
 *                 except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *                     pass    # Last resort: return byte string
 *             members_conv[name] = val
 */
          __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
          if (__pyx_t_10) {
            __Pyx_ErrRestore(0,0,0);
            goto __pyx_L19_exception_handled;
          }
          goto __pyx_L20_except_error;
          __pyx_L20_except_error:;

          /* "h5py/h5t.pyx":1366
 *                 name = name.decode('ascii')
 *             except UnicodeDecodeError:
 *                 try:    # Non-ascii; all platforms try unicode             # <<<<<<<<<<<<<<
 *                     name = name.decode('utf8')
 *                 except UnicodeDecodeError:
 */
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          goto __pyx_L10_except_error;
          __pyx_L19_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          __pyx_L25_try_end:;
        }
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L9_exception_handled;
      }
      goto __pyx_L10_except_error;
      __pyx_L10_except_error:;

      /* "h5py/h5t.pyx":1363
 *         members_conv = {}
 *         for name, val in members.iteritems():
 *             try:    # ASCII;             # <<<<<<<<<<<<<<
 *                 name = name.decode('ascii')
 *             except UnicodeDecodeError:
 */
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L1_error;
      __pyx_L9_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_L15_try_end:;
    }

    /* "h5py/h5t.pyx":1370
 *                 except UnicodeDecodeError:
 *                     pass    # Last resort: return byte string
 *             members_conv[name] = val             # <<<<<<<<<<<<<<
 *         return enum_dtype(members_conv, basetype=basetype.py_dtype())
 * 
 */
    if (unlikely(PyDict_SetItem(__pyx_v_members_conv, __pyx_v_name, __pyx_v_val) < 0)) __PYX_ERR(0, 1370, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1371
 *                     pass    # Last resort: return byte string
 *             members_conv[name] = val
 *         return enum_dtype(members_conv, basetype=basetype.py_dtype())             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_enum_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_members_conv);
  __Pyx_GIVEREF(__pyx_v_members_conv);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_members_conv);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = ((struct __pyx_vtabstruct_4h5py_3h5t_TypeID *)__pyx_v_basetype->__pyx_vtab)->py_dtype(__pyx_v_basetype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_basetype, __pyx_t_1) < 0) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1341
 *         return val
 * 
 *     cdef object py_dtype(self):             # <<<<<<<<<<<<<<
 *         # Translation function for enum types
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_AddTraceback("h5py.h5t.TypeEnumID.py_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_basetype);
  __Pyx_XDECREF(__pyx_v_nmembers);
  __Pyx_XDECREF(__pyx_v_members);
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF(__pyx_v_ref);
  __Pyx_XDECREF(__pyx_v_members_conv);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1380
 * # transient and unlocked.
 * 
 * def _get_float_dtype_to_hdf5():             # <<<<<<<<<<<<<<
 *     float_le = {}
 *     float_be = {}
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_15_get_float_dtype_to_hdf5(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_4h5py_3h5t_15_get_float_dtype_to_hdf5 = {"_get_float_dtype_to_hdf5", (PyCFunction)__pyx_pw_4h5py_3h5t_15_get_float_dtype_to_hdf5, METH_NOARGS, 0};
static PyObject *__pyx_pw_4h5py_3h5t_15_get_float_dtype_to_hdf5(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_float_dtype_to_hdf5 (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_14_get_float_dtype_to_hdf5(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_14_get_float_dtype_to_hdf5(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_float_le = NULL;
  PyObject *__pyx_v_float_be = NULL;
  PyObject *__pyx_v_h5_be_list = NULL;
  PyObject *__pyx_v_h5_le_list = NULL;
  PyObject *__pyx_v_ftype_ = NULL;
  PyObject *__pyx_v_finfo = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_size = NULL;
  int __pyx_v_nmant;
  PyObject *__pyx_v_maxexp = NULL;
  CYTHON_UNUSED int __pyx_v_minexp;
  PyObject *__pyx_v_h5type = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_spos = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_epos = NULL;
  PyObject *__pyx_v_esize = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_mpos = NULL;
  PyObject *__pyx_v_msize = NULL;
  PyObject *__pyx_v_ebias = NULL;
  PyObject *__pyx_v_float_nt = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  __pyx_ctuple_int__and_int__and_int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  int __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_float_dtype_to_hdf5", 0);

  /* "h5py/h5t.pyx":1381
 * 
 * def _get_float_dtype_to_hdf5():
 *     float_le = {}             # <<<<<<<<<<<<<<
 *     float_be = {}
 *     h5_be_list = [IEEE_F16BE, IEEE_F32BE, IEEE_F64BE, IEEE_F128BE, LDOUBLE_BE]
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_float_le = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1382
 * def _get_float_dtype_to_hdf5():
 *     float_le = {}
 *     float_be = {}             # <<<<<<<<<<<<<<
 *     h5_be_list = [IEEE_F16BE, IEEE_F32BE, IEEE_F64BE, IEEE_F128BE, LDOUBLE_BE]
 *     h5_le_list = [IEEE_F16LE, IEEE_F32LE, IEEE_F64LE, IEEE_F128LE, LDOUBLE_LE]
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_float_be = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1383
 *     float_le = {}
 *     float_be = {}
 *     h5_be_list = [IEEE_F16BE, IEEE_F32BE, IEEE_F64BE, IEEE_F128BE, LDOUBLE_BE]             # <<<<<<<<<<<<<<
 *     h5_le_list = [IEEE_F16LE, IEEE_F32LE, IEEE_F64LE, IEEE_F128LE, LDOUBLE_LE]
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_IEEE_F16BE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IEEE_F32BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_IEEE_F64BE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F128BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_LDOUBLE_BE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_t_5);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_v_h5_be_list = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "h5py/h5t.pyx":1384
 *     float_be = {}
 *     h5_be_list = [IEEE_F16BE, IEEE_F32BE, IEEE_F64BE, IEEE_F128BE, LDOUBLE_BE]
 *     h5_le_list = [IEEE_F16LE, IEEE_F32LE, IEEE_F64LE, IEEE_F128LE, LDOUBLE_LE]             # <<<<<<<<<<<<<<
 * 
 *     for ftype_, finfo, size in _available_ftypes:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_IEEE_F16LE); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_IEEE_F32LE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F64LE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_IEEE_F128LE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_LDOUBLE_LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_6);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_t_2);
  __pyx_t_6 = 0;
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_2 = 0;
  __pyx_v_h5_le_list = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1386
 *     h5_le_list = [IEEE_F16LE, IEEE_F32LE, IEEE_F64LE, IEEE_F128LE, LDOUBLE_LE]
 * 
 *     for ftype_, finfo, size in _available_ftypes:             # <<<<<<<<<<<<<<
 *         nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *         for h5type in h5_be_list:
 */
  if (unlikely(__pyx_v_4h5py_3h5t__available_ftypes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1386, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_4h5py_3h5t__available_ftypes; __Pyx_INCREF(__pyx_t_1); __pyx_t_7 = 0;
  for (;;) {
    if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 1386, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1386, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_6)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 2; __pyx_t_5 = __pyx_t_8(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_6), 3) < 0) __PYX_ERR(0, 1386, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1386, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_ftype_, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_finfo, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_size, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "h5py/h5t.pyx":1387
 * 
 *     for ftype_, finfo, size in _available_ftypes:
 *         nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)             # <<<<<<<<<<<<<<
 *         for h5type in h5_be_list:
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 */
    __pyx_t_9 = __pyx_f_4h5py_3h5t__correct_float_info(__pyx_v_ftype_, __pyx_v_finfo);
    __pyx_t_10 = __pyx_t_9.f0;
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_9.f1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_11 = __pyx_t_9.f2;
    __pyx_v_nmant = __pyx_t_10;
    __Pyx_XDECREF_SET(__pyx_v_maxexp, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_v_minexp = __pyx_t_11;

    /* "h5py/h5t.pyx":1388
 *     for ftype_, finfo, size in _available_ftypes:
 *         nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *         for h5type in h5_be_list:             # <<<<<<<<<<<<<<
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 */
    __pyx_t_2 = __pyx_v_h5_be_list; __Pyx_INCREF(__pyx_t_2); __pyx_t_12 = 0;
    for (;;) {
      if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_12); __Pyx_INCREF(__pyx_t_5); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 1388, __pyx_L1_error)
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_h5type, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "h5py/h5t.pyx":1389
 *         nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *         for h5type in h5_be_list:
 *             spos, epos, esize, mpos, msize = h5type.get_fields()             # <<<<<<<<<<<<<<
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_h5type, __pyx_n_s_get_fields); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1389, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1389, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
        PyObject* sequence = __pyx_t_5;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 5)) {
          if (size > 5) __Pyx_RaiseTooManyValuesError(5);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1389, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
          __pyx_t_13 = PyTuple_GET_ITEM(sequence, 3); 
          __pyx_t_14 = PyTuple_GET_ITEM(sequence, 4); 
        } else {
          __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
          __pyx_t_13 = PyList_GET_ITEM(sequence, 3); 
          __pyx_t_14 = PyList_GET_ITEM(sequence, 4); 
        }
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_14);
        #else
        {
          Py_ssize_t i;
          PyObject** temps[5] = {&__pyx_t_4,&__pyx_t_3,&__pyx_t_6,&__pyx_t_13,&__pyx_t_14};
          for (i=0; i < 5; i++) {
            PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 1389, __pyx_L1_error)
            __Pyx_GOTREF(item);
            *(temps[i]) = item;
          }
        }
        #endif
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        Py_ssize_t index = -1;
        PyObject** temps[5] = {&__pyx_t_4,&__pyx_t_3,&__pyx_t_6,&__pyx_t_13,&__pyx_t_14};
        __pyx_t_15 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1389, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_15)->tp_iternext;
        for (index=0; index < 5; index++) {
          PyObject* item = __pyx_t_8(__pyx_t_15); if (unlikely(!item)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(item);
          *(temps[index]) = item;
        }
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_15), 5) < 0) __PYX_ERR(0, 1389, __pyx_L1_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1389, __pyx_L1_error)
        __pyx_L10_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_spos, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_epos, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_esize, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_mpos, __pyx_t_13);
      __pyx_t_13 = 0;
      __Pyx_XDECREF_SET(__pyx_v_msize, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "h5py/h5t.pyx":1390
 *         for h5type in h5_be_list:
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()             # <<<<<<<<<<<<<<
 *             if (finfo.iexp == esize and nmant == msize and
 *                     (maxexp - 1) == ebias):
 */
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_h5type, __pyx_n_s_get_ebias); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_13 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
        }
      }
      __pyx_t_5 = (__pyx_t_13) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_13) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF_SET(__pyx_v_ebias, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "h5py/h5t.pyx":1391
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and             # <<<<<<<<<<<<<<
 *                     (maxexp - 1) == ebias):
 *                 float_be[ftype_] = h5type
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_finfo, __pyx_n_s_iexp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = PyObject_RichCompare(__pyx_t_5, __pyx_v_esize, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (__pyx_t_17) {
      } else {
        __pyx_t_16 = __pyx_t_17;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_14 = __Pyx_PyInt_From_int(__pyx_v_nmant); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_5 = PyObject_RichCompare(__pyx_t_14, __pyx_v_msize, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_17) {
      } else {
        __pyx_t_16 = __pyx_t_17;
        goto __pyx_L12_bool_binop_done;
      }

      /* "h5py/h5t.pyx":1392
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and
 *                     (maxexp - 1) == ebias):             # <<<<<<<<<<<<<<
 *                 float_be[ftype_] = h5type
 *                 break # first found matches, related to #1244
 */
      __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_maxexp, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = PyObject_RichCompare(__pyx_t_5, __pyx_v_ebias, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1392, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 1392, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_16 = __pyx_t_17;
      __pyx_L12_bool_binop_done:;

      /* "h5py/h5t.pyx":1391
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and             # <<<<<<<<<<<<<<
 *                     (maxexp - 1) == ebias):
 *                 float_be[ftype_] = h5type
 */
      if (__pyx_t_16) {

        /* "h5py/h5t.pyx":1393
 *             if (finfo.iexp == esize and nmant == msize and
 *                     (maxexp - 1) == ebias):
 *                 float_be[ftype_] = h5type             # <<<<<<<<<<<<<<
 *                 break # first found matches, related to #1244
 *         for h5type in h5_le_list:
 */
        if (unlikely(PyDict_SetItem(__pyx_v_float_be, __pyx_v_ftype_, __pyx_v_h5type) < 0)) __PYX_ERR(0, 1393, __pyx_L1_error)

        /* "h5py/h5t.pyx":1394
 *                     (maxexp - 1) == ebias):
 *                 float_be[ftype_] = h5type
 *                 break # first found matches, related to #1244             # <<<<<<<<<<<<<<
 *         for h5type in h5_le_list:
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 */
        goto __pyx_L8_break;

        /* "h5py/h5t.pyx":1391
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and             # <<<<<<<<<<<<<<
 *                     (maxexp - 1) == ebias):
 *                 float_be[ftype_] = h5type
 */
      }

      /* "h5py/h5t.pyx":1388
 *     for ftype_, finfo, size in _available_ftypes:
 *         nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *         for h5type in h5_be_list:             # <<<<<<<<<<<<<<
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 */
    }
    __pyx_L8_break:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "h5py/h5t.pyx":1395
 *                 float_be[ftype_] = h5type
 *                 break # first found matches, related to #1244
 *         for h5type in h5_le_list:             # <<<<<<<<<<<<<<
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 */
    __pyx_t_2 = __pyx_v_h5_le_list; __Pyx_INCREF(__pyx_t_2); __pyx_t_12 = 0;
    for (;;) {
      if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_14 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_12); __Pyx_INCREF(__pyx_t_14); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 1395, __pyx_L1_error)
      #else
      __pyx_t_14 = PySequence_ITEM(__pyx_t_2, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_h5type, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "h5py/h5t.pyx":1396
 *                 break # first found matches, related to #1244
 *         for h5type in h5_le_list:
 *             spos, epos, esize, mpos, msize = h5type.get_fields()             # <<<<<<<<<<<<<<
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_h5type, __pyx_n_s_get_fields); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_13 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_14 = (__pyx_t_13) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_13) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_14))) || (PyList_CheckExact(__pyx_t_14))) {
        PyObject* sequence = __pyx_t_14;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 5)) {
          if (size > 5) __Pyx_RaiseTooManyValuesError(5);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1396, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_13 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 3); 
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 4); 
        } else {
          __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_13 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
          __pyx_t_3 = PyList_GET_ITEM(sequence, 3); 
          __pyx_t_4 = PyList_GET_ITEM(sequence, 4); 
        }
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        #else
        {
          Py_ssize_t i;
          PyObject** temps[5] = {&__pyx_t_5,&__pyx_t_13,&__pyx_t_6,&__pyx_t_3,&__pyx_t_4};
          for (i=0; i < 5; i++) {
            PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 1396, __pyx_L1_error)
            __Pyx_GOTREF(item);
            *(temps[i]) = item;
          }
        }
        #endif
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      } else {
        Py_ssize_t index = -1;
        PyObject** temps[5] = {&__pyx_t_5,&__pyx_t_13,&__pyx_t_6,&__pyx_t_3,&__pyx_t_4};
        __pyx_t_15 = PyObject_GetIter(__pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1396, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_15)->tp_iternext;
        for (index=0; index < 5; index++) {
          PyObject* item = __pyx_t_8(__pyx_t_15); if (unlikely(!item)) goto __pyx_L17_unpacking_failed;
          __Pyx_GOTREF(item);
          *(temps[index]) = item;
        }
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_15), 5) < 0) __PYX_ERR(0, 1396, __pyx_L1_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        goto __pyx_L18_unpacking_done;
        __pyx_L17_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1396, __pyx_L1_error)
        __pyx_L18_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_spos, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_XDECREF_SET(__pyx_v_epos, __pyx_t_13);
      __pyx_t_13 = 0;
      __Pyx_XDECREF_SET(__pyx_v_esize, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_mpos, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_msize, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "h5py/h5t.pyx":1397
 *         for h5type in h5_le_list:
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()             # <<<<<<<<<<<<<<
 *             if (finfo.iexp == esize and nmant == msize and
 *                     (maxexp - 1) == ebias):
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_h5type, __pyx_n_s_get_ebias); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1397, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_14 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1397, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_ebias, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "h5py/h5t.pyx":1398
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and             # <<<<<<<<<<<<<<
 *                     (maxexp - 1) == ebias):
 *                 float_le[ftype_] = h5type
 */
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_finfo, __pyx_n_s_iexp); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_14, __pyx_v_esize, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1398, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 1398, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_17) {
      } else {
        __pyx_t_16 = __pyx_t_17;
        goto __pyx_L20_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_nmant); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = PyObject_RichCompare(__pyx_t_4, __pyx_v_msize, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1398, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 1398, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (__pyx_t_17) {
      } else {
        __pyx_t_16 = __pyx_t_17;
        goto __pyx_L20_bool_binop_done;
      }

      /* "h5py/h5t.pyx":1399
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and
 *                     (maxexp - 1) == ebias):             # <<<<<<<<<<<<<<
 *                 float_le[ftype_] = h5type
 *                 break # first found matches, related to #1244
 */
      __pyx_t_14 = __Pyx_PyInt_SubtractObjC(__pyx_v_maxexp, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1399, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_14, __pyx_v_ebias, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1399, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 1399, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_16 = __pyx_t_17;
      __pyx_L20_bool_binop_done:;

      /* "h5py/h5t.pyx":1398
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and             # <<<<<<<<<<<<<<
 *                     (maxexp - 1) == ebias):
 *                 float_le[ftype_] = h5type
 */
      if (__pyx_t_16) {

        /* "h5py/h5t.pyx":1400
 *             if (finfo.iexp == esize and nmant == msize and
 *                     (maxexp - 1) == ebias):
 *                 float_le[ftype_] = h5type             # <<<<<<<<<<<<<<
 *                 break # first found matches, related to #1244
 *     if ORDER_NATIVE == H5T_ORDER_LE:
 */
        if (unlikely(PyDict_SetItem(__pyx_v_float_le, __pyx_v_ftype_, __pyx_v_h5type) < 0)) __PYX_ERR(0, 1400, __pyx_L1_error)

        /* "h5py/h5t.pyx":1401
 *                     (maxexp - 1) == ebias):
 *                 float_le[ftype_] = h5type
 *                 break # first found matches, related to #1244             # <<<<<<<<<<<<<<
 *     if ORDER_NATIVE == H5T_ORDER_LE:
 *         float_nt = dict(float_le)
 */
        goto __pyx_L16_break;

        /* "h5py/h5t.pyx":1398
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 *             if (finfo.iexp == esize and nmant == msize and             # <<<<<<<<<<<<<<
 *                     (maxexp - 1) == ebias):
 *                 float_le[ftype_] = h5type
 */
      }

      /* "h5py/h5t.pyx":1395
 *                 float_be[ftype_] = h5type
 *                 break # first found matches, related to #1244
 *         for h5type in h5_le_list:             # <<<<<<<<<<<<<<
 *             spos, epos, esize, mpos, msize = h5type.get_fields()
 *             ebias = h5type.get_ebias()
 */
    }
    __pyx_L16_break:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "h5py/h5t.pyx":1386
 *     h5_le_list = [IEEE_F16LE, IEEE_F32LE, IEEE_F64LE, IEEE_F128LE, LDOUBLE_LE]
 * 
 *     for ftype_, finfo, size in _available_ftypes:             # <<<<<<<<<<<<<<
 *         nmant, maxexp, minexp = _correct_float_info(ftype_, finfo)
 *         for h5type in h5_be_list:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1402
 *                 float_le[ftype_] = h5type
 *                 break # first found matches, related to #1244
 *     if ORDER_NATIVE == H5T_ORDER_LE:             # <<<<<<<<<<<<<<
 *         float_nt = dict(float_le)
 *     else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ORDER_NATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 1402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_16) {

    /* "h5py/h5t.pyx":1403
 *                 break # first found matches, related to #1244
 *     if ORDER_NATIVE == H5T_ORDER_LE:
 *         float_nt = dict(float_le)             # <<<<<<<<<<<<<<
 *     else:
 *         float_nt = dict(float_be)
 */
    __pyx_t_4 = PyDict_Copy(__pyx_v_float_le); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_float_nt = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "h5py/h5t.pyx":1402
 *                 float_le[ftype_] = h5type
 *                 break # first found matches, related to #1244
 *     if ORDER_NATIVE == H5T_ORDER_LE:             # <<<<<<<<<<<<<<
 *         float_nt = dict(float_le)
 *     else:
 */
    goto __pyx_L23;
  }

  /* "h5py/h5t.pyx":1405
 *         float_nt = dict(float_le)
 *     else:
 *         float_nt = dict(float_be)             # <<<<<<<<<<<<<<
 *     return float_le, float_be, float_nt
 * 
 */
  /*else*/ {
    __pyx_t_4 = PyDict_Copy(__pyx_v_float_be); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_float_nt = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
  }
  __pyx_L23:;

  /* "h5py/h5t.pyx":1406
 *     else:
 *         float_nt = dict(float_be)
 *     return float_le, float_be, float_nt             # <<<<<<<<<<<<<<
 * 
 * cdef dict _float_le
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_float_le);
  __Pyx_GIVEREF(__pyx_v_float_le);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_float_le);
  __Pyx_INCREF(__pyx_v_float_be);
  __Pyx_GIVEREF(__pyx_v_float_be);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_float_be);
  __Pyx_INCREF(__pyx_v_float_nt);
  __Pyx_GIVEREF(__pyx_v_float_nt);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_float_nt);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1380
 * # transient and unlocked.
 * 
 * def _get_float_dtype_to_hdf5():             # <<<<<<<<<<<<<<
 *     float_le = {}
 *     float_be = {}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("h5py.h5t._get_float_dtype_to_hdf5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_float_le);
  __Pyx_XDECREF(__pyx_v_float_be);
  __Pyx_XDECREF(__pyx_v_h5_be_list);
  __Pyx_XDECREF(__pyx_v_h5_le_list);
  __Pyx_XDECREF(__pyx_v_ftype_);
  __Pyx_XDECREF(__pyx_v_finfo);
  __Pyx_XDECREF(__pyx_v_size);
  __Pyx_XDECREF(__pyx_v_maxexp);
  __Pyx_XDECREF(__pyx_v_h5type);
  __Pyx_XDECREF(__pyx_v_spos);
  __Pyx_XDECREF(__pyx_v_epos);
  __Pyx_XDECREF(__pyx_v_esize);
  __Pyx_XDECREF(__pyx_v_mpos);
  __Pyx_XDECREF(__pyx_v_msize);
  __Pyx_XDECREF(__pyx_v_ebias);
  __Pyx_XDECREF(__pyx_v_float_nt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1421
 * cdef dict _uint_nt = {1: H5Tcopy(H5T_NATIVE_UINT8), 2: H5Tcopy(H5T_NATIVE_UINT16), 4: H5Tcopy(H5T_NATIVE_UINT32), 8: H5Tcopy(H5T_NATIVE_UINT64)}
 * 
 * cdef TypeFloatID _c_float(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Floats (single and double)
 *     cdef TypeFloatID tid
 */

static struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_f_4h5py_3h5t__c_float(PyArray_Descr *__pyx_v_dt) {
  struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_v_tid = 0;
  struct __pyx_obj_4h5py_3h5t_TypeFloatID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_float", 0);

  /* "h5py/h5t.pyx":1425
 *     cdef TypeFloatID tid
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if dt.byteorder == c'<':
 *             tid = _float_le[np.dtype(dt).type]
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "h5py/h5t.pyx":1426
 * 
 *     try:
 *         if dt.byteorder == c'<':             # <<<<<<<<<<<<<<
 *             tid = _float_le[np.dtype(dt).type]
 *         elif dt.byteorder == c'>':
 */
      switch (__pyx_v_dt->byteorder) {
        case '<':

        /* "h5py/h5t.pyx":1427
 *     try:
 *         if dt.byteorder == c'<':
 *             tid = _float_le[np.dtype(dt).type]             # <<<<<<<<<<<<<<
 *         elif dt.byteorder == c'>':
 *             tid = _float_be[np.dtype(dt).type]
 */
        if (unlikely(__pyx_v_4h5py_3h5t__float_le == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1427, __pyx_L3_error)
        }
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1427, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1427, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, ((PyObject *)__pyx_v_dt)) : __Pyx_PyObject_CallOneArg(__pyx_t_6, ((PyObject *)__pyx_v_dt));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1427, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1427, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__float_le, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1427, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_4h5py_3h5t_TypeFloatID))))) __PYX_ERR(0, 1427, __pyx_L3_error)
        __pyx_v_tid = ((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_t_4);
        __pyx_t_4 = 0;

        /* "h5py/h5t.pyx":1426
 * 
 *     try:
 *         if dt.byteorder == c'<':             # <<<<<<<<<<<<<<
 *             tid = _float_le[np.dtype(dt).type]
 *         elif dt.byteorder == c'>':
 */
        break;
        case '>':

        /* "h5py/h5t.pyx":1429
 *             tid = _float_le[np.dtype(dt).type]
 *         elif dt.byteorder == c'>':
 *             tid = _float_be[np.dtype(dt).type]             # <<<<<<<<<<<<<<
 *         else:
 *             tid = _float_nt[np.dtype(dt).type]
 */
        if (unlikely(__pyx_v_4h5py_3h5t__float_be == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1429, __pyx_L3_error)
        }
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, ((PyObject *)__pyx_v_dt)) : __Pyx_PyObject_CallOneArg(__pyx_t_5, ((PyObject *)__pyx_v_dt));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__float_be, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_4h5py_3h5t_TypeFloatID))))) __PYX_ERR(0, 1429, __pyx_L3_error)
        __pyx_v_tid = ((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_t_4);
        __pyx_t_4 = 0;

        /* "h5py/h5t.pyx":1428
 *         if dt.byteorder == c'<':
 *             tid = _float_le[np.dtype(dt).type]
 *         elif dt.byteorder == c'>':             # <<<<<<<<<<<<<<
 *             tid = _float_be[np.dtype(dt).type]
 *         else:
 */
        break;
        default:

        /* "h5py/h5t.pyx":1431
 *             tid = _float_be[np.dtype(dt).type]
 *         else:
 *             tid = _float_nt[np.dtype(dt).type]             # <<<<<<<<<<<<<<
 *     except KeyError:
 *         raise TypeError("Unsupported float type (%s)" % dt)
 */
        if (unlikely(__pyx_v_4h5py_3h5t__float_nt == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1431, __pyx_L3_error)
        }
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1431, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1431, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, ((PyObject *)__pyx_v_dt)) : __Pyx_PyObject_CallOneArg(__pyx_t_6, ((PyObject *)__pyx_v_dt));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1431, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1431, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__float_nt, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1431, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_4h5py_3h5t_TypeFloatID))))) __PYX_ERR(0, 1431, __pyx_L3_error)
        __pyx_v_tid = ((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_t_4);
        __pyx_t_4 = 0;
        break;
      }

      /* "h5py/h5t.pyx":1425
 *     cdef TypeFloatID tid
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if dt.byteorder == c'<':
 *             tid = _float_le[np.dtype(dt).type]
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "h5py/h5t.pyx":1432
 *         else:
 *             tid = _float_nt[np.dtype(dt).type]
 *     except KeyError:             # <<<<<<<<<<<<<<
 *         raise TypeError("Unsupported float type (%s)" % dt)
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("h5py.h5t._c_float", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5) < 0) __PYX_ERR(0, 1432, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_5);

      /* "h5py/h5t.pyx":1433
 *             tid = _float_nt[np.dtype(dt).type]
 *     except KeyError:
 *         raise TypeError("Unsupported float type (%s)" % dt)             # <<<<<<<<<<<<<<
 * 
 *     return tid.copy()
 */
      __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_Unsupported_float_type_s, ((PyObject *)__pyx_v_dt)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(0, 1433, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "h5py/h5t.pyx":1425
 *     cdef TypeFloatID tid
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if dt.byteorder == c'<':
 *             tid = _float_le[np.dtype(dt).type]
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "h5py/h5t.pyx":1435
 *         raise TypeError("Unsupported float type (%s)" % dt)
 * 
 *     return tid.copy()             # <<<<<<<<<<<<<<
 * 
 * cdef TypeIntegerID _c_int(cnp.dtype dt):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_tid), __pyx_n_s_copy_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_4h5py_3h5t_TypeFloatID))))) __PYX_ERR(0, 1435, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)__pyx_t_5);
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1421
 * cdef dict _uint_nt = {1: H5Tcopy(H5T_NATIVE_UINT8), 2: H5Tcopy(H5T_NATIVE_UINT16), 4: H5Tcopy(H5T_NATIVE_UINT32), 8: H5Tcopy(H5T_NATIVE_UINT64)}
 * 
 * cdef TypeFloatID _c_float(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Floats (single and double)
 *     cdef TypeFloatID tid
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("h5py.h5t._c_float", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tid);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1437
 *     return tid.copy()
 * 
 * cdef TypeIntegerID _c_int(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Integers (ints and uints)
 *     cdef hid_t tid
 */

static struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_f_4h5py_3h5t__c_int(PyArray_Descr *__pyx_v_dt) {
  hid_t __pyx_v_tid;
  struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  hid_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_int", 0);

  /* "h5py/h5t.pyx":1441
 *     cdef hid_t tid
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if dt.kind == c'i':
 *             if dt.byteorder == c'<':
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "h5py/h5t.pyx":1442
 * 
 *     try:
 *         if dt.kind == c'i':             # <<<<<<<<<<<<<<
 *             if dt.byteorder == c'<':
 *                 tid = _int_le[dt.itemsize]
 */
      switch (__pyx_v_dt->kind) {
        case 'i':

        /* "h5py/h5t.pyx":1443
 *     try:
 *         if dt.kind == c'i':
 *             if dt.byteorder == c'<':             # <<<<<<<<<<<<<<
 *                 tid = _int_le[dt.itemsize]
 *             elif dt.byteorder == c'>':
 */
        switch (__pyx_v_dt->byteorder) {
          case '<':

          /* "h5py/h5t.pyx":1444
 *         if dt.kind == c'i':
 *             if dt.byteorder == c'<':
 *                 tid = _int_le[dt.itemsize]             # <<<<<<<<<<<<<<
 *             elif dt.byteorder == c'>':
 *                 tid = _int_be[dt.itemsize]
 */
          if (unlikely(__pyx_v_4h5py_3h5t__int_le == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1444, __pyx_L3_error)
          }
          __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_dt->elsize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1444, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__int_le, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1444, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_6 = __Pyx_PyInt_As_hid_t(__pyx_t_5); if (unlikely((__pyx_t_6 == ((hid_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1444, __pyx_L3_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_v_tid = __pyx_t_6;

          /* "h5py/h5t.pyx":1443
 *     try:
 *         if dt.kind == c'i':
 *             if dt.byteorder == c'<':             # <<<<<<<<<<<<<<
 *                 tid = _int_le[dt.itemsize]
 *             elif dt.byteorder == c'>':
 */
          break;
          case '>':

          /* "h5py/h5t.pyx":1446
 *                 tid = _int_le[dt.itemsize]
 *             elif dt.byteorder == c'>':
 *                 tid = _int_be[dt.itemsize]             # <<<<<<<<<<<<<<
 *             else:
 *                 tid = _int_nt[dt.itemsize]
 */
          if (unlikely(__pyx_v_4h5py_3h5t__int_be == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1446, __pyx_L3_error)
          }
          __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_dt->elsize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1446, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__int_be, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1446, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_6 = __Pyx_PyInt_As_hid_t(__pyx_t_4); if (unlikely((__pyx_t_6 == ((hid_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1446, __pyx_L3_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_v_tid = __pyx_t_6;

          /* "h5py/h5t.pyx":1445
 *             if dt.byteorder == c'<':
 *                 tid = _int_le[dt.itemsize]
 *             elif dt.byteorder == c'>':             # <<<<<<<<<<<<<<
 *                 tid = _int_be[dt.itemsize]
 *             else:
 */
          break;
          default:

          /* "h5py/h5t.pyx":1448
 *                 tid = _int_be[dt.itemsize]
 *             else:
 *                 tid = _int_nt[dt.itemsize]             # <<<<<<<<<<<<<<
 *         elif dt.kind == c'u':
 *             if dt.byteorder == c'<':
 */
          if (unlikely(__pyx_v_4h5py_3h5t__int_nt == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1448, __pyx_L3_error)
          }
          __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_dt->elsize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1448, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__int_nt, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1448, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_6 = __Pyx_PyInt_As_hid_t(__pyx_t_5); if (unlikely((__pyx_t_6 == ((hid_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1448, __pyx_L3_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_v_tid = __pyx_t_6;
          break;
        }

        /* "h5py/h5t.pyx":1442
 * 
 *     try:
 *         if dt.kind == c'i':             # <<<<<<<<<<<<<<
 *             if dt.byteorder == c'<':
 *                 tid = _int_le[dt.itemsize]
 */
        break;
        case 'u':

        /* "h5py/h5t.pyx":1450
 *                 tid = _int_nt[dt.itemsize]
 *         elif dt.kind == c'u':
 *             if dt.byteorder == c'<':             # <<<<<<<<<<<<<<
 *                 tid = _uint_le[dt.itemsize]
 *             elif dt.byteorder == c'>':
 */
        switch (__pyx_v_dt->byteorder) {
          case '<':

          /* "h5py/h5t.pyx":1451
 *         elif dt.kind == c'u':
 *             if dt.byteorder == c'<':
 *                 tid = _uint_le[dt.itemsize]             # <<<<<<<<<<<<<<
 *             elif dt.byteorder == c'>':
 *                 tid = _uint_be[dt.itemsize]
 */
          if (unlikely(__pyx_v_4h5py_3h5t__uint_le == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1451, __pyx_L3_error)
          }
          __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_dt->elsize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1451, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__uint_le, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1451, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_6 = __Pyx_PyInt_As_hid_t(__pyx_t_4); if (unlikely((__pyx_t_6 == ((hid_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1451, __pyx_L3_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_v_tid = __pyx_t_6;

          /* "h5py/h5t.pyx":1450
 *                 tid = _int_nt[dt.itemsize]
 *         elif dt.kind == c'u':
 *             if dt.byteorder == c'<':             # <<<<<<<<<<<<<<
 *                 tid = _uint_le[dt.itemsize]
 *             elif dt.byteorder == c'>':
 */
          break;
          case '>':

          /* "h5py/h5t.pyx":1453
 *                 tid = _uint_le[dt.itemsize]
 *             elif dt.byteorder == c'>':
 *                 tid = _uint_be[dt.itemsize]             # <<<<<<<<<<<<<<
 *             else:
 *                 tid = _uint_nt[dt.itemsize]
 */
          if (unlikely(__pyx_v_4h5py_3h5t__uint_be == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1453, __pyx_L3_error)
          }
          __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_dt->elsize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1453, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__uint_be, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1453, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_6 = __Pyx_PyInt_As_hid_t(__pyx_t_5); if (unlikely((__pyx_t_6 == ((hid_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1453, __pyx_L3_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_v_tid = __pyx_t_6;

          /* "h5py/h5t.pyx":1452
 *             if dt.byteorder == c'<':
 *                 tid = _uint_le[dt.itemsize]
 *             elif dt.byteorder == c'>':             # <<<<<<<<<<<<<<
 *                 tid = _uint_be[dt.itemsize]
 *             else:
 */
          break;
          default:

          /* "h5py/h5t.pyx":1455
 *                 tid = _uint_be[dt.itemsize]
 *             else:
 *                 tid = _uint_nt[dt.itemsize]             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError('Illegal int kind "%s"' % dt.kind)
 */
          if (unlikely(__pyx_v_4h5py_3h5t__uint_nt == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1455, __pyx_L3_error)
          }
          __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_dt->elsize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1455, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_4h5py_3h5t__uint_nt, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1455, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_6 = __Pyx_PyInt_As_hid_t(__pyx_t_4); if (unlikely((__pyx_t_6 == ((hid_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1455, __pyx_L3_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_v_tid = __pyx_t_6;
          break;
        }

        /* "h5py/h5t.pyx":1449
 *             else:
 *                 tid = _int_nt[dt.itemsize]
 *         elif dt.kind == c'u':             # <<<<<<<<<<<<<<
 *             if dt.byteorder == c'<':
 *                 tid = _uint_le[dt.itemsize]
 */
        break;
        default:

        /* "h5py/h5t.pyx":1457
 *                 tid = _uint_nt[dt.itemsize]
 *         else:
 *             raise TypeError('Illegal int kind "%s"' % dt.kind)             # <<<<<<<<<<<<<<
 *     except KeyError:
 *         raise TypeError("Unsupported integer size (%s)" % dt.itemsize)
 */
        __pyx_t_4 = __Pyx_PyInt_From_char(__pyx_v_dt->kind); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1457, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyUnicode_Format(__pyx_kp_u_Illegal_int_kind_s, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1457, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1457, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1457, __pyx_L3_error)
        break;
      }

      /* "h5py/h5t.pyx":1441
 *     cdef hid_t tid
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if dt.kind == c'i':
 *             if dt.byteorder == c'<':
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "h5py/h5t.pyx":1458
 *         else:
 *             raise TypeError('Illegal int kind "%s"' % dt.kind)
 *     except KeyError:             # <<<<<<<<<<<<<<
 *         raise TypeError("Unsupported integer size (%s)" % dt.itemsize)
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("h5py.h5t._c_int", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_8) < 0) __PYX_ERR(0, 1458, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_8);

      /* "h5py/h5t.pyx":1459
 *             raise TypeError('Illegal int kind "%s"' % dt.kind)
 *     except KeyError:
 *         raise TypeError("Unsupported integer size (%s)" % dt.itemsize)             # <<<<<<<<<<<<<<
 * 
 *     return TypeIntegerID(H5Tcopy(tid))
 */
      __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_dt->elsize); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1459, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = PyUnicode_Format(__pyx_kp_u_Unsupported_integer_size_s, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1459, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1459, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(0, 1459, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "h5py/h5t.pyx":1441
 *     cdef hid_t tid
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if dt.kind == c'i':
 *             if dt.byteorder == c'<':
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "h5py/h5t.pyx":1461
 *         raise TypeError("Unsupported integer size (%s)" % dt.itemsize)
 * 
 *     return TypeIntegerID(H5Tcopy(tid))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_6 = __pyx_f_4h5py_4defs_H5Tcopy(__pyx_v_tid); if (unlikely(__pyx_t_6 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1461, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyInt_From_hid_t(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeIntegerID), __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeIntegerID *)__pyx_t_5);
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1437
 *     return tid.copy()
 * 
 * cdef TypeIntegerID _c_int(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Integers (ints and uints)
 *     cdef hid_t tid
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("h5py.h5t._c_int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1464
 * 
 * 
 * cdef TypeEnumID _c_enum(cnp.dtype dt, dict vals):             # <<<<<<<<<<<<<<
 *     # Enums
 *     cdef:
 */

static struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_f_4h5py_3h5t__c_enum(PyArray_Descr *__pyx_v_dt, PyObject *__pyx_v_vals) {
  struct __pyx_obj_4h5py_3h5t_TypeIntegerID *__pyx_v_base = 0;
  struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_out = 0;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_bname = NULL;
  struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  hid_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_enum", 0);

  /* "h5py/h5t.pyx":1470
 *         TypeEnumID out
 * 
 *     base = _c_int(dt)             # <<<<<<<<<<<<<<
 * 
 *     out = TypeEnumID(H5Tenum_create(base.id))
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_4h5py_3h5t__c_int(__pyx_v_dt)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_base = ((struct __pyx_obj_4h5py_3h5t_TypeIntegerID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1472
 *     base = _c_int(dt)
 * 
 *     out = TypeEnumID(H5Tenum_create(base.id))             # <<<<<<<<<<<<<<
 *     for name in sorted(vals):
 *         if isinstance(name, bytes):
 */
  __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tenum_create(__pyx_v_base->__pyx_base.__pyx_base.__pyx_base.id); if (unlikely(__pyx_t_2 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1472, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyInt_From_hid_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_out = ((struct __pyx_obj_4h5py_3h5t_TypeEnumID *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "h5py/h5t.pyx":1473
 * 
 *     out = TypeEnumID(H5Tenum_create(base.id))
 *     for name in sorted(vals):             # <<<<<<<<<<<<<<
 *         if isinstance(name, bytes):
 *             bname = name
 */
  __pyx_t_1 = PySequence_List(__pyx_v_vals); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_4 = PyList_Sort(__pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1473, __pyx_L1_error)
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1473, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_t_3; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1473, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "h5py/h5t.pyx":1474
 *     out = TypeEnumID(H5Tenum_create(base.id))
 *     for name in sorted(vals):
 *         if isinstance(name, bytes):             # <<<<<<<<<<<<<<
 *             bname = name
 *         else:
 */
    __pyx_t_6 = PyBytes_Check(__pyx_v_name); 
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {

      /* "h5py/h5t.pyx":1475
 *     for name in sorted(vals):
 *         if isinstance(name, bytes):
 *             bname = name             # <<<<<<<<<<<<<<
 *         else:
 *             bname = unicode(name).encode('utf8')
 */
      __Pyx_INCREF(__pyx_v_name);
      __Pyx_XDECREF_SET(__pyx_v_bname, __pyx_v_name);

      /* "h5py/h5t.pyx":1474
 *     out = TypeEnumID(H5Tenum_create(base.id))
 *     for name in sorted(vals):
 *         if isinstance(name, bytes):             # <<<<<<<<<<<<<<
 *             bname = name
 *         else:
 */
      goto __pyx_L5;
    }

    /* "h5py/h5t.pyx":1477
 *             bname = name
 *         else:
 *             bname = unicode(name).encode('utf8')             # <<<<<<<<<<<<<<
 *         out.enum_insert(bname, vals[name])
 *     return out
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Unicode(__pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = PyUnicode_AsUTF8String(((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_bname, __pyx_t_8);
      __pyx_t_8 = 0;
    }
    __pyx_L5:;

    /* "h5py/h5t.pyx":1478
 *         else:
 *             bname = unicode(name).encode('utf8')
 *         out.enum_insert(bname, vals[name])             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_out), __pyx_n_s_enum_insert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(__pyx_v_vals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1478, __pyx_L1_error)
    }
    __pyx_t_9 = __Pyx_PyDict_GetItem(__pyx_v_vals, __pyx_v_name); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = NULL;
    __pyx_t_11 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_11 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_v_bname, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1478, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_v_bname, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1478, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1478, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      if (__pyx_t_10) {
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
      }
      __Pyx_INCREF(__pyx_v_bname);
      __Pyx_GIVEREF(__pyx_v_bname);
      PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_v_bname);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_12, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1478, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "h5py/h5t.pyx":1473
 * 
 *     out = TypeEnumID(H5Tenum_create(base.id))
 *     for name in sorted(vals):             # <<<<<<<<<<<<<<
 *         if isinstance(name, bytes):
 *             bname = name
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1479
 *             bname = unicode(name).encode('utf8')
 *         out.enum_insert(bname, vals[name])
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_out));
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1464
 * 
 * 
 * cdef TypeEnumID _c_enum(cnp.dtype dt, dict vals):             # <<<<<<<<<<<<<<
 *     # Enums
 *     cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("h5py.h5t._c_enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_base);
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_bname);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1482
 * 
 * 
 * cdef TypeEnumID _c_bool(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Booleans
 *     global cfg
 */

static struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_f_4h5py_3h5t__c_bool(CYTHON_UNUSED PyArray_Descr *__pyx_v_dt) {
  struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_v_out = 0;
  struct __pyx_obj_4h5py_3h5t_TypeEnumID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_bool", 0);

  /* "h5py/h5t.pyx":1487
 * 
 *     cdef TypeEnumID out
 *     out = TypeEnumID(H5Tenum_create(H5T_NATIVE_INT8))             # <<<<<<<<<<<<<<
 * 
 *     out.enum_insert(cfg._f_name, 0)
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tenum_create(H5T_NATIVE_INT8); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1487, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_hid_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID), __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_out = ((struct __pyx_obj_4h5py_3h5t_TypeEnumID *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "h5py/h5t.pyx":1489
 *     out = TypeEnumID(H5Tenum_create(H5T_NATIVE_INT8))
 * 
 *     out.enum_insert(cfg._f_name, 0)             # <<<<<<<<<<<<<<
 *     out.enum_insert(cfg._t_name, 1)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_out), __pyx_n_s_enum_insert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_cfg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_f_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_5, __pyx_int_0};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_5, __pyx_int_0};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_t_5);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_int_0);
    __pyx_t_5 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "h5py/h5t.pyx":1490
 * 
 *     out.enum_insert(cfg._f_name, 0)
 *     out.enum_insert(cfg._t_name, 1)             # <<<<<<<<<<<<<<
 * 
 *     return out
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_out), __pyx_n_s_enum_insert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_cfg); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_t_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_5, __pyx_int_1};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1490, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_5, __pyx_int_1};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1490, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_4 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_6, __pyx_t_5);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_6, __pyx_int_1);
    __pyx_t_5 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "h5py/h5t.pyx":1492
 *     out.enum_insert(cfg._t_name, 1)
 * 
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_out));
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1482
 * 
 * 
 * cdef TypeEnumID _c_bool(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Booleans
 *     global cfg
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t._c_bool", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1495
 * 
 * 
 * cdef TypeArrayID _c_array(cnp.dtype dt, int logical):             # <<<<<<<<<<<<<<
 *     # Arrays
 *     cdef:
 */

static struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_f_4h5py_3h5t__c_array(PyArray_Descr *__pyx_v_dt, int __pyx_v_logical) {
  PyArray_Descr *__pyx_v_base = 0;
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_type_base = 0;
  PyObject *__pyx_v_shape = 0;
  struct __pyx_obj_4h5py_3h5t_TypeArrayID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  struct __pyx_opt_args_4h5py_3h5t_py_create __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_array", 0);

  /* "h5py/h5t.pyx":1502
 *         object shape
 * 
 *     base, shape = dt.subdtype             # <<<<<<<<<<<<<<
 *     try:
 *         shape = tuple(shape)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_subdtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1502, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < 0) __PYX_ERR(0, 1502, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1502, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 1502, __pyx_L1_error)
  __pyx_v_base = ((PyArray_Descr *)__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "h5py/h5t.pyx":1503
 * 
 *     base, shape = dt.subdtype
 *     try:             # <<<<<<<<<<<<<<
 *         shape = tuple(shape)
 *     except TypeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "h5py/h5t.pyx":1504
 *     base, shape = dt.subdtype
 *     try:
 *         shape = tuple(shape)             # <<<<<<<<<<<<<<
 *     except TypeError:
 *         try:
 */
      __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_v_shape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1504, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_shape, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "h5py/h5t.pyx":1503
 * 
 *     base, shape = dt.subdtype
 *     try:             # <<<<<<<<<<<<<<
 *         shape = tuple(shape)
 *     except TypeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "h5py/h5t.pyx":1505
 *     try:
 *         shape = tuple(shape)
 *     except TypeError:             # <<<<<<<<<<<<<<
 *         try:
 *             shape = (int(shape),)
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
    if (__pyx_t_9) {
      __Pyx_AddTraceback("h5py.h5t._c_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 1505, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);

      /* "h5py/h5t.pyx":1506
 *         shape = tuple(shape)
 *     except TypeError:
 *         try:             # <<<<<<<<<<<<<<
 *             shape = (int(shape),)
 *         except TypeError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        /*try:*/ {

          /* "h5py/h5t.pyx":1507
 *     except TypeError:
 *         try:
 *             shape = (int(shape),)             # <<<<<<<<<<<<<<
 *         except TypeError:
 *             raise TypeError("Array shape for dtype must be a sequence or integer")
 */
          __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_v_shape); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1507, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1507, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_4);
          PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_4);
          __pyx_t_4 = 0;
          __Pyx_DECREF_SET(__pyx_v_shape, __pyx_t_13);
          __pyx_t_13 = 0;

          /* "h5py/h5t.pyx":1506
 *         shape = tuple(shape)
 *     except TypeError:
 *         try:             # <<<<<<<<<<<<<<
 *             shape = (int(shape),)
 *         except TypeError:
 */
        }
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L20_try_end;
        __pyx_L13_error:;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "h5py/h5t.pyx":1508
 *         try:
 *             shape = (int(shape),)
 *         except TypeError:             # <<<<<<<<<<<<<<
 *             raise TypeError("Array shape for dtype must be a sequence or integer")
 *     type_base = py_create(base, logical=logical)
 */
        __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
        if (__pyx_t_9) {
          __Pyx_AddTraceback("h5py.h5t._c_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_4, &__pyx_t_14) < 0) __PYX_ERR(0, 1508, __pyx_L15_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_t_14);

          /* "h5py/h5t.pyx":1509
 *             shape = (int(shape),)
 *         except TypeError:
 *             raise TypeError("Array shape for dtype must be a sequence or integer")             # <<<<<<<<<<<<<<
 *     type_base = py_create(base, logical=logical)
 *     return array_create(type_base, shape)
 */
          __pyx_t_15 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1509, __pyx_L15_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_Raise(__pyx_t_15, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __PYX_ERR(0, 1509, __pyx_L15_except_error)
        }
        goto __pyx_L15_except_error;
        __pyx_L15_except_error:;

        /* "h5py/h5t.pyx":1506
 *         shape = tuple(shape)
 *     except TypeError:
 *         try:             # <<<<<<<<<<<<<<
 *             shape = (int(shape),)
 *         except TypeError:
 */
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
        goto __pyx_L7_except_error;
        __pyx_L20_try_end:;
      }
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L6_exception_handled;
    }
    goto __pyx_L7_except_error;
    __pyx_L7_except_error:;

    /* "h5py/h5t.pyx":1503
 * 
 *     base, shape = dt.subdtype
 *     try:             # <<<<<<<<<<<<<<
 *         shape = tuple(shape)
 *     except TypeError:
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L6_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_L10_try_end:;
  }

  /* "h5py/h5t.pyx":1510
 *         except TypeError:
 *             raise TypeError("Array shape for dtype must be a sequence or integer")
 *     type_base = py_create(base, logical=logical)             # <<<<<<<<<<<<<<
 *     return array_create(type_base, shape)
 * 
 */
  __pyx_t_16.__pyx_n = 1;
  __pyx_t_16.logical = __pyx_v_logical;
  __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_py_create(((PyObject *)__pyx_v_base), 0, &__pyx_t_16)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_type_base = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1511
 *             raise TypeError("Array shape for dtype must be a sequence or integer")
 *     type_base = py_create(base, logical=logical)
 *     return array_create(type_base, shape)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_array_create); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = NULL;
  __pyx_t_9 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_9 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_1, ((PyObject *)__pyx_v_type_base), __pyx_v_shape};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1511, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_1, ((PyObject *)__pyx_v_type_base), __pyx_v_shape};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1511, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else
  #endif
  {
    __pyx_t_14 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (__pyx_t_1) {
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_1); __pyx_t_1 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_type_base));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_type_base));
    PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_9, ((PyObject *)__pyx_v_type_base));
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_9, __pyx_v_shape);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_14, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_4h5py_3h5t_TypeArrayID))))) __PYX_ERR(0, 1511, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeArrayID *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1495
 * 
 * 
 * cdef TypeArrayID _c_array(cnp.dtype dt, int logical):             # <<<<<<<<<<<<<<
 *     # Arrays
 *     cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("h5py.h5t._c_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_base);
  __Pyx_XDECREF((PyObject *)__pyx_v_type_base);
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1514
 * 
 * 
 * cdef TypeOpaqueID _c_opaque(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Opaque
 *     return TypeOpaqueID(H5Tcreate(H5T_OPAQUE, dt.itemsize))
 */

static struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_f_4h5py_3h5t__c_opaque(PyArray_Descr *__pyx_v_dt) {
  struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_opaque", 0);

  /* "h5py/h5t.pyx":1516
 * cdef TypeOpaqueID _c_opaque(cnp.dtype dt):
 *     # Opaque
 *     return TypeOpaqueID(H5Tcreate(H5T_OPAQUE, dt.itemsize))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tcreate(H5T_OPAQUE, __pyx_v_dt->elsize); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1516, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_hid_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeOpaqueID), __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1514
 * 
 * 
 * cdef TypeOpaqueID _c_opaque(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Opaque
 *     return TypeOpaqueID(H5Tcreate(H5T_OPAQUE, dt.itemsize))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t._c_opaque", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1519
 * 
 * 
 * cdef TypeOpaqueID _c_opaque_tagged(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     """Create an HDF5 opaque data type with a tag recording the numpy dtype.
 * 
 */

static struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_f_4h5py_3h5t__c_opaque_tagged(PyArray_Descr *__pyx_v_dt) {
  struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_v_new_type = 0;
  struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_opaque_tagged", 0);

  /* "h5py/h5t.pyx":1528
 *     ``b"NUMPY:" + dt_in.descr[0][1].encode()``.
 *     """
 *     cdef TypeOpaqueID new_type = _c_opaque(dt)             # <<<<<<<<<<<<<<
 *     new_type.set_tag(b"NUMPY:" + dt.descr[0][1].encode())
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_4h5py_3h5t__c_opaque(__pyx_v_dt)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_new_type = ((struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1529
 *     """
 *     cdef TypeOpaqueID new_type = _c_opaque(dt)
 *     new_type.set_tag(b"NUMPY:" + dt.descr[0][1].encode())             # <<<<<<<<<<<<<<
 * 
 *     return new_type
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_new_type), __pyx_n_s_set_tag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_descr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_5, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_encode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Add(__pyx_kp_b_NUMPY, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1531
 *     new_type.set_tag(b"NUMPY:" + dt.descr[0][1].encode())
 * 
 *     return new_type             # <<<<<<<<<<<<<<
 * 
 * cdef TypeStringID _c_string(cnp.dtype dt):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_new_type));
  __pyx_r = __pyx_v_new_type;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1519
 * 
 * 
 * cdef TypeOpaqueID _c_opaque_tagged(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     """Create an HDF5 opaque data type with a tag recording the numpy dtype.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("h5py.h5t._c_opaque_tagged", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_new_type);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1533
 *     return new_type
 * 
 * cdef TypeStringID _c_string(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Strings (fixed-length)
 *     cdef hid_t tid
 */

static struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_f_4h5py_3h5t__c_string(PyArray_Descr *__pyx_v_dt) {
  hid_t __pyx_v_tid;
  struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  herr_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_string", 0);

  /* "h5py/h5t.pyx":1537
 *     cdef hid_t tid
 * 
 *     tid = H5Tcopy(H5T_C_S1)             # <<<<<<<<<<<<<<
 *     H5Tset_size(tid, dt.itemsize)
 *     H5Tset_strpad(tid, H5T_STR_NULLPAD)
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_C_S1); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1537, __pyx_L1_error)
  __pyx_v_tid = __pyx_t_1;

  /* "h5py/h5t.pyx":1538
 * 
 *     tid = H5Tcopy(H5T_C_S1)
 *     H5Tset_size(tid, dt.itemsize)             # <<<<<<<<<<<<<<
 *     H5Tset_strpad(tid, H5T_STR_NULLPAD)
 *     if dt.metadata and dt.metadata.get('h5py_encoding') == 'utf-8':
 */
  __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tset_size(__pyx_v_tid, __pyx_v_dt->elsize); if (unlikely(__pyx_t_2 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1538, __pyx_L1_error)

  /* "h5py/h5t.pyx":1539
 *     tid = H5Tcopy(H5T_C_S1)
 *     H5Tset_size(tid, dt.itemsize)
 *     H5Tset_strpad(tid, H5T_STR_NULLPAD)             # <<<<<<<<<<<<<<
 *     if dt.metadata and dt.metadata.get('h5py_encoding') == 'utf-8':
 *         H5Tset_cset(tid, H5T_CSET_UTF8)
 */
  __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tset_strpad(__pyx_v_tid, H5T_STR_NULLPAD); if (unlikely(__pyx_t_2 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1539, __pyx_L1_error)

  /* "h5py/h5t.pyx":1540
 *     H5Tset_size(tid, dt.itemsize)
 *     H5Tset_strpad(tid, H5T_STR_NULLPAD)
 *     if dt.metadata and dt.metadata.get('h5py_encoding') == 'utf-8':             # <<<<<<<<<<<<<<
 *         H5Tset_cset(tid, H5T_CSET_UTF8)
 *     return TypeStringID(tid)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_metadata); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_metadata); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_get); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_6, __pyx_n_u_h5py_encoding) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_h5py_encoding);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_kp_u_utf_8, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "h5py/h5t.pyx":1541
 *     H5Tset_strpad(tid, H5T_STR_NULLPAD)
 *     if dt.metadata and dt.metadata.get('h5py_encoding') == 'utf-8':
 *         H5Tset_cset(tid, H5T_CSET_UTF8)             # <<<<<<<<<<<<<<
 *     return TypeStringID(tid)
 * 
 */
    __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tset_cset(__pyx_v_tid, H5T_CSET_UTF8); if (unlikely(__pyx_t_2 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1541, __pyx_L1_error)

    /* "h5py/h5t.pyx":1540
 *     H5Tset_size(tid, dt.itemsize)
 *     H5Tset_strpad(tid, H5T_STR_NULLPAD)
 *     if dt.metadata and dt.metadata.get('h5py_encoding') == 'utf-8':             # <<<<<<<<<<<<<<
 *         H5Tset_cset(tid, H5T_CSET_UTF8)
 *     return TypeStringID(tid)
 */
  }

  /* "h5py/h5t.pyx":1542
 *     if dt.metadata and dt.metadata.get('h5py_encoding') == 'utf-8':
 *         H5Tset_cset(tid, H5T_CSET_UTF8)
 *     return TypeStringID(tid)             # <<<<<<<<<<<<<<
 * 
 * cdef TypeCompoundID _c_complex(cnp.dtype dt):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_4 = __Pyx_PyInt_From_hid_t(__pyx_v_tid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID), __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeStringID *)__pyx_t_7);
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1533
 *     return new_type
 * 
 * cdef TypeStringID _c_string(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Strings (fixed-length)
 *     cdef hid_t tid
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t._c_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1544
 *     return TypeStringID(tid)
 * 
 * cdef TypeCompoundID _c_complex(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Complex numbers (names depend on cfg)
 *     global cfg
 */

static struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_f_4h5py_3h5t__c_complex(PyArray_Descr *__pyx_v_dt) {
  hid_t __pyx_v_tid;
  hid_t __pyx_v_tid_sub;
  size_t __pyx_v_size;
  size_t __pyx_v_off_r;
  size_t __pyx_v_off_i;
  size_t __pyx_v_length;
  char __pyx_v_byteorder;
  struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  char __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  hid_t __pyx_t_5;
  char *__pyx_t_6;
  herr_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_complex", 0);

  /* "h5py/h5t.pyx":1551
 *     cdef size_t size, off_r, off_i
 * 
 *     cdef size_t length = dt.itemsize             # <<<<<<<<<<<<<<
 *     cdef char byteorder = dt.byteorder
 * 
 */
  __pyx_t_1 = __pyx_v_dt->elsize;
  __pyx_v_length = __pyx_t_1;

  /* "h5py/h5t.pyx":1552
 * 
 *     cdef size_t length = dt.itemsize
 *     cdef char byteorder = dt.byteorder             # <<<<<<<<<<<<<<
 * 
 *     if length == 8:
 */
  __pyx_t_2 = __pyx_v_dt->byteorder;
  __pyx_v_byteorder = __pyx_t_2;

  /* "h5py/h5t.pyx":1554
 *     cdef char byteorder = dt.byteorder
 * 
 *     if length == 8:             # <<<<<<<<<<<<<<
 *         size = h5py_size_n64
 *         off_r = h5py_offset_n64_real
 */
  switch (__pyx_v_length) {
    case 8:

    /* "h5py/h5t.pyx":1555
 * 
 *     if length == 8:
 *         size = h5py_size_n64             # <<<<<<<<<<<<<<
 *         off_r = h5py_offset_n64_real
 *         off_i = h5py_offset_n64_imag
 */
    __pyx_v_size = h5py_size_n64;

    /* "h5py/h5t.pyx":1556
 *     if length == 8:
 *         size = h5py_size_n64
 *         off_r = h5py_offset_n64_real             # <<<<<<<<<<<<<<
 *         off_i = h5py_offset_n64_imag
 *         if byteorder == c'<':
 */
    __pyx_v_off_r = h5py_offset_n64_real;

    /* "h5py/h5t.pyx":1557
 *         size = h5py_size_n64
 *         off_r = h5py_offset_n64_real
 *         off_i = h5py_offset_n64_imag             # <<<<<<<<<<<<<<
 *         if byteorder == c'<':
 *             tid_sub = H5T_IEEE_F32LE
 */
    __pyx_v_off_i = h5py_offset_n64_imag;

    /* "h5py/h5t.pyx":1558
 *         off_r = h5py_offset_n64_real
 *         off_i = h5py_offset_n64_imag
 *         if byteorder == c'<':             # <<<<<<<<<<<<<<
 *             tid_sub = H5T_IEEE_F32LE
 *         elif byteorder == c'>':
 */
    switch (__pyx_v_byteorder) {
      case '<':

      /* "h5py/h5t.pyx":1559
 *         off_i = h5py_offset_n64_imag
 *         if byteorder == c'<':
 *             tid_sub = H5T_IEEE_F32LE             # <<<<<<<<<<<<<<
 *         elif byteorder == c'>':
 *             tid_sub = H5T_IEEE_F32BE
 */
      __pyx_v_tid_sub = H5T_IEEE_F32LE;

      /* "h5py/h5t.pyx":1558
 *         off_r = h5py_offset_n64_real
 *         off_i = h5py_offset_n64_imag
 *         if byteorder == c'<':             # <<<<<<<<<<<<<<
 *             tid_sub = H5T_IEEE_F32LE
 *         elif byteorder == c'>':
 */
      break;
      case '>':

      /* "h5py/h5t.pyx":1561
 *             tid_sub = H5T_IEEE_F32LE
 *         elif byteorder == c'>':
 *             tid_sub = H5T_IEEE_F32BE             # <<<<<<<<<<<<<<
 *         else:
 *             tid_sub = H5T_NATIVE_FLOAT
 */
      __pyx_v_tid_sub = H5T_IEEE_F32BE;

      /* "h5py/h5t.pyx":1560
 *         if byteorder == c'<':
 *             tid_sub = H5T_IEEE_F32LE
 *         elif byteorder == c'>':             # <<<<<<<<<<<<<<
 *             tid_sub = H5T_IEEE_F32BE
 *         else:
 */
      break;
      default:

      /* "h5py/h5t.pyx":1563
 *             tid_sub = H5T_IEEE_F32BE
 *         else:
 *             tid_sub = H5T_NATIVE_FLOAT             # <<<<<<<<<<<<<<
 *     elif length == 16:
 *         size = h5py_size_n128
 */
      __pyx_v_tid_sub = H5T_NATIVE_FLOAT;
      break;
    }

    /* "h5py/h5t.pyx":1554
 *     cdef char byteorder = dt.byteorder
 * 
 *     if length == 8:             # <<<<<<<<<<<<<<
 *         size = h5py_size_n64
 *         off_r = h5py_offset_n64_real
 */
    break;
    case 16:

    /* "h5py/h5t.pyx":1565
 *             tid_sub = H5T_NATIVE_FLOAT
 *     elif length == 16:
 *         size = h5py_size_n128             # <<<<<<<<<<<<<<
 *         off_r = h5py_offset_n128_real
 *         off_i = h5py_offset_n128_imag
 */
    __pyx_v_size = h5py_size_n128;

    /* "h5py/h5t.pyx":1566
 *     elif length == 16:
 *         size = h5py_size_n128
 *         off_r = h5py_offset_n128_real             # <<<<<<<<<<<<<<
 *         off_i = h5py_offset_n128_imag
 *         if byteorder == c'<':
 */
    __pyx_v_off_r = h5py_offset_n128_real;

    /* "h5py/h5t.pyx":1567
 *         size = h5py_size_n128
 *         off_r = h5py_offset_n128_real
 *         off_i = h5py_offset_n128_imag             # <<<<<<<<<<<<<<
 *         if byteorder == c'<':
 *             tid_sub = H5T_IEEE_F64LE
 */
    __pyx_v_off_i = h5py_offset_n128_imag;

    /* "h5py/h5t.pyx":1568
 *         off_r = h5py_offset_n128_real
 *         off_i = h5py_offset_n128_imag
 *         if byteorder == c'<':             # <<<<<<<<<<<<<<
 *             tid_sub = H5T_IEEE_F64LE
 *         elif byteorder == c'>':
 */
    switch (__pyx_v_byteorder) {
      case '<':

      /* "h5py/h5t.pyx":1569
 *         off_i = h5py_offset_n128_imag
 *         if byteorder == c'<':
 *             tid_sub = H5T_IEEE_F64LE             # <<<<<<<<<<<<<<
 *         elif byteorder == c'>':
 *             tid_sub = H5T_IEEE_F64BE
 */
      __pyx_v_tid_sub = H5T_IEEE_F64LE;

      /* "h5py/h5t.pyx":1568
 *         off_r = h5py_offset_n128_real
 *         off_i = h5py_offset_n128_imag
 *         if byteorder == c'<':             # <<<<<<<<<<<<<<
 *             tid_sub = H5T_IEEE_F64LE
 *         elif byteorder == c'>':
 */
      break;
      case '>':

      /* "h5py/h5t.pyx":1571
 *             tid_sub = H5T_IEEE_F64LE
 *         elif byteorder == c'>':
 *             tid_sub = H5T_IEEE_F64BE             # <<<<<<<<<<<<<<
 *         else:
 *             tid_sub = H5T_NATIVE_DOUBLE
 */
      __pyx_v_tid_sub = H5T_IEEE_F64BE;

      /* "h5py/h5t.pyx":1570
 *         if byteorder == c'<':
 *             tid_sub = H5T_IEEE_F64LE
 *         elif byteorder == c'>':             # <<<<<<<<<<<<<<
 *             tid_sub = H5T_IEEE_F64BE
 *         else:
 */
      break;
      default:

      /* "h5py/h5t.pyx":1573
 *             tid_sub = H5T_IEEE_F64BE
 *         else:
 *             tid_sub = H5T_NATIVE_DOUBLE             # <<<<<<<<<<<<<<
 * 
 *     elif length == 32:
 */
      __pyx_v_tid_sub = H5T_NATIVE_DOUBLE;
      break;
    }

    /* "h5py/h5t.pyx":1564
 *         else:
 *             tid_sub = H5T_NATIVE_FLOAT
 *     elif length == 16:             # <<<<<<<<<<<<<<
 *         size = h5py_size_n128
 *         off_r = h5py_offset_n128_real
 */
    break;
    case 32:

    /* "h5py/h5t.pyx":1577
 *     elif length == 32:
 *         IF COMPLEX256_SUPPORT:
 *             size = h5py_size_n256             # <<<<<<<<<<<<<<
 *             off_r = h5py_offset_n256_real
 *             off_i = h5py_offset_n256_imag
 */
    __pyx_v_size = h5py_size_n256;

    /* "h5py/h5t.pyx":1578
 *         IF COMPLEX256_SUPPORT:
 *             size = h5py_size_n256
 *             off_r = h5py_offset_n256_real             # <<<<<<<<<<<<<<
 *             off_i = h5py_offset_n256_imag
 *             tid_sub = H5T_NATIVE_LDOUBLE
 */
    __pyx_v_off_r = h5py_offset_n256_real;

    /* "h5py/h5t.pyx":1579
 *             size = h5py_size_n256
 *             off_r = h5py_offset_n256_real
 *             off_i = h5py_offset_n256_imag             # <<<<<<<<<<<<<<
 *             tid_sub = H5T_NATIVE_LDOUBLE
 *         ELSE:
 */
    __pyx_v_off_i = h5py_offset_n256_imag;

    /* "h5py/h5t.pyx":1580
 *             off_r = h5py_offset_n256_real
 *             off_i = h5py_offset_n256_imag
 *             tid_sub = H5T_NATIVE_LDOUBLE             # <<<<<<<<<<<<<<
 *         ELSE:
 *             raise TypeError("Illegal length %d for complex dtype" % length)
 */
    __pyx_v_tid_sub = H5T_NATIVE_LDOUBLE;

    /* "h5py/h5t.pyx":1575
 *             tid_sub = H5T_NATIVE_DOUBLE
 * 
 *     elif length == 32:             # <<<<<<<<<<<<<<
 *         IF COMPLEX256_SUPPORT:
 *             size = h5py_size_n256
 */
    break;
    default:

    /* "h5py/h5t.pyx":1584
 *             raise TypeError("Illegal length %d for complex dtype" % length)
 *     else:
 *         raise TypeError("Illegal length %d for complex dtype" % length)             # <<<<<<<<<<<<<<
 * 
 *     tid = H5Tcreate(H5T_COMPOUND, size)
 */
    __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_Illegal_length_d_for_complex_dty, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1584, __pyx_L1_error)
    break;
  }

  /* "h5py/h5t.pyx":1586
 *         raise TypeError("Illegal length %d for complex dtype" % length)
 * 
 *     tid = H5Tcreate(H5T_COMPOUND, size)             # <<<<<<<<<<<<<<
 *     H5Tinsert(tid, cfg._r_name, off_r, tid_sub)
 *     H5Tinsert(tid, cfg._i_name, off_i, tid_sub)
 */
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcreate(H5T_COMPOUND, __pyx_v_size); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1586, __pyx_L1_error)
  __pyx_v_tid = __pyx_t_5;

  /* "h5py/h5t.pyx":1587
 * 
 *     tid = H5Tcreate(H5T_COMPOUND, size)
 *     H5Tinsert(tid, cfg._r_name, off_r, tid_sub)             # <<<<<<<<<<<<<<
 *     H5Tinsert(tid, cfg._i_name, off_i, tid_sub)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_cfg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_r_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_AsWritableString(__pyx_t_4); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 1587, __pyx_L1_error)
  __pyx_t_7 = __pyx_f_4h5py_4defs_H5Tinsert(__pyx_v_tid, __pyx_t_6, __pyx_v_off_r, __pyx_v_tid_sub); if (unlikely(__pyx_t_7 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":1588
 *     tid = H5Tcreate(H5T_COMPOUND, size)
 *     H5Tinsert(tid, cfg._r_name, off_r, tid_sub)
 *     H5Tinsert(tid, cfg._i_name, off_i, tid_sub)             # <<<<<<<<<<<<<<
 * 
 *     return TypeCompoundID(tid)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_cfg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_i_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_AsWritableString(__pyx_t_3); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 1588, __pyx_L1_error)
  __pyx_t_7 = __pyx_f_4h5py_4defs_H5Tinsert(__pyx_v_tid, __pyx_t_6, __pyx_v_off_i, __pyx_v_tid_sub); if (unlikely(__pyx_t_7 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1588, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "h5py/h5t.pyx":1590
 *     H5Tinsert(tid, cfg._i_name, off_i, tid_sub)
 * 
 *     return TypeCompoundID(tid)             # <<<<<<<<<<<<<<
 * 
 * cdef TypeCompoundID _c_compound(cnp.dtype dt, int logical, int aligned):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_3 = __Pyx_PyInt_From_hid_t(__pyx_v_tid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID), __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeCompoundID *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1544
 *     return TypeStringID(tid)
 * 
 * cdef TypeCompoundID _c_complex(cnp.dtype dt):             # <<<<<<<<<<<<<<
 *     # Complex numbers (names depend on cfg)
 *     global cfg
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("h5py.h5t._c_complex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1613
 *     # Build list of names, offsets, and types, sorted by increasing offset
 *     # (i.e. the position of the member in the struct)
 *     for name in sorted(dt.names, key=(lambda n: dt.fields[n][1])):             # <<<<<<<<<<<<<<
 *         field = dt.fields[name]
 *         h5_name = name.encode('utf8') if isinstance(name, unicode) else name
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_11_c_compound_lambda(PyObject *__pyx_self, PyObject *__pyx_v_n); /*proto*/
static PyMethodDef __pyx_mdef_4h5py_3h5t_11_c_compound_lambda = {"lambda", (PyCFunction)__pyx_pw_4h5py_3h5t_11_c_compound_lambda, METH_O, 0};
static PyObject *__pyx_pw_4h5py_3h5t_11_c_compound_lambda(PyObject *__pyx_self, PyObject *__pyx_v_n) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda(__pyx_self, ((PyObject *)__pyx_v_n));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda(PyObject *__pyx_self, PyObject *__pyx_v_n) {
  struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *__pyx_cur_scope;
  struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda", 0);
  __pyx_outer_scope = (struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_dt)) { __Pyx_RaiseClosureNameError("dt"); __PYX_ERR(0, 1613, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_dt->fields, __pyx_v_n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("h5py.h5t._c_compound.lambda", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1592
 *     return TypeCompoundID(tid)
 * 
 * cdef TypeCompoundID _c_compound(cnp.dtype dt, int logical, int aligned):             # <<<<<<<<<<<<<<
 *     # Compound datatypes
 *     cdef:
 */

static struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_f_4h5py_3h5t__c_compound(PyArray_Descr *__pyx_v_dt, int __pyx_v_logical, int __pyx_v_aligned) {
  struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *__pyx_cur_scope;
  hid_t __pyx_v_tid;
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_member_type = 0;
  PyObject *__pyx_v_member_dt = 0;
  size_t __pyx_v_member_offset;
  PyObject *__pyx_v_fields = 0;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_field = NULL;
  PyObject *__pyx_v_h5_name = NULL;
  struct __pyx_obj_4h5py_3h5t_TypeCompoundID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  struct __pyx_opt_args_4h5py_3h5t_py_create __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  size_t __pyx_t_13;
  hid_t __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *(*__pyx_t_16)(PyObject *);
  char *__pyx_t_17;
  herr_t __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_compound", 0);
  __pyx_cur_scope = (struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *)__pyx_tp_new_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound(__pyx_ptype_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1592, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_dt = __pyx_v_dt;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_dt);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_dt);

  /* "h5py/h5t.pyx":1598
 *         TypeID member_type
 *         object member_dt
 *         size_t member_offset = 0             # <<<<<<<<<<<<<<
 *         dict fields = {}
 * 
 */
  __pyx_v_member_offset = 0;

  /* "h5py/h5t.pyx":1599
 *         object member_dt
 *         size_t member_offset = 0
 *         dict fields = {}             # <<<<<<<<<<<<<<
 * 
 *     # The challenge with correctly converting a numpy/h5py dtype to a HDF5 type
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fields = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1613
 *     # Build list of names, offsets, and types, sorted by increasing offset
 *     # (i.e. the position of the member in the struct)
 *     for name in sorted(dt.names, key=(lambda n: dt.fields[n][1])):             # <<<<<<<<<<<<<<
 *         field = dt.fields[name]
 *         h5_name = name.encode('utf8') if isinstance(name, unicode) else name
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_dt->names);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_dt->names);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_cur_scope->__pyx_v_dt->names);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_4h5py_3h5t_11_c_compound_lambda, 0, __pyx_n_s_c_compound_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_h5py_h5t, __pyx_d, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_key, __pyx_t_3) < 0) __PYX_ERR(0, 1613, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_sorted, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1613, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1613, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1613, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1613, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1613, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "h5py/h5t.pyx":1614
 *     # (i.e. the position of the member in the struct)
 *     for name in sorted(dt.names, key=(lambda n: dt.fields[n][1])):
 *         field = dt.fields[name]             # <<<<<<<<<<<<<<
 *         h5_name = name.encode('utf8') if isinstance(name, unicode) else name
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_dt->fields, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_field, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "h5py/h5t.pyx":1615
 *     for name in sorted(dt.names, key=(lambda n: dt.fields[n][1])):
 *         field = dt.fields[name]
 *         h5_name = name.encode('utf8') if isinstance(name, unicode) else name             # <<<<<<<<<<<<<<
 * 
 *         # Get HDF5 data types and set the offset for each member
 */
    __pyx_t_6 = PyUnicode_Check(__pyx_v_name); 
    if ((__pyx_t_6 != 0)) {
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_encode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_n_u_utf8) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_utf8);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_3 = __pyx_t_1;
      __pyx_t_1 = 0;
    } else {
      __Pyx_INCREF(__pyx_v_name);
      __pyx_t_3 = __pyx_v_name;
    }
    __Pyx_XDECREF_SET(__pyx_v_h5_name, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "h5py/h5t.pyx":1618
 * 
 *         # Get HDF5 data types and set the offset for each member
 *         member_dt = field[0]             # <<<<<<<<<<<<<<
 *         member_offset = max(member_offset, field[1])
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_field, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_member_dt, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "h5py/h5t.pyx":1619
 *         # Get HDF5 data types and set the offset for each member
 *         member_dt = field[0]
 *         member_offset = max(member_offset, field[1])             # <<<<<<<<<<<<<<
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)
 *         if aligned and (member_offset > field[1]
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_field, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __pyx_v_member_offset;
    __pyx_t_7 = __Pyx_PyInt_FromSize_t(__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_3, __pyx_t_7, Py_GT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1619, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1619, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_6) {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_1 = __pyx_t_3;
    } else {
      __pyx_t_8 = __Pyx_PyInt_FromSize_t(__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __pyx_t_8;
      __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = __Pyx_PyInt_As_size_t(__pyx_t_1); if (unlikely((__pyx_t_9 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1619, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_member_offset = __pyx_t_9;

    /* "h5py/h5t.pyx":1620
 *         member_dt = field[0]
 *         member_offset = max(member_offset, field[1])
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)             # <<<<<<<<<<<<<<
 *         if aligned and (member_offset > field[1]
 *                         or member_dt.itemsize != member_type.get_size()):
 */
    __pyx_t_10.__pyx_n = 2;
    __pyx_t_10.logical = __pyx_v_logical;
    __pyx_t_10.aligned = __pyx_v_aligned;
    __pyx_t_1 = ((PyObject *)__pyx_f_4h5py_3h5t_py_create(__pyx_v_member_dt, 0, &__pyx_t_10)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_member_type, ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1621
 *         member_offset = max(member_offset, field[1])
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)
 *         if aligned and (member_offset > field[1]             # <<<<<<<<<<<<<<
 *                         or member_dt.itemsize != member_type.get_size()):
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")
 */
    __pyx_t_11 = (__pyx_v_aligned != 0);
    if (__pyx_t_11) {
    } else {
      __pyx_t_6 = __pyx_t_11;
      goto __pyx_L6_bool_binop_done;
    }

    /* "h5py/h5t.pyx":1622
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)
 *         if aligned and (member_offset > field[1]
 *                         or member_dt.itemsize != member_type.get_size()):             # <<<<<<<<<<<<<<
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")
 *         fields[name] = (h5_name, member_offset, member_type)
 */
    __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_member_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "h5py/h5t.pyx":1621
 *         member_offset = max(member_offset, field[1])
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)
 *         if aligned and (member_offset > field[1]             # <<<<<<<<<<<<<<
 *                         or member_dt.itemsize != member_type.get_size()):
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_field, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1621, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 1621, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (!__pyx_t_11) {
    } else {
      __pyx_t_6 = __pyx_t_11;
      goto __pyx_L6_bool_binop_done;
    }

    /* "h5py/h5t.pyx":1622
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)
 *         if aligned and (member_offset > field[1]
 *                         or member_dt.itemsize != member_type.get_size()):             # <<<<<<<<<<<<<<
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")
 *         fields[name] = (h5_name, member_offset, member_type)
 */
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_member_dt, __pyx_n_s_itemsize); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_member_type), __pyx_n_s_get_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_8, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1622, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 1622, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __pyx_t_11;
    __pyx_L6_bool_binop_done:;

    /* "h5py/h5t.pyx":1621
 *         member_offset = max(member_offset, field[1])
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)
 *         if aligned and (member_offset > field[1]             # <<<<<<<<<<<<<<
 *                         or member_dt.itemsize != member_type.get_size()):
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")
 */
    if (unlikely(__pyx_t_6)) {

      /* "h5py/h5t.pyx":1623
 *         if aligned and (member_offset > field[1]
 *                         or member_dt.itemsize != member_type.get_size()):
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")             # <<<<<<<<<<<<<<
 *         fields[name] = (h5_name, member_offset, member_type)
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 1623, __pyx_L1_error)

      /* "h5py/h5t.pyx":1621
 *         member_offset = max(member_offset, field[1])
 *         member_type = py_create(member_dt, logical=logical, aligned=aligned)
 *         if aligned and (member_offset > field[1]             # <<<<<<<<<<<<<<
 *                         or member_dt.itemsize != member_type.get_size()):
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")
 */
    }

    /* "h5py/h5t.pyx":1624
 *                         or member_dt.itemsize != member_type.get_size()):
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")
 *         fields[name] = (h5_name, member_offset, member_type)             # <<<<<<<<<<<<<<
 * 
 *         # Update member offset based on the HDF5 type size
 */
    __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_member_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1624, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1624, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_h5_name);
    __Pyx_GIVEREF(__pyx_v_h5_name);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_h5_name);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_member_type));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_member_type));
    PyTuple_SET_ITEM(__pyx_t_3, 2, ((PyObject *)__pyx_v_member_type));
    __pyx_t_1 = 0;
    if (unlikely(PyDict_SetItem(__pyx_v_fields, __pyx_v_name, __pyx_t_3) < 0)) __PYX_ERR(0, 1624, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "h5py/h5t.pyx":1627
 * 
 *         # Update member offset based on the HDF5 type size
 *         member_offset += member_type.get_size()             # <<<<<<<<<<<<<<
 * 
 *     member_offset = max(member_offset, dt.itemsize)
 */
    __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_member_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_member_type), __pyx_n_s_get_size); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = __Pyx_PyInt_As_size_t(__pyx_t_8); if (unlikely((__pyx_t_9 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1627, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_member_offset = __pyx_t_9;

    /* "h5py/h5t.pyx":1613
 *     # Build list of names, offsets, and types, sorted by increasing offset
 *     # (i.e. the position of the member in the struct)
 *     for name in sorted(dt.names, key=(lambda n: dt.fields[n][1])):             # <<<<<<<<<<<<<<
 *         field = dt.fields[name]
 *         h5_name = name.encode('utf8') if isinstance(name, unicode) else name
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1629
 *         member_offset += member_type.get_size()
 * 
 *     member_offset = max(member_offset, dt.itemsize)             # <<<<<<<<<<<<<<
 *     if aligned and member_offset > dt.itemsize:
 *         raise TypeError("Enforced alignment not compatible with HDF5 type")
 */
  __pyx_t_12 = __pyx_cur_scope->__pyx_v_dt->elsize;
  __pyx_t_9 = __pyx_v_member_offset;
  if (((__pyx_t_12 > __pyx_t_9) != 0)) {
    __pyx_t_13 = __pyx_t_12;
  } else {
    __pyx_t_13 = __pyx_t_9;
  }
  __pyx_v_member_offset = __pyx_t_13;

  /* "h5py/h5t.pyx":1630
 * 
 *     member_offset = max(member_offset, dt.itemsize)
 *     if aligned and member_offset > dt.itemsize:             # <<<<<<<<<<<<<<
 *         raise TypeError("Enforced alignment not compatible with HDF5 type")
 * 
 */
  __pyx_t_11 = (__pyx_v_aligned != 0);
  if (__pyx_t_11) {
  } else {
    __pyx_t_6 = __pyx_t_11;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_11 = ((__pyx_v_member_offset > __pyx_cur_scope->__pyx_v_dt->elsize) != 0);
  __pyx_t_6 = __pyx_t_11;
  __pyx_L10_bool_binop_done:;
  if (unlikely(__pyx_t_6)) {

    /* "h5py/h5t.pyx":1631
 *     member_offset = max(member_offset, dt.itemsize)
 *     if aligned and member_offset > dt.itemsize:
 *         raise TypeError("Enforced alignment not compatible with HDF5 type")             # <<<<<<<<<<<<<<
 * 
 *     # Create compound with the necessary size, and insert its members
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1631, __pyx_L1_error)

    /* "h5py/h5t.pyx":1630
 * 
 *     member_offset = max(member_offset, dt.itemsize)
 *     if aligned and member_offset > dt.itemsize:             # <<<<<<<<<<<<<<
 *         raise TypeError("Enforced alignment not compatible with HDF5 type")
 * 
 */
  }

  /* "h5py/h5t.pyx":1634
 * 
 *     # Create compound with the necessary size, and insert its members
 *     tid = H5Tcreate(H5T_COMPOUND, member_offset)             # <<<<<<<<<<<<<<
 *     for name in dt.names:
 *         h5_name, member_offset, member_type = fields[name]
 */
  __pyx_t_14 = __pyx_f_4h5py_4defs_H5Tcreate(H5T_COMPOUND, __pyx_v_member_offset); if (unlikely(__pyx_t_14 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1634, __pyx_L1_error)
  __pyx_v_tid = __pyx_t_14;

  /* "h5py/h5t.pyx":1635
 *     # Create compound with the necessary size, and insert its members
 *     tid = H5Tcreate(H5T_COMPOUND, member_offset)
 *     for name in dt.names:             # <<<<<<<<<<<<<<
 *         h5_name, member_offset, member_type = fields[name]
 *         H5Tinsert(tid, h5_name, member_offset, member_type.id)
 */
  if (unlikely(__pyx_cur_scope->__pyx_v_dt->names == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1635, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_dt->names; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
  for (;;) {
    if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_8); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1635, __pyx_L1_error)
    #else
    __pyx_t_8 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "h5py/h5t.pyx":1636
 *     tid = H5Tcreate(H5T_COMPOUND, member_offset)
 *     for name in dt.names:
 *         h5_name, member_offset, member_type = fields[name]             # <<<<<<<<<<<<<<
 *         H5Tinsert(tid, h5_name, member_offset, member_type.id)
 * 
 */
    __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_fields, __pyx_v_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
      PyObject* sequence = __pyx_t_8;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1636, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1636, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1636, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1636, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_15 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1636, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_16 = Py_TYPE(__pyx_t_15)->tp_iternext;
      index = 0; __pyx_t_1 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_1)) goto __pyx_L14_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      index = 1; __pyx_t_3 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_3)) goto __pyx_L14_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 2; __pyx_t_7 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_7)) goto __pyx_L14_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_15), 3) < 0) __PYX_ERR(0, 1636, __pyx_L1_error)
      __pyx_t_16 = NULL;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      goto __pyx_L15_unpacking_done;
      __pyx_L14_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_16 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1636, __pyx_L1_error)
      __pyx_L15_unpacking_done:;
    }
    __pyx_t_13 = __Pyx_PyInt_As_size_t(__pyx_t_3); if (unlikely((__pyx_t_13 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1636, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 1636, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_h5_name, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_v_member_offset = __pyx_t_13;
    __Pyx_XDECREF_SET(__pyx_v_member_type, ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_7));
    __pyx_t_7 = 0;

    /* "h5py/h5t.pyx":1637
 *     for name in dt.names:
 *         h5_name, member_offset, member_type = fields[name]
 *         H5Tinsert(tid, h5_name, member_offset, member_type.id)             # <<<<<<<<<<<<<<
 * 
 *     return TypeCompoundID(tid)
 */
    __pyx_t_17 = __Pyx_PyObject_AsWritableString(__pyx_v_h5_name); if (unlikely((!__pyx_t_17) && PyErr_Occurred())) __PYX_ERR(0, 1637, __pyx_L1_error)
    __pyx_t_18 = __pyx_f_4h5py_4defs_H5Tinsert(__pyx_v_tid, __pyx_t_17, __pyx_v_member_offset, __pyx_v_member_type->__pyx_base.id); if (unlikely(__pyx_t_18 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1637, __pyx_L1_error)

    /* "h5py/h5t.pyx":1635
 *     # Create compound with the necessary size, and insert its members
 *     tid = H5Tcreate(H5T_COMPOUND, member_offset)
 *     for name in dt.names:             # <<<<<<<<<<<<<<
 *         h5_name, member_offset, member_type = fields[name]
 *         H5Tinsert(tid, h5_name, member_offset, member_type.id)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1639
 *         H5Tinsert(tid, h5_name, member_offset, member_type.id)
 * 
 *     return TypeCompoundID(tid)             # <<<<<<<<<<<<<<
 * 
 * cdef TypeStringID _c_vlen_str():
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_2 = __Pyx_PyInt_From_hid_t(__pyx_v_tid); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID), __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeCompoundID *)__pyx_t_8);
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1592
 *     return TypeCompoundID(tid)
 * 
 * cdef TypeCompoundID _c_compound(cnp.dtype dt, int logical, int aligned):             # <<<<<<<<<<<<<<
 *     # Compound datatypes
 *     cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("h5py.h5t._c_compound", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_member_type);
  __Pyx_XDECREF(__pyx_v_member_dt);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_field);
  __Pyx_XDECREF(__pyx_v_h5_name);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1641
 *     return TypeCompoundID(tid)
 * 
 * cdef TypeStringID _c_vlen_str():             # <<<<<<<<<<<<<<
 *     # Variable-length strings
 *     cdef hid_t tid
 */

static struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_f_4h5py_3h5t__c_vlen_str(void) {
  hid_t __pyx_v_tid;
  struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  herr_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_vlen_str", 0);

  /* "h5py/h5t.pyx":1644
 *     # Variable-length strings
 *     cdef hid_t tid
 *     tid = H5Tcopy(H5T_C_S1)             # <<<<<<<<<<<<<<
 *     H5Tset_size(tid, H5T_VARIABLE)
 *     return TypeStringID(tid)
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_C_S1); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1644, __pyx_L1_error)
  __pyx_v_tid = __pyx_t_1;

  /* "h5py/h5t.pyx":1645
 *     cdef hid_t tid
 *     tid = H5Tcopy(H5T_C_S1)
 *     H5Tset_size(tid, H5T_VARIABLE)             # <<<<<<<<<<<<<<
 *     return TypeStringID(tid)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tset_size(__pyx_v_tid, H5T_VARIABLE); if (unlikely(__pyx_t_2 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1645, __pyx_L1_error)

  /* "h5py/h5t.pyx":1646
 *     tid = H5Tcopy(H5T_C_S1)
 *     H5Tset_size(tid, H5T_VARIABLE)
 *     return TypeStringID(tid)             # <<<<<<<<<<<<<<
 * 
 * cdef TypeStringID _c_vlen_unicode():
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_3 = __Pyx_PyInt_From_hid_t(__pyx_v_tid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID), __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeStringID *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1641
 *     return TypeCompoundID(tid)
 * 
 * cdef TypeStringID _c_vlen_str():             # <<<<<<<<<<<<<<
 *     # Variable-length strings
 *     cdef hid_t tid
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("h5py.h5t._c_vlen_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1648
 *     return TypeStringID(tid)
 * 
 * cdef TypeStringID _c_vlen_unicode():             # <<<<<<<<<<<<<<
 *     cdef hid_t tid
 *     tid = H5Tcopy(H5T_C_S1)
 */

static struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_f_4h5py_3h5t__c_vlen_unicode(void) {
  hid_t __pyx_v_tid;
  struct __pyx_obj_4h5py_3h5t_TypeStringID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  hid_t __pyx_t_1;
  herr_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_vlen_unicode", 0);

  /* "h5py/h5t.pyx":1650
 * cdef TypeStringID _c_vlen_unicode():
 *     cdef hid_t tid
 *     tid = H5Tcopy(H5T_C_S1)             # <<<<<<<<<<<<<<
 *     H5Tset_size(tid, H5T_VARIABLE)
 *     H5Tset_cset(tid, H5T_CSET_UTF8)
 */
  __pyx_t_1 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_C_S1); if (unlikely(__pyx_t_1 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1650, __pyx_L1_error)
  __pyx_v_tid = __pyx_t_1;

  /* "h5py/h5t.pyx":1651
 *     cdef hid_t tid
 *     tid = H5Tcopy(H5T_C_S1)
 *     H5Tset_size(tid, H5T_VARIABLE)             # <<<<<<<<<<<<<<
 *     H5Tset_cset(tid, H5T_CSET_UTF8)
 *     return TypeStringID(tid)
 */
  __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tset_size(__pyx_v_tid, H5T_VARIABLE); if (unlikely(__pyx_t_2 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1651, __pyx_L1_error)

  /* "h5py/h5t.pyx":1652
 *     tid = H5Tcopy(H5T_C_S1)
 *     H5Tset_size(tid, H5T_VARIABLE)
 *     H5Tset_cset(tid, H5T_CSET_UTF8)             # <<<<<<<<<<<<<<
 *     return TypeStringID(tid)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_4defs_H5Tset_cset(__pyx_v_tid, H5T_CSET_UTF8); if (unlikely(__pyx_t_2 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1652, __pyx_L1_error)

  /* "h5py/h5t.pyx":1653
 *     H5Tset_size(tid, H5T_VARIABLE)
 *     H5Tset_cset(tid, H5T_CSET_UTF8)
 *     return TypeStringID(tid)             # <<<<<<<<<<<<<<
 * 
 * cdef TypeReferenceID _c_ref(object refclass):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_3 = __Pyx_PyInt_From_hid_t(__pyx_v_tid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID), __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeStringID *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1648
 *     return TypeStringID(tid)
 * 
 * cdef TypeStringID _c_vlen_unicode():             # <<<<<<<<<<<<<<
 *     cdef hid_t tid
 *     tid = H5Tcopy(H5T_C_S1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("h5py.h5t._c_vlen_unicode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1655
 *     return TypeStringID(tid)
 * 
 * cdef TypeReferenceID _c_ref(object refclass):             # <<<<<<<<<<<<<<
 *     if refclass is Reference:
 *         return STD_REF_OBJ
 */

static struct __pyx_obj_4h5py_3h5t_TypeReferenceID *__pyx_f_4h5py_3h5t__c_ref(PyObject *__pyx_v_refclass) {
  struct __pyx_obj_4h5py_3h5t_TypeReferenceID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_ref", 0);

  /* "h5py/h5t.pyx":1656
 * 
 * cdef TypeReferenceID _c_ref(object refclass):
 *     if refclass is Reference:             # <<<<<<<<<<<<<<
 *         return STD_REF_OBJ
 *     elif refclass is RegionReference:
 */
  __pyx_t_1 = (__pyx_v_refclass == ((PyObject *)__pyx_ptype_4h5py_3h5r_Reference));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":1657
 * cdef TypeReferenceID _c_ref(object refclass):
 *     if refclass is Reference:
 *         return STD_REF_OBJ             # <<<<<<<<<<<<<<
 *     elif refclass is RegionReference:
 *         return STD_REF_DSETREG
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_STD_REF_OBJ); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_4h5py_3h5t_TypeReferenceID))))) __PYX_ERR(0, 1657, __pyx_L1_error)
    __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeReferenceID *)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1656
 * 
 * cdef TypeReferenceID _c_ref(object refclass):
 *     if refclass is Reference:             # <<<<<<<<<<<<<<
 *         return STD_REF_OBJ
 *     elif refclass is RegionReference:
 */
  }

  /* "h5py/h5t.pyx":1658
 *     if refclass is Reference:
 *         return STD_REF_OBJ
 *     elif refclass is RegionReference:             # <<<<<<<<<<<<<<
 *         return STD_REF_DSETREG
 *     raise TypeError("Unrecognized reference code")
 */
  __pyx_t_2 = (__pyx_v_refclass == ((PyObject *)__pyx_ptype_4h5py_3h5r_RegionReference));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "h5py/h5t.pyx":1659
 *         return STD_REF_OBJ
 *     elif refclass is RegionReference:
 *         return STD_REF_DSETREG             # <<<<<<<<<<<<<<
 *     raise TypeError("Unrecognized reference code")
 * 
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_STD_REF_DSETREG); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_4h5py_3h5t_TypeReferenceID))))) __PYX_ERR(0, 1659, __pyx_L1_error)
    __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeReferenceID *)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1658
 *     if refclass is Reference:
 *         return STD_REF_OBJ
 *     elif refclass is RegionReference:             # <<<<<<<<<<<<<<
 *         return STD_REF_DSETREG
 *     raise TypeError("Unrecognized reference code")
 */
  }

  /* "h5py/h5t.pyx":1660
 *     elif refclass is RegionReference:
 *         return STD_REF_DSETREG
 *     raise TypeError("Unrecognized reference code")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 1660, __pyx_L1_error)

  /* "h5py/h5t.pyx":1655
 *     return TypeStringID(tid)
 * 
 * cdef TypeReferenceID _c_ref(object refclass):             # <<<<<<<<<<<<<<
 *     if refclass is Reference:
 *         return STD_REF_OBJ
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t._c_ref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1663
 * 
 * 
 * cpdef TypeID py_create(object dtype_in, bint logical=0, bint aligned=0):             # <<<<<<<<<<<<<<
 *     """(OBJECT dtype_in, BOOL logical=False) => TypeID
 * 
 */

static PyObject *__pyx_pw_4h5py_3h5t_17py_create(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_f_4h5py_3h5t_py_create(PyObject *__pyx_v_dtype_in, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_4h5py_3h5t_py_create *__pyx_optional_args) {
  int __pyx_v_logical = ((int)0);
  int __pyx_v_aligned = ((int)0);
  PyArray_Descr *__pyx_v_dt = 0;
  char __pyx_v_kind;
  PyObject *__pyx_v_enum_vals = NULL;
  PyObject *__pyx_v_vlen = NULL;
  PyObject *__pyx_v_refclass = NULL;
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  char __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  struct __pyx_opt_args_4h5py_3h5t_py_create __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  Py_UCS4 __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_create", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_logical = __pyx_optional_args->logical;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_aligned = __pyx_optional_args->aligned;
      }
    }
  }

  /* "h5py/h5t.pyx":1682
 *         char kind
 * 
 *     dt = np.dtype(dtype_in)             # <<<<<<<<<<<<<<
 *     # dt is now the C side of dtype_in. Sometimes the Python behaviour is easier to handle than the C-version
 *     kind = dt.kind
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_dtype_in) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_dtype_in);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 1682, __pyx_L1_error)
  __pyx_v_dt = ((PyArray_Descr *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1684
 *     dt = np.dtype(dtype_in)
 *     # dt is now the C side of dtype_in. Sometimes the Python behaviour is easier to handle than the C-version
 *     kind = dt.kind             # <<<<<<<<<<<<<<
 *     aligned = getattr(dtype_in, "isalignedstruct", aligned)
 * 
 */
  __pyx_t_4 = __pyx_v_dt->kind;
  __pyx_v_kind = __pyx_t_4;

  /* "h5py/h5t.pyx":1685
 *     # dt is now the C side of dtype_in. Sometimes the Python behaviour is easier to handle than the C-version
 *     kind = dt.kind
 *     aligned = getattr(dtype_in, "isalignedstruct", aligned)             # <<<<<<<<<<<<<<
 * 
 *     with phil:
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_aligned); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_GetAttr3(__pyx_v_dtype_in, __pyx_n_u_isalignedstruct, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_aligned = __pyx_t_5;

  /* "h5py/h5t.pyx":1687
 *     aligned = getattr(dtype_in, "isalignedstruct", aligned)
 * 
 *     with phil:             # <<<<<<<<<<<<<<
 *         # Tagged opaque data
 *         if check_opaque_dtype(dt):
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_phil); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_n_s_exit); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_n_s_enter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1687, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1687, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        /*try:*/ {

          /* "h5py/h5t.pyx":1689
 *     with phil:
 *         # Tagged opaque data
 *         if check_opaque_dtype(dt):             # <<<<<<<<<<<<<<
 *             return _c_opaque_tagged(dt)
 * 
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_check_opaque_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1689, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_2 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, ((PyObject *)__pyx_v_dt)) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)__pyx_v_dt));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1689, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1689, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (__pyx_t_5) {

            /* "h5py/h5t.pyx":1690
 *         # Tagged opaque data
 *         if check_opaque_dtype(dt):
 *             return _c_opaque_tagged(dt)             # <<<<<<<<<<<<<<
 * 
 *         # Float
 */
            __Pyx_XDECREF(((PyObject *)__pyx_r));
            __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_opaque_tagged(__pyx_v_dt)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1690, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
            __pyx_t_3 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":1689
 *     with phil:
 *         # Tagged opaque data
 *         if check_opaque_dtype(dt):             # <<<<<<<<<<<<<<
 *             return _c_opaque_tagged(dt)
 * 
 */
          }

          /* "h5py/h5t.pyx":1693
 * 
 *         # Float
 *         if kind == c'f':             # <<<<<<<<<<<<<<
 *             return _c_float(dt)
 * 
 */
          __pyx_t_5 = ((__pyx_v_kind == 'f') != 0);
          if (__pyx_t_5) {

            /* "h5py/h5t.pyx":1694
 *         # Float
 *         if kind == c'f':
 *             return _c_float(dt)             # <<<<<<<<<<<<<<
 * 
 *         # Integer
 */
            __Pyx_XDECREF(((PyObject *)__pyx_r));
            __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_float(__pyx_v_dt)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1694, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
            __pyx_t_3 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":1693
 * 
 *         # Float
 *         if kind == c'f':             # <<<<<<<<<<<<<<
 *             return _c_float(dt)
 * 
 */
          }

          /* "h5py/h5t.pyx":1697
 * 
 *         # Integer
 *         elif kind == c'u' or kind == c'i':             # <<<<<<<<<<<<<<
 * 
 *             if logical:
 */
          switch (__pyx_v_kind) {
            case 'u':
            case 'i':
            __pyx_t_5 = 1;
            break;
            default:
            __pyx_t_5 = 0;
            break;
          }
          if (__pyx_t_5) {

            /* "h5py/h5t.pyx":1699
 *         elif kind == c'u' or kind == c'i':
 * 
 *             if logical:             # <<<<<<<<<<<<<<
 *                 # Check for an enumeration hint
 *                 enum_vals = check_enum_dtype(dt)
 */
            __pyx_t_5 = (__pyx_v_logical != 0);
            if (__pyx_t_5) {

              /* "h5py/h5t.pyx":1701
 *             if logical:
 *                 # Check for an enumeration hint
 *                 enum_vals = check_enum_dtype(dt)             # <<<<<<<<<<<<<<
 *                 if enum_vals is not None:
 *                     return _c_enum(dt, enum_vals)
 */
              __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_check_enum_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1701, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_2 = NULL;
              if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
                __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
                if (likely(__pyx_t_2)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                  __Pyx_INCREF(__pyx_t_2);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_1, function);
                }
              }
              __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, ((PyObject *)__pyx_v_dt)) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)__pyx_v_dt));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1701, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_v_enum_vals = __pyx_t_3;
              __pyx_t_3 = 0;

              /* "h5py/h5t.pyx":1702
 *                 # Check for an enumeration hint
 *                 enum_vals = check_enum_dtype(dt)
 *                 if enum_vals is not None:             # <<<<<<<<<<<<<<
 *                     return _c_enum(dt, enum_vals)
 * 
 */
              __pyx_t_5 = (__pyx_v_enum_vals != Py_None);
              __pyx_t_11 = (__pyx_t_5 != 0);
              if (__pyx_t_11) {

                /* "h5py/h5t.pyx":1703
 *                 enum_vals = check_enum_dtype(dt)
 *                 if enum_vals is not None:
 *                     return _c_enum(dt, enum_vals)             # <<<<<<<<<<<<<<
 * 
 *             return _c_int(dt)
 */
                __Pyx_XDECREF(((PyObject *)__pyx_r));
                if (!(likely(PyDict_CheckExact(__pyx_v_enum_vals))||((__pyx_v_enum_vals) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_enum_vals)->tp_name), 0))) __PYX_ERR(0, 1703, __pyx_L7_error)
                __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_enum(__pyx_v_dt, ((PyObject*)__pyx_v_enum_vals))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1703, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
                __pyx_t_3 = 0;
                goto __pyx_L11_try_return;

                /* "h5py/h5t.pyx":1702
 *                 # Check for an enumeration hint
 *                 enum_vals = check_enum_dtype(dt)
 *                 if enum_vals is not None:             # <<<<<<<<<<<<<<
 *                     return _c_enum(dt, enum_vals)
 * 
 */
              }

              /* "h5py/h5t.pyx":1699
 *         elif kind == c'u' or kind == c'i':
 * 
 *             if logical:             # <<<<<<<<<<<<<<
 *                 # Check for an enumeration hint
 *                 enum_vals = check_enum_dtype(dt)
 */
            }

            /* "h5py/h5t.pyx":1705
 *                     return _c_enum(dt, enum_vals)
 * 
 *             return _c_int(dt)             # <<<<<<<<<<<<<<
 * 
 *         # Complex
 */
            __Pyx_XDECREF(((PyObject *)__pyx_r));
            __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_int(__pyx_v_dt)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1705, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
            __pyx_t_3 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":1697
 * 
 *         # Integer
 *         elif kind == c'u' or kind == c'i':             # <<<<<<<<<<<<<<
 * 
 *             if logical:
 */
          }

          /* "h5py/h5t.pyx":1708
 * 
 *         # Complex
 *         elif kind == c'c':             # <<<<<<<<<<<<<<
 *             return _c_complex(dt)
 * 
 */
          __pyx_t_11 = ((__pyx_v_kind == 'c') != 0);
          if (__pyx_t_11) {

            /* "h5py/h5t.pyx":1709
 *         # Complex
 *         elif kind == c'c':
 *             return _c_complex(dt)             # <<<<<<<<<<<<<<
 * 
 *         # Compound. The explicit cast to object is used to force Python attribute access,
 */
            __Pyx_XDECREF(((PyObject *)__pyx_r));
            __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_complex(__pyx_v_dt)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1709, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
            __pyx_t_3 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":1708
 * 
 *         # Complex
 *         elif kind == c'c':             # <<<<<<<<<<<<<<
 *             return _c_complex(dt)
 * 
 */
          }

          /* "h5py/h5t.pyx":1713
 *         # Compound. The explicit cast to object is used to force Python attribute access,
 *         # as dt.names may be a NULL pointer at the C level when undefined.
 *         elif (kind == c'V') and ((<object> dt).names is not None):             # <<<<<<<<<<<<<<
 *             return _c_compound(dt, logical, aligned)
 * 
 */
          __pyx_t_5 = ((__pyx_v_kind == 'V') != 0);
          if (__pyx_t_5) {
          } else {
            __pyx_t_11 = __pyx_t_5;
            goto __pyx_L17_bool_binop_done;
          }
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_names); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1713, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_5 = (__pyx_t_3 != Py_None);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_12 = (__pyx_t_5 != 0);
          __pyx_t_11 = __pyx_t_12;
          __pyx_L17_bool_binop_done:;
          if (__pyx_t_11) {

            /* "h5py/h5t.pyx":1714
 *         # as dt.names may be a NULL pointer at the C level when undefined.
 *         elif (kind == c'V') and ((<object> dt).names is not None):
 *             return _c_compound(dt, logical, aligned)             # <<<<<<<<<<<<<<
 * 
 *         # Array or opaque
 */
            __Pyx_XDECREF(((PyObject *)__pyx_r));
            __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_compound(__pyx_v_dt, __pyx_v_logical, __pyx_v_aligned)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1714, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
            __pyx_t_3 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":1713
 *         # Compound. The explicit cast to object is used to force Python attribute access,
 *         # as dt.names may be a NULL pointer at the C level when undefined.
 *         elif (kind == c'V') and ((<object> dt).names is not None):             # <<<<<<<<<<<<<<
 *             return _c_compound(dt, logical, aligned)
 * 
 */
          }

          /* "h5py/h5t.pyx":1717
 * 
 *         # Array or opaque
 *         elif kind == c'V':             # <<<<<<<<<<<<<<
 *             if dt.subdtype is not None:
 *                 return _c_array(dt, logical)
 */
          __pyx_t_11 = ((__pyx_v_kind == 'V') != 0);
          if (__pyx_t_11) {

            /* "h5py/h5t.pyx":1718
 *         # Array or opaque
 *         elif kind == c'V':
 *             if dt.subdtype is not None:             # <<<<<<<<<<<<<<
 *                 return _c_array(dt, logical)
 *             else:
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_subdtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1718, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_11 = (__pyx_t_3 != Py_None);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_12 = (__pyx_t_11 != 0);
            if (__pyx_t_12) {

              /* "h5py/h5t.pyx":1719
 *         elif kind == c'V':
 *             if dt.subdtype is not None:
 *                 return _c_array(dt, logical)             # <<<<<<<<<<<<<<
 *             else:
 *                 return _c_opaque(dt)
 */
              __Pyx_XDECREF(((PyObject *)__pyx_r));
              __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_array(__pyx_v_dt, __pyx_v_logical)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1719, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
              __pyx_t_3 = 0;
              goto __pyx_L11_try_return;

              /* "h5py/h5t.pyx":1718
 *         # Array or opaque
 *         elif kind == c'V':
 *             if dt.subdtype is not None:             # <<<<<<<<<<<<<<
 *                 return _c_array(dt, logical)
 *             else:
 */
            }

            /* "h5py/h5t.pyx":1721
 *                 return _c_array(dt, logical)
 *             else:
 *                 return _c_opaque(dt)             # <<<<<<<<<<<<<<
 * 
 *         # String
 */
            /*else*/ {
              __Pyx_XDECREF(((PyObject *)__pyx_r));
              __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_opaque(__pyx_v_dt)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1721, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
              __pyx_t_3 = 0;
              goto __pyx_L11_try_return;
            }

            /* "h5py/h5t.pyx":1717
 * 
 *         # Array or opaque
 *         elif kind == c'V':             # <<<<<<<<<<<<<<
 *             if dt.subdtype is not None:
 *                 return _c_array(dt, logical)
 */
          }

          /* "h5py/h5t.pyx":1724
 * 
 *         # String
 *         elif kind == c'S':             # <<<<<<<<<<<<<<
 *             return _c_string(dt)
 * 
 */
          __pyx_t_12 = ((__pyx_v_kind == 'S') != 0);
          if (__pyx_t_12) {

            /* "h5py/h5t.pyx":1725
 *         # String
 *         elif kind == c'S':
 *             return _c_string(dt)             # <<<<<<<<<<<<<<
 * 
 *         # Boolean
 */
            __Pyx_XDECREF(((PyObject *)__pyx_r));
            __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_string(__pyx_v_dt)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1725, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
            __pyx_t_3 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":1724
 * 
 *         # String
 *         elif kind == c'S':             # <<<<<<<<<<<<<<
 *             return _c_string(dt)
 * 
 */
          }

          /* "h5py/h5t.pyx":1728
 * 
 *         # Boolean
 *         elif kind == c'b':             # <<<<<<<<<<<<<<
 *             return _c_bool(dt)
 * 
 */
          __pyx_t_12 = ((__pyx_v_kind == 'b') != 0);
          if (__pyx_t_12) {

            /* "h5py/h5t.pyx":1729
 *         # Boolean
 *         elif kind == c'b':
 *             return _c_bool(dt)             # <<<<<<<<<<<<<<
 * 
 *         # Object types (including those with vlen hints)
 */
            __Pyx_XDECREF(((PyObject *)__pyx_r));
            __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_bool(__pyx_v_dt)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1729, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
            __pyx_t_3 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":1728
 * 
 *         # Boolean
 *         elif kind == c'b':             # <<<<<<<<<<<<<<
 *             return _c_bool(dt)
 * 
 */
          }

          /* "h5py/h5t.pyx":1732
 * 
 *         # Object types (including those with vlen hints)
 *         elif kind == c'O':             # <<<<<<<<<<<<<<
 * 
 *             if logical:
 */
          __pyx_t_12 = ((__pyx_v_kind == 'O') != 0);
          if (likely(__pyx_t_12)) {

            /* "h5py/h5t.pyx":1734
 *         elif kind == c'O':
 * 
 *             if logical:             # <<<<<<<<<<<<<<
 *                 vlen = check_vlen_dtype(dt)
 *                 if vlen is bytes:
 */
            __pyx_t_12 = (__pyx_v_logical != 0);
            if (__pyx_t_12) {

              /* "h5py/h5t.pyx":1735
 * 
 *             if logical:
 *                 vlen = check_vlen_dtype(dt)             # <<<<<<<<<<<<<<
 *                 if vlen is bytes:
 *                     return _c_vlen_str()
 */
              __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_check_vlen_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1735, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_2 = NULL;
              if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
                __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
                if (likely(__pyx_t_2)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                  __Pyx_INCREF(__pyx_t_2);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_1, function);
                }
              }
              __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, ((PyObject *)__pyx_v_dt)) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)__pyx_v_dt));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1735, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_v_vlen = __pyx_t_3;
              __pyx_t_3 = 0;

              /* "h5py/h5t.pyx":1736
 *             if logical:
 *                 vlen = check_vlen_dtype(dt)
 *                 if vlen is bytes:             # <<<<<<<<<<<<<<
 *                     return _c_vlen_str()
 *                 elif vlen is unicode:
 */
              __pyx_t_12 = (__pyx_v_vlen == ((PyObject *)(&PyBytes_Type)));
              __pyx_t_11 = (__pyx_t_12 != 0);
              if (__pyx_t_11) {

                /* "h5py/h5t.pyx":1737
 *                 vlen = check_vlen_dtype(dt)
 *                 if vlen is bytes:
 *                     return _c_vlen_str()             # <<<<<<<<<<<<<<
 *                 elif vlen is unicode:
 *                     return _c_vlen_unicode()
 */
                __Pyx_XDECREF(((PyObject *)__pyx_r));
                __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_vlen_str()); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1737, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
                __pyx_t_3 = 0;
                goto __pyx_L11_try_return;

                /* "h5py/h5t.pyx":1736
 *             if logical:
 *                 vlen = check_vlen_dtype(dt)
 *                 if vlen is bytes:             # <<<<<<<<<<<<<<
 *                     return _c_vlen_str()
 *                 elif vlen is unicode:
 */
              }

              /* "h5py/h5t.pyx":1738
 *                 if vlen is bytes:
 *                     return _c_vlen_str()
 *                 elif vlen is unicode:             # <<<<<<<<<<<<<<
 *                     return _c_vlen_unicode()
 *                 elif vlen is not None:
 */
              __pyx_t_11 = (__pyx_v_vlen == ((PyObject *)(&PyUnicode_Type)));
              __pyx_t_12 = (__pyx_t_11 != 0);
              if (__pyx_t_12) {

                /* "h5py/h5t.pyx":1739
 *                     return _c_vlen_str()
 *                 elif vlen is unicode:
 *                     return _c_vlen_unicode()             # <<<<<<<<<<<<<<
 *                 elif vlen is not None:
 *                     return vlen_create(py_create(vlen, logical))
 */
                __Pyx_XDECREF(((PyObject *)__pyx_r));
                __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_vlen_unicode()); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1739, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
                __pyx_t_3 = 0;
                goto __pyx_L11_try_return;

                /* "h5py/h5t.pyx":1738
 *                 if vlen is bytes:
 *                     return _c_vlen_str()
 *                 elif vlen is unicode:             # <<<<<<<<<<<<<<
 *                     return _c_vlen_unicode()
 *                 elif vlen is not None:
 */
              }

              /* "h5py/h5t.pyx":1740
 *                 elif vlen is unicode:
 *                     return _c_vlen_unicode()
 *                 elif vlen is not None:             # <<<<<<<<<<<<<<
 *                     return vlen_create(py_create(vlen, logical))
 * 
 */
              __pyx_t_12 = (__pyx_v_vlen != Py_None);
              __pyx_t_11 = (__pyx_t_12 != 0);
              if (__pyx_t_11) {

                /* "h5py/h5t.pyx":1741
 *                     return _c_vlen_unicode()
 *                 elif vlen is not None:
 *                     return vlen_create(py_create(vlen, logical))             # <<<<<<<<<<<<<<
 * 
 *                 refclass = check_ref_dtype(dt)
 */
                __Pyx_XDECREF(((PyObject *)__pyx_r));
                __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_vlen_create); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1741, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_1);
                __pyx_t_13.__pyx_n = 1;
                __pyx_t_13.logical = __pyx_v_logical;
                __pyx_t_2 = ((PyObject *)__pyx_f_4h5py_3h5t_py_create(__pyx_v_vlen, 0, &__pyx_t_13)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1741, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_7 = NULL;
                if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
                  __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
                  if (likely(__pyx_t_7)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                    __Pyx_INCREF(__pyx_t_7);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_1, function);
                  }
                }
                __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2);
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1741, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_3);
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 1741, __pyx_L7_error)
                __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
                __pyx_t_3 = 0;
                goto __pyx_L11_try_return;

                /* "h5py/h5t.pyx":1740
 *                 elif vlen is unicode:
 *                     return _c_vlen_unicode()
 *                 elif vlen is not None:             # <<<<<<<<<<<<<<
 *                     return vlen_create(py_create(vlen, logical))
 * 
 */
              }

              /* "h5py/h5t.pyx":1743
 *                     return vlen_create(py_create(vlen, logical))
 * 
 *                 refclass = check_ref_dtype(dt)             # <<<<<<<<<<<<<<
 *                 if refclass is not None:
 *                     return _c_ref(refclass)
 */
              __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_check_ref_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1743, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_2 = NULL;
              if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
                __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
                if (likely(__pyx_t_2)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                  __Pyx_INCREF(__pyx_t_2);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_1, function);
                }
              }
              __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, ((PyObject *)__pyx_v_dt)) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)__pyx_v_dt));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1743, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_v_refclass = __pyx_t_3;
              __pyx_t_3 = 0;

              /* "h5py/h5t.pyx":1744
 * 
 *                 refclass = check_ref_dtype(dt)
 *                 if refclass is not None:             # <<<<<<<<<<<<<<
 *                     return _c_ref(refclass)
 * 
 */
              __pyx_t_11 = (__pyx_v_refclass != Py_None);
              __pyx_t_12 = (__pyx_t_11 != 0);
              if (__pyx_t_12) {

                /* "h5py/h5t.pyx":1745
 *                 refclass = check_ref_dtype(dt)
 *                 if refclass is not None:
 *                     return _c_ref(refclass)             # <<<<<<<<<<<<<<
 * 
 *                 raise TypeError("Object dtype %r has no native HDF5 equivalent" % (dt,))
 */
                __Pyx_XDECREF(((PyObject *)__pyx_r));
                __pyx_t_3 = ((PyObject *)__pyx_f_4h5py_3h5t__c_ref(__pyx_v_refclass)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1745, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
                __pyx_t_3 = 0;
                goto __pyx_L11_try_return;

                /* "h5py/h5t.pyx":1744
 * 
 *                 refclass = check_ref_dtype(dt)
 *                 if refclass is not None:             # <<<<<<<<<<<<<<
 *                     return _c_ref(refclass)
 * 
 */
              }

              /* "h5py/h5t.pyx":1747
 *                     return _c_ref(refclass)
 * 
 *                 raise TypeError("Object dtype %r has no native HDF5 equivalent" % (dt,))             # <<<<<<<<<<<<<<
 * 
 *             return PYTHON_OBJECT
 */
              __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1747, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_14 = 0;
              __pyx_t_15 = 127;
              __Pyx_INCREF(__pyx_kp_u_Object_dtype);
              __pyx_t_14 += 13;
              __Pyx_GIVEREF(__pyx_kp_u_Object_dtype);
              PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Object_dtype);
              __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(((PyObject *)__pyx_v_dt)), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1747, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_15 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_15) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_15;
              __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
              __pyx_t_1 = 0;
              __Pyx_INCREF(__pyx_kp_u_has_no_native_HDF5_equivalent);
              __pyx_t_14 += 30;
              __Pyx_GIVEREF(__pyx_kp_u_has_no_native_HDF5_equivalent);
              PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_has_no_native_HDF5_equivalent);
              __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_14, __pyx_t_15); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1747, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1747, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_Raise(__pyx_t_3, 0, 0, 0);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __PYX_ERR(0, 1747, __pyx_L7_error)

              /* "h5py/h5t.pyx":1734
 *         elif kind == c'O':
 * 
 *             if logical:             # <<<<<<<<<<<<<<
 *                 vlen = check_vlen_dtype(dt)
 *                 if vlen is bytes:
 */
            }

            /* "h5py/h5t.pyx":1749
 *                 raise TypeError("Object dtype %r has no native HDF5 equivalent" % (dt,))
 * 
 *             return PYTHON_OBJECT             # <<<<<<<<<<<<<<
 * 
 *         # Unrecognized
 */
            __Pyx_XDECREF(((PyObject *)__pyx_r));
            __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PYTHON_OBJECT); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1749, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_4h5py_3h5t_TypeID))))) __PYX_ERR(0, 1749, __pyx_L7_error)
            __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)__pyx_t_3);
            __pyx_t_3 = 0;
            goto __pyx_L11_try_return;

            /* "h5py/h5t.pyx":1732
 * 
 *         # Object types (including those with vlen hints)
 *         elif kind == c'O':             # <<<<<<<<<<<<<<
 * 
 *             if logical:
 */
          }

          /* "h5py/h5t.pyx":1753
 *         # Unrecognized
 *         else:
 *             raise TypeError("No conversion path for dtype: %s" % repr(dt))             # <<<<<<<<<<<<<<
 * 
 * def vlen_dtype(basetype):
 */
          /*else*/ {
            __pyx_t_3 = PyObject_Repr(((PyObject *)__pyx_v_dt)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1753, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_No_conversion_path_for_dtype_s, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1753, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1753, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_Raise(__pyx_t_3, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __PYX_ERR(0, 1753, __pyx_L7_error)
          }

          /* "h5py/h5t.pyx":1687
 *     aligned = getattr(dtype_in, "isalignedstruct", aligned)
 * 
 *     with phil:             # <<<<<<<<<<<<<<
 *         # Tagged opaque data
 *         if check_opaque_dtype(dt):
 */
        }
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("h5py.h5t.py_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 1687, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_7 = PyTuple_Pack(3, __pyx_t_3, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1687, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1687, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (__pyx_t_12 < 0) __PYX_ERR(0, 1687, __pyx_L9_except_error)
          __pyx_t_11 = ((!(__pyx_t_12 != 0)) != 0);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_XGIVEREF(__pyx_t_2);
            __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_1, __pyx_t_2);
            __pyx_t_3 = 0; __pyx_t_1 = 0; __pyx_t_2 = 0; 
            __PYX_ERR(0, 1687, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L1_error;
        __pyx_L11_try_return:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L4_return;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_6) {
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1687, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L4_return: {
        __pyx_t_17 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_6) {
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__3, NULL);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1687, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __pyx_r = __pyx_t_17;
        __pyx_t_17 = 0;
        goto __pyx_L0;
      }
      __pyx_L6:;
    }
    goto __pyx_L26;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L1_error;
    __pyx_L26:;
  }

  /* "h5py/h5t.pyx":1663
 * 
 * 
 * cpdef TypeID py_create(object dtype_in, bint logical=0, bint aligned=0):             # <<<<<<<<<<<<<<
 *     """(OBJECT dtype_in, BOOL logical=False) => TypeID
 * 
 */

  /* function exit code */
  __pyx_r = ((struct __pyx_obj_4h5py_3h5t_TypeID *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t.py_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_dt);
  __Pyx_XDECREF(__pyx_v_enum_vals);
  __Pyx_XDECREF(__pyx_v_vlen);
  __Pyx_XDECREF(__pyx_v_refclass);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_17py_create(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_16py_create[] = "(OBJECT dtype_in, BOOL logical=False) => TypeID\n\n    Given a Numpy dtype object, generate a byte-for-byte memory-compatible\n    HDF5 datatype object.  The result is guaranteed to be transient and\n    unlocked.\n\n    :param dtype_in: may be a dtype object, or anything which can be\n        converted to a dtype, including strings like '<i4' or an \"int\".\n    :param logical: when this flag is set, instead of returning a byte-for-byte\n        identical representation of the type, the function returns the closest\n        logically appropriate HDF5 type.  For example, in the case of a \"hinted\"\n        dtype of kind \"O\" representing a string, it would return an HDF5 variable-\n        length string type.\n    ";
static PyObject *__pyx_pw_4h5py_3h5t_17py_create(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_dtype_in = 0;
  int __pyx_v_logical;
  int __pyx_v_aligned;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("py_create (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtype_in,&__pyx_n_s_logical,&__pyx_n_s_aligned,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dtype_in)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_logical);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_aligned);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "py_create") < 0)) __PYX_ERR(0, 1663, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_dtype_in = values[0];
    if (values[1]) {
      __pyx_v_logical = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_logical == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1663, __pyx_L3_error)
    } else {
      __pyx_v_logical = ((int)0);
    }
    if (values[2]) {
      __pyx_v_aligned = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_aligned == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1663, __pyx_L3_error)
    } else {
      __pyx_v_aligned = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("py_create", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1663, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.py_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_16py_create(__pyx_self, __pyx_v_dtype_in, __pyx_v_logical, __pyx_v_aligned);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_16py_create(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dtype_in, int __pyx_v_logical, int __pyx_v_aligned) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_4h5py_3h5t_py_create __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_create", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.logical = __pyx_v_logical;
  __pyx_t_2.aligned = __pyx_v_aligned;
  __pyx_t_1 = ((PyObject *)__pyx_f_4h5py_3h5t_py_create(__pyx_v_dtype_in, 0, &__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5t.py_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1755
 *             raise TypeError("No conversion path for dtype: %s" % repr(dt))
 * 
 * def vlen_dtype(basetype):             # <<<<<<<<<<<<<<
 *     """Make a numpy dtype for an HDF5 variable-length datatype
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_19vlen_dtype(PyObject *__pyx_self, PyObject *__pyx_v_basetype); /*proto*/
static char __pyx_doc_4h5py_3h5t_18vlen_dtype[] = "Make a numpy dtype for an HDF5 variable-length datatype\n\n    For variable-length string dtypes, use :func:`string_dtype` instead.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_19vlen_dtype = {"vlen_dtype", (PyCFunction)__pyx_pw_4h5py_3h5t_19vlen_dtype, METH_O, __pyx_doc_4h5py_3h5t_18vlen_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_19vlen_dtype(PyObject *__pyx_self, PyObject *__pyx_v_basetype) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vlen_dtype (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_18vlen_dtype(__pyx_self, ((PyObject *)__pyx_v_basetype));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_18vlen_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_basetype) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vlen_dtype", 0);

  /* "h5py/h5t.pyx":1760
 *     For variable-length string dtypes, use :func:`string_dtype` instead.
 *     """
 *     return np.dtype('O', metadata={'vlen': basetype})             # <<<<<<<<<<<<<<
 * 
 * def string_dtype(encoding='utf-8', length=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_vlen, __pyx_v_basetype) < 0) __PYX_ERR(0, 1760, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_metadata, __pyx_t_3) < 0) __PYX_ERR(0, 1760, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__12, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1755
 *             raise TypeError("No conversion path for dtype: %s" % repr(dt))
 * 
 * def vlen_dtype(basetype):             # <<<<<<<<<<<<<<
 *     """Make a numpy dtype for an HDF5 variable-length datatype
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.h5t.vlen_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1762
 *     return np.dtype('O', metadata={'vlen': basetype})
 * 
 * def string_dtype(encoding='utf-8', length=None):             # <<<<<<<<<<<<<<
 *     """Make a numpy dtype for HDF5 strings
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_21string_dtype(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_20string_dtype[] = "Make a numpy dtype for HDF5 strings\n\n    encoding may be 'utf-8' or 'ascii'.\n\n    length may be an integer for a fixed length string dtype, or None for\n    variable length strings. String lengths for HDF5 are counted in bytes,\n    not unicode code points.\n\n    For variable length strings, the data should be passed as Python str objects\n    (unicode in Python 2) if the encoding is 'utf-8', and bytes if it is 'ascii'.\n    For fixed length strings, the data should be numpy fixed length *bytes*\n    arrays, regardless of the encoding. Fixed length unicode data is not\n    supported.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_21string_dtype = {"string_dtype", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_21string_dtype, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_20string_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_21string_dtype(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_encoding = 0;
  PyObject *__pyx_v_length = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("string_dtype (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_encoding,&__pyx_n_s_length,0};
    PyObject* values[2] = {0,0};
    values[0] = ((PyObject *)__pyx_kp_u_utf_8);
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_encoding);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_length);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "string_dtype") < 0)) __PYX_ERR(0, 1762, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_encoding = values[0];
    __pyx_v_length = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("string_dtype", 0, 0, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1762, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.string_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_20string_dtype(__pyx_self, __pyx_v_encoding, __pyx_v_length);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_20string_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_encoding, PyObject *__pyx_v_length) {
  PyTypeObject *__pyx_v_vlen = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("string_dtype", 0);
  __Pyx_INCREF(__pyx_v_encoding);

  /* "h5py/h5t.pyx":1778
 *     """
 *     # Normalise encoding name:
 *     try:             # <<<<<<<<<<<<<<
 *         encoding = codecs.lookup(encoding).name
 *     except LookupError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "h5py/h5t.pyx":1779
 *     # Normalise encoding name:
 *     try:
 *         encoding = codecs.lookup(encoding).name             # <<<<<<<<<<<<<<
 *     except LookupError:
 *         pass  # Use our error below
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_codecs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1779, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_lookup); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1779, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_v_encoding) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_encoding);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1779, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1779, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_encoding, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "h5py/h5t.pyx":1778
 *     """
 *     # Normalise encoding name:
 *     try:             # <<<<<<<<<<<<<<
 *         encoding = codecs.lookup(encoding).name
 *     except LookupError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "h5py/h5t.pyx":1780
 *     try:
 *         encoding = codecs.lookup(encoding).name
 *     except LookupError:             # <<<<<<<<<<<<<<
 *         pass  # Use our error below
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_LookupError);
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "h5py/h5t.pyx":1778
 *     """
 *     # Normalise encoding name:
 *     try:             # <<<<<<<<<<<<<<
 *         encoding = codecs.lookup(encoding).name
 *     except LookupError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "h5py/h5t.pyx":1783
 *         pass  # Use our error below
 * 
 *     if encoding not in {'ascii', 'utf-8'}:             # <<<<<<<<<<<<<<
 *         raise ValueError("Invalid encoding (%r); 'utf-8' or 'ascii' allowed"
 *                          % encoding)
 */
  __Pyx_INCREF(__pyx_v_encoding);
  __pyx_t_6 = __pyx_v_encoding;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_n_u_ascii, Py_NE)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1783, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_kp_u_utf_8, Py_NE)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1783, __pyx_L1_error)
  __pyx_t_8 = __pyx_t_9;
  __pyx_L10_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (unlikely(__pyx_t_9)) {

    /* "h5py/h5t.pyx":1785
 *     if encoding not in {'ascii', 'utf-8'}:
 *         raise ValueError("Invalid encoding (%r); 'utf-8' or 'ascii' allowed"
 *                          % encoding)             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(length, int):
 */
    __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Invalid_encoding_r_utf_8_or_asci, __pyx_v_encoding); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1785, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "h5py/h5t.pyx":1784
 * 
 *     if encoding not in {'ascii', 'utf-8'}:
 *         raise ValueError("Invalid encoding (%r); 'utf-8' or 'ascii' allowed"             # <<<<<<<<<<<<<<
 *                          % encoding)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1784, __pyx_L1_error)

    /* "h5py/h5t.pyx":1783
 *         pass  # Use our error below
 * 
 *     if encoding not in {'ascii', 'utf-8'}:             # <<<<<<<<<<<<<<
 *         raise ValueError("Invalid encoding (%r); 'utf-8' or 'ascii' allowed"
 *                          % encoding)
 */
  }

  /* "h5py/h5t.pyx":1787
 *                          % encoding)
 * 
 *     if isinstance(length, int):             # <<<<<<<<<<<<<<
 *         # Fixed length string
 *         return np.dtype("|S" + str(length), metadata={'h5py_encoding': encoding})
 */
  __pyx_t_9 = PyInt_Check(__pyx_v_length); 
  __pyx_t_8 = (__pyx_t_9 != 0);
  if (__pyx_t_8) {

    /* "h5py/h5t.pyx":1789
 *     if isinstance(length, int):
 *         # Fixed length string
 *         return np.dtype("|S" + str(length), metadata={'h5py_encoding': encoding})             # <<<<<<<<<<<<<<
 *     elif length is None:
 *         vlen = unicode if (encoding == 'utf-8') else bytes
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_length); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_kp_u_S, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (PyDict_SetItem(__pyx_t_10, __pyx_n_u_h5py_encoding, __pyx_v_encoding) < 0) __PYX_ERR(0, 1789, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_metadata, __pyx_t_10) < 0) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1787
 *                          % encoding)
 * 
 *     if isinstance(length, int):             # <<<<<<<<<<<<<<
 *         # Fixed length string
 *         return np.dtype("|S" + str(length), metadata={'h5py_encoding': encoding})
 */
  }

  /* "h5py/h5t.pyx":1790
 *         # Fixed length string
 *         return np.dtype("|S" + str(length), metadata={'h5py_encoding': encoding})
 *     elif length is None:             # <<<<<<<<<<<<<<
 *         vlen = unicode if (encoding == 'utf-8') else bytes
 *         return np.dtype('O', metadata={'vlen': vlen})
 */
  __pyx_t_8 = (__pyx_v_length == Py_None);
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (likely(__pyx_t_9)) {

    /* "h5py/h5t.pyx":1791
 *         return np.dtype("|S" + str(length), metadata={'h5py_encoding': encoding})
 *     elif length is None:
 *         vlen = unicode if (encoding == 'utf-8') else bytes             # <<<<<<<<<<<<<<
 *         return np.dtype('O', metadata={'vlen': vlen})
 *     else:
 */
    __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_encoding, __pyx_kp_u_utf_8, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1791, __pyx_L1_error)
    if (__pyx_t_9) {
      __Pyx_INCREF(((PyObject *)(&PyUnicode_Type)));
      __pyx_t_10 = ((PyObject *)(&PyUnicode_Type));
    } else {
      __Pyx_INCREF(((PyObject *)(&PyBytes_Type)));
      __pyx_t_10 = ((PyObject *)(&PyBytes_Type));
    }
    __pyx_v_vlen = ((PyTypeObject*)__pyx_t_10);
    __pyx_t_10 = 0;

    /* "h5py/h5t.pyx":1792
 *     elif length is None:
 *         vlen = unicode if (encoding == 'utf-8') else bytes
 *         return np.dtype('O', metadata={'vlen': vlen})             # <<<<<<<<<<<<<<
 *     else:
 *         raise TypeError("length must be integer or None (got %r)" % length)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_np); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_vlen, ((PyObject *)__pyx_v_vlen)) < 0) __PYX_ERR(0, 1792, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_metadata, __pyx_t_4) < 0) __PYX_ERR(0, 1792, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__12, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1790
 *         # Fixed length string
 *         return np.dtype("|S" + str(length), metadata={'h5py_encoding': encoding})
 *     elif length is None:             # <<<<<<<<<<<<<<
 *         vlen = unicode if (encoding == 'utf-8') else bytes
 *         return np.dtype('O', metadata={'vlen': vlen})
 */
  }

  /* "h5py/h5t.pyx":1794
 *         return np.dtype('O', metadata={'vlen': vlen})
 *     else:
 *         raise TypeError("length must be integer or None (got %r)" % length)             # <<<<<<<<<<<<<<
 * 
 * def enum_dtype(values_dict, basetype=np.uint8):
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_length_must_be_integer_or_None_g, __pyx_v_length); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_10, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __PYX_ERR(0, 1794, __pyx_L1_error)
  }

  /* "h5py/h5t.pyx":1762
 *     return np.dtype('O', metadata={'vlen': basetype})
 * 
 * def string_dtype(encoding='utf-8', length=None):             # <<<<<<<<<<<<<<
 *     """Make a numpy dtype for HDF5 strings
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("h5py.h5t.string_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_vlen);
  __Pyx_XDECREF(__pyx_v_encoding);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1796
 *         raise TypeError("length must be integer or None (got %r)" % length)
 * 
 * def enum_dtype(values_dict, basetype=np.uint8):             # <<<<<<<<<<<<<<
 *     """Create a NumPy representation of an HDF5 enumerated type
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_23enum_dtype(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_22enum_dtype[] = "Create a NumPy representation of an HDF5 enumerated type\n\n    *values_dict* maps string names to integer values. *basetype* is an\n    appropriate integer base dtype large enough to hold the possible options.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_23enum_dtype = {"enum_dtype", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_23enum_dtype, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_22enum_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_23enum_dtype(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_values_dict = 0;
  PyObject *__pyx_v_basetype = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enum_dtype (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values_dict,&__pyx_n_s_basetype,0};
    PyObject* values[2] = {0,0};
    values[1] = __pyx_k__13;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_values_dict)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_basetype);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "enum_dtype") < 0)) __PYX_ERR(0, 1796, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values_dict = values[0];
    __pyx_v_basetype = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enum_dtype", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1796, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.enum_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_3h5t_22enum_dtype(__pyx_self, __pyx_v_values_dict, __pyx_v_basetype);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_22enum_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_values_dict, PyObject *__pyx_v_basetype) {
  PyObject *__pyx_v_dt = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enum_dtype", 0);

  /* "h5py/h5t.pyx":1802
 *     appropriate integer base dtype large enough to hold the possible options.
 *     """
 *     dt = np.dtype(basetype)             # <<<<<<<<<<<<<<
 *     if not np.issubdtype(dt, np.integer):
 *         raise TypeError("Only integer types can be used as enums")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_basetype) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_basetype);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_dt = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1803
 *     """
 *     dt = np.dtype(basetype)
 *     if not np.issubdtype(dt, np.integer):             # <<<<<<<<<<<<<<
 *         raise TypeError("Only integer types can be used as enums")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_issubdtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_integer); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_dt, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1803, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_dt, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1803, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_dt);
    __Pyx_GIVEREF(__pyx_v_dt);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_dt);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = ((!__pyx_t_7) != 0);
  if (unlikely(__pyx_t_8)) {

    /* "h5py/h5t.pyx":1804
 *     dt = np.dtype(basetype)
 *     if not np.issubdtype(dt, np.integer):
 *         raise TypeError("Only integer types can be used as enums")             # <<<<<<<<<<<<<<
 * 
 *     return np.dtype(dt, metadata={'enum': values_dict})
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1804, __pyx_L1_error)

    /* "h5py/h5t.pyx":1803
 *     """
 *     dt = np.dtype(basetype)
 *     if not np.issubdtype(dt, np.integer):             # <<<<<<<<<<<<<<
 *         raise TypeError("Only integer types can be used as enums")
 * 
 */
  }

  /* "h5py/h5t.pyx":1806
 *         raise TypeError("Only integer types can be used as enums")
 * 
 *     return np.dtype(dt, metadata={'enum': values_dict})             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_dt);
  __Pyx_GIVEREF(__pyx_v_dt);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_dt);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_enum, __pyx_v_values_dict) < 0) __PYX_ERR(0, 1806, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_metadata, __pyx_t_4) < 0) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1796
 *         raise TypeError("length must be integer or None (got %r)" % length)
 * 
 * def enum_dtype(values_dict, basetype=np.uint8):             # <<<<<<<<<<<<<<
 *     """Create a NumPy representation of an HDF5 enumerated type
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("h5py.h5t.enum_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1809
 * 
 * 
 * def opaque_dtype(np_dtype):             # <<<<<<<<<<<<<<
 *     """Return an equivalent dtype tagged to be stored in an HDF5 opaque type.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_25opaque_dtype(PyObject *__pyx_self, PyObject *__pyx_v_np_dtype); /*proto*/
static char __pyx_doc_4h5py_3h5t_24opaque_dtype[] = "Return an equivalent dtype tagged to be stored in an HDF5 opaque type.\n\n    This makes it easy to store numpy data like datetimes for which there is\n    no equivalent HDF5 type, but it's not interoperable: other tools won't treat\n    the opaque data as datetimes.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_25opaque_dtype = {"opaque_dtype", (PyCFunction)__pyx_pw_4h5py_3h5t_25opaque_dtype, METH_O, __pyx_doc_4h5py_3h5t_24opaque_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_25opaque_dtype(PyObject *__pyx_self, PyObject *__pyx_v_np_dtype) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("opaque_dtype (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_24opaque_dtype(__pyx_self, ((PyObject *)__pyx_v_np_dtype));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_24opaque_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_np_dtype) {
  PyObject *__pyx_v_dt = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("opaque_dtype", 0);

  /* "h5py/h5t.pyx":1816
 *     the opaque data as datetimes.
 *     """
 *     dt = np.dtype(np_dtype)             # <<<<<<<<<<<<<<
 *     if np.issubdtype(dt, np.object_):
 *         raise TypeError("Cannot store numpy object arrays as opaque data")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_np_dtype) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_np_dtype);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_dt = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1817
 *     """
 *     dt = np.dtype(np_dtype)
 *     if np.issubdtype(dt, np.object_):             # <<<<<<<<<<<<<<
 *         raise TypeError("Cannot store numpy object arrays as opaque data")
 *     if dt.names is not None:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_issubdtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_dt, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1817, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_dt, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1817, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_dt);
    __Pyx_GIVEREF(__pyx_v_dt);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_dt);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_7)) {

    /* "h5py/h5t.pyx":1818
 *     dt = np.dtype(np_dtype)
 *     if np.issubdtype(dt, np.object_):
 *         raise TypeError("Cannot store numpy object arrays as opaque data")             # <<<<<<<<<<<<<<
 *     if dt.names is not None:
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1818, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1818, __pyx_L1_error)

    /* "h5py/h5t.pyx":1817
 *     """
 *     dt = np.dtype(np_dtype)
 *     if np.issubdtype(dt, np.object_):             # <<<<<<<<<<<<<<
 *         raise TypeError("Cannot store numpy object arrays as opaque data")
 *     if dt.names is not None:
 */
  }

  /* "h5py/h5t.pyx":1819
 *     if np.issubdtype(dt, np.object_):
 *         raise TypeError("Cannot store numpy object arrays as opaque data")
 *     if dt.names is not None:             # <<<<<<<<<<<<<<
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")
 *     if dt.subdtype is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_names); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = (__pyx_t_7 != 0);
  if (unlikely(__pyx_t_8)) {

    /* "h5py/h5t.pyx":1820
 *         raise TypeError("Cannot store numpy object arrays as opaque data")
 *     if dt.names is not None:
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")             # <<<<<<<<<<<<<<
 *     if dt.subdtype is not None:
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1820, __pyx_L1_error)

    /* "h5py/h5t.pyx":1819
 *     if np.issubdtype(dt, np.object_):
 *         raise TypeError("Cannot store numpy object arrays as opaque data")
 *     if dt.names is not None:             # <<<<<<<<<<<<<<
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")
 *     if dt.subdtype is not None:
 */
  }

  /* "h5py/h5t.pyx":1821
 *     if dt.names is not None:
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")
 *     if dt.subdtype is not None:             # <<<<<<<<<<<<<<
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")
 *     if dt.itemsize == 0:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_subdtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__pyx_t_8 != 0);
  if (unlikely(__pyx_t_7)) {

    /* "h5py/h5t.pyx":1822
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")
 *     if dt.subdtype is not None:
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")             # <<<<<<<<<<<<<<
 *     if dt.itemsize == 0:
 *         raise TypeError("dtype for opaque data must have explicit size")
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1822, __pyx_L1_error)

    /* "h5py/h5t.pyx":1821
 *     if dt.names is not None:
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")
 *     if dt.subdtype is not None:             # <<<<<<<<<<<<<<
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")
 *     if dt.itemsize == 0:
 */
  }

  /* "h5py/h5t.pyx":1823
 *     if dt.subdtype is not None:
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")
 *     if dt.itemsize == 0:             # <<<<<<<<<<<<<<
 *         raise TypeError("dtype for opaque data must have explicit size")
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1823, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_7)) {

    /* "h5py/h5t.pyx":1824
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")
 *     if dt.itemsize == 0:
 *         raise TypeError("dtype for opaque data must have explicit size")             # <<<<<<<<<<<<<<
 * 
 *     return np.dtype(dt, metadata={'h5py_opaque': True})
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1824, __pyx_L1_error)

    /* "h5py/h5t.pyx":1823
 *     if dt.subdtype is not None:
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")
 *     if dt.itemsize == 0:             # <<<<<<<<<<<<<<
 *         raise TypeError("dtype for opaque data must have explicit size")
 * 
 */
  }

  /* "h5py/h5t.pyx":1826
 *         raise TypeError("dtype for opaque data must have explicit size")
 * 
 *     return np.dtype(dt, metadata={'h5py_opaque': True})             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_dt);
  __Pyx_GIVEREF(__pyx_v_dt);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_dt);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_h5py_opaque, Py_True) < 0) __PYX_ERR(0, 1826, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_metadata, __pyx_t_4) < 0) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "h5py/h5t.pyx":1809
 * 
 * 
 * def opaque_dtype(np_dtype):             # <<<<<<<<<<<<<<
 *     """Return an equivalent dtype tagged to be stored in an HDF5 opaque type.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("h5py.h5t.opaque_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1834
 * 
 * @with_phil
 * def special_dtype(**kwds):             # <<<<<<<<<<<<<<
 *     """ Create a new h5py "special" type.  Only one keyword may be given.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_27special_dtype(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_26special_dtype[] = " Create a new h5py \"special\" type.  Only one keyword may be given.\n\n    Legal keywords are:\n\n    vlen = basetype\n        Base type for HDF5 variable-length datatype. This can be Python\n        str type or instance of np.dtype.\n        Example: special_dtype( vlen=str )\n\n    enum = (basetype, values_dict)\n        Create a NumPy representation of an HDF5 enumerated type.  Provide\n        a 2-tuple containing an (integer) base dtype and a dict mapping\n        string names to integer values.\n\n    ref = Reference | RegionReference\n        Create a NumPy representation of an HDF5 object or region reference\n        type.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_27special_dtype = {"special_dtype", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_27special_dtype, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_26special_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_27special_dtype(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_kwds = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("special_dtype (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("special_dtype", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return NULL;}
  if (__pyx_kwds && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "special_dtype", 1))) return NULL;
  __pyx_v_kwds = (__pyx_kwds) ? PyDict_Copy(__pyx_kwds) : PyDict_New(); if (unlikely(!__pyx_v_kwds)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwds);
  __pyx_r = __pyx_pf_4h5py_3h5t_26special_dtype(__pyx_self, __pyx_v_kwds);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_kwds);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_26special_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_kwds) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_v_dt = NULL;
  PyObject *__pyx_v_enum_vals = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("special_dtype", 0);

  /* "h5py/h5t.pyx":1854
 *     """
 * 
 *     if len(kwds) != 1:             # <<<<<<<<<<<<<<
 *         raise TypeError("Exactly one keyword may be provided")
 * 
 */
  __pyx_t_1 = PyDict_Size(__pyx_v_kwds); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1854, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 1) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "h5py/h5t.pyx":1855
 * 
 *     if len(kwds) != 1:
 *         raise TypeError("Exactly one keyword may be provided")             # <<<<<<<<<<<<<<
 * 
 *     name, val = kwds.popitem()
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1855, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1855, __pyx_L1_error)

    /* "h5py/h5t.pyx":1854
 *     """
 * 
 *     if len(kwds) != 1:             # <<<<<<<<<<<<<<
 *         raise TypeError("Exactly one keyword may be provided")
 * 
 */
  }

  /* "h5py/h5t.pyx":1857
 *         raise TypeError("Exactly one keyword may be provided")
 * 
 *     name, val = kwds.popitem()             # <<<<<<<<<<<<<<
 * 
 *     if name == 'vlen':
 */
  __pyx_t_3 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_popitem, __pyx_v_kwds); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1857, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 1857, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1857, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_name = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_val = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "h5py/h5t.pyx":1859
 *     name, val = kwds.popitem()
 * 
 *     if name == 'vlen':             # <<<<<<<<<<<<<<
 *         return np.dtype('O', metadata={'vlen': val})
 * 
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_vlen, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1859, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":1860
 * 
 *     if name == 'vlen':
 *         return np.dtype('O', metadata={'vlen': val})             # <<<<<<<<<<<<<<
 * 
 *     if name == 'enum':
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1860, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1860, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1860, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1860, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_vlen, __pyx_v_val) < 0) __PYX_ERR(0, 1860, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_metadata, __pyx_t_4) < 0) __PYX_ERR(0, 1860, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__12, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1860, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1859
 *     name, val = kwds.popitem()
 * 
 *     if name == 'vlen':             # <<<<<<<<<<<<<<
 *         return np.dtype('O', metadata={'vlen': val})
 * 
 */
  }

  /* "h5py/h5t.pyx":1862
 *         return np.dtype('O', metadata={'vlen': val})
 * 
 *     if name == 'enum':             # <<<<<<<<<<<<<<
 *         try:
 *             dt, enum_vals = val
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_enum, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1862, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":1863
 * 
 *     if name == 'enum':
 *         try:             # <<<<<<<<<<<<<<
 *             dt, enum_vals = val
 *         except TypeError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "h5py/h5t.pyx":1864
 *     if name == 'enum':
 *         try:
 *             dt, enum_vals = val             # <<<<<<<<<<<<<<
 *         except TypeError:
 *             raise TypeError("Enums must be created from a 2-tuple (basetype, values_dict)")
 */
        if ((likely(PyTuple_CheckExact(__pyx_v_val))) || (PyList_CheckExact(__pyx_v_val))) {
          PyObject* sequence = __pyx_v_val;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1864, __pyx_L8_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          #else
          __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1864, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1864, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          Py_ssize_t index = -1;
          __pyx_t_5 = PyObject_GetIter(__pyx_v_val); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1864, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_7 = Py_TYPE(__pyx_t_5)->tp_iternext;
          index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L14_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_4);
          index = 1; __pyx_t_3 = __pyx_t_7(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L14_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1864, __pyx_L8_error)
          __pyx_t_7 = NULL;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          goto __pyx_L15_unpacking_done;
          __pyx_L14_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_7 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1864, __pyx_L8_error)
          __pyx_L15_unpacking_done:;
        }
        __pyx_v_dt = __pyx_t_4;
        __pyx_t_4 = 0;
        __pyx_v_enum_vals = __pyx_t_3;
        __pyx_t_3 = 0;

        /* "h5py/h5t.pyx":1863
 * 
 *     if name == 'enum':
 *         try:             # <<<<<<<<<<<<<<
 *             dt, enum_vals = val
 *         except TypeError:
 */
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L13_try_end;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "h5py/h5t.pyx":1865
 *         try:
 *             dt, enum_vals = val
 *         except TypeError:             # <<<<<<<<<<<<<<
 *             raise TypeError("Enums must be created from a 2-tuple (basetype, values_dict)")
 *         return enum_dtype(enum_vals, dt)
 */
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_11) {
        __Pyx_AddTraceback("h5py.h5t.special_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 1865, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_5);

        /* "h5py/h5t.pyx":1866
 *             dt, enum_vals = val
 *         except TypeError:
 *             raise TypeError("Enums must be created from a 2-tuple (basetype, values_dict)")             # <<<<<<<<<<<<<<
 *         return enum_dtype(enum_vals, dt)
 * 
 */
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1866, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(0, 1866, __pyx_L10_except_error)
      }
      goto __pyx_L10_except_error;
      __pyx_L10_except_error:;

      /* "h5py/h5t.pyx":1863
 * 
 *     if name == 'enum':
 *         try:             # <<<<<<<<<<<<<<
 *             dt, enum_vals = val
 *         except TypeError:
 */
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L13_try_end:;
    }

    /* "h5py/h5t.pyx":1867
 *         except TypeError:
 *             raise TypeError("Enums must be created from a 2-tuple (basetype, values_dict)")
 *         return enum_dtype(enum_vals, dt)             # <<<<<<<<<<<<<<
 * 
 *     if name == 'ref':
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_enum_dtype); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = NULL;
    __pyx_t_11 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_11 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_enum_vals, __pyx_v_dt};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1867, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_enum_vals, __pyx_v_dt};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1867, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1867, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_v_enum_vals);
      __Pyx_GIVEREF(__pyx_v_enum_vals);
      PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_11, __pyx_v_enum_vals);
      __Pyx_INCREF(__pyx_v_dt);
      __Pyx_GIVEREF(__pyx_v_dt);
      PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_11, __pyx_v_dt);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1867, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1862
 *         return np.dtype('O', metadata={'vlen': val})
 * 
 *     if name == 'enum':             # <<<<<<<<<<<<<<
 *         try:
 *             dt, enum_vals = val
 */
  }

  /* "h5py/h5t.pyx":1869
 *         return enum_dtype(enum_vals, dt)
 * 
 *     if name == 'ref':             # <<<<<<<<<<<<<<
 *         if val not in (Reference, RegionReference):
 *             raise ValueError("Ref class must be Reference or RegionReference")
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ref, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1869, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":1870
 * 
 *     if name == 'ref':
 *         if val not in (Reference, RegionReference):             # <<<<<<<<<<<<<<
 *             raise ValueError("Ref class must be Reference or RegionReference")
 *         return ref_dtype if (val is Reference) else regionref_dtype
 */
    __Pyx_INCREF(__pyx_v_val);
    __pyx_t_5 = __pyx_v_val;
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, ((PyObject *)__pyx_ptype_4h5py_3h5r_Reference), Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1870, __pyx_L1_error)
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 1870, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_12) {
    } else {
      __pyx_t_2 = __pyx_t_12;
      goto __pyx_L20_bool_binop_done;
    }
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, ((PyObject *)__pyx_ptype_4h5py_3h5r_RegionReference), Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1870, __pyx_L1_error)
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 1870, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __pyx_t_12;
    __pyx_L20_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_12 = (__pyx_t_2 != 0);
    if (unlikely(__pyx_t_12)) {

      /* "h5py/h5t.pyx":1871
 *     if name == 'ref':
 *         if val not in (Reference, RegionReference):
 *             raise ValueError("Ref class must be Reference or RegionReference")             # <<<<<<<<<<<<<<
 *         return ref_dtype if (val is Reference) else regionref_dtype
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1871, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 1871, __pyx_L1_error)

      /* "h5py/h5t.pyx":1870
 * 
 *     if name == 'ref':
 *         if val not in (Reference, RegionReference):             # <<<<<<<<<<<<<<
 *             raise ValueError("Ref class must be Reference or RegionReference")
 *         return ref_dtype if (val is Reference) else regionref_dtype
 */
    }

    /* "h5py/h5t.pyx":1872
 *         if val not in (Reference, RegionReference):
 *             raise ValueError("Ref class must be Reference or RegionReference")
 *         return ref_dtype if (val is Reference) else regionref_dtype             # <<<<<<<<<<<<<<
 * 
 *     raise TypeError('Unknown special type "%s"' % name)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_12 = (__pyx_v_val == ((PyObject *)__pyx_ptype_4h5py_3h5r_Reference));
    if ((__pyx_t_12 != 0)) {
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ref_dtype); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __pyx_t_4;
      __pyx_t_4 = 0;
    } else {
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_regionref_dtype); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1869
 *         return enum_dtype(enum_vals, dt)
 * 
 *     if name == 'ref':             # <<<<<<<<<<<<<<
 *         if val not in (Reference, RegionReference):
 *             raise ValueError("Ref class must be Reference or RegionReference")
 */
  }

  /* "h5py/h5t.pyx":1874
 *         return ref_dtype if (val is Reference) else regionref_dtype
 * 
 *     raise TypeError('Unknown special type "%s"' % name)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Unknown_special_type_s, __pyx_v_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_Raise(__pyx_t_4, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __PYX_ERR(0, 1874, __pyx_L1_error)

  /* "h5py/h5t.pyx":1834
 * 
 * @with_phil
 * def special_dtype(**kwds):             # <<<<<<<<<<<<<<
 *     """ Create a new h5py "special" type.  Only one keyword may be given.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("h5py.h5t.special_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XDECREF(__pyx_v_enum_vals);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1877
 * 
 * 
 * def check_vlen_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 vlen, returns the Python base class.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_29check_vlen_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt); /*proto*/
static char __pyx_doc_4h5py_3h5t_28check_vlen_dtype[] = "If the dtype represents an HDF5 vlen, returns the Python base class.\n\n    Returns None if the dtype does not represent an HDF5 vlen.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_29check_vlen_dtype = {"check_vlen_dtype", (PyCFunction)__pyx_pw_4h5py_3h5t_29check_vlen_dtype, METH_O, __pyx_doc_4h5py_3h5t_28check_vlen_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_29check_vlen_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_vlen_dtype (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_28check_vlen_dtype(__pyx_self, ((PyObject *)__pyx_v_dt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_28check_vlen_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_vlen_dtype", 0);

  /* "h5py/h5t.pyx":1882
 *     Returns None if the dtype does not represent an HDF5 vlen.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('vlen', None)
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "h5py/h5t.pyx":1883
 *     """
 *     try:
 *         return dt.metadata.get('vlen', None)             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_metadata); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1883, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1883, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1883, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "h5py/h5t.pyx":1882
 *     Returns None if the dtype does not represent an HDF5 vlen.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('vlen', None)
 *     except AttributeError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "h5py/h5t.pyx":1884
 *     try:
 *         return dt.metadata.get('vlen', None)
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("h5py.h5t.check_vlen_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 1884, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);

      /* "h5py/h5t.pyx":1885
 *         return dt.metadata.get('vlen', None)
 *     except AttributeError:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * string_info = namedtuple('string_info', ['encoding', 'length'])
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "h5py/h5t.pyx":1882
 *     Returns None if the dtype does not represent an HDF5 vlen.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('vlen', None)
 *     except AttributeError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "h5py/h5t.pyx":1877
 * 
 * 
 * def check_vlen_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 vlen, returns the Python base class.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t.check_vlen_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1889
 * string_info = namedtuple('string_info', ['encoding', 'length'])
 * 
 * def check_string_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 string, returns a string_info object.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_31check_string_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt); /*proto*/
static char __pyx_doc_4h5py_3h5t_30check_string_dtype[] = "If the dtype represents an HDF5 string, returns a string_info object.\n\n    The returned string_info object holds the encoding and the length.\n    The encoding can only be 'utf-8' or 'ascii'. The length may be None\n    for a variable-length string, or a fixed length in bytes.\n\n    Returns None if the dtype does not represent an HDF5 string.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_31check_string_dtype = {"check_string_dtype", (PyCFunction)__pyx_pw_4h5py_3h5t_31check_string_dtype, METH_O, __pyx_doc_4h5py_3h5t_30check_string_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_31check_string_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_string_dtype (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_30check_string_dtype(__pyx_self, ((PyObject *)__pyx_v_dt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_30check_string_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_v_vlen_kind = NULL;
  PyObject *__pyx_v_enc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_string_dtype", 0);

  /* "h5py/h5t.pyx":1898
 *     Returns None if the dtype does not represent an HDF5 string.
 *     """
 *     vlen_kind = check_vlen_dtype(dt)             # <<<<<<<<<<<<<<
 *     if vlen_kind is unicode:
 *         return string_info('utf-8', None)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_check_vlen_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_dt) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_dt);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_vlen_kind = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1899
 *     """
 *     vlen_kind = check_vlen_dtype(dt)
 *     if vlen_kind is unicode:             # <<<<<<<<<<<<<<
 *         return string_info('utf-8', None)
 *     elif vlen_kind is bytes:
 */
  __pyx_t_4 = (__pyx_v_vlen_kind == ((PyObject *)(&PyUnicode_Type)));
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "h5py/h5t.pyx":1900
 *     vlen_kind = check_vlen_dtype(dt)
 *     if vlen_kind is unicode:
 *         return string_info('utf-8', None)             # <<<<<<<<<<<<<<
 *     elif vlen_kind is bytes:
 *         return string_info('ascii', None)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_string_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1899
 *     """
 *     vlen_kind = check_vlen_dtype(dt)
 *     if vlen_kind is unicode:             # <<<<<<<<<<<<<<
 *         return string_info('utf-8', None)
 *     elif vlen_kind is bytes:
 */
  }

  /* "h5py/h5t.pyx":1901
 *     if vlen_kind is unicode:
 *         return string_info('utf-8', None)
 *     elif vlen_kind is bytes:             # <<<<<<<<<<<<<<
 *         return string_info('ascii', None)
 *     elif dt.kind == 'S':
 */
  __pyx_t_5 = (__pyx_v_vlen_kind == ((PyObject *)(&PyBytes_Type)));
  __pyx_t_4 = (__pyx_t_5 != 0);
  if (__pyx_t_4) {

    /* "h5py/h5t.pyx":1902
 *         return string_info('utf-8', None)
 *     elif vlen_kind is bytes:
 *         return string_info('ascii', None)             # <<<<<<<<<<<<<<
 *     elif dt.kind == 'S':
 *         enc = (dt.metadata or {}).get('h5py_encoding', 'ascii')
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_string_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1901
 *     if vlen_kind is unicode:
 *         return string_info('utf-8', None)
 *     elif vlen_kind is bytes:             # <<<<<<<<<<<<<<
 *         return string_info('ascii', None)
 *     elif dt.kind == 'S':
 */
  }

  /* "h5py/h5t.pyx":1903
 *     elif vlen_kind is bytes:
 *         return string_info('ascii', None)
 *     elif dt.kind == 'S':             # <<<<<<<<<<<<<<
 *         enc = (dt.metadata or {}).get('h5py_encoding', 'ascii')
 *         return string_info(enc, dt.itemsize)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_kind); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_S_2, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1903, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "h5py/h5t.pyx":1904
 *         return string_info('ascii', None)
 *     elif dt.kind == 'S':
 *         enc = (dt.metadata or {}).get('h5py_encoding', 'ascii')             # <<<<<<<<<<<<<<
 *         return string_info(enc, dt.itemsize)
 *     else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_metadata); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1904, __pyx_L1_error)
    if (!__pyx_t_4) {
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_1 = __pyx_t_2;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_L4_bool_binop_done:;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_enc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "h5py/h5t.pyx":1905
 *     elif dt.kind == 'S':
 *         enc = (dt.metadata or {}).get('h5py_encoding', 'ascii')
 *         return string_info(enc, dt.itemsize)             # <<<<<<<<<<<<<<
 *     else:
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_string_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_itemsize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_enc, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1905, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_enc, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1905, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_INCREF(__pyx_v_enc);
      __Pyx_GIVEREF(__pyx_v_enc);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_enc);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "h5py/h5t.pyx":1903
 *     elif vlen_kind is bytes:
 *         return string_info('ascii', None)
 *     elif dt.kind == 'S':             # <<<<<<<<<<<<<<
 *         enc = (dt.metadata or {}).get('h5py_encoding', 'ascii')
 *         return string_info(enc, dt.itemsize)
 */
  }

  /* "h5py/h5t.pyx":1907
 *         return string_info(enc, dt.itemsize)
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * def check_enum_dtype(dt):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "h5py/h5t.pyx":1889
 * string_info = namedtuple('string_info', ['encoding', 'length'])
 * 
 * def check_string_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 string, returns a string_info object.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("h5py.h5t.check_string_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_vlen_kind);
  __Pyx_XDECREF(__pyx_v_enc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1909
 *         return None
 * 
 * def check_enum_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 enumerated type, returns the dictionary
 *     mapping string names to integer values.
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_33check_enum_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt); /*proto*/
static char __pyx_doc_4h5py_3h5t_32check_enum_dtype[] = "If the dtype represents an HDF5 enumerated type, returns the dictionary\n    mapping string names to integer values.\n\n    Returns None if the dtype does not represent an HDF5 enumerated type.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_33check_enum_dtype = {"check_enum_dtype", (PyCFunction)__pyx_pw_4h5py_3h5t_33check_enum_dtype, METH_O, __pyx_doc_4h5py_3h5t_32check_enum_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_33check_enum_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_enum_dtype (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_32check_enum_dtype(__pyx_self, ((PyObject *)__pyx_v_dt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_32check_enum_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_enum_dtype", 0);

  /* "h5py/h5t.pyx":1915
 *     Returns None if the dtype does not represent an HDF5 enumerated type.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('enum', None)
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "h5py/h5t.pyx":1916
 *     """
 *     try:
 *         return dt.metadata.get('enum', None)             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_metadata); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1916, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1916, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1916, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "h5py/h5t.pyx":1915
 *     Returns None if the dtype does not represent an HDF5 enumerated type.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('enum', None)
 *     except AttributeError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "h5py/h5t.pyx":1917
 *     try:
 *         return dt.metadata.get('enum', None)
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("h5py.h5t.check_enum_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 1917, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);

      /* "h5py/h5t.pyx":1918
 *         return dt.metadata.get('enum', None)
 *     except AttributeError:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * def check_opaque_dtype(dt):
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "h5py/h5t.pyx":1915
 *     Returns None if the dtype does not represent an HDF5 enumerated type.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('enum', None)
 *     except AttributeError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "h5py/h5t.pyx":1909
 *         return None
 * 
 * def check_enum_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 enumerated type, returns the dictionary
 *     mapping string names to integer values.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t.check_enum_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1920
 *         return None
 * 
 * def check_opaque_dtype(dt):             # <<<<<<<<<<<<<<
 *     """Return True if the dtype given is tagged to be stored as HDF5 opaque data
 *     """
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_35check_opaque_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt); /*proto*/
static char __pyx_doc_4h5py_3h5t_34check_opaque_dtype[] = "Return True if the dtype given is tagged to be stored as HDF5 opaque data\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_35check_opaque_dtype = {"check_opaque_dtype", (PyCFunction)__pyx_pw_4h5py_3h5t_35check_opaque_dtype, METH_O, __pyx_doc_4h5py_3h5t_34check_opaque_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_35check_opaque_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_opaque_dtype (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_34check_opaque_dtype(__pyx_self, ((PyObject *)__pyx_v_dt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_34check_opaque_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_opaque_dtype", 0);

  /* "h5py/h5t.pyx":1923
 *     """Return True if the dtype given is tagged to be stored as HDF5 opaque data
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('h5py_opaque', False)
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "h5py/h5t.pyx":1924
 *     """
 *     try:
 *         return dt.metadata.get('h5py_opaque', False)             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return False
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_metadata); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1924, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1924, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1924, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "h5py/h5t.pyx":1923
 *     """Return True if the dtype given is tagged to be stored as HDF5 opaque data
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('h5py_opaque', False)
 *     except AttributeError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "h5py/h5t.pyx":1925
 *     try:
 *         return dt.metadata.get('h5py_opaque', False)
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("h5py.h5t.check_opaque_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 1925, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);

      /* "h5py/h5t.pyx":1926
 *         return dt.metadata.get('h5py_opaque', False)
 *     except AttributeError:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * def check_ref_dtype(dt):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "h5py/h5t.pyx":1923
 *     """Return True if the dtype given is tagged to be stored as HDF5 opaque data
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('h5py_opaque', False)
 *     except AttributeError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "h5py/h5t.pyx":1920
 *         return None
 * 
 * def check_opaque_dtype(dt):             # <<<<<<<<<<<<<<
 *     """Return True if the dtype given is tagged to be stored as HDF5 opaque data
 *     """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t.check_opaque_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1928
 *         return False
 * 
 * def check_ref_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 reference type, returns the reference
 *     class (either Reference or RegionReference).
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_37check_ref_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt); /*proto*/
static char __pyx_doc_4h5py_3h5t_36check_ref_dtype[] = "If the dtype represents an HDF5 reference type, returns the reference\n    class (either Reference or RegionReference).\n\n    Returns None if the dtype does not represent an HDF5 reference type.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_37check_ref_dtype = {"check_ref_dtype", (PyCFunction)__pyx_pw_4h5py_3h5t_37check_ref_dtype, METH_O, __pyx_doc_4h5py_3h5t_36check_ref_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_37check_ref_dtype(PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_ref_dtype (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_3h5t_36check_ref_dtype(__pyx_self, ((PyObject *)__pyx_v_dt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_36check_ref_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_ref_dtype", 0);

  /* "h5py/h5t.pyx":1934
 *     Returns None if the dtype does not represent an HDF5 reference type.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('ref', None)
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "h5py/h5t.pyx":1935
 *     """
 *     try:
 *         return dt.metadata.get('ref', None)             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_metadata); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1935, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1935, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1935, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "h5py/h5t.pyx":1934
 *     Returns None if the dtype does not represent an HDF5 reference type.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('ref', None)
 *     except AttributeError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "h5py/h5t.pyx":1936
 *     try:
 *         return dt.metadata.get('ref', None)
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("h5py.h5t.check_ref_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 1936, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);

      /* "h5py/h5t.pyx":1937
 *         return dt.metadata.get('ref', None)
 *     except AttributeError:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * @with_phil
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "h5py/h5t.pyx":1934
 *     Returns None if the dtype does not represent an HDF5 reference type.
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata.get('ref', None)
 *     except AttributeError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "h5py/h5t.pyx":1928
 *         return False
 * 
 * def check_ref_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 reference type, returns the reference
 *     class (either Reference or RegionReference).
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("h5py.h5t.check_ref_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1940
 * 
 * @with_phil
 * def check_dtype(**kwds):             # <<<<<<<<<<<<<<
 *     """ Check a dtype for h5py special type "hint" information.  Only one
 *     keyword may be given.
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_39check_dtype(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_38check_dtype[] = " Check a dtype for h5py special type \"hint\" information.  Only one\n    keyword may be given.\n\n    vlen = dtype\n        If the dtype represents an HDF5 vlen, returns the Python base class.\n        Currently only builting string vlens (str) are supported.  Returns\n        None if the dtype does not represent an HDF5 vlen.\n\n    enum = dtype\n        If the dtype represents an HDF5 enumerated type, returns the dictionary\n        mapping string names to integer values.  Returns None if the dtype does\n        not represent an HDF5 enumerated type.\n\n    ref = dtype\n        If the dtype represents an HDF5 reference type, returns the reference\n        class (either Reference or RegionReference).  Returns None if the dtype\n        does not represent an HDF5 reference type.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_39check_dtype = {"check_dtype", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_39check_dtype, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_38check_dtype};
static PyObject *__pyx_pw_4h5py_3h5t_39check_dtype(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_kwds = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_dtype (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("check_dtype", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return NULL;}
  if (__pyx_kwds && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "check_dtype", 1))) return NULL;
  __pyx_v_kwds = (__pyx_kwds) ? PyDict_Copy(__pyx_kwds) : PyDict_New(); if (unlikely(!__pyx_v_kwds)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwds);
  __pyx_r = __pyx_pf_4h5py_3h5t_38check_dtype(__pyx_self, __pyx_v_kwds);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_kwds);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_38check_dtype(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_kwds) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_dt = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_dtype", 0);

  /* "h5py/h5t.pyx":1960
 *     """
 * 
 *     if len(kwds) != 1:             # <<<<<<<<<<<<<<
 *         raise TypeError("Exactly one keyword may be provided")
 * 
 */
  __pyx_t_1 = PyDict_Size(__pyx_v_kwds); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1960, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 1) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "h5py/h5t.pyx":1961
 * 
 *     if len(kwds) != 1:
 *         raise TypeError("Exactly one keyword may be provided")             # <<<<<<<<<<<<<<
 * 
 *     name, dt = kwds.popitem()
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1961, __pyx_L1_error)

    /* "h5py/h5t.pyx":1960
 *     """
 * 
 *     if len(kwds) != 1:             # <<<<<<<<<<<<<<
 *         raise TypeError("Exactly one keyword may be provided")
 * 
 */
  }

  /* "h5py/h5t.pyx":1963
 *         raise TypeError("Exactly one keyword may be provided")
 * 
 *     name, dt = kwds.popitem()             # <<<<<<<<<<<<<<
 * 
 *     if name not in ('vlen', 'enum', 'ref'):
 */
  __pyx_t_3 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_popitem, __pyx_v_kwds); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1963, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 1963, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1963, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_name = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_dt = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "h5py/h5t.pyx":1965
 *     name, dt = kwds.popitem()
 * 
 *     if name not in ('vlen', 'enum', 'ref'):             # <<<<<<<<<<<<<<
 *         raise TypeError('Unknown special type "%s"' % name)
 * 
 */
  __Pyx_INCREF(__pyx_v_name);
  __pyx_t_3 = __pyx_v_name;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_n_u_vlen, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 1965, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_2 = __pyx_t_8;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_n_u_enum, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 1965, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_2 = __pyx_t_8;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_n_u_ref, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_8;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_8 = (__pyx_t_2 != 0);
  if (unlikely(__pyx_t_8)) {

    /* "h5py/h5t.pyx":1966
 * 
 *     if name not in ('vlen', 'enum', 'ref'):
 *         raise TypeError('Unknown special type "%s"' % name)             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Unknown_special_type_s, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 1966, __pyx_L1_error)

    /* "h5py/h5t.pyx":1965
 *     name, dt = kwds.popitem()
 * 
 *     if name not in ('vlen', 'enum', 'ref'):             # <<<<<<<<<<<<<<
 *         raise TypeError('Unknown special type "%s"' % name)
 * 
 */
  }

  /* "h5py/h5t.pyx":1968
 *         raise TypeError('Unknown special type "%s"' % name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata[name]
 *     except TypeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    /*try:*/ {

      /* "h5py/h5t.pyx":1969
 * 
 *     try:
 *         return dt.metadata[name]             # <<<<<<<<<<<<<<
 *     except TypeError:
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_metadata); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1969, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1969, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L14_try_return;

      /* "h5py/h5t.pyx":1968
 *         raise TypeError('Unknown special type "%s"' % name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata[name]
 *     except TypeError:
 */
    }
    __pyx_L10_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "h5py/h5t.pyx":1970
 *     try:
 *         return dt.metadata[name]
 *     except TypeError:             # <<<<<<<<<<<<<<
 *         return None
 *     except KeyError:
 */
    __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
    if (__pyx_t_12) {
      __Pyx_AddTraceback("h5py.h5t.check_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 1970, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);

      /* "h5py/h5t.pyx":1971
 *         return dt.metadata[name]
 *     except TypeError:
 *         return None             # <<<<<<<<<<<<<<
 *     except KeyError:
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L13_except_return;
    }

    /* "h5py/h5t.pyx":1972
 *     except TypeError:
 *         return None
 *     except KeyError:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
    __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_12) {
      __Pyx_AddTraceback("h5py.h5t.check_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_3) < 0) __PYX_ERR(0, 1972, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_3);

      /* "h5py/h5t.pyx":1973
 *         return None
 *     except KeyError:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L13_except_return;
    }
    goto __pyx_L12_except_error;
    __pyx_L12_except_error:;

    /* "h5py/h5t.pyx":1968
 *         raise TypeError('Unknown special type "%s"' % name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         return dt.metadata[name]
 *     except TypeError:
 */
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L1_error;
    __pyx_L14_try_return:;
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L0;
    __pyx_L13_except_return:;
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L0;
  }

  /* "h5py/h5t.pyx":1940
 * 
 * @with_phil
 * def check_dtype(**kwds):             # <<<<<<<<<<<<<<
 *     """ Check a dtype for h5py special type "hint" information.  Only one
 *     keyword may be given.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("h5py.h5t.check_dtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":1977
 * 
 * @with_phil
 * def convert(TypeID src not None, TypeID dst not None, size_t n,             # <<<<<<<<<<<<<<
 *             cnp.ndarray buf not None, cnp.ndarray bkg=None, ObjectID dxpl=None):
 *     """ (TypeID src, TypeID dst, UINT n, NDARRAY buf, NDARRAY bkg=None,
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_41convert(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_40convert[] = " (TypeID src, TypeID dst, UINT n, NDARRAY buf, NDARRAY bkg=None,\n    PropID dxpl=None)\n\n    Convert n contiguous elements of a buffer in-place.  The array dtype\n    is ignored.  The backing buffer is optional; for conversion of compound\n    types, a temporary copy of conversion buffer will used for backing if\n    one is not supplied.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_41convert = {"convert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_41convert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_40convert};
static PyObject *__pyx_pw_4h5py_3h5t_41convert(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_src = 0;
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_dst = 0;
  size_t __pyx_v_n;
  PyArrayObject *__pyx_v_buf = 0;
  PyArrayObject *__pyx_v_bkg = 0;
  struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_dxpl = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convert (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_src,&__pyx_n_s_dst,&__pyx_n_s_n,&__pyx_n_s_buf,&__pyx_n_s_bkg,&__pyx_n_s_dxpl,0};
    PyObject* values[6] = {0,0,0,0,0,0};

    /* "h5py/h5t.pyx":1978
 * @with_phil
 * def convert(TypeID src not None, TypeID dst not None, size_t n,
 *             cnp.ndarray buf not None, cnp.ndarray bkg=None, ObjectID dxpl=None):             # <<<<<<<<<<<<<<
 *     """ (TypeID src, TypeID dst, UINT n, NDARRAY buf, NDARRAY bkg=None,
 *     PropID dxpl=None)
 */
    values[4] = (PyObject *)((PyArrayObject *)Py_None);
    values[5] = (PyObject *)((struct __pyx_obj_4h5py_8_objects_ObjectID *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_src)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dst)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("convert", 0, 4, 6, 1); __PYX_ERR(0, 1977, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("convert", 0, 4, 6, 2); __PYX_ERR(0, 1977, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_buf)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("convert", 0, 4, 6, 3); __PYX_ERR(0, 1977, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bkg);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dxpl);
          if (value) { values[5] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "convert") < 0)) __PYX_ERR(0, 1977, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_src = ((struct __pyx_obj_4h5py_3h5t_TypeID *)values[0]);
    __pyx_v_dst = ((struct __pyx_obj_4h5py_3h5t_TypeID *)values[1]);
    __pyx_v_n = __Pyx_PyInt_As_size_t(values[2]); if (unlikely((__pyx_v_n == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1977, __pyx_L3_error)
    __pyx_v_buf = ((PyArrayObject *)values[3]);
    __pyx_v_bkg = ((PyArrayObject *)values[4]);
    __pyx_v_dxpl = ((struct __pyx_obj_4h5py_8_objects_ObjectID *)values[5]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("convert", 0, 4, 6, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1977, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.convert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_src), __pyx_ptype_4h5py_3h5t_TypeID, 0, "src", 0))) __PYX_ERR(0, 1977, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dst), __pyx_ptype_4h5py_3h5t_TypeID, 0, "dst", 0))) __PYX_ERR(0, 1977, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_buf), __pyx_ptype_5numpy_ndarray, 0, "buf", 0))) __PYX_ERR(0, 1978, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_bkg), __pyx_ptype_5numpy_ndarray, 1, "bkg", 0))) __PYX_ERR(0, 1978, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dxpl), __pyx_ptype_4h5py_8_objects_ObjectID, 1, "dxpl", 0))) __PYX_ERR(0, 1978, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_40convert(__pyx_self, __pyx_v_src, __pyx_v_dst, __pyx_v_n, __pyx_v_buf, __pyx_v_bkg, __pyx_v_dxpl);

  /* "h5py/h5t.pyx":1977
 * 
 * @with_phil
 * def convert(TypeID src not None, TypeID dst not None, size_t n,             # <<<<<<<<<<<<<<
 *             cnp.ndarray buf not None, cnp.ndarray bkg=None, ObjectID dxpl=None):
 *     """ (TypeID src, TypeID dst, UINT n, NDARRAY buf, NDARRAY bkg=None,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_40convert(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_src, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_dst, size_t __pyx_v_n, PyArrayObject *__pyx_v_buf, PyArrayObject *__pyx_v_bkg, struct __pyx_obj_4h5py_8_objects_ObjectID *__pyx_v_dxpl) {
  void *__pyx_v_bkg_;
  void *__pyx_v_buf_;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  herr_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_bkg);

  /* "h5py/h5t.pyx":1988
 *     """
 *     cdef:
 *         void* bkg_ = NULL             # <<<<<<<<<<<<<<
 *         void* buf_ = buf.data
 * 
 */
  __pyx_v_bkg_ = NULL;

  /* "h5py/h5t.pyx":1989
 *     cdef:
 *         void* bkg_ = NULL
 *         void* buf_ = buf.data             # <<<<<<<<<<<<<<
 * 
 *     if bkg is None and (src.detect_class(H5T_COMPOUND) or
 */
  __pyx_t_1 = __pyx_v_buf->data;
  __pyx_v_buf_ = __pyx_t_1;

  /* "h5py/h5t.pyx":1991
 *         void* buf_ = buf.data
 * 
 *     if bkg is None and (src.detect_class(H5T_COMPOUND) or             # <<<<<<<<<<<<<<
 *                         dst.detect_class(H5T_COMPOUND)):
 *         bkg = buf.copy()
 */
  __pyx_t_3 = (((PyObject *)__pyx_v_bkg) == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_src), __pyx_n_s_detect_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_COMPOUND); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1991, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }

  /* "h5py/h5t.pyx":1992
 * 
 *     if bkg is None and (src.detect_class(H5T_COMPOUND) or
 *                         dst.detect_class(H5T_COMPOUND)):             # <<<<<<<<<<<<<<
 *         bkg = buf.copy()
 *     if bkg is not None:
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dst), __pyx_n_s_detect_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_COMPOUND); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;

  /* "h5py/h5t.pyx":1991
 *         void* buf_ = buf.data
 * 
 *     if bkg is None and (src.detect_class(H5T_COMPOUND) or             # <<<<<<<<<<<<<<
 *                         dst.detect_class(H5T_COMPOUND)):
 *         bkg = buf.copy()
 */
  if (__pyx_t_2) {

    /* "h5py/h5t.pyx":1993
 *     if bkg is None and (src.detect_class(H5T_COMPOUND) or
 *                         dst.detect_class(H5T_COMPOUND)):
 *         bkg = buf.copy()             # <<<<<<<<<<<<<<
 *     if bkg is not None:
 *         bkg_ = bkg.data
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_buf), __pyx_n_s_copy_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1993, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_bkg, ((PyArrayObject *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "h5py/h5t.pyx":1991
 *         void* buf_ = buf.data
 * 
 *     if bkg is None and (src.detect_class(H5T_COMPOUND) or             # <<<<<<<<<<<<<<
 *                         dst.detect_class(H5T_COMPOUND)):
 *         bkg = buf.copy()
 */
  }

  /* "h5py/h5t.pyx":1994
 *                         dst.detect_class(H5T_COMPOUND)):
 *         bkg = buf.copy()
 *     if bkg is not None:             # <<<<<<<<<<<<<<
 *         bkg_ = bkg.data
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_bkg) != Py_None);
  __pyx_t_4 = (__pyx_t_2 != 0);
  if (__pyx_t_4) {

    /* "h5py/h5t.pyx":1995
 *         bkg = buf.copy()
 *     if bkg is not None:
 *         bkg_ = bkg.data             # <<<<<<<<<<<<<<
 * 
 *     H5Tconvert(src.id, dst.id, n, buf_, bkg_, pdefault(dxpl))
 */
    __pyx_t_1 = __pyx_v_bkg->data;
    __pyx_v_bkg_ = __pyx_t_1;

    /* "h5py/h5t.pyx":1994
 *                         dst.detect_class(H5T_COMPOUND)):
 *         bkg = buf.copy()
 *     if bkg is not None:             # <<<<<<<<<<<<<<
 *         bkg_ = bkg.data
 * 
 */
  }

  /* "h5py/h5t.pyx":1997
 *         bkg_ = bkg.data
 * 
 *     H5Tconvert(src.id, dst.id, n, buf_, bkg_, pdefault(dxpl))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_9 = __pyx_f_4h5py_4defs_H5Tconvert(__pyx_v_src->__pyx_base.id, __pyx_v_dst->__pyx_base.id, __pyx_v_n, __pyx_v_buf_, __pyx_v_bkg_, __pyx_f_4h5py_8_objects_pdefault(__pyx_v_dxpl)); if (unlikely(__pyx_t_9 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 1997, __pyx_L1_error)

  /* "h5py/h5t.pyx":1977
 * 
 * @with_phil
 * def convert(TypeID src not None, TypeID dst not None, size_t n,             # <<<<<<<<<<<<<<
 *             cnp.ndarray buf not None, cnp.ndarray bkg=None, ObjectID dxpl=None):
 *     """ (TypeID src, TypeID dst, UINT n, NDARRAY buf, NDARRAY bkg=None,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("h5py.h5t.convert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_bkg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5t.pyx":2001
 * 
 * @with_phil
 * def find(TypeID src not None, TypeID dst not None):             # <<<<<<<<<<<<<<
 *     """ (TypeID src, TypeID dst) => TUPLE or None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_3h5t_43find(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4h5py_3h5t_42find[] = " (TypeID src, TypeID dst) => TUPLE or None\n\n    Determine if a conversion path exists from src to dst.  Result is None\n    or a tuple describing the conversion path.  Currently tuple entries are:\n\n    1. INT need_bkg:    Whether this routine requires a backing buffer.\n                        Values are BKG_NO, BKG_TEMP and BKG_YES.\n    ";
static PyMethodDef __pyx_mdef_4h5py_3h5t_43find = {"find", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_43find, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_42find};
static PyObject *__pyx_pw_4h5py_3h5t_43find(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_src = 0;
  struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_dst = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_src,&__pyx_n_s_dst,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_src)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dst)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("find", 1, 2, 2, 1); __PYX_ERR(0, 2001, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "find") < 0)) __PYX_ERR(0, 2001, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_src = ((struct __pyx_obj_4h5py_3h5t_TypeID *)values[0]);
    __pyx_v_dst = ((struct __pyx_obj_4h5py_3h5t_TypeID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("find", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2001, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5t.find", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_src), __pyx_ptype_4h5py_3h5t_TypeID, 0, "src", 0))) __PYX_ERR(0, 2001, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dst), __pyx_ptype_4h5py_3h5t_TypeID, 0, "dst", 0))) __PYX_ERR(0, 2001, __pyx_L1_error)
  __pyx_r = __pyx_pf_4h5py_3h5t_42find(__pyx_self, __pyx_v_src, __pyx_v_dst);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4h5py_3h5t_42find(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_src, struct __pyx_obj_4h5py_3h5t_TypeID *__pyx_v_dst) {
  H5T_cdata_t *__pyx_v_data;
  H5T_conv_t __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  H5T_conv_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find", 0);

  /* "h5py/h5t.pyx":2012
 *     cdef:
 *         H5T_cdata_t *data
 *         H5T_conv_t result = NULL             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __pyx_v_result = NULL;

  /* "h5py/h5t.pyx":2014
 *         H5T_conv_t result = NULL
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         result = H5Tfind(src.id, dst.id, &data)
 *         if result == NULL:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "h5py/h5t.pyx":2015
 * 
 *     try:
 *         result = H5Tfind(src.id, dst.id, &data)             # <<<<<<<<<<<<<<
 *         if result == NULL:
 *             return None
 */
      __pyx_t_4 = __pyx_f_4h5py_4defs_H5Tfind(__pyx_v_src->__pyx_base.id, __pyx_v_dst->__pyx_base.id, (&__pyx_v_data)); if (unlikely(__pyx_t_4 == ((H5T_conv_t)((H5T_conv_t)NULL)))) __PYX_ERR(0, 2015, __pyx_L3_error)
      __pyx_v_result = __pyx_t_4;

      /* "h5py/h5t.pyx":2016
 *     try:
 *         result = H5Tfind(src.id, dst.id, &data)
 *         if result == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return (data[0].need_bkg,)
 */
      __pyx_t_5 = ((__pyx_v_result == NULL) != 0);
      if (__pyx_t_5) {

        /* "h5py/h5t.pyx":2017
 *         result = H5Tfind(src.id, dst.id, &data)
 *         if result == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         return (data[0].need_bkg,)
 *     except:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L7_try_return;

        /* "h5py/h5t.pyx":2016
 *     try:
 *         result = H5Tfind(src.id, dst.id, &data)
 *         if result == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return (data[0].need_bkg,)
 */
      }

      /* "h5py/h5t.pyx":2018
 *         if result == NULL:
 *             return None
 *         return (data[0].need_bkg,)             # <<<<<<<<<<<<<<
 *     except:
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_6 = __Pyx_PyInt_From_H5T_bkg_t((__pyx_v_data[0]).need_bkg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2018, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2018, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L7_try_return;

      /* "h5py/h5t.pyx":2014
 *         H5T_conv_t result = NULL
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         result = H5Tfind(src.id, dst.id, &data)
 *         if result == NULL:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "h5py/h5t.pyx":2019
 *             return None
 *         return (data[0].need_bkg,)
 *     except:             # <<<<<<<<<<<<<<
 *         return None
 */
    /*except:*/ {
      __Pyx_AddTraceback("h5py.h5t.find", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_6, &__pyx_t_8) < 0) __PYX_ERR(0, 2019, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_8);

      /* "h5py/h5t.pyx":2020
 *         return (data[0].need_bkg,)
 *     except:
 *         return None             # <<<<<<<<<<<<<<
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "h5py/h5t.pyx":2014
 *         H5T_conv_t result = NULL
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         result = H5Tfind(src.id, dst.id, &data)
 *         if result == NULL:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "h5py/h5t.pyx":2001
 * 
 * @with_phil
 * def find(TypeID src not None, TypeID dst not None):             # <<<<<<<<<<<<<<
 *     """ (TypeID src, TypeID dst) => TUPLE or None
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("h5py.h5t.find", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":734
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":735
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":734
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":737
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":738
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":737
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":740
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":741
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":740
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":743
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":744
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":743
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":746
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":747
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":746
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":749
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":750
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = (PyDataType_HASSUBARRAY(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":751
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_d->subarray->shape));
    __pyx_r = ((PyObject*)__pyx_v_d->subarray->shape);
    goto __pyx_L0;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":750
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":753
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":749
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":928
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":929
 * 
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!             # <<<<<<<<<<<<<<
 *     PyArray_SetBaseObject(arr, base)
 * 
 */
  Py_INCREF(__pyx_v_base);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":930
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  (void)(PyArray_SetBaseObject(__pyx_v_arr, __pyx_v_base));

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":928
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":932
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_v_base;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":933
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)             # <<<<<<<<<<<<<<
 *     if base is NULL:
 *         return None
 */
  __pyx_v_base = PyArray_BASE(__pyx_v_arr);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":934
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  __pyx_t_1 = ((__pyx_v_base == NULL) != 0);
  if (__pyx_t_1) {

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":935
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return <object>base
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":934
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":936
 *     if base is NULL:
 *         return None
 *     return <object>base             # <<<<<<<<<<<<<<
 * 
 * # Versions of the import_* functions which are more suitable for
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_base));
  __pyx_r = ((PyObject *)__pyx_v_base);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":932
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":940
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_array", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":941
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":942
 * cdef inline int import_array() except -1:
 *     try:
 *         __pyx_import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 942, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":941
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":943
 *     try:
 *         __pyx_import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 943, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":944
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 944, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 944, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":941
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":940
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":946
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_umath", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":947
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":948
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 948, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":947
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":949
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 949, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":950
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 950, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 950, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":947
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":946
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":952
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_ufunc", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":953
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":954
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 954, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":953
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":955
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 955, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":956
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef extern from *:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 956, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 956, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":953
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":952
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":966
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_timedelta64_object", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":978
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":966
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":981
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_datetime64_object", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":993
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":981
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":996
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

static CYTHON_INLINE npy_datetime __pyx_f_5numpy_get_datetime64_value(PyObject *__pyx_v_obj) {
  npy_datetime __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1003
 *     also needed.  That can be found using `get_datetime64_unit`.
 *     """
 *     return (<PyDatetimeScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyDatetimeScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":996
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1006
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

static CYTHON_INLINE npy_timedelta __pyx_f_5numpy_get_timedelta64_value(PyObject *__pyx_v_obj) {
  npy_timedelta __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1010
 *     returns the int64 value underlying scalar numpy timedelta64 object
 *     """
 *     return (<PyTimedeltaScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyTimedeltaScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1006
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1013
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

static CYTHON_INLINE NPY_DATETIMEUNIT __pyx_f_5numpy_get_datetime64_unit(PyObject *__pyx_v_obj) {
  NPY_DATETIMEUNIT __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1017
 *     returns the unit part of the dtype for a numpy datetime64 object.
 *     """
 *     return <NPY_DATETIMEUNIT>(<PyDatetimeScalarObject*>obj).obmeta.base             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((NPY_DATETIMEUNIT)((PyDatetimeScalarObject *)__pyx_v_obj)->obmeta.base);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1013
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}
static struct __pyx_vtabstruct_4h5py_3h5t_TypeID __pyx_vtable_4h5py_3h5t_TypeID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeID *p;
  PyObject *o = __pyx_ptype_4h5py_8_objects_ObjectID->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeID *)o);
  p->__pyx_vtab = __pyx_vtabptr_4h5py_3h5t_TypeID;
  return o;
}

static void __pyx_tp_dealloc_4h5py_3h5t_TypeID(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  PyObject_GC_Track(o);
  if (likely(__pyx_ptype_4h5py_8_objects_ObjectID)) __pyx_ptype_4h5py_8_objects_ObjectID->tp_dealloc(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_4h5py_3h5t_TypeID);
}

static int __pyx_tp_traverse_4h5py_3h5t_TypeID(PyObject *o, visitproc v, void *a) {
  int e;
  e = ((likely(__pyx_ptype_4h5py_8_objects_ObjectID)) ? ((__pyx_ptype_4h5py_8_objects_ObjectID->tp_traverse) ? __pyx_ptype_4h5py_8_objects_ObjectID->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_4h5py_3h5t_TypeID)); if (e) return e;
  return 0;
}

static int __pyx_tp_clear_4h5py_3h5t_TypeID(PyObject *o) {
  if (likely(__pyx_ptype_4h5py_8_objects_ObjectID)) { if (__pyx_ptype_4h5py_8_objects_ObjectID->tp_clear) __pyx_ptype_4h5py_8_objects_ObjectID->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_4h5py_3h5t_TypeID);
  return 0;
}

static PyObject *__pyx_getprop_4h5py_3h5t_6TypeID_dtype(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_3h5t_6TypeID_5dtype_1__get__(o);
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeID[] = {
  {"__copy__", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_5__copy__, METH_NOARGS, 0},
  {"commit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_6TypeID_7commit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_6TypeID_6commit},
  {"committed", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_9committed, METH_NOARGS, __pyx_doc_4h5py_3h5t_6TypeID_8committed},
  {"copy", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_11copy, METH_NOARGS, __pyx_doc_4h5py_3h5t_6TypeID_10copy},
  {"equal", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_13equal, METH_O, __pyx_doc_4h5py_3h5t_6TypeID_12equal},
  {"lock", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_15lock, METH_NOARGS, __pyx_doc_4h5py_3h5t_6TypeID_14lock},
  {"get_class", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_17get_class, METH_NOARGS, __pyx_doc_4h5py_3h5t_6TypeID_16get_class},
  {"set_size", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_19set_size, METH_O, __pyx_doc_4h5py_3h5t_6TypeID_18set_size},
  {"get_size", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_21get_size, METH_NOARGS, __pyx_doc_4h5py_3h5t_6TypeID_20get_size},
  {"get_super", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_23get_super, METH_NOARGS, __pyx_doc_4h5py_3h5t_6TypeID_22get_super},
  {"detect_class", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_25detect_class, METH_O, __pyx_doc_4h5py_3h5t_6TypeID_24detect_class},
  {"encode", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_27encode, METH_NOARGS, __pyx_doc_4h5py_3h5t_6TypeID_26encode},
  {"get_create_plist", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_29get_create_plist, METH_NOARGS, __pyx_doc_4h5py_3h5t_6TypeID_28get_create_plist},
  {"__reduce__", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_31__reduce__, METH_NOARGS, 0},
  {"__setstate__", (PyCFunction)__pyx_pw_4h5py_3h5t_6TypeID_33__setstate__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4h5py_3h5t_TypeID[] = {
  {(char *)"dtype", __pyx_getprop_4h5py_3h5t_6TypeID_dtype, 0, (char *)" A Numpy-style dtype object representing this object.\n        ", 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  __pyx_pw_4h5py_3h5t_6TypeID_1__hash__, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Base class for type identifiers (implements common operations)\n\n        * Hashable: If committed; in HDF5 1.8.X, also if locked\n        * Equality: Logical H5T comparison\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  __pyx_pw_4h5py_3h5t_6TypeID_3__richcmp__, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeID, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4h5py_3h5t_TypeID, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeArrayID __pyx_vtable_4h5py_3h5t_TypeArrayID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeArrayID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeArrayID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeArrayID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeArrayID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeArrayID[] = {
  {"get_array_ndims", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeArrayID_1get_array_ndims, METH_NOARGS, __pyx_doc_4h5py_3h5t_11TypeArrayID_get_array_ndims},
  {"get_array_dims", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeArrayID_3get_array_dims, METH_NOARGS, __pyx_doc_4h5py_3h5t_11TypeArrayID_2get_array_dims},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeArrayID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeArrayID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeArrayID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Represents an array datatype\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeArrayID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeArrayID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeOpaqueID __pyx_vtable_4h5py_3h5t_TypeOpaqueID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeOpaqueID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeOpaqueID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeOpaqueID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeOpaqueID[] = {
  {"set_tag", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeOpaqueID_1set_tag, METH_O, __pyx_doc_4h5py_3h5t_12TypeOpaqueID_set_tag},
  {"get_tag", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeOpaqueID_3get_tag, METH_NOARGS, __pyx_doc_4h5py_3h5t_12TypeOpaqueID_2get_tag},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeOpaqueID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeOpaqueID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeOpaqueID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Represents an opaque type\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeOpaqueID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeOpaqueID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeStringID __pyx_vtable_4h5py_3h5t_TypeStringID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeStringID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeStringID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeStringID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeStringID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeStringID[] = {
  {"is_variable_str", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeStringID_1is_variable_str, METH_NOARGS, __pyx_doc_4h5py_3h5t_12TypeStringID_is_variable_str},
  {"get_cset", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeStringID_3get_cset, METH_NOARGS, __pyx_doc_4h5py_3h5t_12TypeStringID_2get_cset},
  {"set_cset", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeStringID_5set_cset, METH_O, __pyx_doc_4h5py_3h5t_12TypeStringID_4set_cset},
  {"get_strpad", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeStringID_7get_strpad, METH_NOARGS, __pyx_doc_4h5py_3h5t_12TypeStringID_6get_strpad},
  {"set_strpad", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeStringID_9set_strpad, METH_O, __pyx_doc_4h5py_3h5t_12TypeStringID_8set_strpad},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeStringID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeStringID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeStringID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        String datatypes, both fixed and vlen.\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeStringID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeStringID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeVlenID __pyx_vtable_4h5py_3h5t_TypeVlenID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeVlenID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeVlenID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeVlenID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeVlenID;
  return o;
}

static PyTypeObject __pyx_type_4h5py_3h5t_TypeVlenID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeVlenID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeVlenID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Non-string vlen datatypes.\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeVlenID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeTimeID __pyx_vtable_4h5py_3h5t_TypeTimeID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeTimeID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeTimeID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeTimeID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeTimeID;
  return o;
}

static PyTypeObject __pyx_type_4h5py_3h5t_TypeTimeID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeTimeID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeTimeID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Unix-style time_t (deprecated)\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeTimeID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeBitfieldID __pyx_vtable_4h5py_3h5t_TypeBitfieldID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeBitfieldID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeBitfieldID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeBitfieldID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeBitfieldID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeBitfieldID[] = {
  {"get_order", (PyCFunction)__pyx_pw_4h5py_3h5t_14TypeBitfieldID_1get_order, METH_NOARGS, __pyx_doc_4h5py_3h5t_14TypeBitfieldID_get_order},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeBitfieldID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeBitfieldID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeBitfieldID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        HDF5 bitfield type\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeBitfieldID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeBitfieldID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeReferenceID __pyx_vtable_4h5py_3h5t_TypeReferenceID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeReferenceID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeReferenceID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeReferenceID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeReferenceID;
  return o;
}

static PyTypeObject __pyx_type_4h5py_3h5t_TypeReferenceID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeReferenceID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeReferenceID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        HDF5 object or region reference\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeReferenceID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeAtomicID __pyx_vtable_4h5py_3h5t_TypeAtomicID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeAtomicID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeAtomicID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeAtomicID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeAtomicID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeAtomicID[] = {
  {"get_order", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeAtomicID_1get_order, METH_NOARGS, __pyx_doc_4h5py_3h5t_12TypeAtomicID_get_order},
  {"set_order", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeAtomicID_3set_order, METH_O, __pyx_doc_4h5py_3h5t_12TypeAtomicID_2set_order},
  {"get_precision", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeAtomicID_5get_precision, METH_NOARGS, __pyx_doc_4h5py_3h5t_12TypeAtomicID_4get_precision},
  {"set_precision", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeAtomicID_7set_precision, METH_O, __pyx_doc_4h5py_3h5t_12TypeAtomicID_6set_precision},
  {"get_offset", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeAtomicID_9get_offset, METH_NOARGS, __pyx_doc_4h5py_3h5t_12TypeAtomicID_8get_offset},
  {"set_offset", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeAtomicID_11set_offset, METH_O, __pyx_doc_4h5py_3h5t_12TypeAtomicID_10set_offset},
  {"get_pad", (PyCFunction)__pyx_pw_4h5py_3h5t_12TypeAtomicID_13get_pad, METH_NOARGS, __pyx_doc_4h5py_3h5t_12TypeAtomicID_12get_pad},
  {"set_pad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_12TypeAtomicID_15set_pad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_12TypeAtomicID_14set_pad},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeAtomicID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeAtomicID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeAtomicID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Base class for atomic datatypes (float or integer)\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeAtomicID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeAtomicID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeIntegerID __pyx_vtable_4h5py_3h5t_TypeIntegerID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeIntegerID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeIntegerID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeAtomicID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeIntegerID *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeIntegerID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeIntegerID[] = {
  {"get_sign", (PyCFunction)__pyx_pw_4h5py_3h5t_13TypeIntegerID_1get_sign, METH_NOARGS, __pyx_doc_4h5py_3h5t_13TypeIntegerID_get_sign},
  {"set_sign", (PyCFunction)__pyx_pw_4h5py_3h5t_13TypeIntegerID_3set_sign, METH_O, __pyx_doc_4h5py_3h5t_13TypeIntegerID_2set_sign},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeIntegerID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeIntegerID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeIntegerID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Integer atomic datatypes\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeIntegerID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeIntegerID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeFloatID __pyx_vtable_4h5py_3h5t_TypeFloatID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeFloatID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeFloatID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeAtomicID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeFloatID *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeFloatID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeFloatID[] = {
  {"get_fields", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeFloatID_1get_fields, METH_NOARGS, __pyx_doc_4h5py_3h5t_11TypeFloatID_get_fields},
  {"set_fields", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_11TypeFloatID_3set_fields, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_11TypeFloatID_2set_fields},
  {"get_ebias", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeFloatID_5get_ebias, METH_NOARGS, __pyx_doc_4h5py_3h5t_11TypeFloatID_4get_ebias},
  {"set_ebias", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeFloatID_7set_ebias, METH_O, __pyx_doc_4h5py_3h5t_11TypeFloatID_6set_ebias},
  {"get_norm", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeFloatID_9get_norm, METH_NOARGS, __pyx_doc_4h5py_3h5t_11TypeFloatID_8get_norm},
  {"set_norm", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeFloatID_11set_norm, METH_O, __pyx_doc_4h5py_3h5t_11TypeFloatID_10set_norm},
  {"get_inpad", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeFloatID_13get_inpad, METH_NOARGS, __pyx_doc_4h5py_3h5t_11TypeFloatID_12get_inpad},
  {"set_inpad", (PyCFunction)__pyx_pw_4h5py_3h5t_11TypeFloatID_15set_inpad, METH_O, __pyx_doc_4h5py_3h5t_11TypeFloatID_14set_inpad},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeFloatID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeFloatID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeFloatID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Floating-point atomic datatypes\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeFloatID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeFloatID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeCompositeID __pyx_vtable_4h5py_3h5t_TypeCompositeID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeCompositeID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeCompositeID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeCompositeID *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeCompositeID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeCompositeID[] = {
  {"get_nmembers", (PyCFunction)__pyx_pw_4h5py_3h5t_15TypeCompositeID_1get_nmembers, METH_NOARGS, __pyx_doc_4h5py_3h5t_15TypeCompositeID_get_nmembers},
  {"get_member_name", (PyCFunction)__pyx_pw_4h5py_3h5t_15TypeCompositeID_3get_member_name, METH_O, __pyx_doc_4h5py_3h5t_15TypeCompositeID_2get_member_name},
  {"get_member_index", (PyCFunction)__pyx_pw_4h5py_3h5t_15TypeCompositeID_5get_member_index, METH_O, __pyx_doc_4h5py_3h5t_15TypeCompositeID_4get_member_index},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeCompositeID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeCompositeID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeCompositeID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Base class for enumerated and compound types.\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeCompositeID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeCompositeID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeEnumID __pyx_vtable_4h5py_3h5t_TypeEnumID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeEnumID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeEnumID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeCompositeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeEnumID *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeEnumID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeEnumID[] = {
  {"enum_insert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_10TypeEnumID_1enum_insert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_10TypeEnumID_enum_insert},
  {"enum_nameof", (PyCFunction)__pyx_pw_4h5py_3h5t_10TypeEnumID_3enum_nameof, METH_O, __pyx_doc_4h5py_3h5t_10TypeEnumID_2enum_nameof},
  {"enum_valueof", (PyCFunction)__pyx_pw_4h5py_3h5t_10TypeEnumID_5enum_valueof, METH_O, __pyx_doc_4h5py_3h5t_10TypeEnumID_4enum_valueof},
  {"get_member_value", (PyCFunction)__pyx_pw_4h5py_3h5t_10TypeEnumID_7get_member_value, METH_O, __pyx_doc_4h5py_3h5t_10TypeEnumID_6get_member_value},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeEnumID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeEnumID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeEnumID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Represents an enumerated type\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeEnumID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeEnumID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_4h5py_3h5t_TypeCompoundID __pyx_vtable_4h5py_3h5t_TypeCompoundID;

static PyObject *__pyx_tp_new_4h5py_3h5t_TypeCompoundID(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4h5py_3h5t_TypeCompoundID *p;
  PyObject *o = __pyx_tp_new_4h5py_3h5t_TypeCompositeID(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4h5py_3h5t_TypeCompoundID *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4h5py_3h5t_TypeID*)__pyx_vtabptr_4h5py_3h5t_TypeCompoundID;
  return o;
}

static PyMethodDef __pyx_methods_4h5py_3h5t_TypeCompoundID[] = {
  {"get_member_class", (PyCFunction)__pyx_pw_4h5py_3h5t_14TypeCompoundID_1get_member_class, METH_O, __pyx_doc_4h5py_3h5t_14TypeCompoundID_get_member_class},
  {"get_member_offset", (PyCFunction)__pyx_pw_4h5py_3h5t_14TypeCompoundID_3get_member_offset, METH_O, __pyx_doc_4h5py_3h5t_14TypeCompoundID_2get_member_offset},
  {"get_member_type", (PyCFunction)__pyx_pw_4h5py_3h5t_14TypeCompoundID_5get_member_type, METH_O, __pyx_doc_4h5py_3h5t_14TypeCompoundID_4get_member_type},
  {"insert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_14TypeCompoundID_7insert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_14TypeCompoundID_6insert},
  {"pack", (PyCFunction)__pyx_pw_4h5py_3h5t_14TypeCompoundID_9pack, METH_NOARGS, __pyx_doc_4h5py_3h5t_14TypeCompoundID_8pack},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4h5py_3h5t_TypeCompoundID = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.TypeCompoundID", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t_TypeCompoundID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t_TypeID, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n        Represents a compound datatype\n    ", /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t_TypeID, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t_TypeID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_3h5t_TypeCompoundID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t_TypeCompoundID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *__pyx_freelist_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound[8];
static int __pyx_freecount_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound = 0;

static PyObject *__pyx_tp_new_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound)))) {
    o = (PyObject*)__pyx_freelist_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound[--__pyx_freecount_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound];
    memset(o, 0, sizeof(struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound(PyObject *o) {
  struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *p = (struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_dt);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound)))) {
    __pyx_freelist_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound[__pyx_freecount_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound++] = ((struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *p = (struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *)o;
  if (p->__pyx_v_dt) {
    e = (*v)(((PyObject *)p->__pyx_v_dt), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *p = (struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound *)o;
  tmp = ((PyObject*)p->__pyx_v_dt);
  p->__pyx_v_dt = ((PyArray_Descr *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound = {
  PyVarObject_HEAD_INIT(0, 0)
  "h5py.h5t.__pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound", /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound, /*tp_traverse*/
  __pyx_tp_clear_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {"typewrap", (PyCFunction)__pyx_pw_4h5py_3h5t_1typewrap, METH_O, 0},
  {"py_create", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4h5py_3h5t_17py_create, METH_VARARGS|METH_KEYWORDS, __pyx_doc_4h5py_3h5t_16py_create},
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_h5t(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_h5t},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "h5t",
    __pyx_k_HDF5_H5T_data_type_API_This_mod, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_ARRAY, __pyx_k_ARRAY, sizeof(__pyx_k_ARRAY), 0, 0, 1, 1},
  {&__pyx_kp_u_Array_shape_for_dtype_must_be_a, __pyx_k_Array_shape_for_dtype_must_be_a, sizeof(__pyx_k_Array_shape_for_dtype_must_be_a), 0, 1, 0, 0},
  {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
  {&__pyx_n_s_BITFIELD, __pyx_k_BITFIELD, sizeof(__pyx_k_BITFIELD), 0, 0, 1, 1},
  {&__pyx_n_s_BKG_NO, __pyx_k_BKG_NO, sizeof(__pyx_k_BKG_NO), 0, 0, 1, 1},
  {&__pyx_n_s_BKG_TEMP, __pyx_k_BKG_TEMP, sizeof(__pyx_k_BKG_TEMP), 0, 0, 1, 1},
  {&__pyx_n_s_BKG_YES, __pyx_k_BKG_YES, sizeof(__pyx_k_BKG_YES), 0, 0, 1, 1},
  {&__pyx_n_s_COMPOUND, __pyx_k_COMPOUND, sizeof(__pyx_k_COMPOUND), 0, 0, 1, 1},
  {&__pyx_n_s_CSET_ASCII, __pyx_k_CSET_ASCII, sizeof(__pyx_k_CSET_ASCII), 0, 0, 1, 1},
  {&__pyx_n_s_CSET_UTF8, __pyx_k_CSET_UTF8, sizeof(__pyx_k_CSET_UTF8), 0, 0, 1, 1},
  {&__pyx_n_s_C_S1, __pyx_k_C_S1, sizeof(__pyx_k_C_S1), 0, 0, 1, 1},
  {&__pyx_kp_u_Cannot_store_numpy_object_arrays, __pyx_k_Cannot_store_numpy_object_arrays, sizeof(__pyx_k_Cannot_store_numpy_object_arrays), 0, 1, 0, 0},
  {&__pyx_kp_u_Cannot_store_numpy_structured_ar, __pyx_k_Cannot_store_numpy_structured_ar, sizeof(__pyx_k_Cannot_store_numpy_structured_ar), 0, 1, 0, 0},
  {&__pyx_kp_u_Cannot_store_numpy_sub_array_dty, __pyx_k_Cannot_store_numpy_sub_array_dty, sizeof(__pyx_k_Cannot_store_numpy_sub_array_dty), 0, 1, 0, 0},
  {&__pyx_kp_u_Class_must_be_COMPOUND_or_OPAQUE, __pyx_k_Class_must_be_COMPOUND_or_OPAQUE, sizeof(__pyx_k_Class_must_be_COMPOUND_or_OPAQUE), 0, 1, 0, 0},
  {&__pyx_n_s_DIR_ASCEND, __pyx_k_DIR_ASCEND, sizeof(__pyx_k_DIR_ASCEND), 0, 0, 1, 1},
  {&__pyx_n_s_DIR_DEFAULT, __pyx_k_DIR_DEFAULT, sizeof(__pyx_k_DIR_DEFAULT), 0, 0, 1, 1},
  {&__pyx_n_s_DIR_DESCEND, __pyx_k_DIR_DESCEND, sizeof(__pyx_k_DIR_DESCEND), 0, 0, 1, 1},
  {&__pyx_n_s_ENUM, __pyx_k_ENUM, sizeof(__pyx_k_ENUM), 0, 0, 1, 1},
  {&__pyx_kp_u_Enforced_alignment_not_compatibl, __pyx_k_Enforced_alignment_not_compatibl, sizeof(__pyx_k_Enforced_alignment_not_compatibl), 0, 1, 0, 0},
  {&__pyx_kp_u_Enums_must_be_created_from_a_2_t, __pyx_k_Enums_must_be_created_from_a_2_t, sizeof(__pyx_k_Enums_must_be_created_from_a_2_t), 0, 1, 0, 0},
  {&__pyx_kp_u_Exactly_one_keyword_may_be_provi, __pyx_k_Exactly_one_keyword_may_be_provi, sizeof(__pyx_k_Exactly_one_keyword_may_be_provi), 0, 1, 0, 0},
  {&__pyx_n_s_FLOAT, __pyx_k_FLOAT, sizeof(__pyx_k_FLOAT), 0, 0, 1, 1},
  {&__pyx_n_s_FORTRAN_S1, __pyx_k_FORTRAN_S1, sizeof(__pyx_k_FORTRAN_S1), 0, 0, 1, 1},
  {&__pyx_n_u_Float, __pyx_k_Float, sizeof(__pyx_k_Float), 0, 1, 0, 1},
  {&__pyx_n_s_H5PY_OBJ, __pyx_k_H5PY_OBJ, sizeof(__pyx_k_H5PY_OBJ), 0, 0, 1, 1},
  {&__pyx_n_s_H5PY_PYTHON_OPAQUE_TAG, __pyx_k_H5PY_PYTHON_OPAQUE_TAG, sizeof(__pyx_k_H5PY_PYTHON_OPAQUE_TAG), 0, 0, 1, 1},
  {&__pyx_n_s_IEEE_F128BE, __pyx_k_IEEE_F128BE, sizeof(__pyx_k_IEEE_F128BE), 0, 0, 1, 1},
  {&__pyx_n_s_IEEE_F128LE, __pyx_k_IEEE_F128LE, sizeof(__pyx_k_IEEE_F128LE), 0, 0, 1, 1},
  {&__pyx_n_s_IEEE_F16BE, __pyx_k_IEEE_F16BE, sizeof(__pyx_k_IEEE_F16BE), 0, 0, 1, 1},
  {&__pyx_n_s_IEEE_F16LE, __pyx_k_IEEE_F16LE, sizeof(__pyx_k_IEEE_F16LE), 0, 0, 1, 1},
  {&__pyx_n_s_IEEE_F32BE, __pyx_k_IEEE_F32BE, sizeof(__pyx_k_IEEE_F32BE), 0, 0, 1, 1},
  {&__pyx_n_s_IEEE_F32LE, __pyx_k_IEEE_F32LE, sizeof(__pyx_k_IEEE_F32LE), 0, 0, 1, 1},
  {&__pyx_n_s_IEEE_F64BE, __pyx_k_IEEE_F64BE, sizeof(__pyx_k_IEEE_F64BE), 0, 0, 1, 1},
  {&__pyx_n_s_IEEE_F64LE, __pyx_k_IEEE_F64LE, sizeof(__pyx_k_IEEE_F64LE), 0, 0, 1, 1},
  {&__pyx_n_s_INTEGER, __pyx_k_INTEGER, sizeof(__pyx_k_INTEGER), 0, 0, 1, 1},
  {&__pyx_kp_u_Illegal_int_kind_s, __pyx_k_Illegal_int_kind_s, sizeof(__pyx_k_Illegal_int_kind_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Illegal_length_d_for_complex_dty, __pyx_k_Illegal_length_d_for_complex_dty, sizeof(__pyx_k_Illegal_length_d_for_complex_dty), 0, 1, 0, 0},
  {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
  {&__pyx_kp_u_Index_must_be_non_negative, __pyx_k_Index_must_be_non_negative, sizeof(__pyx_k_Index_must_be_non_negative), 0, 1, 0, 0},
  {&__pyx_kp_u_Insufficient_precision_in_availa, __pyx_k_Insufficient_precision_in_availa, sizeof(__pyx_k_Insufficient_precision_in_availa), 0, 1, 0, 0},
  {&__pyx_kp_u_Invalid_encoding_r_utf_8_or_asci, __pyx_k_Invalid_encoding_r_utf_8_or_asci, sizeof(__pyx_k_Invalid_encoding_r_utf_8_or_asci), 0, 1, 0, 0},
  {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
  {&__pyx_n_s_LDOUBLE_BE, __pyx_k_LDOUBLE_BE, sizeof(__pyx_k_LDOUBLE_BE), 0, 0, 1, 1},
  {&__pyx_n_s_LDOUBLE_LE, __pyx_k_LDOUBLE_LE, sizeof(__pyx_k_LDOUBLE_LE), 0, 0, 1, 1},
  {&__pyx_n_s_LookupError, __pyx_k_LookupError, sizeof(__pyx_k_LookupError), 0, 0, 1, 1},
  {&__pyx_kp_u_Member_index_must_be_non_negativ, __pyx_k_Member_index_must_be_non_negativ, sizeof(__pyx_k_Member_index_must_be_non_negativ), 0, 1, 0, 0},
  {&__pyx_n_s_NATIVE_B16, __pyx_k_NATIVE_B16, sizeof(__pyx_k_NATIVE_B16), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_B32, __pyx_k_NATIVE_B32, sizeof(__pyx_k_NATIVE_B32), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_B64, __pyx_k_NATIVE_B64, sizeof(__pyx_k_NATIVE_B64), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_B8, __pyx_k_NATIVE_B8, sizeof(__pyx_k_NATIVE_B8), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_DOUBLE, __pyx_k_NATIVE_DOUBLE, sizeof(__pyx_k_NATIVE_DOUBLE), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_FLOAT, __pyx_k_NATIVE_FLOAT, sizeof(__pyx_k_NATIVE_FLOAT), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_INT16, __pyx_k_NATIVE_INT16, sizeof(__pyx_k_NATIVE_INT16), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_INT32, __pyx_k_NATIVE_INT32, sizeof(__pyx_k_NATIVE_INT32), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_INT64, __pyx_k_NATIVE_INT64, sizeof(__pyx_k_NATIVE_INT64), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_INT8, __pyx_k_NATIVE_INT8, sizeof(__pyx_k_NATIVE_INT8), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_LDOUBLE, __pyx_k_NATIVE_LDOUBLE, sizeof(__pyx_k_NATIVE_LDOUBLE), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_UINT16, __pyx_k_NATIVE_UINT16, sizeof(__pyx_k_NATIVE_UINT16), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_UINT32, __pyx_k_NATIVE_UINT32, sizeof(__pyx_k_NATIVE_UINT32), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_UINT64, __pyx_k_NATIVE_UINT64, sizeof(__pyx_k_NATIVE_UINT64), 0, 0, 1, 1},
  {&__pyx_n_s_NATIVE_UINT8, __pyx_k_NATIVE_UINT8, sizeof(__pyx_k_NATIVE_UINT8), 0, 0, 1, 1},
  {&__pyx_n_s_NORM_IMPLIED, __pyx_k_NORM_IMPLIED, sizeof(__pyx_k_NORM_IMPLIED), 0, 0, 1, 1},
  {&__pyx_n_s_NORM_MSBSET, __pyx_k_NORM_MSBSET, sizeof(__pyx_k_NORM_MSBSET), 0, 0, 1, 1},
  {&__pyx_n_s_NORM_NONE, __pyx_k_NORM_NONE, sizeof(__pyx_k_NORM_NONE), 0, 0, 1, 1},
  {&__pyx_n_s_NO_CLASS, __pyx_k_NO_CLASS, sizeof(__pyx_k_NO_CLASS), 0, 0, 1, 1},
  {&__pyx_kp_b_NUMPY, __pyx_k_NUMPY, sizeof(__pyx_k_NUMPY), 0, 0, 0, 0},
  {&__pyx_kp_u_No_NumPy_equivalent_for_s_exists, __pyx_k_No_NumPy_equivalent_for_s_exists, sizeof(__pyx_k_No_NumPy_equivalent_for_s_exists), 0, 1, 0, 0},
  {&__pyx_kp_u_No_conversion_path_for_dtype_s, __pyx_k_No_conversion_path_for_dtype_s, sizeof(__pyx_k_No_conversion_path_for_dtype_s), 0, 1, 0, 0},
  {&__pyx_n_s_NotImplemented, __pyx_k_NotImplemented, sizeof(__pyx_k_NotImplemented), 0, 0, 1, 1},
  {&__pyx_n_u_O, __pyx_k_O, sizeof(__pyx_k_O), 0, 1, 0, 1},
  {&__pyx_n_s_OPAQUE, __pyx_k_OPAQUE, sizeof(__pyx_k_OPAQUE), 0, 0, 1, 1},
  {&__pyx_n_s_ORDER_BE, __pyx_k_ORDER_BE, sizeof(__pyx_k_ORDER_BE), 0, 0, 1, 1},
  {&__pyx_n_s_ORDER_LE, __pyx_k_ORDER_LE, sizeof(__pyx_k_ORDER_LE), 0, 0, 1, 1},
  {&__pyx_n_s_ORDER_NATIVE, __pyx_k_ORDER_NATIVE, sizeof(__pyx_k_ORDER_NATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_ORDER_NONE, __pyx_k_ORDER_NONE, sizeof(__pyx_k_ORDER_NONE), 0, 0, 1, 1},
  {&__pyx_n_s_ORDER_VAX, __pyx_k_ORDER_VAX, sizeof(__pyx_k_ORDER_VAX), 0, 0, 1, 1},
  {&__pyx_kp_u_Object_dtype, __pyx_k_Object_dtype, sizeof(__pyx_k_Object_dtype), 0, 1, 0, 0},
  {&__pyx_kp_u_Only_integer_types_can_be_used_a, __pyx_k_Only_integer_types_can_be_used_a, sizeof(__pyx_k_Only_integer_types_can_be_used_a), 0, 1, 0, 0},
  {&__pyx_kp_u_Only_locked_or_committed_types_c, __pyx_k_Only_locked_or_committed_types_c, sizeof(__pyx_k_Only_locked_or_committed_types_c), 0, 1, 0, 0},
  {&__pyx_n_s_PAD_BACKGROUND, __pyx_k_PAD_BACKGROUND, sizeof(__pyx_k_PAD_BACKGROUND), 0, 0, 1, 1},
  {&__pyx_n_s_PAD_ONE, __pyx_k_PAD_ONE, sizeof(__pyx_k_PAD_ONE), 0, 0, 1, 1},
  {&__pyx_n_s_PAD_ZERO, __pyx_k_PAD_ZERO, sizeof(__pyx_k_PAD_ZERO), 0, 0, 1, 1},
  {&__pyx_n_s_PYTHON_OBJECT, __pyx_k_PYTHON_OBJECT, sizeof(__pyx_k_PYTHON_OBJECT), 0, 0, 1, 1},
  {&__pyx_n_s_REFERENCE, __pyx_k_REFERENCE, sizeof(__pyx_k_REFERENCE), 0, 0, 1, 1},
  {&__pyx_kp_u_Ref_class_must_be_Reference_or_R, __pyx_k_Ref_class_must_be_Reference_or_R, sizeof(__pyx_k_Ref_class_must_be_Reference_or_R), 0, 1, 0, 0},
  {&__pyx_kp_u_S, __pyx_k_S, sizeof(__pyx_k_S), 0, 1, 0, 0},
  {&__pyx_n_s_SGN_2, __pyx_k_SGN_2, sizeof(__pyx_k_SGN_2), 0, 0, 1, 1},
  {&__pyx_n_s_SGN_NONE, __pyx_k_SGN_NONE, sizeof(__pyx_k_SGN_NONE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_B16BE, __pyx_k_STD_B16BE, sizeof(__pyx_k_STD_B16BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_B16LE, __pyx_k_STD_B16LE, sizeof(__pyx_k_STD_B16LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_B32BE, __pyx_k_STD_B32BE, sizeof(__pyx_k_STD_B32BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_B32LE, __pyx_k_STD_B32LE, sizeof(__pyx_k_STD_B32LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_B64BE, __pyx_k_STD_B64BE, sizeof(__pyx_k_STD_B64BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_B64LE, __pyx_k_STD_B64LE, sizeof(__pyx_k_STD_B64LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_B8BE, __pyx_k_STD_B8BE, sizeof(__pyx_k_STD_B8BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_B8LE, __pyx_k_STD_B8LE, sizeof(__pyx_k_STD_B8LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_I16BE, __pyx_k_STD_I16BE, sizeof(__pyx_k_STD_I16BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_I16LE, __pyx_k_STD_I16LE, sizeof(__pyx_k_STD_I16LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_I32BE, __pyx_k_STD_I32BE, sizeof(__pyx_k_STD_I32BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_I32LE, __pyx_k_STD_I32LE, sizeof(__pyx_k_STD_I32LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_I64BE, __pyx_k_STD_I64BE, sizeof(__pyx_k_STD_I64BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_I64LE, __pyx_k_STD_I64LE, sizeof(__pyx_k_STD_I64LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_I8BE, __pyx_k_STD_I8BE, sizeof(__pyx_k_STD_I8BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_I8LE, __pyx_k_STD_I8LE, sizeof(__pyx_k_STD_I8LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_REF_DSETREG, __pyx_k_STD_REF_DSETREG, sizeof(__pyx_k_STD_REF_DSETREG), 0, 0, 1, 1},
  {&__pyx_n_s_STD_REF_OBJ, __pyx_k_STD_REF_OBJ, sizeof(__pyx_k_STD_REF_OBJ), 0, 0, 1, 1},
  {&__pyx_n_s_STD_U16BE, __pyx_k_STD_U16BE, sizeof(__pyx_k_STD_U16BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_U16LE, __pyx_k_STD_U16LE, sizeof(__pyx_k_STD_U16LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_U32BE, __pyx_k_STD_U32BE, sizeof(__pyx_k_STD_U32BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_U32LE, __pyx_k_STD_U32LE, sizeof(__pyx_k_STD_U32LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_U64BE, __pyx_k_STD_U64BE, sizeof(__pyx_k_STD_U64BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_U64LE, __pyx_k_STD_U64LE, sizeof(__pyx_k_STD_U64LE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_U8BE, __pyx_k_STD_U8BE, sizeof(__pyx_k_STD_U8BE), 0, 0, 1, 1},
  {&__pyx_n_s_STD_U8LE, __pyx_k_STD_U8LE, sizeof(__pyx_k_STD_U8LE), 0, 0, 1, 1},
  {&__pyx_n_s_STRING, __pyx_k_STRING, sizeof(__pyx_k_STRING), 0, 0, 1, 1},
  {&__pyx_n_s_STR_NULLPAD, __pyx_k_STR_NULLPAD, sizeof(__pyx_k_STR_NULLPAD), 0, 0, 1, 1},
  {&__pyx_n_s_STR_NULLTERM, __pyx_k_STR_NULLTERM, sizeof(__pyx_k_STR_NULLTERM), 0, 0, 1, 1},
  {&__pyx_n_s_STR_SPACEPAD, __pyx_k_STR_SPACEPAD, sizeof(__pyx_k_STR_SPACEPAD), 0, 0, 1, 1},
  {&__pyx_n_u_S_2, __pyx_k_S_2, sizeof(__pyx_k_S_2), 0, 1, 0, 1},
  {&__pyx_n_s_TIME, __pyx_k_TIME, sizeof(__pyx_k_TIME), 0, 0, 1, 1},
  {&__pyx_kp_u_This_type_class_d_is_not_of_clas, __pyx_k_This_type_class_d_is_not_of_clas, sizeof(__pyx_k_This_type_class_d_is_not_of_clas), 0, 1, 0, 0},
  {&__pyx_n_s_TypeArrayID, __pyx_k_TypeArrayID, sizeof(__pyx_k_TypeArrayID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeAtomicID, __pyx_k_TypeAtomicID, sizeof(__pyx_k_TypeAtomicID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeBitfieldID, __pyx_k_TypeBitfieldID, sizeof(__pyx_k_TypeBitfieldID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeCompositeID, __pyx_k_TypeCompositeID, sizeof(__pyx_k_TypeCompositeID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeCompoundID, __pyx_k_TypeCompoundID, sizeof(__pyx_k_TypeCompoundID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeEnumID, __pyx_k_TypeEnumID, sizeof(__pyx_k_TypeEnumID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_n_s_TypeFloatID, __pyx_k_TypeFloatID, sizeof(__pyx_k_TypeFloatID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeID, __pyx_k_TypeID, sizeof(__pyx_k_TypeID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeIntegerID, __pyx_k_TypeIntegerID, sizeof(__pyx_k_TypeIntegerID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeOpaqueID, __pyx_k_TypeOpaqueID, sizeof(__pyx_k_TypeOpaqueID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeReferenceID, __pyx_k_TypeReferenceID, sizeof(__pyx_k_TypeReferenceID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeStringID, __pyx_k_TypeStringID, sizeof(__pyx_k_TypeStringID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeTimeID, __pyx_k_TypeTimeID, sizeof(__pyx_k_TypeTimeID), 0, 0, 1, 1},
  {&__pyx_n_s_TypeVlenID, __pyx_k_TypeVlenID, sizeof(__pyx_k_TypeVlenID), 0, 0, 1, 1},
  {&__pyx_n_s_UNIX_D32BE, __pyx_k_UNIX_D32BE, sizeof(__pyx_k_UNIX_D32BE), 0, 0, 1, 1},
  {&__pyx_n_s_UNIX_D32LE, __pyx_k_UNIX_D32LE, sizeof(__pyx_k_UNIX_D32LE), 0, 0, 1, 1},
  {&__pyx_n_s_UNIX_D64BE, __pyx_k_UNIX_D64BE, sizeof(__pyx_k_UNIX_D64BE), 0, 0, 1, 1},
  {&__pyx_n_s_UNIX_D64LE, __pyx_k_UNIX_D64LE, sizeof(__pyx_k_UNIX_D64LE), 0, 0, 1, 1},
  {&__pyx_n_s_UnicodeDecodeError, __pyx_k_UnicodeDecodeError, sizeof(__pyx_k_UnicodeDecodeError), 0, 0, 1, 1},
  {&__pyx_kp_u_Unknown_reference_type, __pyx_k_Unknown_reference_type, sizeof(__pyx_k_Unknown_reference_type), 0, 1, 0, 0},
  {&__pyx_kp_u_Unknown_special_type_s, __pyx_k_Unknown_special_type_s, sizeof(__pyx_k_Unknown_special_type_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Unknown_string_encoding_value_d, __pyx_k_Unknown_string_encoding_value_d, sizeof(__pyx_k_Unknown_string_encoding_value_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Unrecognized_reference_code, __pyx_k_Unrecognized_reference_code, sizeof(__pyx_k_Unrecognized_reference_code), 0, 1, 0, 0},
  {&__pyx_kp_u_Unsupported_float_type_s, __pyx_k_Unsupported_float_type_s, sizeof(__pyx_k_Unsupported_float_type_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Unsupported_integer_size_s, __pyx_k_Unsupported_integer_size_s, sizeof(__pyx_k_Unsupported_integer_size_s), 0, 1, 0, 0},
  {&__pyx_kp_u_V, __pyx_k_V, sizeof(__pyx_k_V), 0, 1, 0, 0},
  {&__pyx_n_s_VARIABLE, __pyx_k_VARIABLE, sizeof(__pyx_k_VARIABLE), 0, 0, 1, 1},
  {&__pyx_n_s_VLEN, __pyx_k_VLEN, sizeof(__pyx_k_VLEN), 0, 0, 1, 1},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_kp_u__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 1, 0, 0},
  {&__pyx_kp_u__39, __pyx_k__39, sizeof(__pyx_k__39), 0, 1, 0, 0},
  {&__pyx_kp_u__40, __pyx_k__40, sizeof(__pyx_k__40), 0, 1, 0, 0},
  {&__pyx_n_s_aligned, __pyx_k_aligned, sizeof(__pyx_k_aligned), 0, 0, 1, 1},
  {&__pyx_n_s_array_create, __pyx_k_array_create, sizeof(__pyx_k_array_create), 0, 0, 1, 1},
  {&__pyx_n_u_ascii, __pyx_k_ascii, sizeof(__pyx_k_ascii), 0, 1, 0, 1},
  {&__pyx_n_s_base, __pyx_k_base, sizeof(__pyx_k_base), 0, 0, 1, 1},
  {&__pyx_n_s_basetype, __pyx_k_basetype, sizeof(__pyx_k_basetype), 0, 0, 1, 1},
  {&__pyx_n_s_bkg, __pyx_k_bkg, sizeof(__pyx_k_bkg), 0, 0, 1, 1},
  {&__pyx_n_s_bkg_2, __pyx_k_bkg_2, sizeof(__pyx_k_bkg_2), 0, 0, 1, 1},
  {&__pyx_n_u_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 1, 0, 1},
  {&__pyx_n_s_buf, __pyx_k_buf, sizeof(__pyx_k_buf), 0, 0, 1, 1},
  {&__pyx_n_s_buf_2, __pyx_k_buf_2, sizeof(__pyx_k_buf_2), 0, 0, 1, 1},
  {&__pyx_n_s_byteorder, __pyx_k_byteorder, sizeof(__pyx_k_byteorder), 0, 0, 1, 1},
  {&__pyx_n_u_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 1, 0, 1},
  {&__pyx_n_s_c_compound_locals_lambda, __pyx_k_c_compound_locals_lambda, sizeof(__pyx_k_c_compound_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_cfg, __pyx_k_cfg, sizeof(__pyx_k_cfg), 0, 0, 1, 1},
  {&__pyx_n_s_check_dtype, __pyx_k_check_dtype, sizeof(__pyx_k_check_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_check_enum_dtype, __pyx_k_check_enum_dtype, sizeof(__pyx_k_check_enum_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_check_opaque_dtype, __pyx_k_check_opaque_dtype, sizeof(__pyx_k_check_opaque_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_check_ref_dtype, __pyx_k_check_ref_dtype, sizeof(__pyx_k_check_ref_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_check_string_dtype, __pyx_k_check_string_dtype, sizeof(__pyx_k_check_string_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_check_vlen_dtype, __pyx_k_check_vlen_dtype, sizeof(__pyx_k_check_vlen_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
  {&__pyx_n_s_classtype, __pyx_k_classtype, sizeof(__pyx_k_classtype), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_codecs, __pyx_k_codecs, sizeof(__pyx_k_codecs), 0, 0, 1, 1},
  {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
  {&__pyx_n_s_commit, __pyx_k_commit, sizeof(__pyx_k_commit), 0, 0, 1, 1},
  {&__pyx_n_s_committed, __pyx_k_committed, sizeof(__pyx_k_committed), 0, 0, 1, 1},
  {&__pyx_n_s_convert, __pyx_k_convert, sizeof(__pyx_k_convert), 0, 0, 1, 1},
  {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
  {&__pyx_n_s_copy_2, __pyx_k_copy_2, sizeof(__pyx_k_copy_2), 0, 0, 1, 1},
  {&__pyx_n_s_create, __pyx_k_create, sizeof(__pyx_k_create), 0, 0, 1, 1},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
  {&__pyx_n_s_descr, __pyx_k_descr, sizeof(__pyx_k_descr), 0, 0, 1, 1},
  {&__pyx_n_s_detect_class, __pyx_k_detect_class, sizeof(__pyx_k_detect_class), 0, 0, 1, 1},
  {&__pyx_n_s_dims, __pyx_k_dims, sizeof(__pyx_k_dims), 0, 0, 1, 1},
  {&__pyx_n_s_dims_tpl, __pyx_k_dims_tpl, sizeof(__pyx_k_dims_tpl), 0, 0, 1, 1},
  {&__pyx_n_s_dst, __pyx_k_dst, sizeof(__pyx_k_dst), 0, 0, 1, 1},
  {&__pyx_n_s_dt, __pyx_k_dt, sizeof(__pyx_k_dt), 0, 0, 1, 1},
  {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
  {&__pyx_kp_u_dtype_for_opaque_data_must_have, __pyx_k_dtype_for_opaque_data_must_have, sizeof(__pyx_k_dtype_for_opaque_data_must_have), 0, 1, 0, 0},
  {&__pyx_n_s_dtype_in, __pyx_k_dtype_in, sizeof(__pyx_k_dtype_in), 0, 0, 1, 1},
  {&__pyx_n_s_dxpl, __pyx_k_dxpl, sizeof(__pyx_k_dxpl), 0, 0, 1, 1},
  {&__pyx_n_s_ebias, __pyx_k_ebias, sizeof(__pyx_k_ebias), 0, 0, 1, 1},
  {&__pyx_n_s_enc, __pyx_k_enc, sizeof(__pyx_k_enc), 0, 0, 1, 1},
  {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
  {&__pyx_n_s_encoding, __pyx_k_encoding, sizeof(__pyx_k_encoding), 0, 0, 1, 1},
  {&__pyx_n_u_encoding, __pyx_k_encoding, sizeof(__pyx_k_encoding), 0, 1, 0, 1},
  {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
  {&__pyx_n_u_enum, __pyx_k_enum, sizeof(__pyx_k_enum), 0, 1, 0, 1},
  {&__pyx_n_s_enum_create, __pyx_k_enum_create, sizeof(__pyx_k_enum_create), 0, 0, 1, 1},
  {&__pyx_n_s_enum_dtype, __pyx_k_enum_dtype, sizeof(__pyx_k_enum_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_enum_insert, __pyx_k_enum_insert, sizeof(__pyx_k_enum_insert), 0, 0, 1, 1},
  {&__pyx_n_s_enum_nameof, __pyx_k_enum_nameof, sizeof(__pyx_k_enum_nameof), 0, 0, 1, 1},
  {&__pyx_n_s_enum_vals, __pyx_k_enum_vals, sizeof(__pyx_k_enum_vals), 0, 0, 1, 1},
  {&__pyx_n_s_enum_valueof, __pyx_k_enum_valueof, sizeof(__pyx_k_enum_valueof), 0, 0, 1, 1},
  {&__pyx_n_s_epos, __pyx_k_epos, sizeof(__pyx_k_epos), 0, 0, 1, 1},
  {&__pyx_n_s_equal, __pyx_k_equal, sizeof(__pyx_k_equal), 0, 0, 1, 1},
  {&__pyx_n_s_esize, __pyx_k_esize, sizeof(__pyx_k_esize), 0, 0, 1, 1},
  {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
  {&__pyx_n_u_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 1, 0, 1},
  {&__pyx_n_s_f_name, __pyx_k_f_name, sizeof(__pyx_k_f_name), 0, 0, 1, 1},
  {&__pyx_n_s_field, __pyx_k_field, sizeof(__pyx_k_field), 0, 0, 1, 1},
  {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
  {&__pyx_n_s_finfo, __pyx_k_finfo, sizeof(__pyx_k_finfo), 0, 0, 1, 1},
  {&__pyx_n_s_float_be, __pyx_k_float_be, sizeof(__pyx_k_float_be), 0, 0, 1, 1},
  {&__pyx_n_s_float_le, __pyx_k_float_le, sizeof(__pyx_k_float_le), 0, 0, 1, 1},
  {&__pyx_n_s_float_nt, __pyx_k_float_nt, sizeof(__pyx_k_float_nt), 0, 0, 1, 1},
  {&__pyx_n_u_formats, __pyx_k_formats, sizeof(__pyx_k_formats), 0, 1, 0, 1},
  {&__pyx_n_s_ftype, __pyx_k_ftype, sizeof(__pyx_k_ftype), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_get_array_dims, __pyx_k_get_array_dims, sizeof(__pyx_k_get_array_dims), 0, 0, 1, 1},
  {&__pyx_n_s_get_array_ndims, __pyx_k_get_array_ndims, sizeof(__pyx_k_get_array_ndims), 0, 0, 1, 1},
  {&__pyx_n_s_get_class, __pyx_k_get_class, sizeof(__pyx_k_get_class), 0, 0, 1, 1},
  {&__pyx_n_s_get_config, __pyx_k_get_config, sizeof(__pyx_k_get_config), 0, 0, 1, 1},
  {&__pyx_n_s_get_create_plist, __pyx_k_get_create_plist, sizeof(__pyx_k_get_create_plist), 0, 0, 1, 1},
  {&__pyx_n_s_get_cset, __pyx_k_get_cset, sizeof(__pyx_k_get_cset), 0, 0, 1, 1},
  {&__pyx_n_s_get_ebias, __pyx_k_get_ebias, sizeof(__pyx_k_get_ebias), 0, 0, 1, 1},
  {&__pyx_n_s_get_fields, __pyx_k_get_fields, sizeof(__pyx_k_get_fields), 0, 0, 1, 1},
  {&__pyx_n_s_get_float_dtype_to_hdf5, __pyx_k_get_float_dtype_to_hdf5, sizeof(__pyx_k_get_float_dtype_to_hdf5), 0, 0, 1, 1},
  {&__pyx_n_s_get_inpad, __pyx_k_get_inpad, sizeof(__pyx_k_get_inpad), 0, 0, 1, 1},
  {&__pyx_n_s_get_member_class, __pyx_k_get_member_class, sizeof(__pyx_k_get_member_class), 0, 0, 1, 1},
  {&__pyx_n_s_get_member_index, __pyx_k_get_member_index, sizeof(__pyx_k_get_member_index), 0, 0, 1, 1},
  {&__pyx_n_s_get_member_name, __pyx_k_get_member_name, sizeof(__pyx_k_get_member_name), 0, 0, 1, 1},
  {&__pyx_n_s_get_member_offset, __pyx_k_get_member_offset, sizeof(__pyx_k_get_member_offset), 0, 0, 1, 1},
  {&__pyx_n_s_get_member_type, __pyx_k_get_member_type, sizeof(__pyx_k_get_member_type), 0, 0, 1, 1},
  {&__pyx_n_s_get_member_value, __pyx_k_get_member_value, sizeof(__pyx_k_get_member_value), 0, 0, 1, 1},
  {&__pyx_n_s_get_nmembers, __pyx_k_get_nmembers, sizeof(__pyx_k_get_nmembers), 0, 0, 1, 1},
  {&__pyx_n_s_get_norm, __pyx_k_get_norm, sizeof(__pyx_k_get_norm), 0, 0, 1, 1},
  {&__pyx_n_s_get_offset, __pyx_k_get_offset, sizeof(__pyx_k_get_offset), 0, 0, 1, 1},
  {&__pyx_n_s_get_order, __pyx_k_get_order, sizeof(__pyx_k_get_order), 0, 0, 1, 1},
  {&__pyx_n_s_get_pad, __pyx_k_get_pad, sizeof(__pyx_k_get_pad), 0, 0, 1, 1},
  {&__pyx_n_s_get_precision, __pyx_k_get_precision, sizeof(__pyx_k_get_precision), 0, 0, 1, 1},
  {&__pyx_n_s_get_sign, __pyx_k_get_sign, sizeof(__pyx_k_get_sign), 0, 0, 1, 1},
  {&__pyx_n_s_get_size, __pyx_k_get_size, sizeof(__pyx_k_get_size), 0, 0, 1, 1},
  {&__pyx_n_s_get_strpad, __pyx_k_get_strpad, sizeof(__pyx_k_get_strpad), 0, 0, 1, 1},
  {&__pyx_n_s_get_super, __pyx_k_get_super, sizeof(__pyx_k_get_super), 0, 0, 1, 1},
  {&__pyx_n_s_get_tag, __pyx_k_get_tag, sizeof(__pyx_k_get_tag), 0, 0, 1, 1},
  {&__pyx_n_s_group, __pyx_k_group, sizeof(__pyx_k_group), 0, 0, 1, 1},
  {&__pyx_n_s_h5, __pyx_k_h5, sizeof(__pyx_k_h5), 0, 0, 1, 1},
  {&__pyx_n_s_h5_be_list, __pyx_k_h5_be_list, sizeof(__pyx_k_h5_be_list), 0, 0, 1, 1},
  {&__pyx_n_s_h5_le_list, __pyx_k_h5_le_list, sizeof(__pyx_k_h5_le_list), 0, 0, 1, 1},
  {&__pyx_n_u_h5py_encoding, __pyx_k_h5py_encoding, sizeof(__pyx_k_h5py_encoding), 0, 1, 0, 1},
  {&__pyx_n_s_h5py_h5t, __pyx_k_h5py_h5t, sizeof(__pyx_k_h5py_h5t), 0, 0, 1, 1},
  {&__pyx_kp_s_h5py_h5t_pyx, __pyx_k_h5py_h5t_pyx, sizeof(__pyx_k_h5py_h5t_pyx), 0, 0, 1, 0},
  {&__pyx_n_u_h5py_opaque, __pyx_k_h5py_opaque, sizeof(__pyx_k_h5py_opaque), 0, 1, 0, 1},
  {&__pyx_n_s_h5type, __pyx_k_h5type, sizeof(__pyx_k_h5type), 0, 0, 1, 1},
  {&__pyx_kp_u_has_no_native_HDF5_equivalent, __pyx_k_has_no_native_HDF5_equivalent, sizeof(__pyx_k_has_no_native_HDF5_equivalent), 0, 1, 0, 0},
  {&__pyx_n_s_hash, __pyx_k_hash, sizeof(__pyx_k_hash), 0, 0, 1, 1},
  {&__pyx_n_u_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 1, 0, 1},
  {&__pyx_n_s_i_name, __pyx_k_i_name, sizeof(__pyx_k_i_name), 0, 0, 1, 1},
  {&__pyx_n_s_iexp, __pyx_k_iexp, sizeof(__pyx_k_iexp), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_insert, __pyx_k_insert, sizeof(__pyx_k_insert), 0, 0, 1, 1},
  {&__pyx_n_s_integer, __pyx_k_integer, sizeof(__pyx_k_integer), 0, 0, 1, 1},
  {&__pyx_n_s_is_variable_str, __pyx_k_is_variable_str, sizeof(__pyx_k_is_variable_str), 0, 0, 1, 1},
  {&__pyx_n_u_isalignedstruct, __pyx_k_isalignedstruct, sizeof(__pyx_k_isalignedstruct), 0, 1, 0, 1},
  {&__pyx_n_s_issubdtype, __pyx_k_issubdtype, sizeof(__pyx_k_issubdtype), 0, 0, 1, 1},
  {&__pyx_n_s_itemsize, __pyx_k_itemsize, sizeof(__pyx_k_itemsize), 0, 0, 1, 1},
  {&__pyx_n_u_itemsize, __pyx_k_itemsize, sizeof(__pyx_k_itemsize), 0, 1, 0, 1},
  {&__pyx_n_s_iteritems, __pyx_k_iteritems, sizeof(__pyx_k_iteritems), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_kind, __pyx_k_kind, sizeof(__pyx_k_kind), 0, 0, 1, 1},
  {&__pyx_n_s_kwds, __pyx_k_kwds, sizeof(__pyx_k_kwds), 0, 0, 1, 1},
  {&__pyx_n_s_lcpl, __pyx_k_lcpl, sizeof(__pyx_k_lcpl), 0, 0, 1, 1},
  {&__pyx_n_s_length, __pyx_k_length, sizeof(__pyx_k_length), 0, 0, 1, 1},
  {&__pyx_n_u_length, __pyx_k_length, sizeof(__pyx_k_length), 0, 1, 0, 1},
  {&__pyx_kp_u_length_must_be_integer_or_None_g, __pyx_k_length_must_be_integer_or_None_g, sizeof(__pyx_k_length_must_be_integer_or_None_g), 0, 1, 0, 0},
  {&__pyx_n_u_little, __pyx_k_little, sizeof(__pyx_k_little), 0, 1, 0, 1},
  {&__pyx_n_s_lock, __pyx_k_lock, sizeof(__pyx_k_lock), 0, 0, 1, 1},
  {&__pyx_n_s_logical, __pyx_k_logical, sizeof(__pyx_k_logical), 0, 0, 1, 1},
  {&__pyx_n_s_longdouble, __pyx_k_longdouble, sizeof(__pyx_k_longdouble), 0, 0, 1, 1},
  {&__pyx_n_s_lookup, __pyx_k_lookup, sizeof(__pyx_k_lookup), 0, 0, 1, 1},
  {&__pyx_n_s_lsb, __pyx_k_lsb, sizeof(__pyx_k_lsb), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_maxexp, __pyx_k_maxexp, sizeof(__pyx_k_maxexp), 0, 0, 1, 1},
  {&__pyx_n_s_metadata, __pyx_k_metadata, sizeof(__pyx_k_metadata), 0, 0, 1, 1},
  {&__pyx_n_s_minexp, __pyx_k_minexp, sizeof(__pyx_k_minexp), 0, 0, 1, 1},
  {&__pyx_n_s_mpos, __pyx_k_mpos, sizeof(__pyx_k_mpos), 0, 0, 1, 1},
  {&__pyx_n_s_msb, __pyx_k_msb, sizeof(__pyx_k_msb), 0, 0, 1, 1},
  {&__pyx_n_s_msize, __pyx_k_msize, sizeof(__pyx_k_msize), 0, 0, 1, 1},
  {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_namedtuple, __pyx_k_namedtuple, sizeof(__pyx_k_namedtuple), 0, 0, 1, 1},
  {&__pyx_n_s_names, __pyx_k_names, sizeof(__pyx_k_names), 0, 0, 1, 1},
  {&__pyx_n_u_names, __pyx_k_names, sizeof(__pyx_k_names), 0, 1, 0, 1},
  {&__pyx_n_s_newbyteorder, __pyx_k_newbyteorder, sizeof(__pyx_k_newbyteorder), 0, 0, 1, 1},
  {&__pyx_n_s_nexp, __pyx_k_nexp, sizeof(__pyx_k_nexp), 0, 0, 1, 1},
  {&__pyx_n_s_nmant, __pyx_k_nmant, sizeof(__pyx_k_nmant), 0, 0, 1, 1},
  {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
  {&__pyx_n_s_np_dtype, __pyx_k_np_dtype, sizeof(__pyx_k_np_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
  {&__pyx_kp_u_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 1, 0, 0},
  {&__pyx_kp_u_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 1, 0, 0},
  {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
  {&__pyx_n_s_objects, __pyx_k_objects, sizeof(__pyx_k_objects), 0, 0, 1, 1},
  {&__pyx_n_s_offset, __pyx_k_offset, sizeof(__pyx_k_offset), 0, 0, 1, 1},
  {&__pyx_n_u_offsets, __pyx_k_offsets, sizeof(__pyx_k_offsets), 0, 1, 0, 1},
  {&__pyx_n_s_opaque_dtype, __pyx_k_opaque_dtype, sizeof(__pyx_k_opaque_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
  {&__pyx_n_s_pack, __pyx_k_pack, sizeof(__pyx_k_pack), 0, 0, 1, 1},
  {&__pyx_n_s_phil, __pyx_k_phil, sizeof(__pyx_k_phil), 0, 0, 1, 1},
  {&__pyx_n_s_popitem, __pyx_k_popitem, sizeof(__pyx_k_popitem), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_capi, __pyx_k_pyx_capi, sizeof(__pyx_k_pyx_capi), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_r_name, __pyx_k_r_name, sizeof(__pyx_k_r_name), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_rank, __pyx_k_rank, sizeof(__pyx_k_rank), 0, 0, 1, 1},
  {&__pyx_n_u_ref, __pyx_k_ref, sizeof(__pyx_k_ref), 0, 1, 0, 1},
  {&__pyx_n_s_ref_dtype, __pyx_k_ref_dtype, sizeof(__pyx_k_ref_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_regionref_dtype, __pyx_k_regionref_dtype, sizeof(__pyx_k_regionref_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
  {&__pyx_n_s_set_cset, __pyx_k_set_cset, sizeof(__pyx_k_set_cset), 0, 0, 1, 1},
  {&__pyx_n_s_set_ebias, __pyx_k_set_ebias, sizeof(__pyx_k_set_ebias), 0, 0, 1, 1},
  {&__pyx_n_s_set_fields, __pyx_k_set_fields, sizeof(__pyx_k_set_fields), 0, 0, 1, 1},
  {&__pyx_n_s_set_inpad, __pyx_k_set_inpad, sizeof(__pyx_k_set_inpad), 0, 0, 1, 1},
  {&__pyx_n_s_set_norm, __pyx_k_set_norm, sizeof(__pyx_k_set_norm), 0, 0, 1, 1},
  {&__pyx_n_s_set_offset, __pyx_k_set_offset, sizeof(__pyx_k_set_offset), 0, 0, 1, 1},
  {&__pyx_n_s_set_order, __pyx_k_set_order, sizeof(__pyx_k_set_order), 0, 0, 1, 1},
  {&__pyx_n_s_set_pad, __pyx_k_set_pad, sizeof(__pyx_k_set_pad), 0, 0, 1, 1},
  {&__pyx_n_s_set_precision, __pyx_k_set_precision, sizeof(__pyx_k_set_precision), 0, 0, 1, 1},
  {&__pyx_n_s_set_sign, __pyx_k_set_sign, sizeof(__pyx_k_set_sign), 0, 0, 1, 1},
  {&__pyx_n_s_set_size, __pyx_k_set_size, sizeof(__pyx_k_set_size), 0, 0, 1, 1},
  {&__pyx_n_s_set_strpad, __pyx_k_set_strpad, sizeof(__pyx_k_set_strpad), 0, 0, 1, 1},
  {&__pyx_n_s_set_tag, __pyx_k_set_tag, sizeof(__pyx_k_set_tag), 0, 0, 1, 1},
  {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
  {&__pyx_n_s_sorted, __pyx_k_sorted, sizeof(__pyx_k_sorted), 0, 0, 1, 1},
  {&__pyx_n_s_special_dtype, __pyx_k_special_dtype, sizeof(__pyx_k_special_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_spos, __pyx_k_spos, sizeof(__pyx_k_spos), 0, 0, 1, 1},
  {&__pyx_n_s_src, __pyx_k_src, sizeof(__pyx_k_src), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_n_s_string_dtype, __pyx_k_string_dtype, sizeof(__pyx_k_string_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_string_info, __pyx_k_string_info, sizeof(__pyx_k_string_info), 0, 0, 1, 1},
  {&__pyx_n_u_string_info, __pyx_k_string_info, sizeof(__pyx_k_string_info), 0, 1, 0, 1},
  {&__pyx_n_s_subdtype, __pyx_k_subdtype, sizeof(__pyx_k_subdtype), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_t_name, __pyx_k_t_name, sizeof(__pyx_k_t_name), 0, 0, 1, 1},
  {&__pyx_n_s_tapl, __pyx_k_tapl, sizeof(__pyx_k_tapl), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
  {&__pyx_n_s_typecodes, __pyx_k_typecodes, sizeof(__pyx_k_typecodes), 0, 0, 1, 1},
  {&__pyx_n_u_u, __pyx_k_u, sizeof(__pyx_k_u), 0, 1, 0, 1},
  {&__pyx_n_s_uint8, __pyx_k_uint8, sizeof(__pyx_k_uint8), 0, 0, 1, 1},
  {&__pyx_n_u_utf8, __pyx_k_utf8, sizeof(__pyx_k_utf8), 0, 1, 0, 1},
  {&__pyx_kp_u_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 1, 0, 0},
  {&__pyx_n_s_val, __pyx_k_val, sizeof(__pyx_k_val), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_values_dict, __pyx_k_values_dict, sizeof(__pyx_k_values_dict), 0, 0, 1, 1},
  {&__pyx_n_s_vlen, __pyx_k_vlen, sizeof(__pyx_k_vlen), 0, 0, 1, 1},
  {&__pyx_n_u_vlen, __pyx_k_vlen, sizeof(__pyx_k_vlen), 0, 1, 0, 1},
  {&__pyx_n_s_vlen_create, __pyx_k_vlen_create, sizeof(__pyx_k_vlen_create), 0, 0, 1, 1},
  {&__pyx_n_s_vlen_dtype, __pyx_k_vlen_dtype, sizeof(__pyx_k_vlen_dtype), 0, 0, 1, 1},
  {&__pyx_n_s_vlen_kind, __pyx_k_vlen_kind, sizeof(__pyx_k_vlen_kind), 0, 0, 1, 1},
  {&__pyx_n_s_with_phil, __pyx_k_with_phil, sizeof(__pyx_k_with_phil), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 315, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 400, __pyx_L1_error)
  __pyx_builtin_NotImplemented = __Pyx_GetBuiltinName(__pyx_n_s_NotImplemented); if (!__pyx_builtin_NotImplemented) __PYX_ERR(0, 414, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 1214, __pyx_L1_error)
  __pyx_builtin_UnicodeDecodeError = __Pyx_GetBuiltinName(__pyx_n_s_UnicodeDecodeError); if (!__pyx_builtin_UnicodeDecodeError) __PYX_ERR(0, 1365, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 1432, __pyx_L1_error)
  __pyx_builtin_sorted = __Pyx_GetBuiltinName(__pyx_n_s_sorted); if (!__pyx_builtin_sorted) __PYX_ERR(0, 1613, __pyx_L1_error)
  __pyx_builtin_LookupError = __Pyx_GetBuiltinName(__pyx_n_s_LookupError); if (!__pyx_builtin_LookupError) __PYX_ERR(0, 1780, __pyx_L1_error)
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(0, 1884, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(1, 944, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "h5py/h5t.pyx":315
 *     # HDF5 versions 1.6.X segfault with anything else
 *     if classtype != H5T_COMPOUND and classtype != H5T_OPAQUE:
 *         raise ValueError("Class must be COMPOUND or OPAQUE.")             # <<<<<<<<<<<<<<
 * 
 *     return typewrap(H5Tcreate(<H5T_class_t>classtype, size))
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_u_Class_must_be_COMPOUND_or_OPAQUE); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "h5py/h5t.pyx":405
 *                         self._hash = hash(self.encode())
 *                     else:
 *                         raise TypeError("Only locked or committed types can be hashed")             # <<<<<<<<<<<<<<
 * 
 *             return self._hash
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_u_Only_locked_or_committed_types_c); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(0, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "h5py/h5t.pyx":395
 * 
 *     def __hash__(self):
 *         with phil:             # <<<<<<<<<<<<<<
 *             if self._hash is None:
 *                 try:
 */
  __pyx_tuple__3 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "h5py/h5t.pyx":571
 *     def __reduce__(self):
 *         with phil:
 *             return (type(self), (-1,), self.encode())             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_int_neg_1); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "h5py/h5t.pyx":815
 *             return regionref_dtype
 *         else:
 *             raise TypeError("Unknown reference type")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_u_Unknown_reference_type); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "h5py/h5t.pyx":1114
 * 
 *         if member < 0:
 *             raise ValueError("Member index must be non-negative.")             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_u_Member_index_must_be_non_negativ); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 1114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "h5py/h5t.pyx":1229
 * 
 *             bstring = field_types[0].str
 *             blen = int(bstring[2:])             # <<<<<<<<<<<<<<
 *             nstring = bstring[0] + "c" + str(2*blen)
 *             typeobj = np.dtype(nstring)
 */
  __pyx_slice__7 = PySlice_New(__pyx_int_2, Py_None, Py_None); if (unlikely(!__pyx_slice__7)) __PYX_ERR(0, 1229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__7);
  __Pyx_GIVEREF(__pyx_slice__7);

  /* "h5py/h5t.pyx":1335
 * 
 *         if idx < 0:
 *             raise ValueError("Index must be non-negative.")             # <<<<<<<<<<<<<<
 * 
 *         H5Tget_member_value(self.id, idx, &val)
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_u_Index_must_be_non_negative); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "h5py/h5t.pyx":1509
 *             shape = (int(shape),)
 *         except TypeError:
 *             raise TypeError("Array shape for dtype must be a sequence or integer")             # <<<<<<<<<<<<<<
 *     type_base = py_create(base, logical=logical)
 *     return array_create(type_base, shape)
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_Array_shape_for_dtype_must_be_a); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 1509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "h5py/h5t.pyx":1623
 *         if aligned and (member_offset > field[1]
 *                         or member_dt.itemsize != member_type.get_size()):
 *             raise TypeError("Enforced alignment not compatible with HDF5 type")             # <<<<<<<<<<<<<<
 *         fields[name] = (h5_name, member_offset, member_type)
 * 
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_Enforced_alignment_not_compatibl); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "h5py/h5t.pyx":1660
 *     elif refclass is RegionReference:
 *         return STD_REF_DSETREG
 *     raise TypeError("Unrecognized reference code")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_Unrecognized_reference_code); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 1660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "h5py/h5t.pyx":1760
 *     For variable-length string dtypes, use :func:`string_dtype` instead.
 *     """
 *     return np.dtype('O', metadata={'vlen': basetype})             # <<<<<<<<<<<<<<
 * 
 * def string_dtype(encoding='utf-8', length=None):
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_n_u_O); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 1760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "h5py/h5t.pyx":1804
 *     dt = np.dtype(basetype)
 *     if not np.issubdtype(dt, np.integer):
 *         raise TypeError("Only integer types can be used as enums")             # <<<<<<<<<<<<<<
 * 
 *     return np.dtype(dt, metadata={'enum': values_dict})
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_u_Only_integer_types_can_be_used_a); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 1804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "h5py/h5t.pyx":1818
 *     dt = np.dtype(np_dtype)
 *     if np.issubdtype(dt, np.object_):
 *         raise TypeError("Cannot store numpy object arrays as opaque data")             # <<<<<<<<<<<<<<
 *     if dt.names is not None:
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_u_Cannot_store_numpy_object_arrays); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "h5py/h5t.pyx":1820
 *         raise TypeError("Cannot store numpy object arrays as opaque data")
 *     if dt.names is not None:
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")             # <<<<<<<<<<<<<<
 *     if dt.subdtype is not None:
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_u_Cannot_store_numpy_structured_ar); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "h5py/h5t.pyx":1822
 *         raise TypeError("Cannot store numpy structured arrays as opaque data")
 *     if dt.subdtype is not None:
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")             # <<<<<<<<<<<<<<
 *     if dt.itemsize == 0:
 *         raise TypeError("dtype for opaque data must have explicit size")
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_Cannot_store_numpy_sub_array_dty); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 1822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "h5py/h5t.pyx":1824
 *         raise TypeError("Cannot store numpy sub-array dtype as opaque data")
 *     if dt.itemsize == 0:
 *         raise TypeError("dtype for opaque data must have explicit size")             # <<<<<<<<<<<<<<
 * 
 *     return np.dtype(dt, metadata={'h5py_opaque': True})
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_u_dtype_for_opaque_data_must_have); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 1824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "h5py/h5t.pyx":1855
 * 
 *     if len(kwds) != 1:
 *         raise TypeError("Exactly one keyword may be provided")             # <<<<<<<<<<<<<<
 * 
 *     name, val = kwds.popitem()
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_kp_u_Exactly_one_keyword_may_be_provi); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 1855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "h5py/h5t.pyx":1866
 *             dt, enum_vals = val
 *         except TypeError:
 *             raise TypeError("Enums must be created from a 2-tuple (basetype, values_dict)")             # <<<<<<<<<<<<<<
 *         return enum_dtype(enum_vals, dt)
 * 
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_u_Enums_must_be_created_from_a_2_t); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 1866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "h5py/h5t.pyx":1871
 *     if name == 'ref':
 *         if val not in (Reference, RegionReference):
 *             raise ValueError("Ref class must be Reference or RegionReference")             # <<<<<<<<<<<<<<
 *         return ref_dtype if (val is Reference) else regionref_dtype
 * 
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_kp_u_Ref_class_must_be_Reference_or_R); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 1871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "h5py/h5t.pyx":1883
 *     """
 *     try:
 *         return dt.metadata.get('vlen', None)             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return None
 */
  __pyx_tuple__22 = PyTuple_Pack(2, __pyx_n_u_vlen, Py_None); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 1883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "h5py/h5t.pyx":1900
 *     vlen_kind = check_vlen_dtype(dt)
 *     if vlen_kind is unicode:
 *         return string_info('utf-8', None)             # <<<<<<<<<<<<<<
 *     elif vlen_kind is bytes:
 *         return string_info('ascii', None)
 */
  __pyx_tuple__23 = PyTuple_Pack(2, __pyx_kp_u_utf_8, Py_None); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 1900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "h5py/h5t.pyx":1902
 *         return string_info('utf-8', None)
 *     elif vlen_kind is bytes:
 *         return string_info('ascii', None)             # <<<<<<<<<<<<<<
 *     elif dt.kind == 'S':
 *         enc = (dt.metadata or {}).get('h5py_encoding', 'ascii')
 */
  __pyx_tuple__24 = PyTuple_Pack(2, __pyx_n_u_ascii, Py_None); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 1902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "h5py/h5t.pyx":1904
 *         return string_info('ascii', None)
 *     elif dt.kind == 'S':
 *         enc = (dt.metadata or {}).get('h5py_encoding', 'ascii')             # <<<<<<<<<<<<<<
 *         return string_info(enc, dt.itemsize)
 *     else:
 */
  __pyx_tuple__25 = PyTuple_Pack(2, __pyx_n_u_h5py_encoding, __pyx_n_u_ascii); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 1904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "h5py/h5t.pyx":1916
 *     """
 *     try:
 *         return dt.metadata.get('enum', None)             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return None
 */
  __pyx_tuple__26 = PyTuple_Pack(2, __pyx_n_u_enum, Py_None); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 1916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "h5py/h5t.pyx":1924
 *     """
 *     try:
 *         return dt.metadata.get('h5py_opaque', False)             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return False
 */
  __pyx_tuple__27 = PyTuple_Pack(2, __pyx_n_u_h5py_opaque, Py_False); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "h5py/h5t.pyx":1935
 *     """
 *     try:
 *         return dt.metadata.get('ref', None)             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return None
 */
  __pyx_tuple__28 = PyTuple_Pack(2, __pyx_n_u_ref, Py_None); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 1935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":944
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__29 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(1, 944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":950
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__30 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(1, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "h5py/h5t.pyx":222
 * # Mini (or short) floats
 * IEEE_F16BE = IEEE_F32BE.copy()
 * IEEE_F16BE.set_fields(15, 10, 5, 0, 10)             # <<<<<<<<<<<<<<
 * IEEE_F16BE.set_size(2)
 * IEEE_F16BE.set_ebias(15)
 */
  __pyx_tuple__31 = PyTuple_Pack(5, __pyx_int_15, __pyx_int_10, __pyx_int_5, __pyx_int_0, __pyx_int_10); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "h5py/h5t.pyx":223
 * IEEE_F16BE = IEEE_F32BE.copy()
 * IEEE_F16BE.set_fields(15, 10, 5, 0, 10)
 * IEEE_F16BE.set_size(2)             # <<<<<<<<<<<<<<
 * IEEE_F16BE.set_ebias(15)
 * IEEE_F16BE.lock()
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_int_2); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "h5py/h5t.pyx":224
 * IEEE_F16BE.set_fields(15, 10, 5, 0, 10)
 * IEEE_F16BE.set_size(2)
 * IEEE_F16BE.set_ebias(15)             # <<<<<<<<<<<<<<
 * IEEE_F16BE.lock()
 * 
 */
  __pyx_tuple__33 = PyTuple_Pack(1, __pyx_int_15); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "h5py/h5t.pyx":233
 * # Quad floats
 * IEEE_F128BE = IEEE_F64BE.copy()
 * IEEE_F128BE.set_size(16)             # <<<<<<<<<<<<<<
 * IEEE_F128BE.set_precision(128)
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)
 */
  __pyx_tuple__34 = PyTuple_Pack(1, __pyx_int_16); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "h5py/h5t.pyx":234
 * IEEE_F128BE = IEEE_F64BE.copy()
 * IEEE_F128BE.set_size(16)
 * IEEE_F128BE.set_precision(128)             # <<<<<<<<<<<<<<
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)
 * IEEE_F128BE.set_ebias(16383)
 */
  __pyx_tuple__35 = PyTuple_Pack(1, __pyx_int_128); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "h5py/h5t.pyx":235
 * IEEE_F128BE.set_size(16)
 * IEEE_F128BE.set_precision(128)
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)             # <<<<<<<<<<<<<<
 * IEEE_F128BE.set_ebias(16383)
 * IEEE_F128BE.lock()
 */
  __pyx_tuple__36 = PyTuple_Pack(5, __pyx_int_127, __pyx_int_112, __pyx_int_15, __pyx_int_0, __pyx_int_112); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "h5py/h5t.pyx":236
 * IEEE_F128BE.set_precision(128)
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)
 * IEEE_F128BE.set_ebias(16383)             # <<<<<<<<<<<<<<
 * IEEE_F128BE.lock()
 * 
 */
  __pyx_tuple__37 = PyTuple_Pack(1, __pyx_int_16383); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "h5py/h5t.pyx":306
 * 
 * @with_phil
 * def create(int classtype, size_t size):             # <<<<<<<<<<<<<<
 *     """(INT classtype, UINT size) => TypeID
 * 
 */
  __pyx_tuple__41 = PyTuple_Pack(2, __pyx_n_s_classtype, __pyx_n_s_size); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);
  __pyx_codeobj__42 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__41, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_create, 306, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__42)) __PYX_ERR(0, 306, __pyx_L1_error)

  /* "h5py/h5t.pyx":321
 * 
 * @with_phil
 * def open(ObjectID group not None, char* name, ObjectID tapl=None):             # <<<<<<<<<<<<<<
 *     """(ObjectID group, STRING name) => TypeID
 * 
 */
  __pyx_tuple__43 = PyTuple_Pack(3, __pyx_n_s_group, __pyx_n_s_name, __pyx_n_s_tapl); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);
  __pyx_codeobj__44 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__43, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_open, 321, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__44)) __PYX_ERR(0, 321, __pyx_L1_error)

  /* "h5py/h5t.pyx":331
 * 
 * @with_phil
 * def array_create(TypeID base not None, object dims_tpl):             # <<<<<<<<<<<<<<
 *     """(TypeID base, TUPLE dimensions) => TypeArrayID
 * 
 */
  __pyx_tuple__45 = PyTuple_Pack(4, __pyx_n_s_base, __pyx_n_s_dims_tpl, __pyx_n_s_rank, __pyx_n_s_dims); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);
  __pyx_codeobj__46 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__45, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_array_create, 331, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__46)) __PYX_ERR(0, 331, __pyx_L1_error)

  /* "h5py/h5t.pyx":353
 * 
 * @with_phil
 * def enum_create(TypeID base not None):             # <<<<<<<<<<<<<<
 *     """(TypeID base) => TypeID
 * 
 */
  __pyx_tuple__47 = PyTuple_Pack(1, __pyx_n_s_base); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);
  __pyx_codeobj__48 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_enum_create, 353, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__48)) __PYX_ERR(0, 353, __pyx_L1_error)

  /* "h5py/h5t.pyx":362
 * 
 * @with_phil
 * def vlen_create(TypeID base not None):             # <<<<<<<<<<<<<<
 *     """(TypeID base) => TypeID
 * 
 */
  __pyx_tuple__49 = PyTuple_Pack(1, __pyx_n_s_base); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);
  __pyx_codeobj__50 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__49, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_vlen_create, 362, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__50)) __PYX_ERR(0, 362, __pyx_L1_error)

  /* "h5py/h5t.pyx":374
 * 
 * @with_phil
 * def decode(char* buf):             # <<<<<<<<<<<<<<
 *     """(STRING buf) => TypeID
 * 
 */
  __pyx_tuple__51 = PyTuple_Pack(2, __pyx_n_s_buf, __pyx_n_s_buf); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);
  __pyx_codeobj__52 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__51, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_decode, 374, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__52)) __PYX_ERR(0, 374, __pyx_L1_error)

  /* "h5py/h5t.pyx":1380
 * # transient and unlocked.
 * 
 * def _get_float_dtype_to_hdf5():             # <<<<<<<<<<<<<<
 *     float_le = {}
 *     float_be = {}
 */
  __pyx_tuple__53 = PyTuple_Pack(18, __pyx_n_s_float_le, __pyx_n_s_float_be, __pyx_n_s_h5_be_list, __pyx_n_s_h5_le_list, __pyx_n_s_ftype, __pyx_n_s_finfo, __pyx_n_s_size, __pyx_n_s_nmant, __pyx_n_s_maxexp, __pyx_n_s_minexp, __pyx_n_s_h5type, __pyx_n_s_spos, __pyx_n_s_epos, __pyx_n_s_esize, __pyx_n_s_mpos, __pyx_n_s_msize, __pyx_n_s_ebias, __pyx_n_s_float_nt); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 1380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);
  __pyx_codeobj__54 = (PyObject*)__Pyx_PyCode_New(0, 0, 18, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__53, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_get_float_dtype_to_hdf5, 1380, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__54)) __PYX_ERR(0, 1380, __pyx_L1_error)

  /* "h5py/h5t.pyx":1755
 *             raise TypeError("No conversion path for dtype: %s" % repr(dt))
 * 
 * def vlen_dtype(basetype):             # <<<<<<<<<<<<<<
 *     """Make a numpy dtype for an HDF5 variable-length datatype
 * 
 */
  __pyx_tuple__55 = PyTuple_Pack(1, __pyx_n_s_basetype); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);
  __pyx_codeobj__56 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__55, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_vlen_dtype, 1755, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__56)) __PYX_ERR(0, 1755, __pyx_L1_error)

  /* "h5py/h5t.pyx":1762
 *     return np.dtype('O', metadata={'vlen': basetype})
 * 
 * def string_dtype(encoding='utf-8', length=None):             # <<<<<<<<<<<<<<
 *     """Make a numpy dtype for HDF5 strings
 * 
 */
  __pyx_tuple__57 = PyTuple_Pack(3, __pyx_n_s_encoding, __pyx_n_s_length, __pyx_n_s_vlen); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);
  __pyx_codeobj__58 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__57, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_string_dtype, 1762, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__58)) __PYX_ERR(0, 1762, __pyx_L1_error)

  /* "h5py/h5t.pyx":1796
 *         raise TypeError("length must be integer or None (got %r)" % length)
 * 
 * def enum_dtype(values_dict, basetype=np.uint8):             # <<<<<<<<<<<<<<
 *     """Create a NumPy representation of an HDF5 enumerated type
 * 
 */
  __pyx_tuple__59 = PyTuple_Pack(3, __pyx_n_s_values_dict, __pyx_n_s_basetype, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);
  __pyx_codeobj__60 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__59, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_enum_dtype, 1796, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__60)) __PYX_ERR(0, 1796, __pyx_L1_error)

  /* "h5py/h5t.pyx":1809
 * 
 * 
 * def opaque_dtype(np_dtype):             # <<<<<<<<<<<<<<
 *     """Return an equivalent dtype tagged to be stored in an HDF5 opaque type.
 * 
 */
  __pyx_tuple__61 = PyTuple_Pack(2, __pyx_n_s_np_dtype, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 1809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);
  __pyx_codeobj__62 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__61, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_opaque_dtype, 1809, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__62)) __PYX_ERR(0, 1809, __pyx_L1_error)

  /* "h5py/h5t.pyx":1834
 * 
 * @with_phil
 * def special_dtype(**kwds):             # <<<<<<<<<<<<<<
 *     """ Create a new h5py "special" type.  Only one keyword may be given.
 * 
 */
  __pyx_tuple__63 = PyTuple_Pack(5, __pyx_n_s_kwds, __pyx_n_s_name, __pyx_n_s_val, __pyx_n_s_dt, __pyx_n_s_enum_vals); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 1834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);
  __pyx_codeobj__64 = (PyObject*)__Pyx_PyCode_New(0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__63, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_special_dtype, 1834, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__64)) __PYX_ERR(0, 1834, __pyx_L1_error)

  /* "h5py/h5t.pyx":1877
 * 
 * 
 * def check_vlen_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 vlen, returns the Python base class.
 * 
 */
  __pyx_tuple__65 = PyTuple_Pack(1, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 1877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__65, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_check_vlen_dtype, 1877, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(0, 1877, __pyx_L1_error)

  /* "h5py/h5t.pyx":1889
 * string_info = namedtuple('string_info', ['encoding', 'length'])
 * 
 * def check_string_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 string, returns a string_info object.
 * 
 */
  __pyx_tuple__67 = PyTuple_Pack(3, __pyx_n_s_dt, __pyx_n_s_vlen_kind, __pyx_n_s_enc); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 1889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__67, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_check_string_dtype, 1889, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(0, 1889, __pyx_L1_error)

  /* "h5py/h5t.pyx":1909
 *         return None
 * 
 * def check_enum_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 enumerated type, returns the dictionary
 *     mapping string names to integer values.
 */
  __pyx_tuple__69 = PyTuple_Pack(1, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 1909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__69, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_check_enum_dtype, 1909, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(0, 1909, __pyx_L1_error)

  /* "h5py/h5t.pyx":1920
 *         return None
 * 
 * def check_opaque_dtype(dt):             # <<<<<<<<<<<<<<
 *     """Return True if the dtype given is tagged to be stored as HDF5 opaque data
 *     """
 */
  __pyx_tuple__71 = PyTuple_Pack(1, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 1920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__71, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_check_opaque_dtype, 1920, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(0, 1920, __pyx_L1_error)

  /* "h5py/h5t.pyx":1928
 *         return False
 * 
 * def check_ref_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 reference type, returns the reference
 *     class (either Reference or RegionReference).
 */
  __pyx_tuple__73 = PyTuple_Pack(1, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);
  __pyx_codeobj__74 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__73, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_check_ref_dtype, 1928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__74)) __PYX_ERR(0, 1928, __pyx_L1_error)

  /* "h5py/h5t.pyx":1940
 * 
 * @with_phil
 * def check_dtype(**kwds):             # <<<<<<<<<<<<<<
 *     """ Check a dtype for h5py special type "hint" information.  Only one
 *     keyword may be given.
 */
  __pyx_tuple__75 = PyTuple_Pack(3, __pyx_n_s_kwds, __pyx_n_s_name, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 1940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);
  __pyx_codeobj__76 = (PyObject*)__Pyx_PyCode_New(0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__75, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_check_dtype, 1940, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__76)) __PYX_ERR(0, 1940, __pyx_L1_error)

  /* "h5py/h5t.pyx":1977
 * 
 * @with_phil
 * def convert(TypeID src not None, TypeID dst not None, size_t n,             # <<<<<<<<<<<<<<
 *             cnp.ndarray buf not None, cnp.ndarray bkg=None, ObjectID dxpl=None):
 *     """ (TypeID src, TypeID dst, UINT n, NDARRAY buf, NDARRAY bkg=None,
 */
  __pyx_tuple__77 = PyTuple_Pack(8, __pyx_n_s_src, __pyx_n_s_dst, __pyx_n_s_n, __pyx_n_s_buf, __pyx_n_s_bkg, __pyx_n_s_dxpl, __pyx_n_s_bkg_2, __pyx_n_s_buf_2); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);
  __pyx_codeobj__78 = (PyObject*)__Pyx_PyCode_New(6, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_convert, 1977, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__78)) __PYX_ERR(0, 1977, __pyx_L1_error)

  /* "h5py/h5t.pyx":2001
 * 
 * @with_phil
 * def find(TypeID src not None, TypeID dst not None):             # <<<<<<<<<<<<<<
 *     """ (TypeID src, TypeID dst) => TUPLE or None
 * 
 */
  __pyx_tuple__79 = PyTuple_Pack(4, __pyx_n_s_src, __pyx_n_s_dst, __pyx_n_s_data, __pyx_n_s_result); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);
  __pyx_codeobj__80 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__79, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_h5py_h5t_pyx, __pyx_n_s_find, 2001, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__80)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyDict_Type_popitem.type = (PyObject*)&PyDict_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_16 = PyInt_FromLong(16); if (unlikely(!__pyx_int_16)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_52 = PyInt_FromLong(52); if (unlikely(!__pyx_int_52)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_63 = PyInt_FromLong(63); if (unlikely(!__pyx_int_63)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_112 = PyInt_FromLong(112); if (unlikely(!__pyx_int_112)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_116 = PyInt_FromLong(116); if (unlikely(!__pyx_int_116)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_127 = PyInt_FromLong(127); if (unlikely(!__pyx_int_127)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1024 = PyInt_FromLong(1024); if (unlikely(!__pyx_int_1024)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_16383 = PyInt_FromLong(16383L); if (unlikely(!__pyx_int_16383)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1022 = PyInt_FromLong(-1022); if (unlikely(!__pyx_int_neg_1022)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_4h5py_3h5t__order_map = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__sign_map = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__available_ftypes = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__float_le = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__float_be = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__float_nt = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__int_le = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__int_be = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__int_nt = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__uint_le = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__uint_be = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4h5py_3h5t__uint_nt = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  if (__Pyx_ExportVoidPtr(__pyx_n_s_H5PY_OBJ, (void *)&__pyx_v_4h5py_3h5t_H5PY_OBJ, "hid_t") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportVoidPtr(__pyx_n_s_H5PY_PYTHON_OPAQUE_TAG, (void *)&__pyx_v_4h5py_3h5t_H5PY_PYTHON_OPAQUE_TAG, "char *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("typewrap", (void (*)(void))__pyx_f_4h5py_3h5t_typewrap, "struct __pyx_obj_4h5py_3h5t_TypeID *(hid_t, int __pyx_skip_dispatch)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("py_create", (void (*)(void))__pyx_f_4h5py_3h5t_py_create, "struct __pyx_obj_4h5py_3h5t_TypeID *(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_4h5py_3h5t_py_create *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_t_1 = PyImport_ImportModule("h5py._objects"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_4h5py_8_objects_ObjectID = __Pyx_ImportType(__pyx_t_1, "h5py._objects", "ObjectID", sizeof(struct __pyx_obj_4h5py_8_objects_ObjectID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_8_objects_ObjectID) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_4h5py_3h5t_TypeID = &__pyx_vtable_4h5py_3h5t_TypeID;
  __pyx_vtable_4h5py_3h5t_TypeID.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_6TypeID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeID.tp_base = __pyx_ptype_4h5py_8_objects_ObjectID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeID) < 0) __PYX_ERR(0, 385, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeID) < 0) __PYX_ERR(0, 385, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeID) < 0) __PYX_ERR(0, 385, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeID, __pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeID = &__pyx_type_4h5py_3h5t_TypeID;
  __pyx_vtabptr_4h5py_3h5t_TypeArrayID = &__pyx_vtable_4h5py_3h5t_TypeArrayID;
  __pyx_vtable_4h5py_3h5t_TypeArrayID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_vtable_4h5py_3h5t_TypeArrayID.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_11TypeArrayID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeArrayID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeArrayID) < 0) __PYX_ERR(0, 581, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeArrayID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeArrayID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeArrayID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeArrayID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeArrayID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeArrayID) < 0) __PYX_ERR(0, 581, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeArrayID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeArrayID) < 0) __PYX_ERR(0, 581, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeArrayID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeArrayID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeArrayID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeArrayID = &__pyx_type_4h5py_3h5t_TypeArrayID;
  __pyx_vtabptr_4h5py_3h5t_TypeOpaqueID = &__pyx_vtable_4h5py_3h5t_TypeOpaqueID;
  __pyx_vtable_4h5py_3h5t_TypeOpaqueID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_vtable_4h5py_3h5t_TypeOpaqueID.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_12TypeOpaqueID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeOpaqueID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeOpaqueID) < 0) __PYX_ERR(0, 626, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeOpaqueID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeOpaqueID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeOpaqueID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeOpaqueID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeOpaqueID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeOpaqueID) < 0) __PYX_ERR(0, 626, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeOpaqueID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeOpaqueID) < 0) __PYX_ERR(0, 626, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeOpaqueID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeOpaqueID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeOpaqueID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeOpaqueID = &__pyx_type_4h5py_3h5t_TypeOpaqueID;
  __pyx_vtabptr_4h5py_3h5t_TypeStringID = &__pyx_vtable_4h5py_3h5t_TypeStringID;
  __pyx_vtable_4h5py_3h5t_TypeStringID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_vtable_4h5py_3h5t_TypeStringID.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_12TypeStringID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeStringID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeStringID) < 0) __PYX_ERR(0, 672, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeStringID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeStringID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeStringID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeStringID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeStringID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeStringID) < 0) __PYX_ERR(0, 672, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeStringID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeStringID) < 0) __PYX_ERR(0, 672, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeStringID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeStringID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeStringID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeStringID = &__pyx_type_4h5py_3h5t_TypeStringID;
  __pyx_vtabptr_4h5py_3h5t_TypeVlenID = &__pyx_vtable_4h5py_3h5t_TypeVlenID;
  __pyx_vtable_4h5py_3h5t_TypeVlenID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_vtable_4h5py_3h5t_TypeVlenID.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_10TypeVlenID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeVlenID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeVlenID) < 0) __PYX_ERR(0, 758, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeVlenID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeVlenID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeVlenID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeVlenID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeVlenID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeVlenID) < 0) __PYX_ERR(0, 758, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeVlenID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeVlenID) < 0) __PYX_ERR(0, 758, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeVlenID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeVlenID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeVlenID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeVlenID = &__pyx_type_4h5py_3h5t_TypeVlenID;
  __pyx_vtabptr_4h5py_3h5t_TypeTimeID = &__pyx_vtable_4h5py_3h5t_TypeTimeID;
  __pyx_vtable_4h5py_3h5t_TypeTimeID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_type_4h5py_3h5t_TypeTimeID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeTimeID) < 0) __PYX_ERR(0, 772, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeTimeID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeTimeID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeTimeID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeTimeID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeTimeID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeTimeID) < 0) __PYX_ERR(0, 772, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeTimeID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeTimeID) < 0) __PYX_ERR(0, 772, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeTimeID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeTimeID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeTimeID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeTimeID = &__pyx_type_4h5py_3h5t_TypeTimeID;
  __pyx_vtabptr_4h5py_3h5t_TypeBitfieldID = &__pyx_vtable_4h5py_3h5t_TypeBitfieldID;
  __pyx_vtable_4h5py_3h5t_TypeBitfieldID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_vtable_4h5py_3h5t_TypeBitfieldID.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_14TypeBitfieldID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeBitfieldID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeBitfieldID) < 0) __PYX_ERR(0, 779, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeBitfieldID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeBitfieldID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeBitfieldID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeBitfieldID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeBitfieldID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeBitfieldID) < 0) __PYX_ERR(0, 779, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeBitfieldID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeBitfieldID) < 0) __PYX_ERR(0, 779, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeBitfieldID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeBitfieldID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeBitfieldID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeBitfieldID = &__pyx_type_4h5py_3h5t_TypeBitfieldID;
  __pyx_vtabptr_4h5py_3h5t_TypeReferenceID = &__pyx_vtable_4h5py_3h5t_TypeReferenceID;
  __pyx_vtable_4h5py_3h5t_TypeReferenceID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_vtable_4h5py_3h5t_TypeReferenceID.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_15TypeReferenceID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeReferenceID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeReferenceID) < 0) __PYX_ERR(0, 803, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeReferenceID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeReferenceID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeReferenceID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeReferenceID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeReferenceID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeReferenceID) < 0) __PYX_ERR(0, 803, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeReferenceID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeReferenceID) < 0) __PYX_ERR(0, 803, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeReferenceID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeReferenceID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeReferenceID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeReferenceID = &__pyx_type_4h5py_3h5t_TypeReferenceID;
  __pyx_vtabptr_4h5py_3h5t_TypeAtomicID = &__pyx_vtable_4h5py_3h5t_TypeAtomicID;
  __pyx_vtable_4h5py_3h5t_TypeAtomicID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_type_4h5py_3h5t_TypeAtomicID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeAtomicID) < 0) __PYX_ERR(0, 820, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeAtomicID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeAtomicID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeAtomicID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeAtomicID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeAtomicID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeAtomicID) < 0) __PYX_ERR(0, 820, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeAtomicID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeAtomicID) < 0) __PYX_ERR(0, 820, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeAtomicID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeAtomicID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeAtomicID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeAtomicID = &__pyx_type_4h5py_3h5t_TypeAtomicID;
  __pyx_vtabptr_4h5py_3h5t_TypeIntegerID = &__pyx_vtable_4h5py_3h5t_TypeIntegerID;
  __pyx_vtable_4h5py_3h5t_TypeIntegerID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeAtomicID;
  __pyx_vtable_4h5py_3h5t_TypeIntegerID.__pyx_base.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_13TypeIntegerID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeIntegerID.tp_base = __pyx_ptype_4h5py_3h5t_TypeAtomicID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeIntegerID) < 0) __PYX_ERR(0, 916, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeIntegerID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeIntegerID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeIntegerID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeIntegerID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeIntegerID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeIntegerID) < 0) __PYX_ERR(0, 916, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeIntegerID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeIntegerID) < 0) __PYX_ERR(0, 916, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeIntegerID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeIntegerID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeIntegerID, __pyx_base.__pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeIntegerID = &__pyx_type_4h5py_3h5t_TypeIntegerID;
  __pyx_vtabptr_4h5py_3h5t_TypeFloatID = &__pyx_vtable_4h5py_3h5t_TypeFloatID;
  __pyx_vtable_4h5py_3h5t_TypeFloatID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeAtomicID;
  __pyx_vtable_4h5py_3h5t_TypeFloatID.__pyx_base.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_11TypeFloatID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeFloatID.tp_base = __pyx_ptype_4h5py_3h5t_TypeAtomicID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeFloatID) < 0) __PYX_ERR(0, 958, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeFloatID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeFloatID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeFloatID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeFloatID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeFloatID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeFloatID) < 0) __PYX_ERR(0, 958, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeFloatID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeFloatID) < 0) __PYX_ERR(0, 958, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeFloatID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeFloatID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeFloatID, __pyx_base.__pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeFloatID = &__pyx_type_4h5py_3h5t_TypeFloatID;
  __pyx_vtabptr_4h5py_3h5t_TypeCompositeID = &__pyx_vtable_4h5py_3h5t_TypeCompositeID;
  __pyx_vtable_4h5py_3h5t_TypeCompositeID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeID;
  __pyx_type_4h5py_3h5t_TypeCompositeID.tp_base = __pyx_ptype_4h5py_3h5t_TypeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeCompositeID) < 0) __PYX_ERR(0, 1087, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeCompositeID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeCompositeID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeCompositeID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeCompositeID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeCompositeID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeCompositeID) < 0) __PYX_ERR(0, 1087, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeCompositeID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeCompositeID) < 0) __PYX_ERR(0, 1087, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeCompositeID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeCompositeID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeCompositeID, __pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeCompositeID = &__pyx_type_4h5py_3h5t_TypeCompositeID;
  __pyx_vtabptr_4h5py_3h5t_TypeEnumID = &__pyx_vtable_4h5py_3h5t_TypeEnumID;
  __pyx_vtable_4h5py_3h5t_TypeEnumID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeCompositeID;
  __pyx_vtable_4h5py_3h5t_TypeEnumID.__pyx_base.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_10TypeEnumID_py_dtype;
  __pyx_vtable_4h5py_3h5t_TypeEnumID.enum_convert = (int (*)(struct __pyx_obj_4h5py_3h5t_TypeEnumID *, PY_LONG_LONG *, int))__pyx_f_4h5py_3h5t_10TypeEnumID_enum_convert;
  __pyx_type_4h5py_3h5t_TypeEnumID.tp_base = __pyx_ptype_4h5py_3h5t_TypeCompositeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeEnumID) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeEnumID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeEnumID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeEnumID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeEnumID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeEnumID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeEnumID) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeEnumID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeEnumID) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeEnumID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeEnumID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeEnumID, __pyx_base.__pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeEnumID = &__pyx_type_4h5py_3h5t_TypeEnumID;
  __pyx_vtabptr_4h5py_3h5t_TypeCompoundID = &__pyx_vtable_4h5py_3h5t_TypeCompoundID;
  __pyx_vtable_4h5py_3h5t_TypeCompoundID.__pyx_base = *__pyx_vtabptr_4h5py_3h5t_TypeCompositeID;
  __pyx_vtable_4h5py_3h5t_TypeCompoundID.__pyx_base.__pyx_base.py_dtype = (PyObject *(*)(struct __pyx_obj_4h5py_3h5t_TypeID *))__pyx_f_4h5py_3h5t_14TypeCompoundID_py_dtype;
  __pyx_type_4h5py_3h5t_TypeCompoundID.tp_base = __pyx_ptype_4h5py_3h5t_TypeCompositeID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t_TypeCompoundID) < 0) __PYX_ERR(0, 1138, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t_TypeCompoundID.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t_TypeCompoundID.tp_dictoffset && __pyx_type_4h5py_3h5t_TypeCompoundID.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t_TypeCompoundID.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_4h5py_3h5t_TypeCompoundID.tp_dict, __pyx_vtabptr_4h5py_3h5t_TypeCompoundID) < 0) __PYX_ERR(0, 1138, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TypeCompoundID, (PyObject *)&__pyx_type_4h5py_3h5t_TypeCompoundID) < 0) __PYX_ERR(0, 1138, __pyx_L1_error)
  if (__pyx_type_4h5py_3h5t_TypeCompoundID.tp_weaklistoffset == 0) __pyx_type_4h5py_3h5t_TypeCompoundID.tp_weaklistoffset = offsetof(struct __pyx_obj_4h5py_3h5t_TypeCompoundID, __pyx_base.__pyx_base.__pyx_base.__weakref__);
  __pyx_ptype_4h5py_3h5t_TypeCompoundID = &__pyx_type_4h5py_3h5t_TypeCompoundID;
  if (PyType_Ready(&__pyx_type_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound) < 0) __PYX_ERR(0, 1592, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound.tp_dictoffset && __pyx_type_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound = &__pyx_type_4h5py_3h5t___pyx_scope_struct____pyx_f_4h5py_3h5t__c_compound;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(2, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("numpy"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType(__pyx_t_1, "numpy", "dtype", sizeof(PyArray_Descr), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_dtype) __PYX_ERR(1, 199, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType(__pyx_t_1, "numpy", "flatiter", sizeof(PyArrayIterObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_flatiter) __PYX_ERR(1, 222, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType(__pyx_t_1, "numpy", "broadcast", sizeof(PyArrayMultiIterObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_broadcast) __PYX_ERR(1, 226, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType(__pyx_t_1, "numpy", "ndarray", sizeof(PyArrayObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_ndarray) __PYX_ERR(1, 238, __pyx_L1_error)
  __pyx_ptype_5numpy_generic = __Pyx_ImportType(__pyx_t_1, "numpy", "generic", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_generic) __PYX_ERR(1, 770, __pyx_L1_error)
  __pyx_ptype_5numpy_number = __Pyx_ImportType(__pyx_t_1, "numpy", "number", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_number) __PYX_ERR(1, 772, __pyx_L1_error)
  __pyx_ptype_5numpy_integer = __Pyx_ImportType(__pyx_t_1, "numpy", "integer", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_integer) __PYX_ERR(1, 774, __pyx_L1_error)
  __pyx_ptype_5numpy_signedinteger = __Pyx_ImportType(__pyx_t_1, "numpy", "signedinteger", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_signedinteger) __PYX_ERR(1, 776, __pyx_L1_error)
  __pyx_ptype_5numpy_unsignedinteger = __Pyx_ImportType(__pyx_t_1, "numpy", "unsignedinteger", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_unsignedinteger) __PYX_ERR(1, 778, __pyx_L1_error)
  __pyx_ptype_5numpy_inexact = __Pyx_ImportType(__pyx_t_1, "numpy", "inexact", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_inexact) __PYX_ERR(1, 780, __pyx_L1_error)
  __pyx_ptype_5numpy_floating = __Pyx_ImportType(__pyx_t_1, "numpy", "floating", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_floating) __PYX_ERR(1, 782, __pyx_L1_error)
  __pyx_ptype_5numpy_complexfloating = __Pyx_ImportType(__pyx_t_1, "numpy", "complexfloating", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_complexfloating) __PYX_ERR(1, 784, __pyx_L1_error)
  __pyx_ptype_5numpy_flexible = __Pyx_ImportType(__pyx_t_1, "numpy", "flexible", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_flexible) __PYX_ERR(1, 786, __pyx_L1_error)
  __pyx_ptype_5numpy_character = __Pyx_ImportType(__pyx_t_1, "numpy", "character", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_character) __PYX_ERR(1, 788, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType(__pyx_t_1, "numpy", "ufunc", sizeof(PyUFuncObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_ufunc) __PYX_ERR(1, 826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("h5py.h5r"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_4h5py_3h5r_Reference = __Pyx_ImportType(__pyx_t_1, "h5py.h5r", "Reference", sizeof(struct __pyx_obj_4h5py_3h5r_Reference), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5r_Reference) __PYX_ERR(3, 27, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5r_RegionReference = __Pyx_ImportType(__pyx_t_1, "h5py.h5r", "RegionReference", sizeof(struct __pyx_obj_4h5py_3h5r_RegionReference), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5r_RegionReference) __PYX_ERR(3, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("h5py.h5p"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_4h5py_3h5p_PropID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropID", sizeof(struct __pyx_obj_4h5py_3h5p_PropID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropID) __PYX_ERR(4, 17, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropClassID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropClassID", sizeof(struct __pyx_obj_4h5py_3h5p_PropClassID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropClassID) __PYX_ERR(4, 21, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropInstanceID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropInstanceID", sizeof(struct __pyx_obj_4h5py_3h5p_PropInstanceID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropInstanceID) __PYX_ERR(4, 27, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropCreateID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropCreateID", sizeof(struct __pyx_obj_4h5py_3h5p_PropCreateID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropCreateID) __PYX_ERR(4, 33, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropCopyID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropCopyID", sizeof(struct __pyx_obj_4h5py_3h5p_PropCopyID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropCopyID) __PYX_ERR(4, 40, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropOCID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropOCID", sizeof(struct __pyx_obj_4h5py_3h5p_PropOCID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropOCID) __PYX_ERR(4, 45, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropDCID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropDCID", sizeof(struct __pyx_obj_4h5py_3h5p_PropDCID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropDCID) __PYX_ERR(4, 49, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropFCID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropFCID", sizeof(struct __pyx_obj_4h5py_3h5p_PropFCID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropFCID) __PYX_ERR(4, 53, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropFAID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropFAID", sizeof(struct __pyx_obj_4h5py_3h5p_PropFAID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropFAID) __PYX_ERR(4, 60, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropDXID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropDXID", sizeof(struct __pyx_obj_4h5py_3h5p_PropDXID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropDXID) __PYX_ERR(4, 64, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropDAID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropDAID", sizeof(struct __pyx_obj_4h5py_3h5p_PropDAID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropDAID) __PYX_ERR(4, 68, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropLCID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropLCID", sizeof(struct __pyx_obj_4h5py_3h5p_PropLCID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropLCID) __PYX_ERR(4, 75, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropLAID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropLAID", sizeof(struct __pyx_obj_4h5py_3h5p_PropLAID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropLAID) __PYX_ERR(4, 79, __pyx_L1_error)
  __pyx_ptype_4h5py_3h5p_PropGCID = __Pyx_ImportType(__pyx_t_1, "h5py.h5p", "PropGCID", sizeof(struct __pyx_obj_4h5py_3h5p_PropGCID), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4h5py_3h5p_PropGCID) __PYX_ERR(4, 83, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __pyx_t_1 = PyImport_ImportModule("h5py.defs"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction(__pyx_t_1, "H5free_memory", (void (**)(void))&__pyx_f_4h5py_4defs_H5free_memory, "herr_t (void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tcreate", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tcreate, "hid_t (enum H5T_class_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Topen", (void (**)(void))&__pyx_f_4h5py_4defs_H5Topen, "hid_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tcommitted", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tcommitted, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tcopy", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tcopy, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tequal", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tequal, "htri_t (hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tlock", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tlock, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_class", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_class, "enum H5T_class_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_size", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_size, "size_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_super", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_super, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tdetect_class", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tdetect_class, "htri_t (hid_t, enum H5T_class_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tclose", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tcommit", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tcommit, "herr_t (hid_t, char *, hid_t, hid_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_create_plist", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_create_plist, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tdecode", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tdecode, "hid_t (unsigned char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tencode", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tencode, "herr_t (hid_t, unsigned char *, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tfind", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tfind, "H5T_conv_t (hid_t, hid_t, H5T_cdata_t **)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tconvert", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tconvert, "herr_t (hid_t, hid_t, size_t, void *, void *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_size", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_size, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_order", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_order, "H5T_order_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_order", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_order, "herr_t (hid_t, H5T_order_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_precision", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_precision, "hsize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_precision", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_precision, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_offset", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_offset, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_offset", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_offset, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_pad", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_pad, "herr_t (hid_t, H5T_pad_t *, H5T_pad_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_pad", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_pad, "herr_t (hid_t, H5T_pad_t, H5T_pad_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_sign", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_sign, "H5T_sign_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_sign", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_sign, "herr_t (hid_t, H5T_sign_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_fields", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_fields, "herr_t (hid_t, size_t *, size_t *, size_t *, size_t *, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_fields", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_fields, "herr_t (hid_t, size_t, size_t, size_t, size_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_ebias", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_ebias, "size_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_ebias", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_ebias, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_norm", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_norm, "H5T_norm_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_norm", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_norm, "herr_t (hid_t, H5T_norm_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_inpad", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_inpad, "H5T_pad_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_inpad", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_inpad, "herr_t (hid_t, H5T_pad_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_cset", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_cset, "H5T_cset_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_cset", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_cset, "herr_t (hid_t, H5T_cset_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_strpad", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_strpad, "H5T_str_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_strpad", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_strpad, "herr_t (hid_t, H5T_str_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tvlen_create", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tvlen_create, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tis_variable_str", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tis_variable_str, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_nmembers", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_nmembers, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_member_class", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_member_class, "enum H5T_class_t (hid_t, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_member_name", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_member_name, "char *(hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_member_type", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_member_type, "hid_t (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_member_offset", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_member_offset, "int (hid_t, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_member_index", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_member_index, "int (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tinsert", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tinsert, "herr_t (hid_t, char *, size_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tpack", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tpack, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tenum_create", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tenum_create, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tenum_insert", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tenum_insert, "herr_t (hid_t, char *, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tenum_nameof", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tenum_nameof, "herr_t (hid_t, void *, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tenum_valueof", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tenum_valueof, "herr_t (hid_t, char *, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_member_value", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_member_value, "herr_t (hid_t, unsigned int, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tarray_create", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tarray_create, "hid_t (hid_t, int, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_array_ndims", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_array_ndims, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_array_dims", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_array_dims, "int (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tset_tag", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tset_tag, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "H5Tget_tag", (void (**)(void))&__pyx_f_4h5py_4defs_H5Tget_tag, "char *(hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("h5py._objects"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction(__pyx_t_1, "pdefault", (void (**)(void))&__pyx_f_4h5py_8_objects_pdefault, "hid_t (struct __pyx_obj_4h5py_8_objects_ObjectID *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("h5py.h5p"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction(__pyx_t_1, "propwrap", (void (**)(void))&__pyx_f_4h5py_3h5p_propwrap, "PyObject *(hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("h5py.utils"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction(__pyx_t_1, "emalloc", (void (**)(void))&__pyx_f_4h5py_5utils_emalloc, "void *(size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "efree", (void (**)(void))&__pyx_f_4h5py_5utils_efree, "void (void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "convert_tuple", (void (**)(void))&__pyx_f_4h5py_5utils_convert_tuple, "int (PyObject *, hsize_t *, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "convert_dims", (void (**)(void))&__pyx_f_4h5py_5utils_convert_dims, "PyObject *(hsize_t *, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "require_tuple", (void (**)(void))&__pyx_f_4h5py_5utils_require_tuple, "int (PyObject *, int, int, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC inith5t(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC inith5t(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_h5t(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_h5t(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_h5t(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  hid_t __pyx_t_5;
  herr_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'h5t' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_h5t(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("h5t", __pyx_methods, __pyx_k_HDF5_H5T_data_type_API_This_mod, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_h5py__h5t) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "h5py.h5t")) {
      if (unlikely(PyDict_SetItemString(modules, "h5py.h5t", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  if (unlikely(__Pyx_modinit_variable_export_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_function_export_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  if (unlikely(__Pyx_modinit_function_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "h5py/h5t.pyx":30
 * 
 * # Python imports
 * import codecs             # <<<<<<<<<<<<<<
 * import sys
 * from collections import namedtuple
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_codecs, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_codecs, __pyx_t_1) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":31
 * # Python imports
 * import codecs
 * import sys             # <<<<<<<<<<<<<<
 * from collections import namedtuple
 * import sys
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":32
 * import codecs
 * import sys
 * from collections import namedtuple             # <<<<<<<<<<<<<<
 * import sys
 * import numpy as np
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_namedtuple);
  __Pyx_GIVEREF(__pyx_n_s_namedtuple);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_namedtuple);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_namedtuple); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_namedtuple, __pyx_t_1) < 0) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":33
 * import sys
 * from collections import namedtuple
 * import sys             # <<<<<<<<<<<<<<
 * import numpy as np
 * from .h5 import get_config
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_sys, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_2) < 0) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":34
 * from collections import namedtuple
 * import sys
 * import numpy as np             # <<<<<<<<<<<<<<
 * from .h5 import get_config
 * 
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_numpy, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_2) < 0) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":35
 * import sys
 * import numpy as np
 * from .h5 import get_config             # <<<<<<<<<<<<<<
 * 
 * from ._objects import phil, with_phil
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_get_config);
  __Pyx_GIVEREF(__pyx_n_s_get_config);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_get_config);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_h5, __pyx_t_2, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_get_config); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_config, __pyx_t_2) < 0) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":37
 * from .h5 import get_config
 * 
 * from ._objects import phil, with_phil             # <<<<<<<<<<<<<<
 * 
 * cfg = get_config()
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_phil);
  __Pyx_GIVEREF(__pyx_n_s_phil);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_phil);
  __Pyx_INCREF(__pyx_n_s_with_phil);
  __Pyx_GIVEREF(__pyx_n_s_with_phil);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_with_phil);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_objects, __pyx_t_1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_phil, __pyx_t_1) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_with_phil, __pyx_t_1) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":39
 * from ._objects import phil, with_phil
 * 
 * cfg = get_config()             # <<<<<<<<<<<<<<
 * 
 * DEF MACHINE = UNAME_MACHINE  # processor architecture, provided by Cython
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_get_config); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cfg, __pyx_t_1) < 0) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":42
 * 
 * DEF MACHINE = UNAME_MACHINE  # processor architecture, provided by Cython
 * cdef char* H5PY_PYTHON_OPAQUE_TAG = "PYTHON:OBJECT"             # <<<<<<<<<<<<<<
 * 
 * # === Custom C API ============================================================
 */
  __pyx_v_4h5py_3h5t_H5PY_PYTHON_OPAQUE_TAG = ((char *)"PYTHON:OBJECT");

  /* "h5py/h5t.pyx":88
 * 
 * # Enumeration H5T_class_t
 * NO_CLASS  = H5T_NO_CLASS             # <<<<<<<<<<<<<<
 * INTEGER   = H5T_INTEGER
 * FLOAT     = H5T_FLOAT
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_NO_CLASS); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NO_CLASS, __pyx_t_1) < 0) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":89
 * # Enumeration H5T_class_t
 * NO_CLASS  = H5T_NO_CLASS
 * INTEGER   = H5T_INTEGER             # <<<<<<<<<<<<<<
 * FLOAT     = H5T_FLOAT
 * TIME      = H5T_TIME
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_INTEGER); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_INTEGER, __pyx_t_1) < 0) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":90
 * NO_CLASS  = H5T_NO_CLASS
 * INTEGER   = H5T_INTEGER
 * FLOAT     = H5T_FLOAT             # <<<<<<<<<<<<<<
 * TIME      = H5T_TIME
 * STRING    = H5T_STRING
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_FLOAT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FLOAT, __pyx_t_1) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":91
 * INTEGER   = H5T_INTEGER
 * FLOAT     = H5T_FLOAT
 * TIME      = H5T_TIME             # <<<<<<<<<<<<<<
 * STRING    = H5T_STRING
 * BITFIELD  = H5T_BITFIELD
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_TIME); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TIME, __pyx_t_1) < 0) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":92
 * FLOAT     = H5T_FLOAT
 * TIME      = H5T_TIME
 * STRING    = H5T_STRING             # <<<<<<<<<<<<<<
 * BITFIELD  = H5T_BITFIELD
 * OPAQUE    = H5T_OPAQUE
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_STRING); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STRING, __pyx_t_1) < 0) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":93
 * TIME      = H5T_TIME
 * STRING    = H5T_STRING
 * BITFIELD  = H5T_BITFIELD             # <<<<<<<<<<<<<<
 * OPAQUE    = H5T_OPAQUE
 * COMPOUND  = H5T_COMPOUND
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_BITFIELD); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BITFIELD, __pyx_t_1) < 0) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":94
 * STRING    = H5T_STRING
 * BITFIELD  = H5T_BITFIELD
 * OPAQUE    = H5T_OPAQUE             # <<<<<<<<<<<<<<
 * COMPOUND  = H5T_COMPOUND
 * REFERENCE = H5T_REFERENCE
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_OPAQUE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OPAQUE, __pyx_t_1) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":95
 * BITFIELD  = H5T_BITFIELD
 * OPAQUE    = H5T_OPAQUE
 * COMPOUND  = H5T_COMPOUND             # <<<<<<<<<<<<<<
 * REFERENCE = H5T_REFERENCE
 * ENUM      = H5T_ENUM
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_COMPOUND); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_COMPOUND, __pyx_t_1) < 0) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":96
 * OPAQUE    = H5T_OPAQUE
 * COMPOUND  = H5T_COMPOUND
 * REFERENCE = H5T_REFERENCE             # <<<<<<<<<<<<<<
 * ENUM      = H5T_ENUM
 * VLEN      = H5T_VLEN
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_REFERENCE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_REFERENCE, __pyx_t_1) < 0) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":97
 * COMPOUND  = H5T_COMPOUND
 * REFERENCE = H5T_REFERENCE
 * ENUM      = H5T_ENUM             # <<<<<<<<<<<<<<
 * VLEN      = H5T_VLEN
 * ARRAY     = H5T_ARRAY
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_ENUM); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ENUM, __pyx_t_1) < 0) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":98
 * REFERENCE = H5T_REFERENCE
 * ENUM      = H5T_ENUM
 * VLEN      = H5T_VLEN             # <<<<<<<<<<<<<<
 * ARRAY     = H5T_ARRAY
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_VLEN); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_VLEN, __pyx_t_1) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":99
 * ENUM      = H5T_ENUM
 * VLEN      = H5T_VLEN
 * ARRAY     = H5T_ARRAY             # <<<<<<<<<<<<<<
 * 
 * # Enumeration H5T_sign_t
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_class_t(H5T_ARRAY); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ARRAY, __pyx_t_1) < 0) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":102
 * 
 * # Enumeration H5T_sign_t
 * SGN_NONE   = H5T_SGN_NONE             # <<<<<<<<<<<<<<
 * SGN_2      = H5T_SGN_2
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_sign_t(H5T_SGN_NONE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SGN_NONE, __pyx_t_1) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":103
 * # Enumeration H5T_sign_t
 * SGN_NONE   = H5T_SGN_NONE
 * SGN_2      = H5T_SGN_2             # <<<<<<<<<<<<<<
 * 
 * # Enumeration H5T_order_t
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_sign_t(H5T_SGN_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SGN_2, __pyx_t_1) < 0) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":106
 * 
 * # Enumeration H5T_order_t
 * ORDER_LE    = H5T_ORDER_LE             # <<<<<<<<<<<<<<
 * ORDER_BE    = H5T_ORDER_BE
 * ORDER_VAX   = H5T_ORDER_VAX
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_LE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ORDER_LE, __pyx_t_1) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":107
 * # Enumeration H5T_order_t
 * ORDER_LE    = H5T_ORDER_LE
 * ORDER_BE    = H5T_ORDER_BE             # <<<<<<<<<<<<<<
 * ORDER_VAX   = H5T_ORDER_VAX
 * ORDER_NONE  = H5T_ORDER_NONE
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_BE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ORDER_BE, __pyx_t_1) < 0) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":108
 * ORDER_LE    = H5T_ORDER_LE
 * ORDER_BE    = H5T_ORDER_BE
 * ORDER_VAX   = H5T_ORDER_VAX             # <<<<<<<<<<<<<<
 * ORDER_NONE  = H5T_ORDER_NONE
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_VAX); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ORDER_VAX, __pyx_t_1) < 0) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":109
 * ORDER_BE    = H5T_ORDER_BE
 * ORDER_VAX   = H5T_ORDER_VAX
 * ORDER_NONE  = H5T_ORDER_NONE             # <<<<<<<<<<<<<<
 * 
 * DIR_DEFAULT = H5T_DIR_DEFAULT
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_NONE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ORDER_NONE, __pyx_t_1) < 0) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":111
 * ORDER_NONE  = H5T_ORDER_NONE
 * 
 * DIR_DEFAULT = H5T_DIR_DEFAULT             # <<<<<<<<<<<<<<
 * DIR_ASCEND  = H5T_DIR_ASCEND
 * DIR_DESCEND = H5T_DIR_DESCEND
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_direction_t(H5T_DIR_DEFAULT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DIR_DEFAULT, __pyx_t_1) < 0) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":112
 * 
 * DIR_DEFAULT = H5T_DIR_DEFAULT
 * DIR_ASCEND  = H5T_DIR_ASCEND             # <<<<<<<<<<<<<<
 * DIR_DESCEND = H5T_DIR_DESCEND
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_direction_t(H5T_DIR_ASCEND); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DIR_ASCEND, __pyx_t_1) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":113
 * DIR_DEFAULT = H5T_DIR_DEFAULT
 * DIR_ASCEND  = H5T_DIR_ASCEND
 * DIR_DESCEND = H5T_DIR_DESCEND             # <<<<<<<<<<<<<<
 * 
 * # Enumeration H5T_str_t
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum__H5T_direction_t(H5T_DIR_DESCEND); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DIR_DESCEND, __pyx_t_1) < 0) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":116
 * 
 * # Enumeration H5T_str_t
 * STR_NULLTERM = H5T_STR_NULLTERM             # <<<<<<<<<<<<<<
 * STR_NULLPAD  = H5T_STR_NULLPAD
 * STR_SPACEPAD = H5T_STR_SPACEPAD
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_str_t(H5T_STR_NULLTERM); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STR_NULLTERM, __pyx_t_1) < 0) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":117
 * # Enumeration H5T_str_t
 * STR_NULLTERM = H5T_STR_NULLTERM
 * STR_NULLPAD  = H5T_STR_NULLPAD             # <<<<<<<<<<<<<<
 * STR_SPACEPAD = H5T_STR_SPACEPAD
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_str_t(H5T_STR_NULLPAD); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STR_NULLPAD, __pyx_t_1) < 0) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":118
 * STR_NULLTERM = H5T_STR_NULLTERM
 * STR_NULLPAD  = H5T_STR_NULLPAD
 * STR_SPACEPAD = H5T_STR_SPACEPAD             # <<<<<<<<<<<<<<
 * 
 * # Enumeration H5T_norm_t
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_str_t(H5T_STR_SPACEPAD); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STR_SPACEPAD, __pyx_t_1) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":121
 * 
 * # Enumeration H5T_norm_t
 * NORM_IMPLIED = H5T_NORM_IMPLIED             # <<<<<<<<<<<<<<
 * NORM_MSBSET = H5T_NORM_MSBSET
 * NORM_NONE = H5T_NORM_NONE
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_norm_t(H5T_NORM_IMPLIED); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NORM_IMPLIED, __pyx_t_1) < 0) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":122
 * # Enumeration H5T_norm_t
 * NORM_IMPLIED = H5T_NORM_IMPLIED
 * NORM_MSBSET = H5T_NORM_MSBSET             # <<<<<<<<<<<<<<
 * NORM_NONE = H5T_NORM_NONE
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_norm_t(H5T_NORM_MSBSET); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NORM_MSBSET, __pyx_t_1) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":123
 * NORM_IMPLIED = H5T_NORM_IMPLIED
 * NORM_MSBSET = H5T_NORM_MSBSET
 * NORM_NONE = H5T_NORM_NONE             # <<<<<<<<<<<<<<
 * 
 * # Enumeration H5T_cset_t:
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_norm_t(H5T_NORM_NONE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NORM_NONE, __pyx_t_1) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":126
 * 
 * # Enumeration H5T_cset_t:
 * CSET_ASCII = H5T_CSET_ASCII             # <<<<<<<<<<<<<<
 * 
 * # Enumeration H5T_pad_t:
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_cset_t(H5T_CSET_ASCII); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CSET_ASCII, __pyx_t_1) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":129
 * 
 * # Enumeration H5T_pad_t:
 * PAD_ZERO = H5T_PAD_ZERO             # <<<<<<<<<<<<<<
 * PAD_ONE = H5T_PAD_ONE
 * PAD_BACKGROUND = H5T_PAD_BACKGROUND
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_pad_t(H5T_PAD_ZERO); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PAD_ZERO, __pyx_t_1) < 0) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":130
 * # Enumeration H5T_pad_t:
 * PAD_ZERO = H5T_PAD_ZERO
 * PAD_ONE = H5T_PAD_ONE             # <<<<<<<<<<<<<<
 * PAD_BACKGROUND = H5T_PAD_BACKGROUND
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_pad_t(H5T_PAD_ONE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PAD_ONE, __pyx_t_1) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":131
 * PAD_ZERO = H5T_PAD_ZERO
 * PAD_ONE = H5T_PAD_ONE
 * PAD_BACKGROUND = H5T_PAD_BACKGROUND             # <<<<<<<<<<<<<<
 * 
 * if sys.byteorder == "little":    # Custom python addition
 */
  __pyx_t_1 = __Pyx_PyInt_From_H5T_pad_t(H5T_PAD_BACKGROUND); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PAD_BACKGROUND, __pyx_t_1) < 0) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":133
 * PAD_BACKGROUND = H5T_PAD_BACKGROUND
 * 
 * if sys.byteorder == "little":    # Custom python addition             # <<<<<<<<<<<<<<
 *     ORDER_NATIVE = H5T_ORDER_LE
 * else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_byteorder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_little, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "h5py/h5t.pyx":134
 * 
 * if sys.byteorder == "little":    # Custom python addition
 *     ORDER_NATIVE = H5T_ORDER_LE             # <<<<<<<<<<<<<<
 * else:
 *     ORDER_NATIVE = H5T_ORDER_BE
 */
    __pyx_t_2 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_ORDER_NATIVE, __pyx_t_2) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "h5py/h5t.pyx":133
 * PAD_BACKGROUND = H5T_PAD_BACKGROUND
 * 
 * if sys.byteorder == "little":    # Custom python addition             # <<<<<<<<<<<<<<
 *     ORDER_NATIVE = H5T_ORDER_LE
 * else:
 */
    goto __pyx_L2;
  }

  /* "h5py/h5t.pyx":136
 *     ORDER_NATIVE = H5T_ORDER_LE
 * else:
 *     ORDER_NATIVE = H5T_ORDER_BE             # <<<<<<<<<<<<<<
 * 
 * # For conversion
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_ORDER_NATIVE, __pyx_t_2) < 0) __PYX_ERR(0, 136, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L2:;

  /* "h5py/h5t.pyx":139
 * 
 * # For conversion
 * BKG_NO = H5T_BKG_NO             # <<<<<<<<<<<<<<
 * BKG_TEMP = H5T_BKG_TEMP
 * BKG_YES = H5T_BKG_YES
 */
  __pyx_t_2 = __Pyx_PyInt_From_H5T_bkg_t(H5T_BKG_NO); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BKG_NO, __pyx_t_2) < 0) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":140
 * # For conversion
 * BKG_NO = H5T_BKG_NO
 * BKG_TEMP = H5T_BKG_TEMP             # <<<<<<<<<<<<<<
 * BKG_YES = H5T_BKG_YES
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_H5T_bkg_t(H5T_BKG_TEMP); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BKG_TEMP, __pyx_t_2) < 0) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":141
 * BKG_NO = H5T_BKG_NO
 * BKG_TEMP = H5T_BKG_TEMP
 * BKG_YES = H5T_BKG_YES             # <<<<<<<<<<<<<<
 * 
 * # --- Built-in HDF5 datatypes -------------------------------------------------
 */
  __pyx_t_2 = __Pyx_PyInt_From_H5T_bkg_t(H5T_BKG_YES); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BKG_YES, __pyx_t_2) < 0) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":146
 * 
 * # IEEE floating-point
 * IEEE_F32LE = lockid(H5T_IEEE_F32LE)             # <<<<<<<<<<<<<<
 * IEEE_F32BE = lockid(H5T_IEEE_F32BE)
 * IEEE_F64LE = lockid(H5T_IEEE_F64LE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_IEEE_F32LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IEEE_F32LE, __pyx_t_2) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":147
 * # IEEE floating-point
 * IEEE_F32LE = lockid(H5T_IEEE_F32LE)
 * IEEE_F32BE = lockid(H5T_IEEE_F32BE)             # <<<<<<<<<<<<<<
 * IEEE_F64LE = lockid(H5T_IEEE_F64LE)
 * IEEE_F64BE = lockid(H5T_IEEE_F64BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_IEEE_F32BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IEEE_F32BE, __pyx_t_2) < 0) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":148
 * IEEE_F32LE = lockid(H5T_IEEE_F32LE)
 * IEEE_F32BE = lockid(H5T_IEEE_F32BE)
 * IEEE_F64LE = lockid(H5T_IEEE_F64LE)             # <<<<<<<<<<<<<<
 * IEEE_F64BE = lockid(H5T_IEEE_F64BE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_IEEE_F64LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IEEE_F64LE, __pyx_t_2) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":149
 * IEEE_F32BE = lockid(H5T_IEEE_F32BE)
 * IEEE_F64LE = lockid(H5T_IEEE_F64LE)
 * IEEE_F64BE = lockid(H5T_IEEE_F64BE)             # <<<<<<<<<<<<<<
 * 
 * # Signed 2's complement integer types
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_IEEE_F64BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IEEE_F64BE, __pyx_t_2) < 0) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":152
 * 
 * # Signed 2's complement integer types
 * STD_I8LE  = lockid(H5T_STD_I8LE)             # <<<<<<<<<<<<<<
 * STD_I16LE = lockid(H5T_STD_I16LE)
 * STD_I32LE = lockid(H5T_STD_I32LE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_I8LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_I8LE, __pyx_t_2) < 0) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":153
 * # Signed 2's complement integer types
 * STD_I8LE  = lockid(H5T_STD_I8LE)
 * STD_I16LE = lockid(H5T_STD_I16LE)             # <<<<<<<<<<<<<<
 * STD_I32LE = lockid(H5T_STD_I32LE)
 * STD_I64LE = lockid(H5T_STD_I64LE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_I16LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_I16LE, __pyx_t_2) < 0) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":154
 * STD_I8LE  = lockid(H5T_STD_I8LE)
 * STD_I16LE = lockid(H5T_STD_I16LE)
 * STD_I32LE = lockid(H5T_STD_I32LE)             # <<<<<<<<<<<<<<
 * STD_I64LE = lockid(H5T_STD_I64LE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_I32LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_I32LE, __pyx_t_2) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":155
 * STD_I16LE = lockid(H5T_STD_I16LE)
 * STD_I32LE = lockid(H5T_STD_I32LE)
 * STD_I64LE = lockid(H5T_STD_I64LE)             # <<<<<<<<<<<<<<
 * 
 * STD_I8BE  = lockid(H5T_STD_I8BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_I64LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_I64LE, __pyx_t_2) < 0) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":157
 * STD_I64LE = lockid(H5T_STD_I64LE)
 * 
 * STD_I8BE  = lockid(H5T_STD_I8BE)             # <<<<<<<<<<<<<<
 * STD_I16BE = lockid(H5T_STD_I16BE)
 * STD_I32BE = lockid(H5T_STD_I32BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_I8BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_I8BE, __pyx_t_2) < 0) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":158
 * 
 * STD_I8BE  = lockid(H5T_STD_I8BE)
 * STD_I16BE = lockid(H5T_STD_I16BE)             # <<<<<<<<<<<<<<
 * STD_I32BE = lockid(H5T_STD_I32BE)
 * STD_I64BE = lockid(H5T_STD_I64BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_I16BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_I16BE, __pyx_t_2) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":159
 * STD_I8BE  = lockid(H5T_STD_I8BE)
 * STD_I16BE = lockid(H5T_STD_I16BE)
 * STD_I32BE = lockid(H5T_STD_I32BE)             # <<<<<<<<<<<<<<
 * STD_I64BE = lockid(H5T_STD_I64BE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_I32BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_I32BE, __pyx_t_2) < 0) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":160
 * STD_I16BE = lockid(H5T_STD_I16BE)
 * STD_I32BE = lockid(H5T_STD_I32BE)
 * STD_I64BE = lockid(H5T_STD_I64BE)             # <<<<<<<<<<<<<<
 * 
 * # Bitfields
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_I64BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_I64BE, __pyx_t_2) < 0) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":163
 * 
 * # Bitfields
 * STD_B8LE = lockid(H5T_STD_B8LE)             # <<<<<<<<<<<<<<
 * STD_B16LE = lockid(H5T_STD_B16LE)
 * STD_B32LE = lockid(H5T_STD_B32LE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_B8LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_B8LE, __pyx_t_2) < 0) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":164
 * # Bitfields
 * STD_B8LE = lockid(H5T_STD_B8LE)
 * STD_B16LE = lockid(H5T_STD_B16LE)             # <<<<<<<<<<<<<<
 * STD_B32LE = lockid(H5T_STD_B32LE)
 * STD_B64LE = lockid(H5T_STD_B64LE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_B16LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_B16LE, __pyx_t_2) < 0) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":165
 * STD_B8LE = lockid(H5T_STD_B8LE)
 * STD_B16LE = lockid(H5T_STD_B16LE)
 * STD_B32LE = lockid(H5T_STD_B32LE)             # <<<<<<<<<<<<<<
 * STD_B64LE = lockid(H5T_STD_B64LE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_B32LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_B32LE, __pyx_t_2) < 0) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":166
 * STD_B16LE = lockid(H5T_STD_B16LE)
 * STD_B32LE = lockid(H5T_STD_B32LE)
 * STD_B64LE = lockid(H5T_STD_B64LE)             # <<<<<<<<<<<<<<
 * 
 * STD_B8BE = lockid(H5T_STD_B8BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_B64LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_B64LE, __pyx_t_2) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":168
 * STD_B64LE = lockid(H5T_STD_B64LE)
 * 
 * STD_B8BE = lockid(H5T_STD_B8BE)             # <<<<<<<<<<<<<<
 * STD_B16BE = lockid(H5T_STD_B16BE)
 * STD_B32BE = lockid(H5T_STD_B32BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_B8BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_B8BE, __pyx_t_2) < 0) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":169
 * 
 * STD_B8BE = lockid(H5T_STD_B8BE)
 * STD_B16BE = lockid(H5T_STD_B16BE)             # <<<<<<<<<<<<<<
 * STD_B32BE = lockid(H5T_STD_B32BE)
 * STD_B64BE = lockid(H5T_STD_B64BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_B16BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_B16BE, __pyx_t_2) < 0) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":170
 * STD_B8BE = lockid(H5T_STD_B8BE)
 * STD_B16BE = lockid(H5T_STD_B16BE)
 * STD_B32BE = lockid(H5T_STD_B32BE)             # <<<<<<<<<<<<<<
 * STD_B64BE = lockid(H5T_STD_B64BE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_B32BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_B32BE, __pyx_t_2) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":171
 * STD_B16BE = lockid(H5T_STD_B16BE)
 * STD_B32BE = lockid(H5T_STD_B32BE)
 * STD_B64BE = lockid(H5T_STD_B64BE)             # <<<<<<<<<<<<<<
 * 
 * # Unsigned integers
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_B64BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_B64BE, __pyx_t_2) < 0) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":174
 * 
 * # Unsigned integers
 * STD_U8LE  = lockid(H5T_STD_U8LE)             # <<<<<<<<<<<<<<
 * STD_U16LE = lockid(H5T_STD_U16LE)
 * STD_U32LE = lockid(H5T_STD_U32LE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_U8LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_U8LE, __pyx_t_2) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":175
 * # Unsigned integers
 * STD_U8LE  = lockid(H5T_STD_U8LE)
 * STD_U16LE = lockid(H5T_STD_U16LE)             # <<<<<<<<<<<<<<
 * STD_U32LE = lockid(H5T_STD_U32LE)
 * STD_U64LE = lockid(H5T_STD_U64LE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_U16LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_U16LE, __pyx_t_2) < 0) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":176
 * STD_U8LE  = lockid(H5T_STD_U8LE)
 * STD_U16LE = lockid(H5T_STD_U16LE)
 * STD_U32LE = lockid(H5T_STD_U32LE)             # <<<<<<<<<<<<<<
 * STD_U64LE = lockid(H5T_STD_U64LE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_U32LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_U32LE, __pyx_t_2) < 0) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":177
 * STD_U16LE = lockid(H5T_STD_U16LE)
 * STD_U32LE = lockid(H5T_STD_U32LE)
 * STD_U64LE = lockid(H5T_STD_U64LE)             # <<<<<<<<<<<<<<
 * 
 * STD_U8BE  = lockid(H5T_STD_U8BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_U64LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_U64LE, __pyx_t_2) < 0) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":179
 * STD_U64LE = lockid(H5T_STD_U64LE)
 * 
 * STD_U8BE  = lockid(H5T_STD_U8BE)             # <<<<<<<<<<<<<<
 * STD_U16BE = lockid(H5T_STD_U16BE)
 * STD_U32BE = lockid(H5T_STD_U32BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_U8BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_U8BE, __pyx_t_2) < 0) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":180
 * 
 * STD_U8BE  = lockid(H5T_STD_U8BE)
 * STD_U16BE = lockid(H5T_STD_U16BE)             # <<<<<<<<<<<<<<
 * STD_U32BE = lockid(H5T_STD_U32BE)
 * STD_U64BE = lockid(H5T_STD_U64BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_U16BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_U16BE, __pyx_t_2) < 0) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":181
 * STD_U8BE  = lockid(H5T_STD_U8BE)
 * STD_U16BE = lockid(H5T_STD_U16BE)
 * STD_U32BE = lockid(H5T_STD_U32BE)             # <<<<<<<<<<<<<<
 * STD_U64BE = lockid(H5T_STD_U64BE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_U32BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_U32BE, __pyx_t_2) < 0) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":182
 * STD_U16BE = lockid(H5T_STD_U16BE)
 * STD_U32BE = lockid(H5T_STD_U32BE)
 * STD_U64BE = lockid(H5T_STD_U64BE)             # <<<<<<<<<<<<<<
 * 
 * # Native types by bytesize
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_U64BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_U64BE, __pyx_t_2) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":185
 * 
 * # Native types by bytesize
 * NATIVE_B8 = lockid(H5T_NATIVE_B8)             # <<<<<<<<<<<<<<
 * NATIVE_INT8 = lockid(H5T_NATIVE_INT8)
 * NATIVE_UINT8 = lockid(H5T_NATIVE_UINT8)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_B8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_B8, __pyx_t_2) < 0) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":186
 * # Native types by bytesize
 * NATIVE_B8 = lockid(H5T_NATIVE_B8)
 * NATIVE_INT8 = lockid(H5T_NATIVE_INT8)             # <<<<<<<<<<<<<<
 * NATIVE_UINT8 = lockid(H5T_NATIVE_UINT8)
 * NATIVE_B16 = lockid(H5T_NATIVE_B16)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_INT8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_INT8, __pyx_t_2) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":187
 * NATIVE_B8 = lockid(H5T_NATIVE_B8)
 * NATIVE_INT8 = lockid(H5T_NATIVE_INT8)
 * NATIVE_UINT8 = lockid(H5T_NATIVE_UINT8)             # <<<<<<<<<<<<<<
 * NATIVE_B16 = lockid(H5T_NATIVE_B16)
 * NATIVE_INT16 = lockid(H5T_NATIVE_INT16)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_UINT8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_UINT8, __pyx_t_2) < 0) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":188
 * NATIVE_INT8 = lockid(H5T_NATIVE_INT8)
 * NATIVE_UINT8 = lockid(H5T_NATIVE_UINT8)
 * NATIVE_B16 = lockid(H5T_NATIVE_B16)             # <<<<<<<<<<<<<<
 * NATIVE_INT16 = lockid(H5T_NATIVE_INT16)
 * NATIVE_UINT16 = lockid(H5T_NATIVE_UINT16)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_B16); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_B16, __pyx_t_2) < 0) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":189
 * NATIVE_UINT8 = lockid(H5T_NATIVE_UINT8)
 * NATIVE_B16 = lockid(H5T_NATIVE_B16)
 * NATIVE_INT16 = lockid(H5T_NATIVE_INT16)             # <<<<<<<<<<<<<<
 * NATIVE_UINT16 = lockid(H5T_NATIVE_UINT16)
 * NATIVE_B32 = lockid(H5T_NATIVE_B32)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_INT16); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_INT16, __pyx_t_2) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":190
 * NATIVE_B16 = lockid(H5T_NATIVE_B16)
 * NATIVE_INT16 = lockid(H5T_NATIVE_INT16)
 * NATIVE_UINT16 = lockid(H5T_NATIVE_UINT16)             # <<<<<<<<<<<<<<
 * NATIVE_B32 = lockid(H5T_NATIVE_B32)
 * NATIVE_INT32 = lockid(H5T_NATIVE_INT32)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_UINT16); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_UINT16, __pyx_t_2) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":191
 * NATIVE_INT16 = lockid(H5T_NATIVE_INT16)
 * NATIVE_UINT16 = lockid(H5T_NATIVE_UINT16)
 * NATIVE_B32 = lockid(H5T_NATIVE_B32)             # <<<<<<<<<<<<<<
 * NATIVE_INT32 = lockid(H5T_NATIVE_INT32)
 * NATIVE_UINT32 = lockid(H5T_NATIVE_UINT32)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_B32); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_B32, __pyx_t_2) < 0) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":192
 * NATIVE_UINT16 = lockid(H5T_NATIVE_UINT16)
 * NATIVE_B32 = lockid(H5T_NATIVE_B32)
 * NATIVE_INT32 = lockid(H5T_NATIVE_INT32)             # <<<<<<<<<<<<<<
 * NATIVE_UINT32 = lockid(H5T_NATIVE_UINT32)
 * NATIVE_B64 = lockid(H5T_NATIVE_B64)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_INT32); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_INT32, __pyx_t_2) < 0) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":193
 * NATIVE_B32 = lockid(H5T_NATIVE_B32)
 * NATIVE_INT32 = lockid(H5T_NATIVE_INT32)
 * NATIVE_UINT32 = lockid(H5T_NATIVE_UINT32)             # <<<<<<<<<<<<<<
 * NATIVE_B64 = lockid(H5T_NATIVE_B64)
 * NATIVE_INT64 = lockid(H5T_NATIVE_INT64)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_UINT32); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_UINT32, __pyx_t_2) < 0) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":194
 * NATIVE_INT32 = lockid(H5T_NATIVE_INT32)
 * NATIVE_UINT32 = lockid(H5T_NATIVE_UINT32)
 * NATIVE_B64 = lockid(H5T_NATIVE_B64)             # <<<<<<<<<<<<<<
 * NATIVE_INT64 = lockid(H5T_NATIVE_INT64)
 * NATIVE_UINT64 = lockid(H5T_NATIVE_UINT64)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_B64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_B64, __pyx_t_2) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":195
 * NATIVE_UINT32 = lockid(H5T_NATIVE_UINT32)
 * NATIVE_B64 = lockid(H5T_NATIVE_B64)
 * NATIVE_INT64 = lockid(H5T_NATIVE_INT64)             # <<<<<<<<<<<<<<
 * NATIVE_UINT64 = lockid(H5T_NATIVE_UINT64)
 * NATIVE_FLOAT = lockid(H5T_NATIVE_FLOAT)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_INT64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_INT64, __pyx_t_2) < 0) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":196
 * NATIVE_B64 = lockid(H5T_NATIVE_B64)
 * NATIVE_INT64 = lockid(H5T_NATIVE_INT64)
 * NATIVE_UINT64 = lockid(H5T_NATIVE_UINT64)             # <<<<<<<<<<<<<<
 * NATIVE_FLOAT = lockid(H5T_NATIVE_FLOAT)
 * NATIVE_DOUBLE = lockid(H5T_NATIVE_DOUBLE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_UINT64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_UINT64, __pyx_t_2) < 0) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":197
 * NATIVE_INT64 = lockid(H5T_NATIVE_INT64)
 * NATIVE_UINT64 = lockid(H5T_NATIVE_UINT64)
 * NATIVE_FLOAT = lockid(H5T_NATIVE_FLOAT)             # <<<<<<<<<<<<<<
 * NATIVE_DOUBLE = lockid(H5T_NATIVE_DOUBLE)
 * NATIVE_LDOUBLE = lockid(H5T_NATIVE_LDOUBLE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_FLOAT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_FLOAT, __pyx_t_2) < 0) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":198
 * NATIVE_UINT64 = lockid(H5T_NATIVE_UINT64)
 * NATIVE_FLOAT = lockid(H5T_NATIVE_FLOAT)
 * NATIVE_DOUBLE = lockid(H5T_NATIVE_DOUBLE)             # <<<<<<<<<<<<<<
 * NATIVE_LDOUBLE = lockid(H5T_NATIVE_LDOUBLE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_DOUBLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_DOUBLE, __pyx_t_2) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":199
 * NATIVE_FLOAT = lockid(H5T_NATIVE_FLOAT)
 * NATIVE_DOUBLE = lockid(H5T_NATIVE_DOUBLE)
 * NATIVE_LDOUBLE = lockid(H5T_NATIVE_LDOUBLE)             # <<<<<<<<<<<<<<
 * 
 * # Unix time types
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_NATIVE_LDOUBLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NATIVE_LDOUBLE, __pyx_t_2) < 0) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":202
 * 
 * # Unix time types
 * UNIX_D32LE = lockid(H5T_UNIX_D32LE)             # <<<<<<<<<<<<<<
 * UNIX_D64LE = lockid(H5T_UNIX_D64LE)
 * UNIX_D32BE = lockid(H5T_UNIX_D32BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_UNIX_D32LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UNIX_D32LE, __pyx_t_2) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":203
 * # Unix time types
 * UNIX_D32LE = lockid(H5T_UNIX_D32LE)
 * UNIX_D64LE = lockid(H5T_UNIX_D64LE)             # <<<<<<<<<<<<<<
 * UNIX_D32BE = lockid(H5T_UNIX_D32BE)
 * UNIX_D64BE = lockid(H5T_UNIX_D64BE)
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_UNIX_D64LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UNIX_D64LE, __pyx_t_2) < 0) __PYX_ERR(0, 203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":204
 * UNIX_D32LE = lockid(H5T_UNIX_D32LE)
 * UNIX_D64LE = lockid(H5T_UNIX_D64LE)
 * UNIX_D32BE = lockid(H5T_UNIX_D32BE)             # <<<<<<<<<<<<<<
 * UNIX_D64BE = lockid(H5T_UNIX_D64BE)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_UNIX_D32BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UNIX_D32BE, __pyx_t_2) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":205
 * UNIX_D64LE = lockid(H5T_UNIX_D64LE)
 * UNIX_D32BE = lockid(H5T_UNIX_D32BE)
 * UNIX_D64BE = lockid(H5T_UNIX_D64BE)             # <<<<<<<<<<<<<<
 * 
 * # Reference types
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_UNIX_D64BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UNIX_D64BE, __pyx_t_2) < 0) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":208
 * 
 * # Reference types
 * STD_REF_OBJ = lockid(H5T_STD_REF_OBJ)             # <<<<<<<<<<<<<<
 * STD_REF_DSETREG = lockid(H5T_STD_REF_DSETREG)
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_REF_OBJ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_REF_OBJ, __pyx_t_2) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":209
 * # Reference types
 * STD_REF_OBJ = lockid(H5T_STD_REF_OBJ)
 * STD_REF_DSETREG = lockid(H5T_STD_REF_DSETREG)             # <<<<<<<<<<<<<<
 * 
 * # Null terminated (C) and Fortran string types
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_STD_REF_DSETREG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STD_REF_DSETREG, __pyx_t_2) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":212
 * 
 * # Null terminated (C) and Fortran string types
 * C_S1 = lockid(H5T_C_S1)             # <<<<<<<<<<<<<<
 * FORTRAN_S1 = lockid(H5T_FORTRAN_S1)
 * VARIABLE = H5T_VARIABLE
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_C_S1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_C_S1, __pyx_t_2) < 0) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":213
 * # Null terminated (C) and Fortran string types
 * C_S1 = lockid(H5T_C_S1)
 * FORTRAN_S1 = lockid(H5T_FORTRAN_S1)             # <<<<<<<<<<<<<<
 * VARIABLE = H5T_VARIABLE
 * 
 */
  __pyx_t_2 = __pyx_f_4h5py_3h5t_lockid(H5T_FORTRAN_S1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FORTRAN_S1, __pyx_t_2) < 0) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":214
 * C_S1 = lockid(H5T_C_S1)
 * FORTRAN_S1 = lockid(H5T_FORTRAN_S1)
 * VARIABLE = H5T_VARIABLE             # <<<<<<<<<<<<<<
 * 
 * # Character sets
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(H5T_VARIABLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_VARIABLE, __pyx_t_2) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":217
 * 
 * # Character sets
 * CSET_ASCII = H5T_CSET_ASCII             # <<<<<<<<<<<<<<
 * CSET_UTF8 = H5T_CSET_UTF8
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_H5T_cset_t(H5T_CSET_ASCII); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CSET_ASCII, __pyx_t_2) < 0) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":218
 * # Character sets
 * CSET_ASCII = H5T_CSET_ASCII
 * CSET_UTF8 = H5T_CSET_UTF8             # <<<<<<<<<<<<<<
 * 
 * # Mini (or short) floats
 */
  __pyx_t_2 = __Pyx_PyInt_From_H5T_cset_t(H5T_CSET_UTF8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CSET_UTF8, __pyx_t_2) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":221
 * 
 * # Mini (or short) floats
 * IEEE_F16BE = IEEE_F32BE.copy()             # <<<<<<<<<<<<<<
 * IEEE_F16BE.set_fields(15, 10, 5, 0, 10)
 * IEEE_F16BE.set_size(2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IEEE_F32BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IEEE_F16BE, __pyx_t_2) < 0) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":222
 * # Mini (or short) floats
 * IEEE_F16BE = IEEE_F32BE.copy()
 * IEEE_F16BE.set_fields(15, 10, 5, 0, 10)             # <<<<<<<<<<<<<<
 * IEEE_F16BE.set_size(2)
 * IEEE_F16BE.set_ebias(15)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IEEE_F16BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_fields); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":223
 * IEEE_F16BE = IEEE_F32BE.copy()
 * IEEE_F16BE.set_fields(15, 10, 5, 0, 10)
 * IEEE_F16BE.set_size(2)             # <<<<<<<<<<<<<<
 * IEEE_F16BE.set_ebias(15)
 * IEEE_F16BE.lock()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IEEE_F16BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":224
 * IEEE_F16BE.set_fields(15, 10, 5, 0, 10)
 * IEEE_F16BE.set_size(2)
 * IEEE_F16BE.set_ebias(15)             # <<<<<<<<<<<<<<
 * IEEE_F16BE.lock()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IEEE_F16BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_ebias); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":225
 * IEEE_F16BE.set_size(2)
 * IEEE_F16BE.set_ebias(15)
 * IEEE_F16BE.lock()             # <<<<<<<<<<<<<<
 * 
 * IEEE_F16LE = IEEE_F16BE.copy()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IEEE_F16BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lock); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":227
 * IEEE_F16BE.lock()
 * 
 * IEEE_F16LE = IEEE_F16BE.copy()             # <<<<<<<<<<<<<<
 * IEEE_F16LE.set_order(H5T_ORDER_LE)
 * IEEE_F16LE.lock()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IEEE_F16BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IEEE_F16LE, __pyx_t_2) < 0) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":228
 * 
 * IEEE_F16LE = IEEE_F16BE.copy()
 * IEEE_F16LE.set_order(H5T_ORDER_LE)             # <<<<<<<<<<<<<<
 * IEEE_F16LE.lock()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IEEE_F16LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_order); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":229
 * IEEE_F16LE = IEEE_F16BE.copy()
 * IEEE_F16LE.set_order(H5T_ORDER_LE)
 * IEEE_F16LE.lock()             # <<<<<<<<<<<<<<
 * 
 * # Quad floats
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F16LE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lock); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":232
 * 
 * # Quad floats
 * IEEE_F128BE = IEEE_F64BE.copy()             # <<<<<<<<<<<<<<
 * IEEE_F128BE.set_size(16)
 * IEEE_F128BE.set_precision(128)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F64BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_copy_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IEEE_F128BE, __pyx_t_4) < 0) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":233
 * # Quad floats
 * IEEE_F128BE = IEEE_F64BE.copy()
 * IEEE_F128BE.set_size(16)             # <<<<<<<<<<<<<<
 * IEEE_F128BE.set_precision(128)
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F128BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":234
 * IEEE_F128BE = IEEE_F64BE.copy()
 * IEEE_F128BE.set_size(16)
 * IEEE_F128BE.set_precision(128)             # <<<<<<<<<<<<<<
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)
 * IEEE_F128BE.set_ebias(16383)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F128BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_precision); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":235
 * IEEE_F128BE.set_size(16)
 * IEEE_F128BE.set_precision(128)
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)             # <<<<<<<<<<<<<<
 * IEEE_F128BE.set_ebias(16383)
 * IEEE_F128BE.lock()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F128BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_fields); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":236
 * IEEE_F128BE.set_precision(128)
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)
 * IEEE_F128BE.set_ebias(16383)             # <<<<<<<<<<<<<<
 * IEEE_F128BE.lock()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F128BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_ebias); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__37, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":237
 * IEEE_F128BE.set_fields(127, 112, 15, 0, 112)
 * IEEE_F128BE.set_ebias(16383)
 * IEEE_F128BE.lock()             # <<<<<<<<<<<<<<
 * 
 * IEEE_F128LE = IEEE_F128BE.copy()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F128BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lock); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":239
 * IEEE_F128BE.lock()
 * 
 * IEEE_F128LE = IEEE_F128BE.copy()             # <<<<<<<<<<<<<<
 * IEEE_F128LE.set_order(H5T_ORDER_LE)
 * IEEE_F128LE.lock()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F128BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_copy_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IEEE_F128LE, __pyx_t_4) < 0) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":240
 * 
 * IEEE_F128LE = IEEE_F128BE.copy()
 * IEEE_F128LE.set_order(H5T_ORDER_LE)             # <<<<<<<<<<<<<<
 * IEEE_F128LE.lock()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IEEE_F128LE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_order); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_LE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":241
 * IEEE_F128LE = IEEE_F128BE.copy()
 * IEEE_F128LE.set_order(H5T_ORDER_LE)
 * IEEE_F128LE.lock()             # <<<<<<<<<<<<<<
 * 
 * LDOUBLE_LE = NATIVE_LDOUBLE.copy()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_IEEE_F128LE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_lock); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":243
 * IEEE_F128LE.lock()
 * 
 * LDOUBLE_LE = NATIVE_LDOUBLE.copy()             # <<<<<<<<<<<<<<
 * LDOUBLE_LE.set_order(H5T_ORDER_LE)
 * LDOUBLE_LE.lock()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NATIVE_LDOUBLE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_copy_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LDOUBLE_LE, __pyx_t_1) < 0) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":244
 * 
 * LDOUBLE_LE = NATIVE_LDOUBLE.copy()
 * LDOUBLE_LE.set_order(H5T_ORDER_LE)             # <<<<<<<<<<<<<<
 * LDOUBLE_LE.lock()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_LDOUBLE_LE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_set_order); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_LE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":245
 * LDOUBLE_LE = NATIVE_LDOUBLE.copy()
 * LDOUBLE_LE.set_order(H5T_ORDER_LE)
 * LDOUBLE_LE.lock()             # <<<<<<<<<<<<<<
 * 
 * LDOUBLE_BE = NATIVE_LDOUBLE.copy()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_LDOUBLE_LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lock); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":247
 * LDOUBLE_LE.lock()
 * 
 * LDOUBLE_BE = NATIVE_LDOUBLE.copy()             # <<<<<<<<<<<<<<
 * LDOUBLE_BE.set_order(H5T_ORDER_BE)
 * LDOUBLE_BE.lock()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_NATIVE_LDOUBLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LDOUBLE_BE, __pyx_t_2) < 0) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":248
 * 
 * LDOUBLE_BE = NATIVE_LDOUBLE.copy()
 * LDOUBLE_BE.set_order(H5T_ORDER_BE)             # <<<<<<<<<<<<<<
 * LDOUBLE_BE.lock()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_LDOUBLE_BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_order); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":249
 * LDOUBLE_BE = NATIVE_LDOUBLE.copy()
 * LDOUBLE_BE.set_order(H5T_ORDER_BE)
 * LDOUBLE_BE.lock()             # <<<<<<<<<<<<<<
 * 
 * # Custom Python object pointer type
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_LDOUBLE_BE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lock); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":252
 * 
 * # Custom Python object pointer type
 * cdef hid_t H5PY_OBJ = H5Tcreate(H5T_OPAQUE, sizeof(PyObject*))             # <<<<<<<<<<<<<<
 * H5Tset_tag(H5PY_OBJ, H5PY_PYTHON_OPAQUE_TAG)
 * H5Tlock(H5PY_OBJ)
 */
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcreate(H5T_OPAQUE, (sizeof(PyObject *))); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 252, __pyx_L1_error)
  __pyx_v_4h5py_3h5t_H5PY_OBJ = __pyx_t_5;

  /* "h5py/h5t.pyx":253
 * # Custom Python object pointer type
 * cdef hid_t H5PY_OBJ = H5Tcreate(H5T_OPAQUE, sizeof(PyObject*))
 * H5Tset_tag(H5PY_OBJ, H5PY_PYTHON_OPAQUE_TAG)             # <<<<<<<<<<<<<<
 * H5Tlock(H5PY_OBJ)
 * 
 */
  __pyx_t_6 = __pyx_f_4h5py_4defs_H5Tset_tag(__pyx_v_4h5py_3h5t_H5PY_OBJ, __pyx_v_4h5py_3h5t_H5PY_PYTHON_OPAQUE_TAG); if (unlikely(__pyx_t_6 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 253, __pyx_L1_error)

  /* "h5py/h5t.pyx":254
 * cdef hid_t H5PY_OBJ = H5Tcreate(H5T_OPAQUE, sizeof(PyObject*))
 * H5Tset_tag(H5PY_OBJ, H5PY_PYTHON_OPAQUE_TAG)
 * H5Tlock(H5PY_OBJ)             # <<<<<<<<<<<<<<
 * 
 * PYTHON_OBJECT = lockid(H5PY_OBJ)
 */
  __pyx_t_6 = __pyx_f_4h5py_4defs_H5Tlock(__pyx_v_4h5py_3h5t_H5PY_OBJ); if (unlikely(__pyx_t_6 == ((herr_t)((herr_t)-1L)))) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "h5py/h5t.pyx":256
 * H5Tlock(H5PY_OBJ)
 * 
 * PYTHON_OBJECT = lockid(H5PY_OBJ)             # <<<<<<<<<<<<<<
 * 
 * # Translation tables for HDF5 -> NumPy dtype conversion
 */
  __pyx_t_4 = __pyx_f_4h5py_3h5t_lockid(__pyx_v_4h5py_3h5t_H5PY_OBJ); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PYTHON_OBJECT, __pyx_t_4) < 0) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":259
 * 
 * # Translation tables for HDF5 -> NumPy dtype conversion
 * cdef dict _order_map = { H5T_ORDER_NONE: '|', H5T_ORDER_LE: '<', H5T_ORDER_BE: '>'}             # <<<<<<<<<<<<<<
 * cdef dict _sign_map  = { H5T_SGN_NONE: 'u', H5T_SGN_2: 'i' }
 * 
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_NONE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_kp_u__38) < 0) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_LE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_kp_u__39) < 0) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_H5T_order_t(H5T_ORDER_BE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_kp_u__40) < 0) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__order_map);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__order_map, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":260
 * # Translation tables for HDF5 -> NumPy dtype conversion
 * cdef dict _order_map = { H5T_ORDER_NONE: '|', H5T_ORDER_LE: '<', H5T_ORDER_BE: '>'}
 * cdef dict _sign_map  = { H5T_SGN_NONE: 'u', H5T_SGN_2: 'i' }             # <<<<<<<<<<<<<<
 * 
 * # Available floating point types
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyInt_From_H5T_sign_t(H5T_SGN_NONE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_n_u_u) < 0) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_H5T_sign_t(H5T_SGN_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_n_u_i) < 0) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__sign_map);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__sign_map, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":278
 *     return tuple(available_ftypes)
 * 
 * cdef tuple _available_ftypes = _get_available_ftypes()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __pyx_f_4h5py_3h5t__get_available_ftypes(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__available_ftypes);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__available_ftypes, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":305
 * # === General datatype operations =============================================
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def create(int classtype, size_t size):
 *     """(INT classtype, UINT size) => TypeID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "h5py/h5t.pyx":306
 * 
 * @with_phil
 * def create(int classtype, size_t size):             # <<<<<<<<<<<<<<
 *     """(INT classtype, UINT size) => TypeID
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_3create, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":305
 * # === General datatype operations =============================================
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def create(int classtype, size_t size):
 *     """(INT classtype, UINT size) => TypeID
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_create, __pyx_t_1) < 0) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":320
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def open(ObjectID group not None, char* name, ObjectID tapl=None):
 *     """(ObjectID group, STRING name) => TypeID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "h5py/h5t.pyx":321
 * 
 * @with_phil
 * def open(ObjectID group not None, char* name, ObjectID tapl=None):             # <<<<<<<<<<<<<<
 *     """(ObjectID group, STRING name) => TypeID
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_5open, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":320
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def open(ObjectID group not None, char* name, ObjectID tapl=None):
 *     """(ObjectID group, STRING name) => TypeID
 */
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_open, __pyx_t_4) < 0) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":330
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def array_create(TypeID base not None, object dims_tpl):
 *     """(TypeID base, TUPLE dimensions) => TypeArrayID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "h5py/h5t.pyx":331
 * 
 * @with_phil
 * def array_create(TypeID base not None, object dims_tpl):             # <<<<<<<<<<<<<<
 *     """(TypeID base, TUPLE dimensions) => TypeArrayID
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_7array_create, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":330
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def array_create(TypeID base not None, object dims_tpl):
 *     """(TypeID base, TUPLE dimensions) => TypeArrayID
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_array_create, __pyx_t_1) < 0) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":352
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def enum_create(TypeID base not None):
 *     """(TypeID base) => TypeID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "h5py/h5t.pyx":353
 * 
 * @with_phil
 * def enum_create(TypeID base not None):             # <<<<<<<<<<<<<<
 *     """(TypeID base) => TypeID
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_9enum_create, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":352
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def enum_create(TypeID base not None):
 *     """(TypeID base) => TypeID
 */
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_enum_create, __pyx_t_4) < 0) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":361
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def vlen_create(TypeID base not None):
 *     """(TypeID base) => TypeID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "h5py/h5t.pyx":362
 * 
 * @with_phil
 * def vlen_create(TypeID base not None):             # <<<<<<<<<<<<<<
 *     """(TypeID base) => TypeID
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_11vlen_create, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":361
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def vlen_create(TypeID base not None):
 *     """(TypeID base) => TypeID
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_vlen_create, __pyx_t_1) < 0) __PYX_ERR(0, 362, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":373
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def decode(char* buf):
 *     """(STRING buf) => TypeID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "h5py/h5t.pyx":374
 * 
 * @with_phil
 * def decode(char* buf):             # <<<<<<<<<<<<<<
 *     """(STRING buf) => TypeID
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_13decode, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":373
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def decode(char* buf):
 *     """(STRING buf) => TypeID
 */
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_decode, __pyx_t_4) < 0) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":442
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def commit(self, ObjectID group not None, char* name, ObjectID lcpl=None):
 *         """(ObjectID group, STRING name, PropID lcpl=None)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":443
 * 
 *     @with_phil
 *     def commit(self, ObjectID group not None, char* name, ObjectID lcpl=None):             # <<<<<<<<<<<<<<
 *         """(ObjectID group, STRING name, PropID lcpl=None)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_commit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_commit, __pyx_t_4) < 0) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":453
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def committed(self):
 *         """() => BOOL is_comitted
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":454
 * 
 *     @with_phil
 *     def committed(self):             # <<<<<<<<<<<<<<
 *         """() => BOOL is_comitted
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_committed); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_committed, __pyx_t_4) < 0) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":462
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def copy(self):
 *         """() => TypeID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":463
 * 
 *     @with_phil
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """() => TypeID
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_copy_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_copy_2, __pyx_t_4) < 0) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":471
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def equal(self, TypeID typeid):
 *         """(TypeID typeid) => BOOL
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":472
 * 
 *     @with_phil
 *     def equal(self, TypeID typeid):             # <<<<<<<<<<<<<<
 *         """(TypeID typeid) => BOOL
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_equal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_equal, __pyx_t_4) < 0) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":481
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def lock(self):
 *         """()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":482
 * 
 *     @with_phil
 *     def lock(self):             # <<<<<<<<<<<<<<
 *         """()
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_lock); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_lock, __pyx_t_4) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":492
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_class(self):
 *         """() => INT classcode
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":493
 * 
 *     @with_phil
 *     def get_class(self):             # <<<<<<<<<<<<<<
 *         """() => INT classcode
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_get_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_get_class, __pyx_t_4) < 0) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":501
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_size(self, size_t size):
 *         """(UINT size)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":502
 * 
 *     @with_phil
 *     def set_size(self, size_t size):             # <<<<<<<<<<<<<<
 *         """(UINT size)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_set_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_set_size, __pyx_t_4) < 0) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":510
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_size(self):
 *         """ () => INT size
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":511
 * 
 *     @with_phil
 *     def get_size(self):             # <<<<<<<<<<<<<<
 *         """ () => INT size
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_get_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_get_size, __pyx_t_4) < 0) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":519
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_super(self):
 *         """() => TypeID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":520
 * 
 *     @with_phil
 *     def get_super(self):             # <<<<<<<<<<<<<<
 *         """() => TypeID
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_get_super); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_get_super, __pyx_t_4) < 0) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":528
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def detect_class(self, int classtype):
 *         """(INT classtype) => BOOL class_is_present
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":529
 * 
 *     @with_phil
 *     def detect_class(self, int classtype):             # <<<<<<<<<<<<<<
 *         """(INT classtype) => BOOL class_is_present
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_detect_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_detect_class, __pyx_t_4) < 0) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":538
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def encode(self):
 *         """() => STRING
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":539
 * 
 *     @with_phil
 *     def encode(self):             # <<<<<<<<<<<<<<
 *         """() => STRING
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_encode, __pyx_t_4) < 0) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":559
 *         return pystr
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_create_plist(self):
 *         """ () => PropTCID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":560
 * 
 *     @with_phil
 *     def get_create_plist(self):             # <<<<<<<<<<<<<<
 *         """ () => PropTCID
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeID, __pyx_n_s_get_create_plist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeID->tp_dict, __pyx_n_s_get_create_plist, __pyx_t_4) < 0) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeID);

  /* "h5py/h5t.pyx":588
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_array_ndims(self):
 *         """() => INT rank
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":589
 * 
 *     @with_phil
 *     def get_array_ndims(self):             # <<<<<<<<<<<<<<
 *         """() => INT rank
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeArrayID, __pyx_n_s_get_array_ndims); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeArrayID->tp_dict, __pyx_n_s_get_array_ndims, __pyx_t_4) < 0) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeArrayID);

  /* "h5py/h5t.pyx":597
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_array_dims(self):
 *         """() => TUPLE dimensions
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":598
 * 
 *     @with_phil
 *     def get_array_dims(self):             # <<<<<<<<<<<<<<
 *         """() => TUPLE dimensions
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeArrayID, __pyx_n_s_get_array_dims); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeArrayID->tp_dict, __pyx_n_s_get_array_dims, __pyx_t_4) < 0) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeArrayID);

  /* "h5py/h5t.pyx":633
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_tag(self, char* tag):
 *         """(STRING tag)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":634
 * 
 *     @with_phil
 *     def set_tag(self, char* tag):             # <<<<<<<<<<<<<<
 *         """(STRING tag)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeOpaqueID, __pyx_n_s_set_tag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeOpaqueID->tp_dict, __pyx_n_s_set_tag, __pyx_t_4) < 0) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeOpaqueID);

  /* "h5py/h5t.pyx":643
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_tag(self):
 *         """() => STRING tag
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":644
 * 
 *     @with_phil
 *     def get_tag(self):             # <<<<<<<<<<<<<<
 *         """() => STRING tag
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeOpaqueID, __pyx_n_s_get_tag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeOpaqueID->tp_dict, __pyx_n_s_get_tag, __pyx_t_4) < 0) __PYX_ERR(0, 644, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeOpaqueID);

  /* "h5py/h5t.pyx":679
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def is_variable_str(self):
 *         """() => BOOL is_variable
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":680
 * 
 *     @with_phil
 *     def is_variable_str(self):             # <<<<<<<<<<<<<<
 *         """() => BOOL is_variable
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID, __pyx_n_s_is_variable_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID->tp_dict, __pyx_n_s_is_variable_str, __pyx_t_4) < 0) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeStringID);

  /* "h5py/h5t.pyx":688
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_cset(self):
 *         """() => INT character_set
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":689
 * 
 *     @with_phil
 *     def get_cset(self):             # <<<<<<<<<<<<<<
 *         """() => INT character_set
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID, __pyx_n_s_get_cset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID->tp_dict, __pyx_n_s_get_cset, __pyx_t_4) < 0) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeStringID);

  /* "h5py/h5t.pyx":697
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_cset(self, int cset):
 *         """(INT character_set)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":698
 * 
 *     @with_phil
 *     def set_cset(self, int cset):             # <<<<<<<<<<<<<<
 *         """(INT character_set)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID, __pyx_n_s_set_cset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID->tp_dict, __pyx_n_s_set_cset, __pyx_t_4) < 0) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeStringID);

  /* "h5py/h5t.pyx":706
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_strpad(self):
 *         """() => INT padding_type
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":707
 * 
 *     @with_phil
 *     def get_strpad(self):             # <<<<<<<<<<<<<<
 *         """() => INT padding_type
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID, __pyx_n_s_get_strpad); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID->tp_dict, __pyx_n_s_get_strpad, __pyx_t_4) < 0) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeStringID);

  /* "h5py/h5t.pyx":724
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_strpad(self, int pad):
 *         """(INT pad)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":725
 * 
 *     @with_phil
 *     def set_strpad(self, int pad):             # <<<<<<<<<<<<<<
 *         """(INT pad)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID, __pyx_n_s_set_strpad); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeStringID->tp_dict, __pyx_n_s_set_strpad, __pyx_t_4) < 0) __PYX_ERR(0, 725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeStringID);

  /* "h5py/h5t.pyx":785
 *     """
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_order(self):
 *         """() => INT order
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":786
 * 
 *     @with_phil
 *     def get_order(self):             # <<<<<<<<<<<<<<
 *         """() => INT order
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeBitfieldID, __pyx_n_s_get_order); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeBitfieldID->tp_dict, __pyx_n_s_get_order, __pyx_t_4) < 0) __PYX_ERR(0, 786, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeBitfieldID);

  /* "h5py/h5t.pyx":827
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_order(self):
 *         """() => INT order
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":828
 * 
 *     @with_phil
 *     def get_order(self):             # <<<<<<<<<<<<<<
 *         """() => INT order
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID, __pyx_n_s_get_order); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID->tp_dict, __pyx_n_s_get_order, __pyx_t_4) < 0) __PYX_ERR(0, 828, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeAtomicID);

  /* "h5py/h5t.pyx":839
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_order(self, int order):
 *         """(INT order)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":840
 * 
 *     @with_phil
 *     def set_order(self, int order):             # <<<<<<<<<<<<<<
 *         """(INT order)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID, __pyx_n_s_set_order); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID->tp_dict, __pyx_n_s_set_order, __pyx_t_4) < 0) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeAtomicID);

  /* "h5py/h5t.pyx":851
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_precision(self):
 *         """() => UINT precision
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":852
 * 
 *     @with_phil
 *     def get_precision(self):             # <<<<<<<<<<<<<<
 *         """() => UINT precision
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID, __pyx_n_s_get_precision); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID->tp_dict, __pyx_n_s_get_precision, __pyx_t_4) < 0) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeAtomicID);

  /* "h5py/h5t.pyx":860
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_precision(self, size_t precision):
 *         """(UINT precision)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":861
 * 
 *     @with_phil
 *     def set_precision(self, size_t precision):             # <<<<<<<<<<<<<<
 *         """(UINT precision)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID, __pyx_n_s_set_precision); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID->tp_dict, __pyx_n_s_set_precision, __pyx_t_4) < 0) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeAtomicID);

  /* "h5py/h5t.pyx":869
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_offset(self):
 *         """() => INT offset
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":870
 * 
 *     @with_phil
 *     def get_offset(self):             # <<<<<<<<<<<<<<
 *         """() => INT offset
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID, __pyx_n_s_get_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID->tp_dict, __pyx_n_s_get_offset, __pyx_t_4) < 0) __PYX_ERR(0, 870, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeAtomicID);

  /* "h5py/h5t.pyx":878
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_offset(self, size_t offset):
 *         """(UINT offset)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":879
 * 
 *     @with_phil
 *     def set_offset(self, size_t offset):             # <<<<<<<<<<<<<<
 *         """(UINT offset)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID, __pyx_n_s_set_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID->tp_dict, __pyx_n_s_set_offset, __pyx_t_4) < 0) __PYX_ERR(0, 879, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeAtomicID);

  /* "h5py/h5t.pyx":887
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_pad(self):
 *         """() => (INT lsb_pad_code, INT msb_pad_code)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":888
 * 
 *     @with_phil
 *     def get_pad(self):             # <<<<<<<<<<<<<<
 *         """() => (INT lsb_pad_code, INT msb_pad_code)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID, __pyx_n_s_get_pad); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID->tp_dict, __pyx_n_s_get_pad, __pyx_t_4) < 0) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeAtomicID);

  /* "h5py/h5t.pyx":903
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_pad(self, int lsb, int msb):
 *         """(INT lsb_pad_code, INT msb_pad_code)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":904
 * 
 *     @with_phil
 *     def set_pad(self, int lsb, int msb):             # <<<<<<<<<<<<<<
 *         """(INT lsb_pad_code, INT msb_pad_code)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID, __pyx_n_s_set_pad); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeAtomicID->tp_dict, __pyx_n_s_set_pad, __pyx_t_4) < 0) __PYX_ERR(0, 904, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeAtomicID);

  /* "h5py/h5t.pyx":923
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_sign(self):
 *         """() => INT sign
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":924
 * 
 *     @with_phil
 *     def get_sign(self):             # <<<<<<<<<<<<<<
 *         """() => INT sign
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeIntegerID, __pyx_n_s_get_sign); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeIntegerID->tp_dict, __pyx_n_s_get_sign, __pyx_t_4) < 0) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeIntegerID);

  /* "h5py/h5t.pyx":938
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_sign(self, int sign):
 *         """(INT sign)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":939
 * 
 *     @with_phil
 *     def set_sign(self, int sign):             # <<<<<<<<<<<<<<
 *         """(INT sign)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeIntegerID, __pyx_n_s_set_sign); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeIntegerID->tp_dict, __pyx_n_s_set_sign, __pyx_t_4) < 0) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeIntegerID);

  /* "h5py/h5t.pyx":965
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_fields(self):
 *         """() => TUPLE field_info
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":966
 * 
 *     @with_phil
 *     def get_fields(self):             # <<<<<<<<<<<<<<
 *         """() => TUPLE field_info
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID, __pyx_n_s_get_fields); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID->tp_dict, __pyx_n_s_get_fields, __pyx_t_4) < 0) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeFloatID);

  /* "h5py/h5t.pyx":983
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_fields(self, size_t spos, size_t epos, size_t esize,
 *                           size_t mpos, size_t msize):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":984
 * 
 *     @with_phil
 *     def set_fields(self, size_t spos, size_t epos, size_t esize,             # <<<<<<<<<<<<<<
 *                           size_t mpos, size_t msize):
 *         """(UINT spos, UINT epos, UINT esize, UINT mpos, UINT msize)
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID, __pyx_n_s_set_fields); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID->tp_dict, __pyx_n_s_set_fields, __pyx_t_4) < 0) __PYX_ERR(0, 984, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeFloatID);

  /* "h5py/h5t.pyx":994
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_ebias(self):
 *         """() => UINT ebias
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":995
 * 
 *     @with_phil
 *     def get_ebias(self):             # <<<<<<<<<<<<<<
 *         """() => UINT ebias
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID, __pyx_n_s_get_ebias); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID->tp_dict, __pyx_n_s_get_ebias, __pyx_t_4) < 0) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeFloatID);

  /* "h5py/h5t.pyx":1003
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_ebias(self, size_t ebias):
 *         """(UINT ebias)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1004
 * 
 *     @with_phil
 *     def set_ebias(self, size_t ebias):             # <<<<<<<<<<<<<<
 *         """(UINT ebias)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID, __pyx_n_s_set_ebias); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID->tp_dict, __pyx_n_s_set_ebias, __pyx_t_4) < 0) __PYX_ERR(0, 1004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeFloatID);

  /* "h5py/h5t.pyx":1012
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_norm(self):
 *         """() => INT normalization_code
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1013
 * 
 *     @with_phil
 *     def get_norm(self):             # <<<<<<<<<<<<<<
 *         """() => INT normalization_code
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID, __pyx_n_s_get_norm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID->tp_dict, __pyx_n_s_get_norm, __pyx_t_4) < 0) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeFloatID);

  /* "h5py/h5t.pyx":1025
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_norm(self, int norm):
 *         """(INT normalization_code)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1026
 * 
 *     @with_phil
 *     def set_norm(self, int norm):             # <<<<<<<<<<<<<<
 *         """(INT normalization_code)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID, __pyx_n_s_set_norm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID->tp_dict, __pyx_n_s_set_norm, __pyx_t_4) < 0) __PYX_ERR(0, 1026, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeFloatID);

  /* "h5py/h5t.pyx":1038
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_inpad(self):
 *         """() => INT pad_code
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1039
 * 
 *     @with_phil
 *     def get_inpad(self):             # <<<<<<<<<<<<<<
 *         """() => INT pad_code
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID, __pyx_n_s_get_inpad); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID->tp_dict, __pyx_n_s_get_inpad, __pyx_t_4) < 0) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeFloatID);

  /* "h5py/h5t.pyx":1051
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def set_inpad(self, int pad_code):
 *         """(INT pad_code)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1052
 * 
 *     @with_phil
 *     def set_inpad(self, int pad_code):             # <<<<<<<<<<<<<<
 *         """(INT pad_code)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID, __pyx_n_s_set_inpad); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeFloatID->tp_dict, __pyx_n_s_set_inpad, __pyx_t_4) < 0) __PYX_ERR(0, 1052, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeFloatID);

  /* "h5py/h5t.pyx":1094
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_nmembers(self):
 *         """() => INT number_of_members
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1095
 * 
 *     @with_phil
 *     def get_nmembers(self):             # <<<<<<<<<<<<<<
 *         """() => INT number_of_members
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompositeID, __pyx_n_s_get_nmembers); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompositeID->tp_dict, __pyx_n_s_get_nmembers, __pyx_t_4) < 0) __PYX_ERR(0, 1095, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeCompositeID);

  /* "h5py/h5t.pyx":1103
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_member_name(self, int member):
 *         """(INT member) => STRING name
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1104
 * 
 *     @with_phil
 *     def get_member_name(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => STRING name
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompositeID, __pyx_n_s_get_member_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompositeID->tp_dict, __pyx_n_s_get_member_name, __pyx_t_4) < 0) __PYX_ERR(0, 1104, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeCompositeID);

  /* "h5py/h5t.pyx":1129
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_member_index(self, char* name):
 *         """(STRING name) => INT index
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1130
 * 
 *     @with_phil
 *     def get_member_index(self, char* name):             # <<<<<<<<<<<<<<
 *         """(STRING name) => INT index
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompositeID, __pyx_n_s_get_member_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompositeID->tp_dict, __pyx_n_s_get_member_index, __pyx_t_4) < 0) __PYX_ERR(0, 1130, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeCompositeID);

  /* "h5py/h5t.pyx":1145
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_member_class(self, int member):
 *         """(INT member) => INT class
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1146
 * 
 *     @with_phil
 *     def get_member_class(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => INT class
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID, __pyx_n_s_get_member_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID->tp_dict, __pyx_n_s_get_member_class, __pyx_t_4) < 0) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeCompoundID);

  /* "h5py/h5t.pyx":1157
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_member_offset(self, int member):
 *         """(INT member) => INT offset
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1158
 * 
 *     @with_phil
 *     def get_member_offset(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => INT offset
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID, __pyx_n_s_get_member_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID->tp_dict, __pyx_n_s_get_member_offset, __pyx_t_4) < 0) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeCompoundID);

  /* "h5py/h5t.pyx":1169
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_member_type(self, int member):
 *         """(INT member) => TypeID
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1170
 * 
 *     @with_phil
 *     def get_member_type(self, int member):             # <<<<<<<<<<<<<<
 *         """(INT member) => TypeID
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID, __pyx_n_s_get_member_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID->tp_dict, __pyx_n_s_get_member_type, __pyx_t_4) < 0) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeCompoundID);

  /* "h5py/h5t.pyx":1181
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def insert(self, char* name, size_t offset, TypeID field not None):
 *         """(STRING name, UINT offset, TypeID field)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1182
 * 
 *     @with_phil
 *     def insert(self, char* name, size_t offset, TypeID field not None):             # <<<<<<<<<<<<<<
 *         """(STRING name, UINT offset, TypeID field)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID, __pyx_n_s_insert); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID->tp_dict, __pyx_n_s_insert, __pyx_t_4) < 0) __PYX_ERR(0, 1182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeCompoundID);

  /* "h5py/h5t.pyx":1192
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def pack(self):
 *         """()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1193
 * 
 *     @with_phil
 *     def pack(self):             # <<<<<<<<<<<<<<
 *         """()
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID, __pyx_n_s_pack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeCompoundID->tp_dict, __pyx_n_s_pack, __pyx_t_4) < 0) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeCompoundID);

  /* "h5py/h5t.pyx":1274
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def enum_insert(self, char* name, long long value):
 *         """(STRING name, INT/LONG value)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1275
 * 
 *     @with_phil
 *     def enum_insert(self, char* name, long long value):             # <<<<<<<<<<<<<<
 *         """(STRING name, INT/LONG value)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID, __pyx_n_s_enum_insert); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID->tp_dict, __pyx_n_s_enum_insert, __pyx_t_4) < 0) __PYX_ERR(0, 1275, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeEnumID);

  /* "h5py/h5t.pyx":1290
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def enum_nameof(self, long long value):
 *         """(LONG value) => STRING name
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1291
 * 
 *     @with_phil
 *     def enum_nameof(self, long long value):             # <<<<<<<<<<<<<<
 *         """(LONG value) => STRING name
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID, __pyx_n_s_enum_nameof); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID->tp_dict, __pyx_n_s_enum_nameof, __pyx_t_4) < 0) __PYX_ERR(0, 1291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeEnumID);

  /* "h5py/h5t.pyx":1310
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def enum_valueof(self, char* name):
 *         """(STRING name) => LONG value
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1311
 * 
 *     @with_phil
 *     def enum_valueof(self, char* name):             # <<<<<<<<<<<<<<
 *         """(STRING name) => LONG value
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID, __pyx_n_s_enum_valueof); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID->tp_dict, __pyx_n_s_enum_valueof, __pyx_t_4) < 0) __PYX_ERR(0, 1311, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeEnumID);

  /* "h5py/h5t.pyx":1323
 * 
 * 
 *     @with_phil             # <<<<<<<<<<<<<<
 *     def get_member_value(self, int idx):
 *         """(UINT index) => LONG value
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1324
 * 
 *     @with_phil
 *     def get_member_value(self, int idx):             # <<<<<<<<<<<<<<
 *         """(UINT index) => LONG value
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID, __pyx_n_s_get_member_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4h5py_3h5t_TypeEnumID->tp_dict, __pyx_n_s_get_member_value, __pyx_t_4) < 0) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_4h5py_3h5t_TypeEnumID);

  /* "h5py/h5t.pyx":1380
 * # transient and unlocked.
 * 
 * def _get_float_dtype_to_hdf5():             # <<<<<<<<<<<<<<
 *     float_le = {}
 *     float_be = {}
 */
  __pyx_t_4 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_15_get_float_dtype_to_hdf5, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_float_dtype_to_hdf5, __pyx_t_4) < 0) __PYX_ERR(0, 1380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "h5py/h5t.pyx":1411
 * cdef dict _float_be
 * cdef dict _float_nt
 * _float_le, _float_be, _float_nt = _get_float_dtype_to_hdf5()             # <<<<<<<<<<<<<<
 * 
 * cdef dict _int_le = {1: H5Tcopy(H5T_STD_I8LE), 2: H5Tcopy(H5T_STD_I16LE), 4: H5Tcopy(H5T_STD_I32LE), 8: H5Tcopy(H5T_STD_I64LE)}
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_get_float_dtype_to_hdf5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1411, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_7 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_7);
    #else
    __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_8 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
    index = 0; __pyx_t_4 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    index = 1; __pyx_t_1 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 2; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 3) < 0) __PYX_ERR(0, 1411, __pyx_L1_error)
    __pyx_t_9 = NULL;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_9 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1411, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(PyDict_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 1411, __pyx_L1_error)
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 1411, __pyx_L1_error)
  if (!(likely(PyDict_CheckExact(__pyx_t_7))||((__pyx_t_7) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_7)->tp_name), 0))) __PYX_ERR(0, 1411, __pyx_L1_error)
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__float_le);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__float_le, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__float_be);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__float_be, ((PyObject*)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__float_nt);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__float_nt, ((PyObject*)__pyx_t_7));
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "h5py/h5t.pyx":1413
 * _float_le, _float_be, _float_nt = _get_float_dtype_to_hdf5()
 * 
 * cdef dict _int_le = {1: H5Tcopy(H5T_STD_I8LE), 2: H5Tcopy(H5T_STD_I16LE), 4: H5Tcopy(H5T_STD_I32LE), 8: H5Tcopy(H5T_STD_I64LE)}             # <<<<<<<<<<<<<<
 * cdef dict _int_be = {1: H5Tcopy(H5T_STD_I8BE), 2: H5Tcopy(H5T_STD_I16BE), 4: H5Tcopy(H5T_STD_I32BE), 8: H5Tcopy(H5T_STD_I64BE)}
 * cdef dict _int_nt = {1: H5Tcopy(H5T_NATIVE_INT8), 2: H5Tcopy(H5T_NATIVE_INT16), 4: H5Tcopy(H5T_NATIVE_INT32), 8: H5Tcopy(H5T_NATIVE_INT64)}
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_I8LE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1413, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_1, __pyx_t_7) < 0) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_I16LE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1413, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_2, __pyx_t_7) < 0) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_I32LE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1413, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_4, __pyx_t_7) < 0) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_I64LE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1413, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_8, __pyx_t_7) < 0) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__int_le);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__int_le, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1414
 * 
 * cdef dict _int_le = {1: H5Tcopy(H5T_STD_I8LE), 2: H5Tcopy(H5T_STD_I16LE), 4: H5Tcopy(H5T_STD_I32LE), 8: H5Tcopy(H5T_STD_I64LE)}
 * cdef dict _int_be = {1: H5Tcopy(H5T_STD_I8BE), 2: H5Tcopy(H5T_STD_I16BE), 4: H5Tcopy(H5T_STD_I32BE), 8: H5Tcopy(H5T_STD_I64BE)}             # <<<<<<<<<<<<<<
 * cdef dict _int_nt = {1: H5Tcopy(H5T_NATIVE_INT8), 2: H5Tcopy(H5T_NATIVE_INT16), 4: H5Tcopy(H5T_NATIVE_INT32), 8: H5Tcopy(H5T_NATIVE_INT64)}
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_I8BE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1414, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_1, __pyx_t_7) < 0) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_I16BE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1414, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_2, __pyx_t_7) < 0) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_I32BE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1414, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_4, __pyx_t_7) < 0) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_I64BE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1414, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_8, __pyx_t_7) < 0) __PYX_ERR(0, 1414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__int_be);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__int_be, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1415
 * cdef dict _int_le = {1: H5Tcopy(H5T_STD_I8LE), 2: H5Tcopy(H5T_STD_I16LE), 4: H5Tcopy(H5T_STD_I32LE), 8: H5Tcopy(H5T_STD_I64LE)}
 * cdef dict _int_be = {1: H5Tcopy(H5T_STD_I8BE), 2: H5Tcopy(H5T_STD_I16BE), 4: H5Tcopy(H5T_STD_I32BE), 8: H5Tcopy(H5T_STD_I64BE)}
 * cdef dict _int_nt = {1: H5Tcopy(H5T_NATIVE_INT8), 2: H5Tcopy(H5T_NATIVE_INT16), 4: H5Tcopy(H5T_NATIVE_INT32), 8: H5Tcopy(H5T_NATIVE_INT64)}             # <<<<<<<<<<<<<<
 * 
 * cdef dict _uint_le = {1: H5Tcopy(H5T_STD_U8LE), 2: H5Tcopy(H5T_STD_U16LE), 4: H5Tcopy(H5T_STD_U32LE), 8: H5Tcopy(H5T_STD_U64LE)}
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_NATIVE_INT8); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1415, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_1, __pyx_t_7) < 0) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_NATIVE_INT16); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1415, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_2, __pyx_t_7) < 0) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_NATIVE_INT32); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1415, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_4, __pyx_t_7) < 0) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_NATIVE_INT64); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1415, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_8, __pyx_t_7) < 0) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__int_nt);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__int_nt, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1417
 * cdef dict _int_nt = {1: H5Tcopy(H5T_NATIVE_INT8), 2: H5Tcopy(H5T_NATIVE_INT16), 4: H5Tcopy(H5T_NATIVE_INT32), 8: H5Tcopy(H5T_NATIVE_INT64)}
 * 
 * cdef dict _uint_le = {1: H5Tcopy(H5T_STD_U8LE), 2: H5Tcopy(H5T_STD_U16LE), 4: H5Tcopy(H5T_STD_U32LE), 8: H5Tcopy(H5T_STD_U64LE)}             # <<<<<<<<<<<<<<
 * cdef dict _uint_be = {1: H5Tcopy(H5T_STD_U8BE), 2: H5Tcopy(H5T_STD_U16BE), 4: H5Tcopy(H5T_STD_U32BE), 8: H5Tcopy(H5T_STD_U64BE)}
 * cdef dict _uint_nt = {1: H5Tcopy(H5T_NATIVE_UINT8), 2: H5Tcopy(H5T_NATIVE_UINT16), 4: H5Tcopy(H5T_NATIVE_UINT32), 8: H5Tcopy(H5T_NATIVE_UINT64)}
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_U8LE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1417, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_1, __pyx_t_7) < 0) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_U16LE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1417, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_2, __pyx_t_7) < 0) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_U32LE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1417, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_4, __pyx_t_7) < 0) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_U64LE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1417, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_8, __pyx_t_7) < 0) __PYX_ERR(0, 1417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__uint_le);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__uint_le, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1418
 * 
 * cdef dict _uint_le = {1: H5Tcopy(H5T_STD_U8LE), 2: H5Tcopy(H5T_STD_U16LE), 4: H5Tcopy(H5T_STD_U32LE), 8: H5Tcopy(H5T_STD_U64LE)}
 * cdef dict _uint_be = {1: H5Tcopy(H5T_STD_U8BE), 2: H5Tcopy(H5T_STD_U16BE), 4: H5Tcopy(H5T_STD_U32BE), 8: H5Tcopy(H5T_STD_U64BE)}             # <<<<<<<<<<<<<<
 * cdef dict _uint_nt = {1: H5Tcopy(H5T_NATIVE_UINT8), 2: H5Tcopy(H5T_NATIVE_UINT16), 4: H5Tcopy(H5T_NATIVE_UINT32), 8: H5Tcopy(H5T_NATIVE_UINT64)}
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_U8BE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1418, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_1, __pyx_t_7) < 0) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_U16BE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1418, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_2, __pyx_t_7) < 0) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_U32BE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1418, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_4, __pyx_t_7) < 0) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_STD_U64BE); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1418, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_8, __pyx_t_7) < 0) __PYX_ERR(0, 1418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__uint_be);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__uint_be, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1419
 * cdef dict _uint_le = {1: H5Tcopy(H5T_STD_U8LE), 2: H5Tcopy(H5T_STD_U16LE), 4: H5Tcopy(H5T_STD_U32LE), 8: H5Tcopy(H5T_STD_U64LE)}
 * cdef dict _uint_be = {1: H5Tcopy(H5T_STD_U8BE), 2: H5Tcopy(H5T_STD_U16BE), 4: H5Tcopy(H5T_STD_U32BE), 8: H5Tcopy(H5T_STD_U64BE)}
 * cdef dict _uint_nt = {1: H5Tcopy(H5T_NATIVE_UINT8), 2: H5Tcopy(H5T_NATIVE_UINT16), 4: H5Tcopy(H5T_NATIVE_UINT32), 8: H5Tcopy(H5T_NATIVE_UINT64)}             # <<<<<<<<<<<<<<
 * 
 * cdef TypeFloatID _c_float(cnp.dtype dt):
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_NATIVE_UINT8); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1419, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_1, __pyx_t_7) < 0) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_NATIVE_UINT16); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1419, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_2, __pyx_t_7) < 0) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_NATIVE_UINT32); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1419, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_4, __pyx_t_7) < 0) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __pyx_f_4h5py_4defs_H5Tcopy(H5T_NATIVE_UINT64); if (unlikely(__pyx_t_5 == ((hid_t)((hid_t)-1L)))) __PYX_ERR(0, 1419, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_hid_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_8, __pyx_t_7) < 0) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_4h5py_3h5t__uint_nt);
  __Pyx_DECREF_SET(__pyx_v_4h5py_3h5t__uint_nt, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1755
 *             raise TypeError("No conversion path for dtype: %s" % repr(dt))
 * 
 * def vlen_dtype(basetype):             # <<<<<<<<<<<<<<
 *     """Make a numpy dtype for an HDF5 variable-length datatype
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_19vlen_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_vlen_dtype, __pyx_t_2) < 0) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1762
 *     return np.dtype('O', metadata={'vlen': basetype})
 * 
 * def string_dtype(encoding='utf-8', length=None):             # <<<<<<<<<<<<<<
 *     """Make a numpy dtype for HDF5 strings
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_21string_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_string_dtype, __pyx_t_2) < 0) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1796
 *         raise TypeError("length must be integer or None (got %r)" % length)
 * 
 * def enum_dtype(values_dict, basetype=np.uint8):             # <<<<<<<<<<<<<<
 *     """Create a NumPy representation of an HDF5 enumerated type
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_uint8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_k__13 = __pyx_t_7;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_23enum_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_enum_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1796, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "h5py/h5t.pyx":1809
 * 
 * 
 * def opaque_dtype(np_dtype):             # <<<<<<<<<<<<<<
 *     """Return an equivalent dtype tagged to be stored in an HDF5 opaque type.
 * 
 */
  __pyx_t_7 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_25opaque_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_opaque_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1809, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "h5py/h5t.pyx":1829
 * 
 * 
 * ref_dtype = np.dtype('O', metadata={'ref': Reference})             # <<<<<<<<<<<<<<
 * regionref_dtype = np.dtype('O', metadata={'ref': RegionReference})
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ref, ((PyObject *)__pyx_ptype_4h5py_3h5r_Reference)) < 0) __PYX_ERR(0, 1829, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_metadata, __pyx_t_1) < 0) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__12, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ref_dtype, __pyx_t_1) < 0) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1830
 * 
 * ref_dtype = np.dtype('O', metadata={'ref': Reference})
 * regionref_dtype = np.dtype('O', metadata={'ref': RegionReference})             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dtype); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_ref, ((PyObject *)__pyx_ptype_4h5py_3h5r_RegionReference)) < 0) __PYX_ERR(0, 1830, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_metadata, __pyx_t_2) < 0) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__12, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_regionref_dtype, __pyx_t_2) < 0) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "h5py/h5t.pyx":1833
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def special_dtype(**kwds):
 *     """ Create a new h5py "special" type.  Only one keyword may be given.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1834
 * 
 * @with_phil
 * def special_dtype(**kwds):             # <<<<<<<<<<<<<<
 *     """ Create a new h5py "special" type.  Only one keyword may be given.
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_27special_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "h5py/h5t.pyx":1833
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def special_dtype(**kwds):
 *     """ Create a new h5py "special" type.  Only one keyword may be given.
 */
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_special_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "h5py/h5t.pyx":1877
 * 
 * 
 * def check_vlen_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 vlen, returns the Python base class.
 * 
 */
  __pyx_t_7 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_29check_vlen_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_check_vlen_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1877, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "h5py/h5t.pyx":1887
 *         return None
 * 
 * string_info = namedtuple('string_info', ['encoding', 'length'])             # <<<<<<<<<<<<<<
 * 
 * def check_string_dtype(dt):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_namedtuple); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_encoding);
  __Pyx_GIVEREF(__pyx_n_u_encoding);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_encoding);
  __Pyx_INCREF(__pyx_n_u_length);
  __Pyx_GIVEREF(__pyx_n_u_length);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_length);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_string_info);
  __Pyx_GIVEREF(__pyx_n_u_string_info);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_string_info);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_string_info, __pyx_t_1) < 0) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1889
 * string_info = namedtuple('string_info', ['encoding', 'length'])
 * 
 * def check_string_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 string, returns a string_info object.
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_31check_string_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_check_string_dtype, __pyx_t_1) < 0) __PYX_ERR(0, 1889, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1909
 *         return None
 * 
 * def check_enum_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 enumerated type, returns the dictionary
 *     mapping string names to integer values.
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_33check_enum_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_check_enum_dtype, __pyx_t_1) < 0) __PYX_ERR(0, 1909, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1920
 *         return None
 * 
 * def check_opaque_dtype(dt):             # <<<<<<<<<<<<<<
 *     """Return True if the dtype given is tagged to be stored as HDF5 opaque data
 *     """
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_35check_opaque_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_check_opaque_dtype, __pyx_t_1) < 0) __PYX_ERR(0, 1920, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1928
 *         return False
 * 
 * def check_ref_dtype(dt):             # <<<<<<<<<<<<<<
 *     """If the dtype represents an HDF5 reference type, returns the reference
 *     class (either Reference or RegionReference).
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_37check_ref_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_check_ref_dtype, __pyx_t_1) < 0) __PYX_ERR(0, 1928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":1939
 *         return None
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def check_dtype(**kwds):
 *     """ Check a dtype for h5py special type "hint" information.  Only one
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "h5py/h5t.pyx":1940
 * 
 * @with_phil
 * def check_dtype(**kwds):             # <<<<<<<<<<<<<<
 *     """ Check a dtype for h5py special type "hint" information.  Only one
 *     keyword may be given.
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_39check_dtype, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1939
 *         return None
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def check_dtype(**kwds):
 *     """ Check a dtype for h5py special type "hint" information.  Only one
 */
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_check_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "h5py/h5t.pyx":1976
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def convert(TypeID src not None, TypeID dst not None, size_t n,
 *             cnp.ndarray buf not None, cnp.ndarray bkg=None, ObjectID dxpl=None):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "h5py/h5t.pyx":1977
 * 
 * @with_phil
 * def convert(TypeID src not None, TypeID dst not None, size_t n,             # <<<<<<<<<<<<<<
 *             cnp.ndarray buf not None, cnp.ndarray bkg=None, ObjectID dxpl=None):
 *     """ (TypeID src, TypeID dst, UINT n, NDARRAY buf, NDARRAY bkg=None,
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_41convert, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":1976
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def convert(TypeID src not None, TypeID dst not None, size_t n,
 *             cnp.ndarray buf not None, cnp.ndarray bkg=None, ObjectID dxpl=None):
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_convert, __pyx_t_1) < 0) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "h5py/h5t.pyx":2000
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def find(TypeID src not None, TypeID dst not None):
 *     """ (TypeID src, TypeID dst) => TUPLE or None
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_with_phil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "h5py/h5t.pyx":2001
 * 
 * @with_phil
 * def find(TypeID src not None, TypeID dst not None):             # <<<<<<<<<<<<<<
 *     """ (TypeID src, TypeID dst) => TUPLE or None
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_4h5py_3h5t_43find, NULL, __pyx_n_s_h5py_h5t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "h5py/h5t.pyx":2000
 * 
 * 
 * @with_phil             # <<<<<<<<<<<<<<
 * def find(TypeID src not None, TypeID dst not None):
 *     """ (TypeID src, TypeID dst) => TUPLE or None
 */
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_find, __pyx_t_7) < 0) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "h5py/h5t.pyx":1
 * # cython: language_level=3             # <<<<<<<<<<<<<<
 * # This file is part of h5py, a Python interface to the HDF5 library.
 * #
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1013
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init h5py.h5t", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init h5py.h5t");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (__Pyx_PyFastCFunction_Check(func)) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* unicode_iter */
static CYTHON_INLINE int __Pyx_init_unicode_iteration(
    PyObject* ustring, Py_ssize_t *length, void** data, int *kind) {
#if CYTHON_PEP393_ENABLED
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return -1;
    *kind   = PyUnicode_KIND(ustring);
    *length = PyUnicode_GET_LENGTH(ustring);
    *data   = PyUnicode_DATA(ustring);
#else
    *kind   = 0;
    *length = PyUnicode_GET_SIZE(ustring);
    *data   = (void*)PyUnicode_AS_UNICODE(ustring);
#endif
    return 0;
}

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_FALSE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* bytes_tailmatch */
static int __Pyx_PyBytes_SingleTailmatch(PyObject* self, PyObject* arg,
                                         Py_ssize_t start, Py_ssize_t end, int direction) {
    const char* self_ptr = PyBytes_AS_STRING(self);
    Py_ssize_t self_len = PyBytes_GET_SIZE(self);
    const char* sub_ptr;
    Py_ssize_t sub_len;
    int retval;
    Py_buffer view;
    view.obj = NULL;
    if ( PyBytes_Check(arg) ) {
        sub_ptr = PyBytes_AS_STRING(arg);
        sub_len = PyBytes_GET_SIZE(arg);
    }
#if PY_MAJOR_VERSION < 3
    else if ( PyUnicode_Check(arg) ) {
        return (int) PyUnicode_Tailmatch(self, arg, start, end, direction);
    }
#endif
    else {
        if (unlikely(PyObject_GetBuffer(self, &view, PyBUF_SIMPLE) == -1))
            return -1;
        sub_ptr = (const char*) view.buf;
        sub_len = view.len;
    }
    if (end > self_len)
        end = self_len;
    else if (end < 0)
        end += self_len;
    if (end < 0)
        end = 0;
    if (start < 0)
        start += self_len;
    if (start < 0)
        start = 0;
    if (direction > 0) {
        if (end-sub_len > start)
            start = end - sub_len;
    }
    if (start + sub_len <= end)
        retval = !memcmp(self_ptr+start, sub_ptr, (size_t)sub_len);
    else
        retval = 0;
    if (view.obj)
        PyBuffer_Release(&view);
    return retval;
}
static int __Pyx_PyBytes_TailmatchTuple(PyObject* self, PyObject* substrings,
                                        Py_ssize_t start, Py_ssize_t end, int direction) {
    Py_ssize_t i, count = PyTuple_GET_SIZE(substrings);
    for (i = 0; i < count; i++) {
        int result;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        result = __Pyx_PyBytes_SingleTailmatch(self, PyTuple_GET_ITEM(substrings, i),
                                               start, end, direction);
#else
        PyObject* sub = PySequence_ITEM(substrings, i);
        if (unlikely(!sub)) return -1;
        result = __Pyx_PyBytes_SingleTailmatch(self, sub, start, end, direction);
        Py_DECREF(sub);
#endif
        if (result) {
            return result;
        }
    }
    return 0;
}
static int __Pyx_PyBytes_Tailmatch(PyObject* self, PyObject* substr,
                                   Py_ssize_t start, Py_ssize_t end, int direction) {
    if (unlikely(PyTuple_Check(substr))) {
        return __Pyx_PyBytes_TailmatchTuple(self, substr, start, end, direction);
    }
    return __Pyx_PyBytes_SingleTailmatch(self, substr, start, end, direction);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* PyNumberPow2 */
static PyObject* __Pyx__PyNumber_PowerOf2(PyObject *two, PyObject *exp, PyObject *none, int inplace) {
#if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t shiftby;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(exp))) {
        shiftby = PyInt_AS_LONG(exp);
    } else
#endif
    if (likely(PyLong_CheckExact(exp))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        const Py_ssize_t size = Py_SIZE(exp);
        if (likely(size == 1)) {
            shiftby = ((PyLongObject*)exp)->ob_digit[0];
        } else if (size == 0) {
            return PyInt_FromLong(1L);
        } else if (unlikely(size < 0)) {
            goto fallback;
        } else {
            shiftby = PyLong_AsSsize_t(exp);
        }
        #else
        shiftby = PyLong_AsSsize_t(exp);
        #endif
    } else {
        goto fallback;
    }
    if (likely(shiftby >= 0)) {
        if ((size_t)shiftby <= sizeof(long) * 8 - 2) {
            long value = 1L << shiftby;
            return PyInt_FromLong(value);
#ifdef HAVE_LONG_LONG
        } else if ((size_t)shiftby <= sizeof(unsigned PY_LONG_LONG) * 8 - 1) {
            unsigned PY_LONG_LONG value = ((unsigned PY_LONG_LONG)1) << shiftby;
            return PyLong_FromUnsignedLongLong(value);
#endif
        } else {
            PyObject *result, *one = PyInt_FromLong(1L);
            if (unlikely(!one)) return NULL;
            result = PyNumber_Lshift(one, exp);
            Py_DECREF(one);
            return result;
        }
    } else if (shiftby == -1 && PyErr_Occurred()) {
        PyErr_Clear();
    }
fallback:
#endif
    return (inplace ? PyNumber_InPlacePower : PyNumber_Power)(two, exp, none);
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractCObj(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        const long a = intval;
        long x;
        long b = PyInt_AS_LONG(op2);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op2))) {
        const long a = intval;
        long b, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG lla = intval;
        PY_LONG_LONG llb, llx;
#endif
        const digit* digits = ((PyLongObject*)op2)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op2);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            b = likely(size) ? digits[0] : 0;
            if (size == -1) b = -b;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op2)) {
        const long a = intval;
        double b = PyFloat_AS_DOUBLE(op2);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = Py_TYPE(iter)->tp_iternext;
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* None */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunctionShared */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
#if PY_MAJOR_VERSION < 3
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
#endif
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyString_CheckExact(s))) {
        PyObject *result = PyUnicode_FromEncodedObject(s, NULL, "strict");
        Py_DECREF(s);
        return result;
    }
    #endif
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      CYTHON_UNUSED Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind;
    Py_ssize_t i, char_pos;
    void *result_udata;
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely(char_pos + ulength < 0))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + char_pos * result_ukind, udata, (size_t) (ulength * result_ukind));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    result_ulength++;
    value_count++;
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* UnpackUnboundCMethod */
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    }
#endif
    return 0;
}

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_dealloc != current_tp_dealloc)
        type = type->tp_base;
    while (type && type->tp_dealloc == current_tp_dealloc)
        type = type->tp_base;
    if (type)
        type->tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_traverse != current_tp_traverse)
        type = type->tp_base;
    while (type && type->tp_traverse == current_tp_traverse)
        type = type->tp_base;
    if (type && type->tp_traverse)
        return type->tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_clear != current_tp_clear)
        type = type->tp_base;
    while (type && type->tp_clear == current_tp_clear)
        type = type->tp_base;
    if (type && type->tp_clear)
        type->tp_clear(obj);
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* GetNameInClass */
static PyObject *__Pyx_GetGlobalNameAfterAttributeLookup(PyObject *name) {
    PyObject *result;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    result = __Pyx_PyObject_GetAttrStr(nmspace, name);
    if (!result) {
        result = __Pyx_GetGlobalNameAfterAttributeLookup(name);
    }
    return result;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* Declarations */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = (float)(1.0) / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = (float)(1.0) / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = (double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = (double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* CIntFromPy */
static CYTHON_INLINE hid_t __Pyx_PyInt_As_hid_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const hid_t neg_one = (hid_t) -1, const_zero = (hid_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(hid_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(hid_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (hid_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (hid_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(hid_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(hid_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) >= 2 * PyLong_SHIFT) {
                            return (hid_t) (((((hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(hid_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) >= 3 * PyLong_SHIFT) {
                            return (hid_t) (((((((hid_t)digits[2]) << PyLong_SHIFT) | (hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(hid_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) >= 4 * PyLong_SHIFT) {
                            return (hid_t) (((((((((hid_t)digits[3]) << PyLong_SHIFT) | (hid_t)digits[2]) << PyLong_SHIFT) | (hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (hid_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(hid_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(hid_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(hid_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(hid_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (hid_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(hid_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(hid_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(hid_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) - 1 > 2 * PyLong_SHIFT) {
                            return (hid_t) (((hid_t)-1)*(((((hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(hid_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) - 1 > 2 * PyLong_SHIFT) {
                            return (hid_t) ((((((hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(hid_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) - 1 > 3 * PyLong_SHIFT) {
                            return (hid_t) (((hid_t)-1)*(((((((hid_t)digits[2]) << PyLong_SHIFT) | (hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(hid_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) - 1 > 3 * PyLong_SHIFT) {
                            return (hid_t) ((((((((hid_t)digits[2]) << PyLong_SHIFT) | (hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(hid_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) - 1 > 4 * PyLong_SHIFT) {
                            return (hid_t) (((hid_t)-1)*(((((((((hid_t)digits[3]) << PyLong_SHIFT) | (hid_t)digits[2]) << PyLong_SHIFT) | (hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(hid_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(hid_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(hid_t) - 1 > 4 * PyLong_SHIFT) {
                            return (hid_t) ((((((((((hid_t)digits[3]) << PyLong_SHIFT) | (hid_t)digits[2]) << PyLong_SHIFT) | (hid_t)digits[1]) << PyLong_SHIFT) | (hid_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(hid_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(hid_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(hid_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(hid_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            hid_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (hid_t) -1;
        }
    } else {
        hid_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (hid_t) -1;
        val = __Pyx_PyInt_As_hid_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to hid_t");
    return (hid_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to hid_t");
    return (hid_t) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__H5T_class_t(enum H5T_class_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const enum H5T_class_t neg_one = (enum H5T_class_t) -1, const_zero = (enum H5T_class_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum H5T_class_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum H5T_class_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum H5T_class_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum H5T_class_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum H5T_class_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum H5T_class_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_sign_t(H5T_sign_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const H5T_sign_t neg_one = (H5T_sign_t) -1, const_zero = (H5T_sign_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(H5T_sign_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(H5T_sign_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_sign_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(H5T_sign_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_sign_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(H5T_sign_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_order_t(H5T_order_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const H5T_order_t neg_one = (H5T_order_t) -1, const_zero = (H5T_order_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(H5T_order_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(H5T_order_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_order_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(H5T_order_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_order_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(H5T_order_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__H5T_direction_t(enum H5T_direction_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const enum H5T_direction_t neg_one = (enum H5T_direction_t) -1, const_zero = (enum H5T_direction_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum H5T_direction_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum H5T_direction_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum H5T_direction_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum H5T_direction_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum H5T_direction_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum H5T_direction_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_str_t(H5T_str_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const H5T_str_t neg_one = (H5T_str_t) -1, const_zero = (H5T_str_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(H5T_str_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(H5T_str_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_str_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(H5T_str_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_str_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(H5T_str_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_norm_t(H5T_norm_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const H5T_norm_t neg_one = (H5T_norm_t) -1, const_zero = (H5T_norm_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(H5T_norm_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(H5T_norm_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_norm_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(H5T_norm_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_norm_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(H5T_norm_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_cset_t(H5T_cset_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const H5T_cset_t neg_one = (H5T_cset_t) -1, const_zero = (H5T_cset_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(H5T_cset_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(H5T_cset_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_cset_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(H5T_cset_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_cset_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(H5T_cset_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_pad_t(H5T_pad_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const H5T_pad_t neg_one = (H5T_pad_t) -1, const_zero = (H5T_pad_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(H5T_pad_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(H5T_pad_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_pad_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(H5T_pad_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_pad_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(H5T_pad_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_H5T_bkg_t(H5T_bkg_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const H5T_bkg_t neg_one = (H5T_bkg_t) -1, const_zero = (H5T_bkg_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(H5T_bkg_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(H5T_bkg_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_bkg_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(H5T_bkg_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(H5T_bkg_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(H5T_bkg_t),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(size_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(size_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 2 * PyLong_SHIFT) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 3 * PyLong_SHIFT) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 4 * PyLong_SHIFT) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(size_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(size_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(size_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(size_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntFromPy */
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_As_PY_LONG_LONG(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PY_LONG_LONG neg_one = (PY_LONG_LONG) -1, const_zero = (PY_LONG_LONG) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(PY_LONG_LONG) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (PY_LONG_LONG) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (PY_LONG_LONG) 0;
                case  1: __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, digit, digits[0])
                case 2:
                    if (8 * sizeof(PY_LONG_LONG) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) >= 2 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) (((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(PY_LONG_LONG) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) >= 3 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) (((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(PY_LONG_LONG) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) >= 4 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) (((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (PY_LONG_LONG) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(PY_LONG_LONG) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(PY_LONG_LONG) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (PY_LONG_LONG) 0;
                case -1: __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(PY_LONG_LONG,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(PY_LONG_LONG) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(PY_LONG_LONG) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) ((((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(PY_LONG_LONG) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) ((((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(PY_LONG_LONG) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                            return (PY_LONG_LONG) ((((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(PY_LONG_LONG) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(PY_LONG_LONG) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            PY_LONG_LONG val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (PY_LONG_LONG) -1;
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (PY_LONG_LONG) -1;
        val = __Pyx_PyInt_As_PY_LONG_LONG(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to PY_LONG_LONG");
    return (PY_LONG_LONG) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to PY_LONG_LONG");
    return (PY_LONG_LONG) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_hid_t(hid_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const hid_t neg_one = (hid_t) -1, const_zero = (hid_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(hid_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(hid_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(hid_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(hid_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(hid_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(hid_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_hsize_t(hsize_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const hsize_t neg_one = (hsize_t) -1, const_zero = (hsize_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(hsize_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(hsize_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(hsize_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(hsize_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(hsize_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(hsize_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_PY_LONG_LONG(PY_LONG_LONG value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PY_LONG_LONG neg_one = (PY_LONG_LONG) -1, const_zero = (PY_LONG_LONG) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(PY_LONG_LONG) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(PY_LONG_LONG) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(PY_LONG_LONG) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(PY_LONG_LONG) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(PY_LONG_LONG) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(PY_LONG_LONG),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_char(char value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const char neg_one = (char) -1, const_zero = (char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(char) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(char) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(char) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(char) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(char) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(char),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[5];
    int same=1, i, found_dot;
    const char* rt_from_call = Py_GetVersion();
    PyOS_snprintf(ctversion, 5, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    found_dot = 0;
    for (i = 0; i < 4; i++) {
        if (!ctversion[i]) {
            same = (rt_from_call[i] < '0' || rt_from_call[i] > '9');
            break;
        }
        if (rt_from_call[i] != ctversion[i]) {
            same = 0;
            break;
        }
    }
    if (!same) {
        char rtversion[5] = {'\0'};
        char message[200];
        for (i=0; i<4; ++i) {
            if (rt_from_call[i] == '.') {
                if (found_dot) break;
                found_dot = 1;
            } else if (rt_from_call[i] < '0' || rt_from_call[i] > '9') {
                break;
            }
            rtversion[i] = rt_from_call[i];
        }
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* VoidPtrExport */
static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig) {
    PyObject *d;
    PyObject *cobj = 0;
    d = PyDict_GetItem(__pyx_d, __pyx_n_s_pyx_capi);
    Py_XINCREF(d);
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (__Pyx_PyObject_SetAttrStr(__pyx_m, __pyx_n_s_pyx_capi, d) < 0)
            goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000
    cobj = PyCapsule_New(p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItem(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

/* FunctionExport */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
#if PY_VERSION_HEX >= 0x02070000
    cobj = PyCapsule_New(tmp.p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(tmp.p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction
#define __PYX_HAVE_RT_ImportFunction
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, funcname);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C function %.200s",
                PyModule_GetName(module), funcname);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    tmp.p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, desc);
        goto bad;
    }
    tmp.p = PyCObject_AsVoidPtr(cobj);}
#endif
    *f = tmp.fp;
    if (!(*f))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
