/* Generated by Cython 0.29.32 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "H5_USE_18_API",
                null
            ],
            [
                "NPY_NO_DEPRECATED_API",
                0
            ]
        ],
        "depends": [
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/arrayobject.h",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/arrayscalars.h",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/ndarrayobject.h",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/ndarraytypes.h",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include/numpy/ufuncobject.h",
            "h5py/api_compat.h",
            "lzf/lzf_filter.h"
        ],
        "include_dirs": [
            "./h5py",
            "lzf",
            "lzf/lzf",
            "/scratch/jenkins-BUILDS-eSDK-2024.1_stable-pipeline-build-179_ZynqFull/build/tmp/work/cortexa9t2hf-neon-xilinx-linux-gnueabi/python3-h5py/3.7.0-r0/recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/core/include"
        ],
        "libraries": [
            "hdf5",
            "hdf5_hl"
        ],
        "name": "h5py.defs",
        "sources": [
            "h5py/defs.pyx"
        ]
    },
    "module_name": "h5py.defs"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_32"
#define CYTHON_HEX_VERSION 0x001D20F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_HEX >= 0x07030900)
  #endif
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #if PY_VERSION_HEX >= 0x030B00A4
    #undef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 0
  #elif !defined(CYTHON_FAST_THREAD_STATE)
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL (PY_VERSION_HEX < 0x030A0000)
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #if PY_VERSION_HEX >= 0x030B00A4
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if PY_VERSION_HEX >= 0x030B00A1
    static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *kwds=NULL, *argcount=NULL, *posonlyargcount=NULL, *kwonlyargcount=NULL;
        PyObject *nlocals=NULL, *stacksize=NULL, *flags=NULL, *replace=NULL, *call_result=NULL, *empty=NULL;
        const char *fn_cstr=NULL;
        const char *name_cstr=NULL;
        PyCodeObject* co=NULL;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        if (!(kwds=PyDict_New())) goto end;
        if (!(argcount=PyLong_FromLong(a))) goto end;
        if (PyDict_SetItemString(kwds, "co_argcount", argcount) != 0) goto end;
        if (!(posonlyargcount=PyLong_FromLong(0))) goto end;
        if (PyDict_SetItemString(kwds, "co_posonlyargcount", posonlyargcount) != 0) goto end;
        if (!(kwonlyargcount=PyLong_FromLong(k))) goto end;
        if (PyDict_SetItemString(kwds, "co_kwonlyargcount", kwonlyargcount) != 0) goto end;
        if (!(nlocals=PyLong_FromLong(l))) goto end;
        if (PyDict_SetItemString(kwds, "co_nlocals", nlocals) != 0) goto end;
        if (!(stacksize=PyLong_FromLong(s))) goto end;
        if (PyDict_SetItemString(kwds, "co_stacksize", stacksize) != 0) goto end;
        if (!(flags=PyLong_FromLong(f))) goto end;
        if (PyDict_SetItemString(kwds, "co_flags", flags) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_code", code) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_consts", c) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_names", n) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_varnames", v) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_freevars", fv) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_cellvars", cell) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_linetable", lnos) != 0) goto end;
        if (!(fn_cstr=PyUnicode_AsUTF8AndSize(fn, NULL))) goto end;
        if (!(name_cstr=PyUnicode_AsUTF8AndSize(name, NULL))) goto end;
        if (!(co = PyCode_NewEmpty(fn_cstr, name_cstr, fline))) goto end;
        if (!(replace = PyObject_GetAttrString((PyObject*)co, "replace"))) goto cleanup_code_too;
        if (!(empty = PyTuple_New(0))) goto cleanup_code_too; // unfortunately __pyx_empty_tuple isn't available here
        if (!(call_result = PyObject_Call(replace, empty, kwds))) goto cleanup_code_too;
        Py_XDECREF((PyObject*)co);
        co = (PyCodeObject*)call_result;
        call_result = NULL;
        if (0) {
            cleanup_code_too:
            Py_XDECREF((PyObject*)co);
            co = NULL;
        }
        end:
        Py_XDECREF(kwds);
        Py_XDECREF(argcount);
        Py_XDECREF(posonlyargcount);
        Py_XDECREF(kwonlyargcount);
        Py_XDECREF(nlocals);
        Py_XDECREF(stacksize);
        Py_XDECREF(replace);
        Py_XDECREF(call_result);
        Py_XDECREF(empty);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return co;
    }
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if defined(PyUnicode_IS_READY)
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #else
  #define __Pyx_PyUnicode_READY(op)       (0)
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #endif
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__h5py__defs
#define __PYX_HAVE_API__h5py__defs
/* Early includes */
#include <string.h>
#include <stdlib.h>
#include <stddef.h>
#include <time.h>
#include <stdio.h>
#include "numpy/arrayobject.h"
#include "numpy/ndarrayobject.h"
#include "numpy/ndarraytypes.h"
#include "numpy/arrayscalars.h"
#include "numpy/ufuncobject.h"

    /* NumPy API declarations from "numpy/__init__.pxd" */
    
#include "unistd.h"
#include "api_compat.h"
#include "lzf_filter.h"
#include "H5Cpublic.h"
#include "hdf5.h"
#include "hdf5_hl.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "h5py/defs.pyx",
  "__init__.pxd",
  "type.pxd",
};
/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif


/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":689
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":690
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":691
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":692
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":696
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":697
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":698
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":699
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":703
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":704
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":713
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":714
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":715
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":717
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":718
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":719
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":721
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":722
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":724
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":725
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":726
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;

/* "api_types_ext.pxd":20
 * from libc.string cimport strlen, strchr, strcpy, strncpy, strcmp,\
 *                          strdup, strdup, memcpy, memset
 * ctypedef long size_t             # <<<<<<<<<<<<<<
 * from libc.time cimport time_t
 * 
 */
typedef long __pyx_t_4h5py_13api_types_ext_size_t;
/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);


/*--- Type declarations ---*/

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":728
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":729
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":730
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":732
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_t_4h5py_7_errors_err_cookie;
typedef struct __pyx_t_4h5py_7_errors_err_cookie __pyx_t_4h5py_7_errors_err_cookie;

/* "_errors.pxd":420
 * # --- Functions for managing the HDF5 error callback mechanism ---
 * 
 * ctypedef struct err_cookie:             # <<<<<<<<<<<<<<
 *     # Defines the error handler state (callback and callback data)
 *     H5E_auto_t func
 */
struct __pyx_t_4h5py_7_errors_err_cookie {
  H5E_auto_t func;
  void *data;
};

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* GCCDiagnostics.proto */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'libc.stddef' */

/* Module declarations from 'libc.time' */

/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_generic = 0;
static PyTypeObject *__pyx_ptype_5numpy_number = 0;
static PyTypeObject *__pyx_ptype_5numpy_integer = 0;
static PyTypeObject *__pyx_ptype_5numpy_signedinteger = 0;
static PyTypeObject *__pyx_ptype_5numpy_unsignedinteger = 0;
static PyTypeObject *__pyx_ptype_5numpy_inexact = 0;
static PyTypeObject *__pyx_ptype_5numpy_floating = 0;
static PyTypeObject *__pyx_ptype_5numpy_complexfloating = 0;
static PyTypeObject *__pyx_ptype_5numpy_flexible = 0;
static PyTypeObject *__pyx_ptype_5numpy_character = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;

/* Module declarations from 'h5py.api_types_ext' */

/* Module declarations from 'h5py.api_types_hdf5' */

/* Module declarations from 'h5py' */

/* Module declarations from 'h5py._hdf5' */

/* Module declarations from 'h5py._errors' */
static int (*__pyx_f_4h5py_7_errors_set_exception)(void); /*proto*/
static void (*__pyx_f_4h5py_7_errors_set_default_error_handler)(void); /*proto*/

/* Module declarations from 'h5py.defs' */
#define __Pyx_MODULE_NAME "h5py.defs"
extern int __pyx_module_is_main_h5py__defs;
int __pyx_module_is_main_h5py__defs = 0;

/* Implementation of 'h5py.defs' */
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_ImportError;
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_Unspecified_error_in_H5Aget_num[] = "Unspecified error in H5Aget_num_attrs (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aiterate[] = "Unspecified error in H5Aiterate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aopen_by[] = "Unspecified error in H5Aopen_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSattach[] = "Unspecified error in H5DSattach_scale (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSdetach[] = "Unspecified error in H5DSdetach_scale (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_num[] = "Unspecified error in H5Dget_num_chunks (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Diterate[] = "Unspecified error in H5Diterate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Drefresh[] = "Unspecified error in H5Drefresh (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_mdc[] = "Unspecified error in H5Fget_mdc_config (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_obj[] = "Unspecified error in H5Fget_obj_count (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_vfd[] = "Unspecified error in H5Fget_vfd_handle (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fis_hdf5[] = "Unspecified error in H5Fis_hdf5 (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fset_mdc[] = "Unspecified error in H5Fset_mdc_config (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Funmount[] = "Unspecified error in H5Funmount (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_num[] = "Unspecified error in H5Gget_num_objs (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Giterate[] = "Unspecified error in H5Giterate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Idec_ref[] = "Unspecified error in H5Idec_ref (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Iget_ref[] = "Unspecified error in H5Iget_ref (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Iinc_ref[] = "Unspecified error in H5Iinc_ref (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lget_val[] = "Unspecified error in H5Lget_val (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Literate[] = "Unspecified error in H5Literate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oopen_by[] = "Unspecified error in H5Oopen_by_addr (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5PLappend[] = "Unspecified error in H5PLappend (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5PLinsert[] = "Unspecified error in H5PLinsert (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5PLremove[] = "Unspecified error in H5PLremove (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_edc[] = "Unspecified error in H5Pget_edc_check (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_est[] = "Unspecified error in H5Pget_est_link_info (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_mdc[] = "Unspecified error in H5Pget_mdc_config (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_obj[] = "Unspecified error in H5Pget_obj_track_times (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_sym[] = "Unspecified error in H5Pget_sym_k (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_edc[] = "Unspecified error in H5Pset_edc_check (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_est[] = "Unspecified error in H5Pset_est_link_info (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_mdc[] = "Unspecified error in H5Pset_mdc_config (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_obj[] = "Unspecified error in H5Pset_obj_track_times (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_sym[] = "Unspecified error in H5Pset_sym_k (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Rget_obj[] = "Unspecified error in H5Rget_obj_type (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tconvert[] = "Unspecified error in H5Tconvert (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_pad[] = "Unspecified error in H5Tget_pad (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_tag[] = "Unspecified error in H5Tget_tag (return value ==NULL)";
static const char __pyx_k_Unspecified_error_in_H5Tset_pad[] = "Unspecified error in H5Tset_pad (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_tag[] = "Unspecified error in H5Tset_tag (return value <0)";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_Unspecified_error_in_H5Aclose_re[] = "Unspecified error in H5Aclose (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Acreate_b[] = "Unspecified error in H5Acreate_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Acreate_r[] = "Unspecified error in H5Acreate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Adelete_b[] = "Unspecified error in H5Adelete_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Adelete_r[] = "Unspecified error in H5Adelete (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aexists_b[] = "Unspecified error in H5Aexists_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aexists_r[] = "Unspecified error in H5Aexists (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aget_info[] = "Unspecified error in H5Aget_info (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aget_name[] = "Unspecified error in H5Aget_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aget_spac[] = "Unspecified error in H5Aget_space (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aget_stor[] = "Unspecified error in H5Aget_storage_size (return value ==0)";
static const char __pyx_k_Unspecified_error_in_H5Aget_type[] = "Unspecified error in H5Aget_type (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aopen_idx[] = "Unspecified error in H5Aopen_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aopen_nam[] = "Unspecified error in H5Aopen_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aopen_ret[] = "Unspecified error in H5Aopen (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aread_ret[] = "Unspecified error in H5Aread (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Arename_b[] = "Unspecified error in H5Arename_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Arename_r[] = "Unspecified error in H5Arename (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Awrite_re[] = "Unspecified error in H5Awrite (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DOread_ch[] = "Unspecified error in H5DOread_chunk (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DOwrite_c[] = "Unspecified error in H5DOwrite_chunk (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSget_lab[] = "Unspecified error in H5DSget_label (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSget_num[] = "Unspecified error in H5DSget_num_scales (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSget_sca[] = "Unspecified error in H5DSget_scale_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSis_atta[] = "Unspecified error in H5DSis_attached (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSis_scal[] = "Unspecified error in H5DSis_scale (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSiterate[] = "Unspecified error in H5DSiterate_scales (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSset_lab[] = "Unspecified error in H5DSset_label (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5DSset_sca[] = "Unspecified error in H5DSset_scale (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dclose_re[] = "Unspecified error in H5Dclose (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dcreate_a[] = "Unspecified error in H5Dcreate_anon (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dcreate_r[] = "Unspecified error in H5Dcreate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dextend_r[] = "Unspecified error in H5Dextend (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dfill_ret[] = "Unspecified error in H5Dfill (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dflush_re[] = "Unspecified error in H5Dflush (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_acce[] = "Unspecified error in H5Dget_access_plist (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_chun[] = "Unspecified error in H5Dget_chunk_storage_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_crea[] = "Unspecified error in H5Dget_create_plist (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_offs[] = "Unspecified error in H5Dget_offset (return value ==0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_spac[] = "Unspecified error in H5Dget_space (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_type[] = "Unspecified error in H5Dget_type (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dopen_ret[] = "Unspecified error in H5Dopen (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dread_chu[] = "Unspecified error in H5Dread_chunk (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dread_ret[] = "Unspecified error in H5Dread (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dset_exte[] = "Unspecified error in H5Dset_extent (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dvlen_get[] = "Unspecified error in H5Dvlen_get_buf_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dvlen_rec[] = "Unspecified error in H5Dvlen_reclaim (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dwrite_re[] = "Unspecified error in H5Dwrite (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5FDregiste[] = "Unspecified error in H5FDregister (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5FDunregis[] = "Unspecified error in H5FDunregister (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fclose_re[] = "Unspecified error in H5Fclose (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fcreate_r[] = "Unspecified error in H5Fcreate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fflush_re[] = "Unspecified error in H5Fflush (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_acce[] = "Unspecified error in H5Fget_access_plist (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_crea[] = "Unspecified error in H5Fget_create_plist (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_file[] = "Unspecified error in H5Fget_filesize (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_free[] = "Unspecified error in H5Fget_freespace (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_inte[] = "Unspecified error in H5Fget_intent (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_name[] = "Unspecified error in H5Fget_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_page[] = "Unspecified error in H5Fget_page_buffering_stats (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fmount_re[] = "Unspecified error in H5Fmount (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fopen_ret[] = "Unspecified error in H5Fopen (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Freopen_r[] = "Unspecified error in H5Freopen (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Freset_md[] = "Unspecified error in H5Freset_mdc_hit_rate_stats (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Freset_pa[] = "Unspecified error in H5Freset_page_buffering_stats (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fstart_sw[] = "Unspecified error in H5Fstart_swmr_write (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gclose_re[] = "Unspecified error in H5Gclose (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gcreate_a[] = "Unspecified error in H5Gcreate_anon (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gcreate_r[] = "Unspecified error in H5Gcreate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_comm[] = "Unspecified error in H5Gget_comment (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_crea[] = "Unspecified error in H5Gget_create_plist (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_info[] = "Unspecified error in H5Gget_info (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_link[] = "Unspecified error in H5Gget_linkval (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_obji[] = "Unspecified error in H5Gget_objinfo (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_objn[] = "Unspecified error in H5Gget_objname_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_objt[] = "Unspecified error in H5Gget_objtype_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Glink2_re[] = "Unspecified error in H5Glink2 (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gmove2_re[] = "Unspecified error in H5Gmove2 (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gopen_ret[] = "Unspecified error in H5Gopen (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gset_comm[] = "Unspecified error in H5Gset_comment (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gunlink_r[] = "Unspecified error in H5Gunlink (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Iget_file[] = "Unspecified error in H5Iget_file_id (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Iget_name[] = "Unspecified error in H5Iget_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Iget_type[] = "Unspecified error in H5Iget_type (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Iis_valid[] = "Unspecified error in H5Iis_valid (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5LTopen_fi[] = "Unspecified error in H5LTopen_file_image (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lcopy_ret[] = "Unspecified error in H5Lcopy (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lcreate_e[] = "Unspecified error in H5Lcreate_external (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lcreate_h[] = "Unspecified error in H5Lcreate_hard (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lcreate_s[] = "Unspecified error in H5Lcreate_soft (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Ldelete_b[] = "Unspecified error in H5Ldelete_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Ldelete_r[] = "Unspecified error in H5Ldelete (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lexists_r[] = "Unspecified error in H5Lexists (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lget_info[] = "Unspecified error in H5Lget_info (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lget_name[] = "Unspecified error in H5Lget_name_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lmove_ret[] = "Unspecified error in H5Lmove (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lunpack_e[] = "Unspecified error in H5Lunpack_elink_val (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lvisit_by[] = "Unspecified error in H5Lvisit_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lvisit_re[] = "Unspecified error in H5Lvisit (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oclose_re[] = "Unspecified error in H5Oclose (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Ocopy_ret[] = "Unspecified error in H5Ocopy (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Odecr_ref[] = "Unspecified error in H5Odecr_refcount (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oexists_b[] = "Unspecified error in H5Oexists_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oget_comm[] = "Unspecified error in H5Oget_comment (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oget_info[] = "Unspecified error in H5Oget_info (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oincr_ref[] = "Unspecified error in H5Oincr_refcount (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Olink_ret[] = "Unspecified error in H5Olink (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oopen_ret[] = "Unspecified error in H5Oopen (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oset_comm[] = "Unspecified error in H5Oset_comment (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Ovisit_by[] = "Unspecified error in H5Ovisit_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Ovisit_re[] = "Unspecified error in H5Ovisit (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5PLget_ret[] = "Unspecified error in H5PLget (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5PLprepend[] = "Unspecified error in H5PLprepend (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5PLreplace[] = "Unspecified error in H5PLreplace (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5PLsize_re[] = "Unspecified error in H5PLsize (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pall_filt[] = "Unspecified error in H5Pall_filters_avail (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pclose_cl[] = "Unspecified error in H5Pclose_class (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pclose_re[] = "Unspecified error in H5Pclose (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pcopy_ret[] = "Unspecified error in H5Pcopy (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pcreate_r[] = "Unspecified error in H5Pcreate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pequal_re[] = "Unspecified error in H5Pequal (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pfill_val[] = "Unspecified error in H5Pfill_value_defined (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_alig[] = "Unspecified error in H5Pget_alignment (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_allo[] = "Unspecified error in H5Pget_alloc_time (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_attr[] = "Unspecified error in H5Pget_attr_creation_order (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_cach[] = "Unspecified error in H5Pget_cache (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_char[] = "Unspecified error in H5Pget_char_encoding (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_chun[] = "Unspecified error in H5Pget_chunk (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_clas[] = "Unspecified error in H5Pget_class (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_copy[] = "Unspecified error in H5Pget_copy_object (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_crea[] = "Unspecified error in H5Pget_create_intermediate_group (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_driv[] = "Unspecified error in H5Pget_driver (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_efil[] = "Unspecified error in H5Pget_efile_prefix (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_elin[] = "Unspecified error in H5Pget_elink_prefix (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_exte[] = "Unspecified error in H5Pget_external_count (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_fami[] = "Unspecified error in H5Pget_family_offset (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_fapl[] = "Unspecified error in H5Pget_fapl_core (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_fclo[] = "Unspecified error in H5Pget_fclose_degree (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_file[] = "Unspecified error in H5Pget_file_space_strategy (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_fill[] = "Unspecified error in H5Pget_fill_value (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_filt[] = "Unspecified error in H5Pget_filter (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_isto[] = "Unspecified error in H5Pget_istore_k (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_layo[] = "Unspecified error in H5Pget_layout (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_libv[] = "Unspecified error in H5Pget_libver_bounds (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_link[] = "Unspecified error in H5Pget_link_phase_change (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_loca[] = "Unspecified error in H5Pget_local_heap_size_hint (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_nfil[] = "Unspecified error in H5Pget_nfilters (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_nlin[] = "Unspecified error in H5Pget_nlinks (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_page[] = "Unspecified error in H5Pget_page_buffer_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_siev[] = "Unspecified error in H5Pget_sieve_buf_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_size[] = "Unspecified error in H5Pget_sizes (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_user[] = "Unspecified error in H5Pget_userblock (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_vers[] = "Unspecified error in H5Pget_version (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_virt[] = "Unspecified error in H5Pget_virtual_dsetname (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pmodify_f[] = "Unspecified error in H5Pmodify_filter (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Premove_f[] = "Unspecified error in H5Premove_filter (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_alig[] = "Unspecified error in H5Pset_alignment (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_allo[] = "Unspecified error in H5Pset_alloc_time (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_attr[] = "Unspecified error in H5Pset_attr_creation_order (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_cach[] = "Unspecified error in H5Pset_cache (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_char[] = "Unspecified error in H5Pset_char_encoding (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_chun[] = "Unspecified error in H5Pset_chunk (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_copy[] = "Unspecified error in H5Pset_copy_object (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_crea[] = "Unspecified error in H5Pset_create_intermediate_group (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_defl[] = "Unspecified error in H5Pset_deflate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_driv[] = "Unspecified error in H5Pset_driver (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_efil[] = "Unspecified error in H5Pset_efile_prefix (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_elin[] = "Unspecified error in H5Pset_elink_prefix (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_exte[] = "Unspecified error in H5Pset_external (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fami[] = "Unspecified error in H5Pset_family_offset (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fapl[] = "Unspecified error in H5Pset_fapl_core (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fclo[] = "Unspecified error in H5Pset_fclose_degree (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_file[] = "Unspecified error in H5Pset_file_space_strategy (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fill[] = "Unspecified error in H5Pset_fill_value (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_filt[] = "Unspecified error in H5Pset_filter (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_flet[] = "Unspecified error in H5Pset_fletcher32 (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_isto[] = "Unspecified error in H5Pset_istore_k (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_layo[] = "Unspecified error in H5Pset_layout (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_libv[] = "Unspecified error in H5Pset_libver_bounds (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_link[] = "Unspecified error in H5Pset_link_phase_change (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_loca[] = "Unspecified error in H5Pset_local_heap_size_hint (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_nlin[] = "Unspecified error in H5Pset_nlinks (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_page[] = "Unspecified error in H5Pset_page_buffer_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_scal[] = "Unspecified error in H5Pset_scaleoffset (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_shuf[] = "Unspecified error in H5Pset_shuffle (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_siev[] = "Unspecified error in H5Pset_sieve_buf_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_size[] = "Unspecified error in H5Pset_sizes (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_szip[] = "Unspecified error in H5Pset_szip (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_user[] = "Unspecified error in H5Pset_userblock (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_virt[] = "Unspecified error in H5Pset_virtual (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Rcreate_r[] = "Unspecified error in H5Rcreate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Rderefere[] = "Unspecified error in H5Rdereference (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Rget_name[] = "Unspecified error in H5Rget_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Rget_regi[] = "Unspecified error in H5Rget_region (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sclose_re[] = "Unspecified error in H5Sclose (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Scopy_ret[] = "Unspecified error in H5Scopy (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Screate_r[] = "Unspecified error in H5Screate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Screate_s[] = "Unspecified error in H5Screate_simple (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sdecode_r[] = "Unspecified error in H5Sdecode (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sencode_r[] = "Unspecified error in H5Sencode (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sextent_c[] = "Unspecified error in H5Sextent_copy (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_regu[] = "Unspecified error in H5Sget_regular_hyperslab (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_sele[] = "Unspecified error in H5Sget_select_type (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_simp[] = "Unspecified error in H5Sget_simple_extent_ndims (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sis_regul[] = "Unspecified error in H5Sis_regular_hyperslab (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sis_simpl[] = "Unspecified error in H5Sis_simple (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Soffset_s[] = "Unspecified error in H5Soffset_simple (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sselect_a[] = "Unspecified error in H5Sselect_all (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sselect_e[] = "Unspecified error in H5Sselect_elements (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sselect_h[] = "Unspecified error in H5Sselect_hyperslab (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sselect_n[] = "Unspecified error in H5Sselect_none (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sselect_v[] = "Unspecified error in H5Sselect_valid (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sset_exte[] = "Unspecified error in H5Sset_extent_simple (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tarray_cr[] = "Unspecified error in H5Tarray_create (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tclose_re[] = "Unspecified error in H5Tclose (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tcommit_r[] = "Unspecified error in H5Tcommit (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tcommitte[] = "Unspecified error in H5Tcommitted (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tcopy_ret[] = "Unspecified error in H5Tcopy (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tcreate_r[] = "Unspecified error in H5Tcreate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tdecode_r[] = "Unspecified error in H5Tdecode (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tdetect_c[] = "Unspecified error in H5Tdetect_class (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tencode_r[] = "Unspecified error in H5Tencode (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tenum_cre[] = "Unspecified error in H5Tenum_create (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tenum_ins[] = "Unspecified error in H5Tenum_insert (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tenum_nam[] = "Unspecified error in H5Tenum_nameof (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tenum_val[] = "Unspecified error in H5Tenum_valueof (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tequal_re[] = "Unspecified error in H5Tequal (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tfind_ret[] = "Unspecified error in H5Tfind (return value ==NULL)";
static const char __pyx_k_Unspecified_error_in_H5Tget_arra[] = "Unspecified error in H5Tget_array_ndims (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_clas[] = "Unspecified error in H5Tget_class (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_crea[] = "Unspecified error in H5Tget_create_plist (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_cset[] = "Unspecified error in H5Tget_cset (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_ebia[] = "Unspecified error in H5Tget_ebias (return value ==0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_fiel[] = "Unspecified error in H5Tget_fields (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_inpa[] = "Unspecified error in H5Tget_inpad (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_memb[] = "Unspecified error in H5Tget_member_class (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_nati[] = "Unspecified error in H5Tget_native_type (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_nmem[] = "Unspecified error in H5Tget_nmembers (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_norm[] = "Unspecified error in H5Tget_norm (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_offs[] = "Unspecified error in H5Tget_offset (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_orde[] = "Unspecified error in H5Tget_order (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_prec[] = "Unspecified error in H5Tget_precision (return value ==0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_sign[] = "Unspecified error in H5Tget_sign (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_size[] = "Unspecified error in H5Tget_size (return value ==0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_strp[] = "Unspecified error in H5Tget_strpad (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_supe[] = "Unspecified error in H5Tget_super (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tinsert_r[] = "Unspecified error in H5Tinsert (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tis_varia[] = "Unspecified error in H5Tis_variable_str (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tlock_ret[] = "Unspecified error in H5Tlock (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Topen_ret[] = "Unspecified error in H5Topen (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tpack_ret[] = "Unspecified error in H5Tpack (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tregister[] = "Unspecified error in H5Tregister (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_cset[] = "Unspecified error in H5Tset_cset (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_ebia[] = "Unspecified error in H5Tset_ebias (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_fiel[] = "Unspecified error in H5Tset_fields (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_inpa[] = "Unspecified error in H5Tset_inpad (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_norm[] = "Unspecified error in H5Tset_norm (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_offs[] = "Unspecified error in H5Tset_offset (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_orde[] = "Unspecified error in H5Tset_order (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_prec[] = "Unspecified error in H5Tset_precision (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_sign[] = "Unspecified error in H5Tset_sign (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_size[] = "Unspecified error in H5Tset_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tset_strp[] = "Unspecified error in H5Tset_strpad (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tunregist[] = "Unspecified error in H5Tunregister (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tvlen_cre[] = "Unspecified error in H5Tvlen_create (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Zfilter_a[] = "Unspecified error in H5Zfilter_avail (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Zget_filt[] = "Unspecified error in H5Zget_filter_info (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Zunregist[] = "Unspecified error in H5Zunregister (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5check_ver[] = "Unspecified error in H5check_version (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5close_ret[] = "Unspecified error in H5close (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5free_memo[] = "Unspecified error in H5free_memory (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5get_libve[] = "Unspecified error in H5get_libversion (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5open_retu[] = "Unspecified error in H5open (return value <0)";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static const char __pyx_k_Unspecified_error_in_H5Aopen_by_2[] = "Unspecified error in H5Aopen_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_mdc_2[] = "Unspecified error in H5Fget_mdc_hit_rate (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_mdc_3[] = "Unspecified error in H5Fget_mdc_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_obj_2[] = "Unspecified error in H5Fget_obj_ids (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lget_val_2[] = "Unspecified error in H5Lget_val_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Literate_2[] = "Unspecified error in H5Literate_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oopen_by_2[] = "Unspecified error in H5Oopen_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Adelete_b_2[] = "Unspecified error in H5Adelete_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aget_info_2[] = "Unspecified error in H5Aget_info_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Aget_info_3[] = "Unspecified error in H5Aget_info_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_chun_2[] = "Unspecified error in H5Dget_chunk_info (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_chun_3[] = "Unspecified error in H5Dget_chunk_info_by_coord (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Dget_spac_2[] = "Unspecified error in H5Dget_space_status (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Fget_file_2[] = "Unspecified error in H5Fget_file_image (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Gget_info_2[] = "Unspecified error in H5Gget_info_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Lget_info_2[] = "Unspecified error in H5Lget_info_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oget_comm_2[] = "Unspecified error in H5Oget_comment_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oget_info_2[] = "Unspecified error in H5Oget_info_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oget_info_3[] = "Unspecified error in H5Oget_info_by_idx (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Oset_comm_2[] = "Unspecified error in H5Oset_comment_by_name (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_attr_2[] = "Unspecified error in H5Pget_attr_phase_change (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_chun_2[] = "Unspecified error in H5Pget_chunk_cache (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_driv_2[] = "Unspecified error in H5Pget_driver_info (return value ==NULL)";
static const char __pyx_k_Unspecified_error_in_H5Pget_elin_2[] = "Unspecified error in H5Pget_elink_fapl (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_exte_2[] = "Unspecified error in H5Pget_external (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_fapl_2[] = "Unspecified error in H5Pget_fapl_family (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_file_2[] = "Unspecified error in H5Pget_file_space_page_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_file_3[] = "Unspecified error in H5Pget_file_locking (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_fill_2[] = "Unspecified error in H5Pget_fill_time (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_filt_2[] = "Unspecified error in H5Pget_filter_by_id (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_link_2[] = "Unspecified error in H5Pget_link_creation_order (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_virt_2[] = "Unspecified error in H5Pget_virtual_filename (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_virt_3[] = "Unspecified error in H5Pget_virtual_count (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_virt_4[] = "Unspecified error in H5Pget_virtual_vspace (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_virt_5[] = "Unspecified error in H5Pget_virtual_srcspace (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_virt_6[] = "Unspecified error in H5Pget_virtual_view (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_virt_7[] = "Unspecified error in H5Pget_virtual_printf_gap (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pget_virt_8[] = "Unspecified error in H5Pget_virtual_prefix (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_attr_2[] = "Unspecified error in H5Pset_attr_phase_change (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_chun_2[] = "Unspecified error in H5Pset_chunk_cache (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_elin_2[] = "Unspecified error in H5Pset_elink_fapl (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fapl_2[] = "Unspecified error in H5Pset_fapl_family (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fapl_3[] = "Unspecified error in H5Pset_fapl_log (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fapl_4[] = "Unspecified error in H5Pset_fapl_multi (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fapl_5[] = "Unspecified error in H5Pset_fapl_sec2 (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fapl_6[] = "Unspecified error in H5Pset_fapl_stdio (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fapl_7[] = "Unspecified error in H5Pset_fapl_split (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_file_2[] = "Unspecified error in H5Pset_file_space_page_size (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_file_3[] = "Unspecified error in H5Pset_file_image (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_file_4[] = "Unspecified error in H5Pset_file_locking (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_fill_2[] = "Unspecified error in H5Pset_fill_time (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_link_2[] = "Unspecified error in H5Pset_link_creation_order (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_virt_2[] = "Unspecified error in H5Pset_virtual_view (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_virt_3[] = "Unspecified error in H5Pset_virtual_printf_gap (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Pset_virt_4[] = "Unspecified error in H5Pset_virtual_prefix (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_sele_2[] = "Unspecified error in H5Sget_select_npoints (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_sele_3[] = "Unspecified error in H5Sget_select_bounds (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_sele_4[] = "Unspecified error in H5Sget_select_elem_npoints (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_sele_5[] = "Unspecified error in H5Sget_select_elem_pointlist (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_sele_6[] = "Unspecified error in H5Sget_select_hyper_nblocks (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_sele_7[] = "Unspecified error in H5Sget_select_hyper_blocklist (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_simp_2[] = "Unspecified error in H5Sget_simple_extent_dims (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_simp_3[] = "Unspecified error in H5Sget_simple_extent_npoints (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sget_simp_4[] = "Unspecified error in H5Sget_simple_extent_type (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Sset_exte_2[] = "Unspecified error in H5Sset_extent_none (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_arra_2[] = "Unspecified error in H5Tget_array_dims (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_memb_2[] = "Unspecified error in H5Tget_member_name (return value ==NULL)";
static const char __pyx_k_Unspecified_error_in_H5Tget_memb_3[] = "Unspecified error in H5Tget_member_type (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_memb_4[] = "Unspecified error in H5Tget_member_offset (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_memb_5[] = "Unspecified error in H5Tget_member_index (return value <0)";
static const char __pyx_k_Unspecified_error_in_H5Tget_memb_6[] = "Unspecified error in H5Tget_member_value (return value <0)";
static PyObject *__pyx_n_s_ImportError;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aclose_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Acreate_b;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Acreate_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Adelete_b;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Adelete_b_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Adelete_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aexists_b;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aexists_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aget_info;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aget_info_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aget_info_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aget_name;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aget_num;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aget_spac;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aget_stor;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aget_type;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aiterate;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aopen_by;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aopen_by_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aopen_idx;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aopen_nam;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aopen_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Aread_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Arename_b;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Arename_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Awrite_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DOread_ch;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DOwrite_c;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSattach;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSdetach;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSget_lab;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSget_num;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSget_sca;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSis_atta;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSis_scal;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSiterate;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSset_lab;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5DSset_sca;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dclose_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dcreate_a;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dcreate_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dextend_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dfill_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dflush_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_acce;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_chun;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_chun_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_chun_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_crea;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_num;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_offs;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_spac;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_spac_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dget_type;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Diterate;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dopen_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dread_chu;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dread_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Drefresh;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dset_exte;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dvlen_get;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dvlen_rec;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Dwrite_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5FDregiste;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5FDunregis;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fclose_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fcreate_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fflush_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_acce;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_crea;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_file;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_file_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_free;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_inte;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_mdc;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_mdc_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_mdc_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_name;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_obj;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_obj_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_page;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fget_vfd;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fis_hdf5;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fmount_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fopen_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Freopen_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Freset_md;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Freset_pa;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fset_mdc;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Fstart_sw;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Funmount;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gclose_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gcreate_a;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gcreate_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_comm;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_crea;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_info;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_info_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_link;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_num;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_obji;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_objn;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gget_objt;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Giterate;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Glink2_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gmove2_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gopen_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gset_comm;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Gunlink_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Idec_ref;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Iget_file;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Iget_name;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Iget_ref;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Iget_type;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Iinc_ref;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Iis_valid;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5LTopen_fi;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lcopy_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lcreate_e;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lcreate_h;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lcreate_s;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Ldelete_b;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Ldelete_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lexists_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lget_info;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lget_info_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lget_name;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lget_val;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lget_val_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Literate;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Literate_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lmove_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lunpack_e;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lvisit_by;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Lvisit_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oclose_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Ocopy_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Odecr_ref;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oexists_b;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oget_comm;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oget_comm_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oget_info;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oget_info_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oget_info_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oincr_ref;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Olink_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oopen_by;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oopen_by_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oopen_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oset_comm;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Oset_comm_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Ovisit_by;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Ovisit_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5PLappend;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5PLget_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5PLinsert;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5PLprepend;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5PLremove;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5PLreplace;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5PLsize_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pall_filt;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pclose_cl;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pclose_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pcopy_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pcreate_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pequal_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pfill_val;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_alig;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_allo;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_attr;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_attr_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_cach;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_char;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_chun;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_chun_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_clas;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_copy;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_crea;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_driv;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_driv_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_edc;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_efil;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_elin;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_elin_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_est;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_exte;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_exte_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_fami;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_fapl;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_fapl_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_fclo;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_file;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_file_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_file_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_fill;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_fill_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_filt;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_filt_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_isto;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_layo;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_libv;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_link;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_link_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_loca;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_mdc;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_nfil;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_nlin;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_obj;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_page;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_siev;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_size;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_sym;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_user;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_vers;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_virt;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_virt_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_virt_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_virt_4;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_virt_5;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_virt_6;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_virt_7;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pget_virt_8;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pmodify_f;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Premove_f;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_alig;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_allo;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_attr;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_attr_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_cach;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_char;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_chun;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_chun_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_copy;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_crea;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_defl;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_driv;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_edc;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_efil;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_elin;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_elin_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_est;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_exte;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fami;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fapl;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_4;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_5;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_6;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_7;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fclo;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_file;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_file_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_file_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_file_4;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fill;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_fill_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_filt;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_flet;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_isto;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_layo;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_libv;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_link;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_link_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_loca;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_mdc;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_nlin;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_obj;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_page;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_scal;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_shuf;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_siev;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_size;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_sym;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_szip;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_user;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_virt;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_virt_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_virt_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Pset_virt_4;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Rcreate_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Rderefere;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Rget_name;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Rget_obj;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Rget_regi;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sclose_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Scopy_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Screate_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Screate_s;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sdecode_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sencode_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sextent_c;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_regu;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_sele;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_sele_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_sele_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_sele_4;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_sele_5;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_sele_6;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_sele_7;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_simp;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_simp_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_simp_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sget_simp_4;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sis_regul;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sis_simpl;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Soffset_s;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sselect_a;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sselect_e;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sselect_h;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sselect_n;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sselect_v;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sset_exte;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Sset_exte_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tarray_cr;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tclose_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tcommit_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tcommitte;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tconvert;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tcopy_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tcreate_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tdecode_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tdetect_c;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tencode_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tenum_cre;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tenum_ins;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tenum_nam;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tenum_val;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tequal_re;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tfind_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_arra;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_arra_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_clas;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_crea;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_cset;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_ebia;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_fiel;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_inpa;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_memb;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_memb_2;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_memb_3;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_memb_4;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_memb_5;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_memb_6;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_nati;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_nmem;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_norm;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_offs;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_orde;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_pad;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_prec;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_sign;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_size;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_strp;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_supe;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tget_tag;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tinsert_r;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tis_varia;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tlock_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Topen_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tpack_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tregister;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_cset;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_ebia;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_fiel;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_inpa;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_norm;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_offs;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_orde;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_pad;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_prec;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_sign;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_size;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_strp;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tset_tag;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tunregist;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Tvlen_cre;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Zfilter_a;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Zget_filt;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5Zunregist;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5check_ver;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5close_ret;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5free_memo;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5get_libve;
static PyObject *__pyx_kp_u_Unspecified_error_in_H5open_retu;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_kp_u_numpy_core_multiarray_failed_to;
static PyObject *__pyx_kp_u_numpy_core_umath_failed_to_impor;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__40;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__70;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__74;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__78;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__80;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__82;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__84;
static PyObject *__pyx_tuple__85;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__87;
static PyObject *__pyx_tuple__88;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__90;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_tuple__92;
static PyObject *__pyx_tuple__93;
static PyObject *__pyx_tuple__94;
static PyObject *__pyx_tuple__95;
static PyObject *__pyx_tuple__96;
static PyObject *__pyx_tuple__97;
static PyObject *__pyx_tuple__98;
static PyObject *__pyx_tuple__99;
static PyObject *__pyx_tuple__100;
static PyObject *__pyx_tuple__101;
static PyObject *__pyx_tuple__102;
static PyObject *__pyx_tuple__103;
static PyObject *__pyx_tuple__104;
static PyObject *__pyx_tuple__105;
static PyObject *__pyx_tuple__106;
static PyObject *__pyx_tuple__107;
static PyObject *__pyx_tuple__108;
static PyObject *__pyx_tuple__109;
static PyObject *__pyx_tuple__110;
static PyObject *__pyx_tuple__111;
static PyObject *__pyx_tuple__112;
static PyObject *__pyx_tuple__113;
static PyObject *__pyx_tuple__114;
static PyObject *__pyx_tuple__115;
static PyObject *__pyx_tuple__116;
static PyObject *__pyx_tuple__117;
static PyObject *__pyx_tuple__118;
static PyObject *__pyx_tuple__119;
static PyObject *__pyx_tuple__120;
static PyObject *__pyx_tuple__121;
static PyObject *__pyx_tuple__122;
static PyObject *__pyx_tuple__123;
static PyObject *__pyx_tuple__124;
static PyObject *__pyx_tuple__125;
static PyObject *__pyx_tuple__126;
static PyObject *__pyx_tuple__127;
static PyObject *__pyx_tuple__128;
static PyObject *__pyx_tuple__129;
static PyObject *__pyx_tuple__130;
static PyObject *__pyx_tuple__131;
static PyObject *__pyx_tuple__132;
static PyObject *__pyx_tuple__133;
static PyObject *__pyx_tuple__134;
static PyObject *__pyx_tuple__135;
static PyObject *__pyx_tuple__136;
static PyObject *__pyx_tuple__137;
static PyObject *__pyx_tuple__138;
static PyObject *__pyx_tuple__139;
static PyObject *__pyx_tuple__140;
static PyObject *__pyx_tuple__141;
static PyObject *__pyx_tuple__142;
static PyObject *__pyx_tuple__143;
static PyObject *__pyx_tuple__144;
static PyObject *__pyx_tuple__145;
static PyObject *__pyx_tuple__146;
static PyObject *__pyx_tuple__147;
static PyObject *__pyx_tuple__148;
static PyObject *__pyx_tuple__149;
static PyObject *__pyx_tuple__150;
static PyObject *__pyx_tuple__151;
static PyObject *__pyx_tuple__152;
static PyObject *__pyx_tuple__153;
static PyObject *__pyx_tuple__154;
static PyObject *__pyx_tuple__155;
static PyObject *__pyx_tuple__156;
static PyObject *__pyx_tuple__157;
static PyObject *__pyx_tuple__158;
static PyObject *__pyx_tuple__159;
static PyObject *__pyx_tuple__160;
static PyObject *__pyx_tuple__161;
static PyObject *__pyx_tuple__162;
static PyObject *__pyx_tuple__163;
static PyObject *__pyx_tuple__164;
static PyObject *__pyx_tuple__165;
static PyObject *__pyx_tuple__166;
static PyObject *__pyx_tuple__167;
static PyObject *__pyx_tuple__168;
static PyObject *__pyx_tuple__169;
static PyObject *__pyx_tuple__170;
static PyObject *__pyx_tuple__171;
static PyObject *__pyx_tuple__172;
static PyObject *__pyx_tuple__173;
static PyObject *__pyx_tuple__174;
static PyObject *__pyx_tuple__175;
static PyObject *__pyx_tuple__176;
static PyObject *__pyx_tuple__177;
static PyObject *__pyx_tuple__178;
static PyObject *__pyx_tuple__179;
static PyObject *__pyx_tuple__180;
static PyObject *__pyx_tuple__181;
static PyObject *__pyx_tuple__182;
static PyObject *__pyx_tuple__183;
static PyObject *__pyx_tuple__184;
static PyObject *__pyx_tuple__185;
static PyObject *__pyx_tuple__186;
static PyObject *__pyx_tuple__187;
static PyObject *__pyx_tuple__188;
static PyObject *__pyx_tuple__189;
static PyObject *__pyx_tuple__190;
static PyObject *__pyx_tuple__191;
static PyObject *__pyx_tuple__192;
static PyObject *__pyx_tuple__193;
static PyObject *__pyx_tuple__194;
static PyObject *__pyx_tuple__195;
static PyObject *__pyx_tuple__196;
static PyObject *__pyx_tuple__197;
static PyObject *__pyx_tuple__198;
static PyObject *__pyx_tuple__199;
static PyObject *__pyx_tuple__200;
static PyObject *__pyx_tuple__201;
static PyObject *__pyx_tuple__202;
static PyObject *__pyx_tuple__203;
static PyObject *__pyx_tuple__204;
static PyObject *__pyx_tuple__205;
static PyObject *__pyx_tuple__206;
static PyObject *__pyx_tuple__207;
static PyObject *__pyx_tuple__208;
static PyObject *__pyx_tuple__209;
static PyObject *__pyx_tuple__210;
static PyObject *__pyx_tuple__211;
static PyObject *__pyx_tuple__212;
static PyObject *__pyx_tuple__213;
static PyObject *__pyx_tuple__214;
static PyObject *__pyx_tuple__215;
static PyObject *__pyx_tuple__216;
static PyObject *__pyx_tuple__217;
static PyObject *__pyx_tuple__218;
static PyObject *__pyx_tuple__219;
static PyObject *__pyx_tuple__220;
static PyObject *__pyx_tuple__221;
static PyObject *__pyx_tuple__222;
static PyObject *__pyx_tuple__223;
static PyObject *__pyx_tuple__224;
static PyObject *__pyx_tuple__225;
static PyObject *__pyx_tuple__226;
static PyObject *__pyx_tuple__227;
static PyObject *__pyx_tuple__228;
static PyObject *__pyx_tuple__229;
static PyObject *__pyx_tuple__230;
static PyObject *__pyx_tuple__231;
static PyObject *__pyx_tuple__232;
static PyObject *__pyx_tuple__233;
static PyObject *__pyx_tuple__234;
static PyObject *__pyx_tuple__235;
static PyObject *__pyx_tuple__236;
static PyObject *__pyx_tuple__237;
static PyObject *__pyx_tuple__238;
static PyObject *__pyx_tuple__239;
static PyObject *__pyx_tuple__240;
static PyObject *__pyx_tuple__241;
static PyObject *__pyx_tuple__242;
static PyObject *__pyx_tuple__243;
static PyObject *__pyx_tuple__244;
static PyObject *__pyx_tuple__245;
static PyObject *__pyx_tuple__246;
static PyObject *__pyx_tuple__247;
static PyObject *__pyx_tuple__248;
static PyObject *__pyx_tuple__249;
static PyObject *__pyx_tuple__250;
static PyObject *__pyx_tuple__251;
static PyObject *__pyx_tuple__252;
static PyObject *__pyx_tuple__253;
static PyObject *__pyx_tuple__254;
static PyObject *__pyx_tuple__255;
static PyObject *__pyx_tuple__256;
static PyObject *__pyx_tuple__257;
static PyObject *__pyx_tuple__258;
static PyObject *__pyx_tuple__259;
static PyObject *__pyx_tuple__260;
static PyObject *__pyx_tuple__261;
static PyObject *__pyx_tuple__262;
static PyObject *__pyx_tuple__263;
static PyObject *__pyx_tuple__264;
static PyObject *__pyx_tuple__265;
static PyObject *__pyx_tuple__266;
static PyObject *__pyx_tuple__267;
static PyObject *__pyx_tuple__268;
static PyObject *__pyx_tuple__269;
static PyObject *__pyx_tuple__270;
static PyObject *__pyx_tuple__271;
static PyObject *__pyx_tuple__272;
static PyObject *__pyx_tuple__273;
static PyObject *__pyx_tuple__274;
static PyObject *__pyx_tuple__275;
static PyObject *__pyx_tuple__276;
static PyObject *__pyx_tuple__277;
static PyObject *__pyx_tuple__278;
static PyObject *__pyx_tuple__279;
static PyObject *__pyx_tuple__280;
static PyObject *__pyx_tuple__281;
static PyObject *__pyx_tuple__282;
static PyObject *__pyx_tuple__283;
static PyObject *__pyx_tuple__284;
static PyObject *__pyx_tuple__285;
static PyObject *__pyx_tuple__286;
static PyObject *__pyx_tuple__287;
static PyObject *__pyx_tuple__288;
static PyObject *__pyx_tuple__289;
static PyObject *__pyx_tuple__290;
static PyObject *__pyx_tuple__291;
static PyObject *__pyx_tuple__292;
static PyObject *__pyx_tuple__293;
static PyObject *__pyx_tuple__294;
static PyObject *__pyx_tuple__295;
static PyObject *__pyx_tuple__296;
static PyObject *__pyx_tuple__297;
static PyObject *__pyx_tuple__298;
static PyObject *__pyx_tuple__299;
static PyObject *__pyx_tuple__300;
static PyObject *__pyx_tuple__301;
static PyObject *__pyx_tuple__302;
static PyObject *__pyx_tuple__303;
static PyObject *__pyx_tuple__304;
static PyObject *__pyx_tuple__305;
static PyObject *__pyx_tuple__306;
static PyObject *__pyx_tuple__307;
static PyObject *__pyx_tuple__308;
static PyObject *__pyx_tuple__309;
static PyObject *__pyx_tuple__310;
static PyObject *__pyx_tuple__311;
static PyObject *__pyx_tuple__312;
static PyObject *__pyx_tuple__313;
static PyObject *__pyx_tuple__314;
static PyObject *__pyx_tuple__315;
static PyObject *__pyx_tuple__316;
static PyObject *__pyx_tuple__317;
static PyObject *__pyx_tuple__318;
static PyObject *__pyx_tuple__319;
static PyObject *__pyx_tuple__320;
static PyObject *__pyx_tuple__321;
static PyObject *__pyx_tuple__322;
static PyObject *__pyx_tuple__323;
static PyObject *__pyx_tuple__324;
static PyObject *__pyx_tuple__325;
static PyObject *__pyx_tuple__326;
static PyObject *__pyx_tuple__327;
static PyObject *__pyx_tuple__328;
static PyObject *__pyx_tuple__329;
static PyObject *__pyx_tuple__330;
static PyObject *__pyx_tuple__331;
static PyObject *__pyx_tuple__332;
static PyObject *__pyx_tuple__333;
static PyObject *__pyx_tuple__334;
static PyObject *__pyx_tuple__335;
static PyObject *__pyx_tuple__336;
static PyObject *__pyx_tuple__337;
static PyObject *__pyx_tuple__338;
static PyObject *__pyx_tuple__339;
static PyObject *__pyx_tuple__340;
static PyObject *__pyx_tuple__341;
static PyObject *__pyx_tuple__342;
static PyObject *__pyx_tuple__343;
static PyObject *__pyx_tuple__344;
static PyObject *__pyx_tuple__345;
static PyObject *__pyx_tuple__346;
static PyObject *__pyx_tuple__347;
static PyObject *__pyx_tuple__348;
static PyObject *__pyx_tuple__349;
static PyObject *__pyx_tuple__350;
static PyObject *__pyx_tuple__351;
static PyObject *__pyx_tuple__352;
static PyObject *__pyx_tuple__353;
static PyObject *__pyx_tuple__354;
static PyObject *__pyx_tuple__355;
static PyObject *__pyx_tuple__356;
static PyObject *__pyx_tuple__357;
static PyObject *__pyx_tuple__358;
static PyObject *__pyx_tuple__359;
static PyObject *__pyx_tuple__360;
static PyObject *__pyx_tuple__361;
static PyObject *__pyx_tuple__362;
static PyObject *__pyx_tuple__363;
static PyObject *__pyx_tuple__364;
static PyObject *__pyx_tuple__365;
static PyObject *__pyx_tuple__366;
static PyObject *__pyx_tuple__367;
static PyObject *__pyx_tuple__368;
static PyObject *__pyx_tuple__369;
static PyObject *__pyx_tuple__370;
static PyObject *__pyx_tuple__371;
static PyObject *__pyx_tuple__372;
static PyObject *__pyx_tuple__373;
static PyObject *__pyx_tuple__374;
static PyObject *__pyx_tuple__375;
static PyObject *__pyx_tuple__376;
static PyObject *__pyx_tuple__377;
static PyObject *__pyx_tuple__378;
static PyObject *__pyx_tuple__379;
static PyObject *__pyx_tuple__380;
static PyObject *__pyx_tuple__381;
static PyObject *__pyx_tuple__382;
static PyObject *__pyx_tuple__383;
static PyObject *__pyx_tuple__384;
static PyObject *__pyx_tuple__385;
static PyObject *__pyx_tuple__386;
static PyObject *__pyx_tuple__387;
/* Late includes */

/* "h5py/defs.pyx":14
 * from ._errors cimport set_exception, set_default_error_handler
 * 
 * cdef herr_t H5open() except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5open(void) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5open", 0);

  /* "h5py/defs.pyx":16
 * cdef herr_t H5open() except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5open()
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":17
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5open()             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5open();

  /* "h5py/defs.pyx":18
 *     set_default_error_handler()
 *     r = _hdf5.H5open()
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":19
 *     r = _hdf5.H5open()
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 19, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":20
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5open (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":19
 *     r = _hdf5.H5open()
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":22
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5open (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 22, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 22, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":18
 *     set_default_error_handler()
 *     r = _hdf5.H5open()
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":23
 *         else:
 *             raise RuntimeError("Unspecified error in H5open (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5close() except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":14
 * from ._errors cimport set_exception, set_default_error_handler
 * 
 * cdef herr_t H5open() except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":25
 *     return r
 * 
 * cdef herr_t H5close() except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5close(void) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5close", 0);

  /* "h5py/defs.pyx":27
 * cdef herr_t H5close() except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5close()
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":28
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5close()             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5close();

  /* "h5py/defs.pyx":29
 *     set_default_error_handler()
 *     r = _hdf5.H5close()
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":30
 *     r = _hdf5.H5close()
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 30, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":31
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5close (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":30
 *     r = _hdf5.H5close()
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":33
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5close (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 33, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 33, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":29
 *     set_default_error_handler()
 *     r = _hdf5.H5close()
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":34
 *         else:
 *             raise RuntimeError("Unspecified error in H5close (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5get_libversion(unsigned *majnum, unsigned *minnum, unsigned *relnum) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":25
 *     return r
 * 
 * cdef herr_t H5close() except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":36
 *     return r
 * 
 * cdef herr_t H5get_libversion(unsigned *majnum, unsigned *minnum, unsigned *relnum) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5get_libversion(unsigned int *__pyx_v_majnum, unsigned int *__pyx_v_minnum, unsigned int *__pyx_v_relnum) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5get_libversion", 0);

  /* "h5py/defs.pyx":38
 * cdef herr_t H5get_libversion(unsigned *majnum, unsigned *minnum, unsigned *relnum) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5get_libversion(majnum, minnum, relnum)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":39
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5get_libversion(majnum, minnum, relnum)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5get_libversion(__pyx_v_majnum, __pyx_v_minnum, __pyx_v_relnum);

  /* "h5py/defs.pyx":40
 *     set_default_error_handler()
 *     r = _hdf5.H5get_libversion(majnum, minnum, relnum)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":41
 *     r = _hdf5.H5get_libversion(majnum, minnum, relnum)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 41, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":42
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5get_libversion (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":41
 *     r = _hdf5.H5get_libversion(majnum, minnum, relnum)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":44
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5get_libversion (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 44, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 44, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":40
 *     set_default_error_handler()
 *     r = _hdf5.H5get_libversion(majnum, minnum, relnum)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":45
 *         else:
 *             raise RuntimeError("Unspecified error in H5get_libversion (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5check_version(unsigned majnum, unsigned minnum, unsigned relnum ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":36
 *     return r
 * 
 * cdef herr_t H5get_libversion(unsigned *majnum, unsigned *minnum, unsigned *relnum) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5get_libversion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":47
 *     return r
 * 
 * cdef herr_t H5check_version(unsigned majnum, unsigned minnum, unsigned relnum ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5check_version(unsigned int __pyx_v_majnum, unsigned int __pyx_v_minnum, unsigned int __pyx_v_relnum) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5check_version", 0);

  /* "h5py/defs.pyx":49
 * cdef herr_t H5check_version(unsigned majnum, unsigned minnum, unsigned relnum ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5check_version(majnum, minnum, relnum)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":50
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5check_version(majnum, minnum, relnum)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5check_version(__pyx_v_majnum, __pyx_v_minnum, __pyx_v_relnum);

  /* "h5py/defs.pyx":51
 *     set_default_error_handler()
 *     r = _hdf5.H5check_version(majnum, minnum, relnum)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":52
 *     r = _hdf5.H5check_version(majnum, minnum, relnum)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 52, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":53
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5check_version (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":52
 *     r = _hdf5.H5check_version(majnum, minnum, relnum)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":55
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5check_version (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 55, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 55, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":51
 *     set_default_error_handler()
 *     r = _hdf5.H5check_version(majnum, minnum, relnum)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":56
 *         else:
 *             raise RuntimeError("Unspecified error in H5check_version (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 13):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":47
 *     return r
 * 
 * cdef herr_t H5check_version(unsigned majnum, unsigned minnum, unsigned relnum ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5check_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":59
 * 
 * IF HDF5_VERSION >= (1, 8, 13):
 *     cdef herr_t H5free_memory(void *mem) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5free_memory(void *__pyx_v_mem) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5free_memory", 0);

  /* "h5py/defs.pyx":61
 *     cdef herr_t H5free_memory(void *mem) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5free_memory(mem)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":62
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5free_memory(mem)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5free_memory(__pyx_v_mem);

  /* "h5py/defs.pyx":63
 *         set_default_error_handler()
 *         r = _hdf5.H5free_memory(mem)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":64
 *         r = _hdf5.H5free_memory(mem)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 64, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":65
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5free_memory (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":64
 *         r = _hdf5.H5free_memory(mem)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":67
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5free_memory (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 67, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":63
 *         set_default_error_handler()
 *         r = _hdf5.H5free_memory(mem)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":68
 *             else:
 *                 raise RuntimeError("Unspecified error in H5free_memory (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Acreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t acpl_id, hid_t aapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":59
 * 
 * IF HDF5_VERSION >= (1, 8, 13):
 *     cdef herr_t H5free_memory(void *mem) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5free_memory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":70
 *         return r
 * 
 * cdef hid_t H5Acreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t acpl_id, hid_t aapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Acreate(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_type_id, hid_t __pyx_v_space_id, hid_t __pyx_v_acpl_id, hid_t __pyx_v_aapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Acreate", 0);

  /* "h5py/defs.pyx":72
 * cdef hid_t H5Acreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t acpl_id, hid_t aapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Acreate(loc_id, name, type_id, space_id, acpl_id, aapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":73
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Acreate(loc_id, name, type_id, space_id, acpl_id, aapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Acreate(__pyx_v_loc_id, __pyx_v_name, __pyx_v_type_id, __pyx_v_space_id, __pyx_v_acpl_id, __pyx_v_aapl_id);

  /* "h5py/defs.pyx":74
 *     set_default_error_handler()
 *     r = _hdf5.H5Acreate(loc_id, name, type_id, space_id, acpl_id, aapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":75
 *     r = _hdf5.H5Acreate(loc_id, name, type_id, space_id, acpl_id, aapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 75, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":76
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Acreate (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":75
 *     r = _hdf5.H5Acreate(loc_id, name, type_id, space_id, acpl_id, aapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":78
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Acreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 78, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 78, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":74
 *     set_default_error_handler()
 *     r = _hdf5.H5Acreate(loc_id, name, type_id, space_id, acpl_id, aapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":79
 *         else:
 *             raise RuntimeError("Unspecified error in H5Acreate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Aopen_idx(hid_t loc_id, unsigned int idx) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":70
 *         return r
 * 
 * cdef hid_t H5Acreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t acpl_id, hid_t aapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Acreate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":81
 *     return r
 * 
 * cdef hid_t H5Aopen_idx(hid_t loc_id, unsigned int idx) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Aopen_idx(hid_t __pyx_v_loc_id, unsigned int __pyx_v_idx) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aopen_idx", 0);

  /* "h5py/defs.pyx":83
 * cdef hid_t H5Aopen_idx(hid_t loc_id, unsigned int idx) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aopen_idx(loc_id, idx)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":84
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_idx(loc_id, idx)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aopen_idx(__pyx_v_loc_id, __pyx_v_idx);

  /* "h5py/defs.pyx":85
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_idx(loc_id, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":86
 *     r = _hdf5.H5Aopen_idx(loc_id, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 86, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":87
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_idx (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":86
 *     r = _hdf5.H5Aopen_idx(loc_id, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":89
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 89, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 89, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":85
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_idx(loc_id, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":90
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Aopen_name(hid_t loc_id, char *name) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":81
 *     return r
 * 
 * cdef hid_t H5Aopen_idx(hid_t loc_id, unsigned int idx) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aopen_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":92
 *     return r
 * 
 * cdef hid_t H5Aopen_name(hid_t loc_id, char *name) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Aopen_name(hid_t __pyx_v_loc_id, char *__pyx_v_name) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aopen_name", 0);

  /* "h5py/defs.pyx":94
 * cdef hid_t H5Aopen_name(hid_t loc_id, char *name) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aopen_name(loc_id, name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":95
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_name(loc_id, name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aopen_name(__pyx_v_loc_id, __pyx_v_name);

  /* "h5py/defs.pyx":96
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_name(loc_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":97
 *     r = _hdf5.H5Aopen_name(loc_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 97, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":98
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_name (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":97
 *     r = _hdf5.H5Aopen_name(loc_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":100
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 100, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 100, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":96
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_name(loc_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":101
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Aclose(hid_t attr_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":92
 *     return r
 * 
 * cdef hid_t H5Aopen_name(hid_t loc_id, char *name) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aopen_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":103
 *     return r
 * 
 * cdef herr_t H5Aclose(hid_t attr_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Aclose(hid_t __pyx_v_attr_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aclose", 0);

  /* "h5py/defs.pyx":105
 * cdef herr_t H5Aclose(hid_t attr_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aclose(attr_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":106
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aclose(attr_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aclose(__pyx_v_attr_id);

  /* "h5py/defs.pyx":107
 *     set_default_error_handler()
 *     r = _hdf5.H5Aclose(attr_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":108
 *     r = _hdf5.H5Aclose(attr_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 108, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":109
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aclose (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":108
 *     r = _hdf5.H5Aclose(attr_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":111
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 111, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":107
 *     set_default_error_handler()
 *     r = _hdf5.H5Aclose(attr_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":112
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aclose (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Adelete(hid_t loc_id, char *name) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":103
 *     return r
 * 
 * cdef herr_t H5Aclose(hid_t attr_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":114
 *     return r
 * 
 * cdef herr_t H5Adelete(hid_t loc_id, char *name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Adelete(hid_t __pyx_v_loc_id, char *__pyx_v_name) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Adelete", 0);

  /* "h5py/defs.pyx":116
 * cdef herr_t H5Adelete(hid_t loc_id, char *name) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Adelete(loc_id, name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":117
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete(loc_id, name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Adelete(__pyx_v_loc_id, __pyx_v_name);

  /* "h5py/defs.pyx":118
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete(loc_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":119
 *     r = _hdf5.H5Adelete(loc_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 119, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":120
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":119
 *     r = _hdf5.H5Adelete(loc_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":122
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 122, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 122, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":118
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete(loc_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":123
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Aread(hid_t attr_id, hid_t mem_type_id, void *buf) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":114
 *     return r
 * 
 * cdef herr_t H5Adelete(hid_t loc_id, char *name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Adelete", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":125
 *     return r
 * 
 * cdef herr_t H5Aread(hid_t attr_id, hid_t mem_type_id, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Aread(hid_t __pyx_v_attr_id, hid_t __pyx_v_mem_type_id, void *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aread", 0);

  /* "h5py/defs.pyx":127
 * cdef herr_t H5Aread(hid_t attr_id, hid_t mem_type_id, void *buf) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aread(attr_id, mem_type_id, buf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":128
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aread(attr_id, mem_type_id, buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aread(__pyx_v_attr_id, __pyx_v_mem_type_id, __pyx_v_buf);

  /* "h5py/defs.pyx":129
 *     set_default_error_handler()
 *     r = _hdf5.H5Aread(attr_id, mem_type_id, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":130
 *     r = _hdf5.H5Aread(attr_id, mem_type_id, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 130, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":131
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aread (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":130
 *     r = _hdf5.H5Aread(attr_id, mem_type_id, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":133
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aread (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 133, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":129
 *     set_default_error_handler()
 *     r = _hdf5.H5Aread(attr_id, mem_type_id, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":134
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aread (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Awrite(hid_t attr_id, hid_t mem_type_id, void *buf ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":125
 *     return r
 * 
 * cdef herr_t H5Aread(hid_t attr_id, hid_t mem_type_id, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aread", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":136
 *     return r
 * 
 * cdef herr_t H5Awrite(hid_t attr_id, hid_t mem_type_id, void *buf ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Awrite(hid_t __pyx_v_attr_id, hid_t __pyx_v_mem_type_id, void *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Awrite", 0);

  /* "h5py/defs.pyx":138
 * cdef herr_t H5Awrite(hid_t attr_id, hid_t mem_type_id, void *buf ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Awrite(attr_id, mem_type_id, buf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":139
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Awrite(attr_id, mem_type_id, buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Awrite(__pyx_v_attr_id, __pyx_v_mem_type_id, __pyx_v_buf);

  /* "h5py/defs.pyx":140
 *     set_default_error_handler()
 *     r = _hdf5.H5Awrite(attr_id, mem_type_id, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":141
 *     r = _hdf5.H5Awrite(attr_id, mem_type_id, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 141, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":142
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Awrite (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":141
 *     r = _hdf5.H5Awrite(attr_id, mem_type_id, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":144
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Awrite (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 144, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 144, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":140
 *     set_default_error_handler()
 *     r = _hdf5.H5Awrite(attr_id, mem_type_id, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":145
 *         else:
 *             raise RuntimeError("Unspecified error in H5Awrite (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Aget_num_attrs(hid_t loc_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":136
 *     return r
 * 
 * cdef herr_t H5Awrite(hid_t attr_id, hid_t mem_type_id, void *buf ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Awrite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":147
 *     return r
 * 
 * cdef int H5Aget_num_attrs(hid_t loc_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Aget_num_attrs(hid_t __pyx_v_loc_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aget_num_attrs", 0);

  /* "h5py/defs.pyx":149
 * cdef int H5Aget_num_attrs(hid_t loc_id) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aget_num_attrs(loc_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":150
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_num_attrs(loc_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aget_num_attrs(__pyx_v_loc_id);

  /* "h5py/defs.pyx":151
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_num_attrs(loc_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":152
 *     r = _hdf5.H5Aget_num_attrs(loc_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 152, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":153
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_num_attrs (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":152
 *     r = _hdf5.H5Aget_num_attrs(loc_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":155
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_num_attrs (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 155, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":151
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_num_attrs(loc_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":156
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_num_attrs (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5Aget_name(hid_t attr_id, size_t buf_size, char *buf) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":147
 *     return r
 * 
 * cdef int H5Aget_num_attrs(hid_t loc_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aget_num_attrs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":158
 *     return r
 * 
 * cdef ssize_t H5Aget_name(hid_t attr_id, size_t buf_size, char *buf) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Aget_name(hid_t __pyx_v_attr_id, size_t __pyx_v_buf_size, char *__pyx_v_buf) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aget_name", 0);

  /* "h5py/defs.pyx":160
 * cdef ssize_t H5Aget_name(hid_t attr_id, size_t buf_size, char *buf) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aget_name(attr_id, buf_size, buf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":161
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_name(attr_id, buf_size, buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aget_name(__pyx_v_attr_id, __pyx_v_buf_size, __pyx_v_buf);

  /* "h5py/defs.pyx":162
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_name(attr_id, buf_size, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":163
 *     r = _hdf5.H5Aget_name(attr_id, buf_size, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 163, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":164
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_name (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":163
 *     r = _hdf5.H5Aget_name(attr_id, buf_size, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":166
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 166, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 166, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":162
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_name(attr_id, buf_size, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":167
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Aget_space(hid_t attr_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":158
 *     return r
 * 
 * cdef ssize_t H5Aget_name(hid_t attr_id, size_t buf_size, char *buf) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aget_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":169
 *     return r
 * 
 * cdef hid_t H5Aget_space(hid_t attr_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Aget_space(hid_t __pyx_v_attr_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aget_space", 0);

  /* "h5py/defs.pyx":171
 * cdef hid_t H5Aget_space(hid_t attr_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aget_space(attr_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":172
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_space(attr_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aget_space(__pyx_v_attr_id);

  /* "h5py/defs.pyx":173
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_space(attr_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":174
 *     r = _hdf5.H5Aget_space(attr_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 174, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":175
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_space (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":174
 *     r = _hdf5.H5Aget_space(attr_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":177
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_space (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 177, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 177, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":173
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_space(attr_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":178
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_space (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Aget_type(hid_t attr_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":169
 *     return r
 * 
 * cdef hid_t H5Aget_space(hid_t attr_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aget_space", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":180
 *     return r
 * 
 * cdef hid_t H5Aget_type(hid_t attr_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Aget_type(hid_t __pyx_v_attr_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aget_type", 0);

  /* "h5py/defs.pyx":182
 * cdef hid_t H5Aget_type(hid_t attr_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aget_type(attr_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":183
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_type(attr_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aget_type(__pyx_v_attr_id);

  /* "h5py/defs.pyx":184
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_type(attr_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":185
 *     r = _hdf5.H5Aget_type(attr_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 185, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":186
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_type (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":185
 *     r = _hdf5.H5Aget_type(attr_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":188
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 188, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 188, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":184
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_type(attr_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":189
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_type (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Adelete_by_name(hid_t loc_id, char *obj_name, char *attr_name, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":180
 *     return r
 * 
 * cdef hid_t H5Aget_type(hid_t attr_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aget_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":191
 *     return r
 * 
 * cdef herr_t H5Adelete_by_name(hid_t loc_id, char *obj_name, char *attr_name, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Adelete_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, char *__pyx_v_attr_name, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Adelete_by_name", 0);

  /* "h5py/defs.pyx":193
 * cdef herr_t H5Adelete_by_name(hid_t loc_id, char *obj_name, char *attr_name, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Adelete_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":194
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete_by_name(loc_id, obj_name, attr_name, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Adelete_by_name(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_attr_name, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":195
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":196
 *     r = _hdf5.H5Adelete_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 196, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":197
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":196
 *     r = _hdf5.H5Adelete_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":199
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 199, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":195
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":200
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Adelete_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":191
 *     return r
 * 
 * cdef herr_t H5Adelete_by_name(hid_t loc_id, char *obj_name, char *attr_name, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Adelete_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":202
 *     return r
 * 
 * cdef herr_t H5Adelete_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Adelete_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Adelete_by_idx", 0);

  /* "h5py/defs.pyx":204
 * cdef herr_t H5Adelete_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Adelete_by_idx(loc_id, obj_name, idx_type, order, n, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":205
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete_by_idx(loc_id, obj_name, idx_type, order, n, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Adelete_by_idx(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":206
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete_by_idx(loc_id, obj_name, idx_type, order, n, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":207
 *     r = _hdf5.H5Adelete_by_idx(loc_id, obj_name, idx_type, order, n, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 207, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":208
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete_by_idx (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":207
 *     r = _hdf5.H5Adelete_by_idx(loc_id, obj_name, idx_type, order, n, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":210
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 210, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":206
 *     set_default_error_handler()
 *     r = _hdf5.H5Adelete_by_idx(loc_id, obj_name, idx_type, order, n, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":211
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Acreate_by_name(hid_t loc_id, char *obj_name, char *attr_name, hid_t type_id, hid_t space_id, hid_t acpl_id, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":202
 *     return r
 * 
 * cdef herr_t H5Adelete_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Adelete_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":213
 *     return r
 * 
 * cdef hid_t H5Acreate_by_name(hid_t loc_id, char *obj_name, char *attr_name, hid_t type_id, hid_t space_id, hid_t acpl_id, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Acreate_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, char *__pyx_v_attr_name, hid_t __pyx_v_type_id, hid_t __pyx_v_space_id, hid_t __pyx_v_acpl_id, hid_t __pyx_v_aapl_id, hid_t __pyx_v_lapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Acreate_by_name", 0);

  /* "h5py/defs.pyx":215
 * cdef hid_t H5Acreate_by_name(hid_t loc_id, char *obj_name, char *attr_name, hid_t type_id, hid_t space_id, hid_t acpl_id, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Acreate_by_name(loc_id, obj_name, attr_name, type_id, space_id, acpl_id, aapl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":216
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Acreate_by_name(loc_id, obj_name, attr_name, type_id, space_id, acpl_id, aapl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Acreate_by_name(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_attr_name, __pyx_v_type_id, __pyx_v_space_id, __pyx_v_acpl_id, __pyx_v_aapl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":217
 *     set_default_error_handler()
 *     r = _hdf5.H5Acreate_by_name(loc_id, obj_name, attr_name, type_id, space_id, acpl_id, aapl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":218
 *     r = _hdf5.H5Acreate_by_name(loc_id, obj_name, attr_name, type_id, space_id, acpl_id, aapl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 218, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":219
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Acreate_by_name (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":218
 *     r = _hdf5.H5Acreate_by_name(loc_id, obj_name, attr_name, type_id, space_id, acpl_id, aapl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":221
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Acreate_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 221, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 221, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":217
 *     set_default_error_handler()
 *     r = _hdf5.H5Acreate_by_name(loc_id, obj_name, attr_name, type_id, space_id, acpl_id, aapl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":222
 *         else:
 *             raise RuntimeError("Unspecified error in H5Acreate_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Aopen(hid_t obj_id, char *attr_name, hid_t aapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":213
 *     return r
 * 
 * cdef hid_t H5Acreate_by_name(hid_t loc_id, char *obj_name, char *attr_name, hid_t type_id, hid_t space_id, hid_t acpl_id, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Acreate_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":224
 *     return r
 * 
 * cdef hid_t H5Aopen(hid_t obj_id, char *attr_name, hid_t aapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Aopen(hid_t __pyx_v_obj_id, char *__pyx_v_attr_name, hid_t __pyx_v_aapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aopen", 0);

  /* "h5py/defs.pyx":226
 * cdef hid_t H5Aopen(hid_t obj_id, char *attr_name, hid_t aapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aopen(obj_id, attr_name, aapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":227
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen(obj_id, attr_name, aapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aopen(__pyx_v_obj_id, __pyx_v_attr_name, __pyx_v_aapl_id);

  /* "h5py/defs.pyx":228
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen(obj_id, attr_name, aapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":229
 *     r = _hdf5.H5Aopen(obj_id, attr_name, aapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 229, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":230
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":229
 *     r = _hdf5.H5Aopen(obj_id, attr_name, aapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":232
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 232, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":228
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen(obj_id, attr_name, aapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":233
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Aopen_by_name( hid_t loc_id, char *obj_name, char *attr_name, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":224
 *     return r
 * 
 * cdef hid_t H5Aopen(hid_t obj_id, char *attr_name, hid_t aapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aopen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":235
 *     return r
 * 
 * cdef hid_t H5Aopen_by_name( hid_t loc_id, char *obj_name, char *attr_name, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Aopen_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, char *__pyx_v_attr_name, hid_t __pyx_v_aapl_id, hid_t __pyx_v_lapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aopen_by_name", 0);

  /* "h5py/defs.pyx":237
 * cdef hid_t H5Aopen_by_name( hid_t loc_id, char *obj_name, char *attr_name, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aopen_by_name(loc_id, obj_name, attr_name, aapl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":238
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_by_name(loc_id, obj_name, attr_name, aapl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aopen_by_name(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_attr_name, __pyx_v_aapl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":239
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_by_name(loc_id, obj_name, attr_name, aapl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":240
 *     r = _hdf5.H5Aopen_by_name(loc_id, obj_name, attr_name, aapl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 240, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":241
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_by_name (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":240
 *     r = _hdf5.H5Aopen_by_name(loc_id, obj_name, attr_name, aapl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":243
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 243, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 243, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":239
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_by_name(loc_id, obj_name, attr_name, aapl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":244
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Aopen_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":235
 *     return r
 * 
 * cdef hid_t H5Aopen_by_name( hid_t loc_id, char *obj_name, char *attr_name, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aopen_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":246
 *     return r
 * 
 * cdef hid_t H5Aopen_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Aopen_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, hid_t __pyx_v_aapl_id, hid_t __pyx_v_lapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aopen_by_idx", 0);

  /* "h5py/defs.pyx":248
 * cdef hid_t H5Aopen_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aopen_by_idx(loc_id, obj_name, idx_type, order, n, aapl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":249
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_by_idx(loc_id, obj_name, idx_type, order, n, aapl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aopen_by_idx(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_aapl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":250
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_by_idx(loc_id, obj_name, idx_type, order, n, aapl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":251
 *     r = _hdf5.H5Aopen_by_idx(loc_id, obj_name, idx_type, order, n, aapl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 251, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":252
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_by_idx (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":251
 *     r = _hdf5.H5Aopen_by_idx(loc_id, obj_name, idx_type, order, n, aapl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":254
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 254, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 254, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":250
 *     set_default_error_handler()
 *     r = _hdf5.H5Aopen_by_idx(loc_id, obj_name, idx_type, order, n, aapl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":255
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Aexists_by_name( hid_t loc_id, char *obj_name, char *attr_name, hid_t lapl_id) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":246
 *     return r
 * 
 * cdef hid_t H5Aopen_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t aapl_id, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aopen_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":257
 *     return r
 * 
 * cdef htri_t H5Aexists_by_name( hid_t loc_id, char *obj_name, char *attr_name, hid_t lapl_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Aexists_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, char *__pyx_v_attr_name, hid_t __pyx_v_lapl_id) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aexists_by_name", 0);

  /* "h5py/defs.pyx":259
 * cdef htri_t H5Aexists_by_name( hid_t loc_id, char *obj_name, char *attr_name, hid_t lapl_id) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aexists_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":260
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aexists_by_name(loc_id, obj_name, attr_name, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aexists_by_name(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_attr_name, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":261
 *     set_default_error_handler()
 *     r = _hdf5.H5Aexists_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":262
 *     r = _hdf5.H5Aexists_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 262, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":263
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aexists_by_name (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":262
 *     r = _hdf5.H5Aexists_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":265
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aexists_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 265, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 265, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":261
 *     set_default_error_handler()
 *     r = _hdf5.H5Aexists_by_name(loc_id, obj_name, attr_name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":266
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aexists_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Aexists(hid_t obj_id, char *attr_name) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":257
 *     return r
 * 
 * cdef htri_t H5Aexists_by_name( hid_t loc_id, char *obj_name, char *attr_name, hid_t lapl_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aexists_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":268
 *     return r
 * 
 * cdef htri_t H5Aexists(hid_t obj_id, char *attr_name) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Aexists(hid_t __pyx_v_obj_id, char *__pyx_v_attr_name) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aexists", 0);

  /* "h5py/defs.pyx":270
 * cdef htri_t H5Aexists(hid_t obj_id, char *attr_name) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aexists(obj_id, attr_name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":271
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aexists(obj_id, attr_name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aexists(__pyx_v_obj_id, __pyx_v_attr_name);

  /* "h5py/defs.pyx":272
 *     set_default_error_handler()
 *     r = _hdf5.H5Aexists(obj_id, attr_name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":273
 *     r = _hdf5.H5Aexists(obj_id, attr_name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 273, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":274
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aexists (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":273
 *     r = _hdf5.H5Aexists(obj_id, attr_name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":276
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aexists (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 276, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":272
 *     set_default_error_handler()
 *     r = _hdf5.H5Aexists(obj_id, attr_name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":277
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aexists (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Arename(hid_t loc_id, char *old_attr_name, char *new_attr_name) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":268
 *     return r
 * 
 * cdef htri_t H5Aexists(hid_t obj_id, char *attr_name) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aexists", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":279
 *     return r
 * 
 * cdef herr_t H5Arename(hid_t loc_id, char *old_attr_name, char *new_attr_name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Arename(hid_t __pyx_v_loc_id, char *__pyx_v_old_attr_name, char *__pyx_v_new_attr_name) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Arename", 0);

  /* "h5py/defs.pyx":281
 * cdef herr_t H5Arename(hid_t loc_id, char *old_attr_name, char *new_attr_name) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Arename(loc_id, old_attr_name, new_attr_name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":282
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Arename(loc_id, old_attr_name, new_attr_name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Arename(__pyx_v_loc_id, __pyx_v_old_attr_name, __pyx_v_new_attr_name);

  /* "h5py/defs.pyx":283
 *     set_default_error_handler()
 *     r = _hdf5.H5Arename(loc_id, old_attr_name, new_attr_name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":284
 *     r = _hdf5.H5Arename(loc_id, old_attr_name, new_attr_name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 284, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":285
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Arename (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":284
 *     r = _hdf5.H5Arename(loc_id, old_attr_name, new_attr_name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":287
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Arename (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 287, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 287, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":283
 *     set_default_error_handler()
 *     r = _hdf5.H5Arename(loc_id, old_attr_name, new_attr_name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":288
 *         else:
 *             raise RuntimeError("Unspecified error in H5Arename (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Arename_by_name(hid_t loc_id, char *obj_name, char *old_attr_name, char *new_attr_name, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":279
 *     return r
 * 
 * cdef herr_t H5Arename(hid_t loc_id, char *old_attr_name, char *new_attr_name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Arename", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":290
 *     return r
 * 
 * cdef herr_t H5Arename_by_name(hid_t loc_id, char *obj_name, char *old_attr_name, char *new_attr_name, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Arename_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, char *__pyx_v_old_attr_name, char *__pyx_v_new_attr_name, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Arename_by_name", 0);

  /* "h5py/defs.pyx":292
 * cdef herr_t H5Arename_by_name(hid_t loc_id, char *obj_name, char *old_attr_name, char *new_attr_name, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Arename_by_name(loc_id, obj_name, old_attr_name, new_attr_name, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":293
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Arename_by_name(loc_id, obj_name, old_attr_name, new_attr_name, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Arename_by_name(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_old_attr_name, __pyx_v_new_attr_name, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":294
 *     set_default_error_handler()
 *     r = _hdf5.H5Arename_by_name(loc_id, obj_name, old_attr_name, new_attr_name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":295
 *     r = _hdf5.H5Arename_by_name(loc_id, obj_name, old_attr_name, new_attr_name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 295, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":296
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Arename_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":295
 *     r = _hdf5.H5Arename_by_name(loc_id, obj_name, old_attr_name, new_attr_name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":298
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Arename_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 298, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":294
 *     set_default_error_handler()
 *     r = _hdf5.H5Arename_by_name(loc_id, obj_name, old_attr_name, new_attr_name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":299
 *         else:
 *             raise RuntimeError("Unspecified error in H5Arename_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Aget_info( hid_t attr_id, H5A_info_t *ainfo) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":290
 *     return r
 * 
 * cdef herr_t H5Arename_by_name(hid_t loc_id, char *obj_name, char *old_attr_name, char *new_attr_name, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Arename_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":301
 *     return r
 * 
 * cdef herr_t H5Aget_info( hid_t attr_id, H5A_info_t *ainfo) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Aget_info(hid_t __pyx_v_attr_id, H5A_info_t *__pyx_v_ainfo) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aget_info", 0);

  /* "h5py/defs.pyx":303
 * cdef herr_t H5Aget_info( hid_t attr_id, H5A_info_t *ainfo) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aget_info(attr_id, ainfo)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":304
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info(attr_id, ainfo)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aget_info(__pyx_v_attr_id, __pyx_v_ainfo);

  /* "h5py/defs.pyx":305
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info(attr_id, ainfo)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":306
 *     r = _hdf5.H5Aget_info(attr_id, ainfo)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 306, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":307
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":306
 *     r = _hdf5.H5Aget_info(attr_id, ainfo)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":309
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 309, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":305
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info(attr_id, ainfo)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":310
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Aget_info_by_name(hid_t loc_id, char *obj_name, char *attr_name, H5A_info_t *ainfo, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":301
 *     return r
 * 
 * cdef herr_t H5Aget_info( hid_t attr_id, H5A_info_t *ainfo) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aget_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":312
 *     return r
 * 
 * cdef herr_t H5Aget_info_by_name(hid_t loc_id, char *obj_name, char *attr_name, H5A_info_t *ainfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Aget_info_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, char *__pyx_v_attr_name, H5A_info_t *__pyx_v_ainfo, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aget_info_by_name", 0);

  /* "h5py/defs.pyx":314
 * cdef herr_t H5Aget_info_by_name(hid_t loc_id, char *obj_name, char *attr_name, H5A_info_t *ainfo, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aget_info_by_name(loc_id, obj_name, attr_name, ainfo, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":315
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info_by_name(loc_id, obj_name, attr_name, ainfo, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aget_info_by_name(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_attr_name, __pyx_v_ainfo, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":316
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info_by_name(loc_id, obj_name, attr_name, ainfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":317
 *     r = _hdf5.H5Aget_info_by_name(loc_id, obj_name, attr_name, ainfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 317, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":318
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":317
 *     r = _hdf5.H5Aget_info_by_name(loc_id, obj_name, attr_name, ainfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":320
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 320, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":316
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info_by_name(loc_id, obj_name, attr_name, ainfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":321
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Aget_info_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5A_info_t *ainfo, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":312
 *     return r
 * 
 * cdef herr_t H5Aget_info_by_name(hid_t loc_id, char *obj_name, char *attr_name, H5A_info_t *ainfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aget_info_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":323
 *     return r
 * 
 * cdef herr_t H5Aget_info_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5A_info_t *ainfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Aget_info_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, H5A_info_t *__pyx_v_ainfo, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aget_info_by_idx", 0);

  /* "h5py/defs.pyx":325
 * cdef herr_t H5Aget_info_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5A_info_t *ainfo, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aget_info_by_idx(loc_id, obj_name, idx_type, order, n, ainfo, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":326
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info_by_idx(loc_id, obj_name, idx_type, order, n, ainfo, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aget_info_by_idx(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_ainfo, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":327
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info_by_idx(loc_id, obj_name, idx_type, order, n, ainfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":328
 *     r = _hdf5.H5Aget_info_by_idx(loc_id, obj_name, idx_type, order, n, ainfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 328, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":329
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info_by_idx (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":328
 *     r = _hdf5.H5Aget_info_by_idx(loc_id, obj_name, idx_type, order, n, ainfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":331
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 331, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 331, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":327
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_info_by_idx(loc_id, obj_name, idx_type, order, n, ainfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":332
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Aiterate(hid_t obj_id, H5_index_t idx_type, H5_iter_order_t order, hsize_t *n, H5A_operator2_t op, void *op_data) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":323
 *     return r
 * 
 * cdef herr_t H5Aget_info_by_idx(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5A_info_t *ainfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aget_info_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":334
 *     return r
 * 
 * cdef herr_t H5Aiterate(hid_t obj_id, H5_index_t idx_type, H5_iter_order_t order, hsize_t *n, H5A_operator2_t op, void *op_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Aiterate(hid_t __pyx_v_obj_id, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t *__pyx_v_n, H5A_operator2_t __pyx_v_op, void *__pyx_v_op_data) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aiterate", 0);

  /* "h5py/defs.pyx":336
 * cdef herr_t H5Aiterate(hid_t obj_id, H5_index_t idx_type, H5_iter_order_t order, hsize_t *n, H5A_operator2_t op, void *op_data) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aiterate(obj_id, idx_type, order, n, op, op_data)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":337
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aiterate(obj_id, idx_type, order, n, op, op_data)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aiterate(__pyx_v_obj_id, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_op, __pyx_v_op_data);

  /* "h5py/defs.pyx":338
 *     set_default_error_handler()
 *     r = _hdf5.H5Aiterate(obj_id, idx_type, order, n, op, op_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":339
 *     r = _hdf5.H5Aiterate(obj_id, idx_type, order, n, op, op_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 339, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":340
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aiterate (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":339
 *     r = _hdf5.H5Aiterate(obj_id, idx_type, order, n, op, op_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":342
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aiterate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 342, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 342, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":338
 *     set_default_error_handler()
 *     r = _hdf5.H5Aiterate(obj_id, idx_type, order, n, op, op_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":343
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aiterate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hsize_t H5Aget_storage_size(hid_t attr_id) except <hsize_t>0:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":334
 *     return r
 * 
 * cdef herr_t H5Aiterate(hid_t obj_id, H5_index_t idx_type, H5_iter_order_t order, hsize_t *n, H5A_operator2_t op, void *op_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aiterate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":345
 *     return r
 * 
 * cdef hsize_t H5Aget_storage_size(hid_t attr_id) except <hsize_t>0:             # <<<<<<<<<<<<<<
 *     cdef hsize_t r
 *     set_default_error_handler()
 */

static hsize_t __pyx_f_4h5py_4defs_H5Aget_storage_size(hid_t __pyx_v_attr_id) {
  hsize_t __pyx_v_r;
  hsize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Aget_storage_size", 0);

  /* "h5py/defs.pyx":347
 * cdef hsize_t H5Aget_storage_size(hid_t attr_id) except <hsize_t>0:
 *     cdef hsize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Aget_storage_size(attr_id)
 *     if r==0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":348
 *     cdef hsize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_storage_size(attr_id)             # <<<<<<<<<<<<<<
 *     if r==0:
 *         if set_exception():
 */
  __pyx_v_r = H5Aget_storage_size(__pyx_v_attr_id);

  /* "h5py/defs.pyx":349
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_storage_size(attr_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hsize_t>0
 */
  __pyx_t_1 = ((__pyx_v_r == 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":350
 *     r = _hdf5.H5Aget_storage_size(attr_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hsize_t>0
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 350, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":351
 *     if r==0:
 *         if set_exception():
 *             return <hsize_t>0             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_storage_size (return value ==0)")
 */
      __pyx_r = ((hsize_t)0);
      goto __pyx_L0;

      /* "h5py/defs.pyx":350
 *     r = _hdf5.H5Aget_storage_size(attr_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hsize_t>0
 *         else:
 */
    }

    /* "h5py/defs.pyx":353
 *             return <hsize_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_storage_size (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 353, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 353, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":349
 *     set_default_error_handler()
 *     r = _hdf5.H5Aget_storage_size(attr_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hsize_t>0
 */
  }

  /* "h5py/defs.pyx":354
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_storage_size (return value ==0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Dcreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t lcpl_id, hid_t dcpl_id, hid_t dapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":345
 *     return r
 * 
 * cdef hsize_t H5Aget_storage_size(hid_t attr_id) except <hsize_t>0:             # <<<<<<<<<<<<<<
 *     cdef hsize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Aget_storage_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hsize_t)0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":356
 *     return r
 * 
 * cdef hid_t H5Dcreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t lcpl_id, hid_t dcpl_id, hid_t dapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     with nogil:
 */

static hid_t __pyx_f_4h5py_4defs_H5Dcreate(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_type_id, hid_t __pyx_v_space_id, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_dcpl_id, hid_t __pyx_v_dapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dcreate", 0);

  /* "h5py/defs.pyx":358
 * cdef hid_t H5Dcreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t lcpl_id, hid_t dcpl_id, hid_t dapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate(loc_id, name, type_id, space_id, lcpl_id, dcpl_id, dapl_id)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":359
 *     cdef hid_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dcreate(loc_id, name, type_id, space_id, lcpl_id, dcpl_id, dapl_id)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":360
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate(loc_id, name, type_id, space_id, lcpl_id, dcpl_id, dapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Dcreate(__pyx_v_loc_id, __pyx_v_name, __pyx_v_type_id, __pyx_v_space_id, __pyx_v_lcpl_id, __pyx_v_dcpl_id, __pyx_v_dapl_id);
      }

      /* "h5py/defs.pyx":358
 * cdef hid_t H5Dcreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t lcpl_id, hid_t dcpl_id, hid_t dapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate(loc_id, name, type_id, space_id, lcpl_id, dcpl_id, dapl_id)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":361
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate(loc_id, name, type_id, space_id, lcpl_id, dcpl_id, dapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":362
 *         r = _hdf5.H5Dcreate(loc_id, name, type_id, space_id, lcpl_id, dcpl_id, dapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 362, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":363
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dcreate (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":362
 *         r = _hdf5.H5Dcreate(loc_id, name, type_id, space_id, lcpl_id, dcpl_id, dapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":365
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 365, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":361
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate(loc_id, name, type_id, space_id, lcpl_id, dcpl_id, dapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":366
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dcreate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Dcreate_anon(hid_t file_id, hid_t type_id, hid_t space_id, hid_t plist_id, hid_t dapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":356
 *     return r
 * 
 * cdef hid_t H5Dcreate(hid_t loc_id, char *name, hid_t type_id, hid_t space_id, hid_t lcpl_id, hid_t dcpl_id, hid_t dapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dcreate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":368
 *     return r
 * 
 * cdef hid_t H5Dcreate_anon(hid_t file_id, hid_t type_id, hid_t space_id, hid_t plist_id, hid_t dapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     with nogil:
 */

static hid_t __pyx_f_4h5py_4defs_H5Dcreate_anon(hid_t __pyx_v_file_id, hid_t __pyx_v_type_id, hid_t __pyx_v_space_id, hid_t __pyx_v_plist_id, hid_t __pyx_v_dapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dcreate_anon", 0);

  /* "h5py/defs.pyx":370
 * cdef hid_t H5Dcreate_anon(hid_t file_id, hid_t type_id, hid_t space_id, hid_t plist_id, hid_t dapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate_anon(file_id, type_id, space_id, plist_id, dapl_id)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":371
 *     cdef hid_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dcreate_anon(file_id, type_id, space_id, plist_id, dapl_id)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":372
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate_anon(file_id, type_id, space_id, plist_id, dapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Dcreate_anon(__pyx_v_file_id, __pyx_v_type_id, __pyx_v_space_id, __pyx_v_plist_id, __pyx_v_dapl_id);
      }

      /* "h5py/defs.pyx":370
 * cdef hid_t H5Dcreate_anon(hid_t file_id, hid_t type_id, hid_t space_id, hid_t plist_id, hid_t dapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate_anon(file_id, type_id, space_id, plist_id, dapl_id)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":373
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate_anon(file_id, type_id, space_id, plist_id, dapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":374
 *         r = _hdf5.H5Dcreate_anon(file_id, type_id, space_id, plist_id, dapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 374, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":375
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dcreate_anon (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":374
 *         r = _hdf5.H5Dcreate_anon(file_id, type_id, space_id, plist_id, dapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":377
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dcreate_anon (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 377, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 377, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":373
 *         set_default_error_handler()
 *         r = _hdf5.H5Dcreate_anon(file_id, type_id, space_id, plist_id, dapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":378
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dcreate_anon (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Dopen(hid_t loc_id, char *name, hid_t dapl_id ) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":368
 *     return r
 * 
 * cdef hid_t H5Dcreate_anon(hid_t file_id, hid_t type_id, hid_t space_id, hid_t plist_id, hid_t dapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dcreate_anon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":380
 *     return r
 * 
 * cdef hid_t H5Dopen(hid_t loc_id, char *name, hid_t dapl_id ) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Dopen(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_dapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dopen", 0);

  /* "h5py/defs.pyx":382
 * cdef hid_t H5Dopen(hid_t loc_id, char *name, hid_t dapl_id ) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dopen(loc_id, name, dapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":383
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dopen(loc_id, name, dapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dopen(__pyx_v_loc_id, __pyx_v_name, __pyx_v_dapl_id);

  /* "h5py/defs.pyx":384
 *     set_default_error_handler()
 *     r = _hdf5.H5Dopen(loc_id, name, dapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":385
 *     r = _hdf5.H5Dopen(loc_id, name, dapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 385, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":386
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dopen (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":385
 *     r = _hdf5.H5Dopen(loc_id, name, dapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":388
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 388, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":384
 *     set_default_error_handler()
 *     r = _hdf5.H5Dopen(loc_id, name, dapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":389
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dopen (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dclose(hid_t dset_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":380
 *     return r
 * 
 * cdef hid_t H5Dopen(hid_t loc_id, char *name, hid_t dapl_id ) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dopen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":391
 *     return r
 * 
 * cdef herr_t H5Dclose(hid_t dset_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Dclose(hid_t __pyx_v_dset_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dclose", 0);

  /* "h5py/defs.pyx":393
 * cdef herr_t H5Dclose(hid_t dset_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dclose(dset_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":394
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dclose(dset_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dclose(__pyx_v_dset_id);

  /* "h5py/defs.pyx":395
 *     set_default_error_handler()
 *     r = _hdf5.H5Dclose(dset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":396
 *     r = _hdf5.H5Dclose(dset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 396, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":397
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dclose (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":396
 *     r = _hdf5.H5Dclose(dset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":399
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 399, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 399, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":395
 *     set_default_error_handler()
 *     r = _hdf5.H5Dclose(dset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":400
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dclose (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Dget_space(hid_t dset_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":391
 *     return r
 * 
 * cdef herr_t H5Dclose(hid_t dset_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":402
 *     return r
 * 
 * cdef hid_t H5Dget_space(hid_t dset_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Dget_space(hid_t __pyx_v_dset_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_space", 0);

  /* "h5py/defs.pyx":404
 * cdef hid_t H5Dget_space(hid_t dset_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dget_space(dset_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":405
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_space(dset_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dget_space(__pyx_v_dset_id);

  /* "h5py/defs.pyx":406
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_space(dset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":407
 *     r = _hdf5.H5Dget_space(dset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 407, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":408
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_space (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":407
 *     r = _hdf5.H5Dget_space(dset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":410
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_space (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 410, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":406
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_space(dset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":411
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_space (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dget_space_status(hid_t dset_id, H5D_space_status_t *status) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":402
 *     return r
 * 
 * cdef hid_t H5Dget_space(hid_t dset_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_space", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":413
 *     return r
 * 
 * cdef herr_t H5Dget_space_status(hid_t dset_id, H5D_space_status_t *status) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Dget_space_status(hid_t __pyx_v_dset_id, H5D_space_status_t *__pyx_v_status) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_space_status", 0);

  /* "h5py/defs.pyx":415
 * cdef herr_t H5Dget_space_status(hid_t dset_id, H5D_space_status_t *status) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dget_space_status(dset_id, status)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":416
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_space_status(dset_id, status)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dget_space_status(__pyx_v_dset_id, __pyx_v_status);

  /* "h5py/defs.pyx":417
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_space_status(dset_id, status)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":418
 *     r = _hdf5.H5Dget_space_status(dset_id, status)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 418, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":419
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_space_status (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":418
 *     r = _hdf5.H5Dget_space_status(dset_id, status)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":421
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_space_status (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__37, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 421, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":417
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_space_status(dset_id, status)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":422
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_space_status (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Dget_type(hid_t dset_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":413
 *     return r
 * 
 * cdef herr_t H5Dget_space_status(hid_t dset_id, H5D_space_status_t *status) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_space_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":424
 *     return r
 * 
 * cdef hid_t H5Dget_type(hid_t dset_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Dget_type(hid_t __pyx_v_dset_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_type", 0);

  /* "h5py/defs.pyx":426
 * cdef hid_t H5Dget_type(hid_t dset_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dget_type(dset_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":427
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_type(dset_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dget_type(__pyx_v_dset_id);

  /* "h5py/defs.pyx":428
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_type(dset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":429
 *     r = _hdf5.H5Dget_type(dset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 429, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":430
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_type (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":429
 *     r = _hdf5.H5Dget_type(dset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":432
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__38, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 432, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 432, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":428
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_type(dset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":433
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_type (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Dget_create_plist(hid_t dataset_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":424
 *     return r
 * 
 * cdef hid_t H5Dget_type(hid_t dset_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":435
 *     return r
 * 
 * cdef hid_t H5Dget_create_plist(hid_t dataset_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Dget_create_plist(hid_t __pyx_v_dataset_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_create_plist", 0);

  /* "h5py/defs.pyx":437
 * cdef hid_t H5Dget_create_plist(hid_t dataset_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dget_create_plist(dataset_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":438
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_create_plist(dataset_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dget_create_plist(__pyx_v_dataset_id);

  /* "h5py/defs.pyx":439
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_create_plist(dataset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":440
 *     r = _hdf5.H5Dget_create_plist(dataset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 440, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":441
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_create_plist (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":440
 *     r = _hdf5.H5Dget_create_plist(dataset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":443
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_create_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__39, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 443, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 443, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":439
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_create_plist(dataset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":444
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_create_plist (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Dget_access_plist(hid_t dataset_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":435
 *     return r
 * 
 * cdef hid_t H5Dget_create_plist(hid_t dataset_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_create_plist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":446
 *     return r
 * 
 * cdef hid_t H5Dget_access_plist(hid_t dataset_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Dget_access_plist(hid_t __pyx_v_dataset_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_access_plist", 0);

  /* "h5py/defs.pyx":448
 * cdef hid_t H5Dget_access_plist(hid_t dataset_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dget_access_plist(dataset_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":449
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_access_plist(dataset_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dget_access_plist(__pyx_v_dataset_id);

  /* "h5py/defs.pyx":450
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_access_plist(dataset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":451
 *     r = _hdf5.H5Dget_access_plist(dataset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 451, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":452
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_access_plist (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":451
 *     r = _hdf5.H5Dget_access_plist(dataset_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":454
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_access_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__40, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 454, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":450
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_access_plist(dataset_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":455
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_access_plist (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef haddr_t H5Dget_offset(hid_t dset_id) except <haddr_t>0:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":446
 *     return r
 * 
 * cdef hid_t H5Dget_access_plist(hid_t dataset_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_access_plist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":457
 *     return r
 * 
 * cdef haddr_t H5Dget_offset(hid_t dset_id) except <haddr_t>0:             # <<<<<<<<<<<<<<
 *     cdef haddr_t r
 *     set_default_error_handler()
 */

static haddr_t __pyx_f_4h5py_4defs_H5Dget_offset(hid_t __pyx_v_dset_id) {
  haddr_t __pyx_v_r;
  haddr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_offset", 0);

  /* "h5py/defs.pyx":459
 * cdef haddr_t H5Dget_offset(hid_t dset_id) except <haddr_t>0:
 *     cdef haddr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dget_offset(dset_id)
 *     if r==0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":460
 *     cdef haddr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_offset(dset_id)             # <<<<<<<<<<<<<<
 *     if r==0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dget_offset(__pyx_v_dset_id);

  /* "h5py/defs.pyx":461
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_offset(dset_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <haddr_t>0
 */
  __pyx_t_1 = ((__pyx_v_r == 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":462
 *     r = _hdf5.H5Dget_offset(dset_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <haddr_t>0
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 462, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":463
 *     if r==0:
 *         if set_exception():
 *             return <haddr_t>0             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_offset (return value ==0)")
 */
      __pyx_r = ((haddr_t)0);
      goto __pyx_L0;

      /* "h5py/defs.pyx":462
 *     r = _hdf5.H5Dget_offset(dset_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <haddr_t>0
 *         else:
 */
    }

    /* "h5py/defs.pyx":465
 *             return <haddr_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_offset (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 465, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":461
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_offset(dset_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <haddr_t>0
 */
  }

  /* "h5py/defs.pyx":466
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_offset (return value ==0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hsize_t H5Dget_storage_size(hid_t dset_id) except? <hsize_t>0:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":457
 *     return r
 * 
 * cdef haddr_t H5Dget_offset(hid_t dset_id) except <haddr_t>0:             # <<<<<<<<<<<<<<
 *     cdef haddr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((haddr_t)0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":468
 *     return r
 * 
 * cdef hsize_t H5Dget_storage_size(hid_t dset_id) except? <hsize_t>0:             # <<<<<<<<<<<<<<
 *     cdef hsize_t r
 *     set_default_error_handler()
 */

static hsize_t __pyx_f_4h5py_4defs_H5Dget_storage_size(hid_t __pyx_v_dset_id) {
  hsize_t __pyx_v_r;
  hsize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_storage_size", 0);

  /* "h5py/defs.pyx":470
 * cdef hsize_t H5Dget_storage_size(hid_t dset_id) except? <hsize_t>0:
 *     cdef hsize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dget_storage_size(dset_id)
 *     if r==0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":471
 *     cdef hsize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_storage_size(dset_id)             # <<<<<<<<<<<<<<
 *     if r==0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dget_storage_size(__pyx_v_dset_id);

  /* "h5py/defs.pyx":472
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_storage_size(dset_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hsize_t>0
 */
  __pyx_t_1 = ((__pyx_v_r == 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":473
 *     r = _hdf5.H5Dget_storage_size(dset_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hsize_t>0
 *     return r
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 473, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "h5py/defs.pyx":474
 *     if r==0:
 *         if set_exception():
 *             return <hsize_t>0             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
      __pyx_r = ((hsize_t)0);
      goto __pyx_L0;

      /* "h5py/defs.pyx":473
 *     r = _hdf5.H5Dget_storage_size(dset_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hsize_t>0
 *     return r
 */
    }

    /* "h5py/defs.pyx":472
 *     set_default_error_handler()
 *     r = _hdf5.H5Dget_storage_size(dset_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hsize_t>0
 */
  }

  /* "h5py/defs.pyx":475
 *         if set_exception():
 *             return <hsize_t>0
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t plist_id, void *buf) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":468
 *     return r
 * 
 * cdef hsize_t H5Dget_storage_size(hid_t dset_id) except? <hsize_t>0:             # <<<<<<<<<<<<<<
 *     cdef hsize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("h5py.defs.H5Dget_storage_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hsize_t)0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":477
 *     return r
 * 
 * cdef herr_t H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t plist_id, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Dread(hid_t __pyx_v_dset_id, hid_t __pyx_v_mem_type_id, hid_t __pyx_v_mem_space_id, hid_t __pyx_v_file_space_id, hid_t __pyx_v_plist_id, void *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dread", 0);

  /* "h5py/defs.pyx":479
 * cdef herr_t H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t plist_id, void *buf) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dread(dset_id, mem_type_id, mem_space_id, file_space_id, plist_id, buf)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":480
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dread(dset_id, mem_type_id, mem_space_id, file_space_id, plist_id, buf)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":481
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Dread(dset_id, mem_type_id, mem_space_id, file_space_id, plist_id, buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Dread(__pyx_v_dset_id, __pyx_v_mem_type_id, __pyx_v_mem_space_id, __pyx_v_file_space_id, __pyx_v_plist_id, __pyx_v_buf);
      }

      /* "h5py/defs.pyx":479
 * cdef herr_t H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t plist_id, void *buf) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dread(dset_id, mem_type_id, mem_space_id, file_space_id, plist_id, buf)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":482
 *         set_default_error_handler()
 *         r = _hdf5.H5Dread(dset_id, mem_type_id, mem_space_id, file_space_id, plist_id, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":483
 *         r = _hdf5.H5Dread(dset_id, mem_type_id, mem_space_id, file_space_id, plist_id, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 483, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":484
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dread (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":483
 *         r = _hdf5.H5Dread(dset_id, mem_type_id, mem_space_id, file_space_id, plist_id, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":486
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dread (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__42, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 486, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":482
 *         set_default_error_handler()
 *         r = _hdf5.H5Dread(dset_id, mem_type_id, mem_space_id, file_space_id, plist_id, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":487
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dread (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dwrite(hid_t dset_id, hid_t mem_type, hid_t mem_space, hid_t file_space, hid_t xfer_plist, void* buf) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":477
 *     return r
 * 
 * cdef herr_t H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t plist_id, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dread", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":489
 *     return r
 * 
 * cdef herr_t H5Dwrite(hid_t dset_id, hid_t mem_type, hid_t mem_space, hid_t file_space, hid_t xfer_plist, void* buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Dwrite(hid_t __pyx_v_dset_id, hid_t __pyx_v_mem_type, hid_t __pyx_v_mem_space, hid_t __pyx_v_file_space, hid_t __pyx_v_xfer_plist, void *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dwrite", 0);

  /* "h5py/defs.pyx":491
 * cdef herr_t H5Dwrite(hid_t dset_id, hid_t mem_type, hid_t mem_space, hid_t file_space, hid_t xfer_plist, void* buf) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dwrite(dset_id, mem_type, mem_space, file_space, xfer_plist, buf)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":492
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dwrite(dset_id, mem_type, mem_space, file_space, xfer_plist, buf)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":493
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Dwrite(dset_id, mem_type, mem_space, file_space, xfer_plist, buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Dwrite(__pyx_v_dset_id, __pyx_v_mem_type, __pyx_v_mem_space, __pyx_v_file_space, __pyx_v_xfer_plist, __pyx_v_buf);
      }

      /* "h5py/defs.pyx":491
 * cdef herr_t H5Dwrite(hid_t dset_id, hid_t mem_type, hid_t mem_space, hid_t file_space, hid_t xfer_plist, void* buf) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dwrite(dset_id, mem_type, mem_space, file_space, xfer_plist, buf)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":494
 *         set_default_error_handler()
 *         r = _hdf5.H5Dwrite(dset_id, mem_type, mem_space, file_space, xfer_plist, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":495
 *         r = _hdf5.H5Dwrite(dset_id, mem_type, mem_space, file_space, xfer_plist, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 495, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":496
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dwrite (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":495
 *         r = _hdf5.H5Dwrite(dset_id, mem_type, mem_space, file_space, xfer_plist, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":498
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dwrite (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 498, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 498, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":494
 *         set_default_error_handler()
 *         r = _hdf5.H5Dwrite(dset_id, mem_type, mem_space, file_space, xfer_plist, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":499
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dwrite (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dextend(hid_t dataset_id, hsize_t *size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":489
 *     return r
 * 
 * cdef herr_t H5Dwrite(hid_t dset_id, hid_t mem_type, hid_t mem_space, hid_t file_space, hid_t xfer_plist, void* buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dwrite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":501
 *     return r
 * 
 * cdef herr_t H5Dextend(hid_t dataset_id, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Dextend(hid_t __pyx_v_dataset_id, hsize_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dextend", 0);

  /* "h5py/defs.pyx":503
 * cdef herr_t H5Dextend(hid_t dataset_id, hsize_t *size) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dextend(dataset_id, size)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":504
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dextend(dataset_id, size)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":505
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Dextend(dataset_id, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Dextend(__pyx_v_dataset_id, __pyx_v_size);
      }

      /* "h5py/defs.pyx":503
 * cdef herr_t H5Dextend(hid_t dataset_id, hsize_t *size) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dextend(dataset_id, size)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":506
 *         set_default_error_handler()
 *         r = _hdf5.H5Dextend(dataset_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":507
 *         r = _hdf5.H5Dextend(dataset_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 507, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":508
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dextend (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":507
 *         r = _hdf5.H5Dextend(dataset_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":510
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dextend (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__44, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 510, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":506
 *         set_default_error_handler()
 *         r = _hdf5.H5Dextend(dataset_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":511
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dextend (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dfill(void *fill, hid_t fill_type_id, void *buf,  hid_t buf_type_id, hid_t space_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":501
 *     return r
 * 
 * cdef herr_t H5Dextend(hid_t dataset_id, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dextend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":513
 *     return r
 * 
 * cdef herr_t H5Dfill(void *fill, hid_t fill_type_id, void *buf,  hid_t buf_type_id, hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Dfill(void *__pyx_v_fill, hid_t __pyx_v_fill_type_id, void *__pyx_v_buf, hid_t __pyx_v_buf_type_id, hid_t __pyx_v_space_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dfill", 0);

  /* "h5py/defs.pyx":515
 * cdef herr_t H5Dfill(void *fill, hid_t fill_type_id, void *buf,  hid_t buf_type_id, hid_t space_id) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dfill(fill, fill_type_id, buf, buf_type_id, space_id)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":516
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dfill(fill, fill_type_id, buf, buf_type_id, space_id)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":517
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Dfill(fill, fill_type_id, buf, buf_type_id, space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Dfill(__pyx_v_fill, __pyx_v_fill_type_id, __pyx_v_buf, __pyx_v_buf_type_id, __pyx_v_space_id);
      }

      /* "h5py/defs.pyx":515
 * cdef herr_t H5Dfill(void *fill, hid_t fill_type_id, void *buf,  hid_t buf_type_id, hid_t space_id) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dfill(fill, fill_type_id, buf, buf_type_id, space_id)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":518
 *         set_default_error_handler()
 *         r = _hdf5.H5Dfill(fill, fill_type_id, buf, buf_type_id, space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":519
 *         r = _hdf5.H5Dfill(fill, fill_type_id, buf, buf_type_id, space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 519, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":520
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dfill (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":519
 *         r = _hdf5.H5Dfill(fill, fill_type_id, buf, buf_type_id, space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":522
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dfill (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__45, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 522, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":518
 *         set_default_error_handler()
 *         r = _hdf5.H5Dfill(fill, fill_type_id, buf, buf_type_id, space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":523
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dfill (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dvlen_get_buf_size(hid_t dset_id, hid_t type_id, hid_t space_id, hsize_t *size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":513
 *     return r
 * 
 * cdef herr_t H5Dfill(void *fill, hid_t fill_type_id, void *buf,  hid_t buf_type_id, hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dfill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":525
 *     return r
 * 
 * cdef herr_t H5Dvlen_get_buf_size(hid_t dset_id, hid_t type_id, hid_t space_id, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Dvlen_get_buf_size(hid_t __pyx_v_dset_id, hid_t __pyx_v_type_id, hid_t __pyx_v_space_id, hsize_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dvlen_get_buf_size", 0);

  /* "h5py/defs.pyx":527
 * cdef herr_t H5Dvlen_get_buf_size(hid_t dset_id, hid_t type_id, hid_t space_id, hsize_t *size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dvlen_get_buf_size(dset_id, type_id, space_id, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":528
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dvlen_get_buf_size(dset_id, type_id, space_id, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dvlen_get_buf_size(__pyx_v_dset_id, __pyx_v_type_id, __pyx_v_space_id, __pyx_v_size);

  /* "h5py/defs.pyx":529
 *     set_default_error_handler()
 *     r = _hdf5.H5Dvlen_get_buf_size(dset_id, type_id, space_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":530
 *     r = _hdf5.H5Dvlen_get_buf_size(dset_id, type_id, space_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 530, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":531
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dvlen_get_buf_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":530
 *     r = _hdf5.H5Dvlen_get_buf_size(dset_id, type_id, space_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":533
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dvlen_get_buf_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__46, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 533, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 533, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":529
 *     set_default_error_handler()
 *     r = _hdf5.H5Dvlen_get_buf_size(dset_id, type_id, space_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":534
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dvlen_get_buf_size (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dvlen_reclaim(hid_t type_id, hid_t space_id,  hid_t plist, void *buf) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":525
 *     return r
 * 
 * cdef herr_t H5Dvlen_get_buf_size(hid_t dset_id, hid_t type_id, hid_t space_id, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dvlen_get_buf_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":536
 *     return r
 * 
 * cdef herr_t H5Dvlen_reclaim(hid_t type_id, hid_t space_id,  hid_t plist, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Dvlen_reclaim(hid_t __pyx_v_type_id, hid_t __pyx_v_space_id, hid_t __pyx_v_plist, void *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dvlen_reclaim", 0);

  /* "h5py/defs.pyx":538
 * cdef herr_t H5Dvlen_reclaim(hid_t type_id, hid_t space_id,  hid_t plist, void *buf) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Dvlen_reclaim(type_id, space_id, plist, buf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":539
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Dvlen_reclaim(type_id, space_id, plist, buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Dvlen_reclaim(__pyx_v_type_id, __pyx_v_space_id, __pyx_v_plist, __pyx_v_buf);

  /* "h5py/defs.pyx":540
 *     set_default_error_handler()
 *     r = _hdf5.H5Dvlen_reclaim(type_id, space_id, plist, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":541
 *     r = _hdf5.H5Dvlen_reclaim(type_id, space_id, plist, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 541, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":542
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dvlen_reclaim (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":541
 *     r = _hdf5.H5Dvlen_reclaim(type_id, space_id, plist, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":544
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dvlen_reclaim (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__47, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 544, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 544, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":540
 *     set_default_error_handler()
 *     r = _hdf5.H5Dvlen_reclaim(type_id, space_id, plist, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":545
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dvlen_reclaim (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Diterate(void *buf, hid_t type_id, hid_t space_id,  H5D_operator_t op, void* operator_data) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":536
 *     return r
 * 
 * cdef herr_t H5Dvlen_reclaim(hid_t type_id, hid_t space_id,  hid_t plist, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dvlen_reclaim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":547
 *     return r
 * 
 * cdef herr_t H5Diterate(void *buf, hid_t type_id, hid_t space_id,  H5D_operator_t op, void* operator_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Diterate(void *__pyx_v_buf, hid_t __pyx_v_type_id, hid_t __pyx_v_space_id, H5D_operator_t __pyx_v_op, void *__pyx_v_operator_data) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Diterate", 0);

  /* "h5py/defs.pyx":549
 * cdef herr_t H5Diterate(void *buf, hid_t type_id, hid_t space_id,  H5D_operator_t op, void* operator_data) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Diterate(buf, type_id, space_id, op, operator_data)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":550
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Diterate(buf, type_id, space_id, op, operator_data)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":551
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Diterate(buf, type_id, space_id, op, operator_data)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Diterate(__pyx_v_buf, __pyx_v_type_id, __pyx_v_space_id, __pyx_v_op, __pyx_v_operator_data);
      }

      /* "h5py/defs.pyx":549
 * cdef herr_t H5Diterate(void *buf, hid_t type_id, hid_t space_id,  H5D_operator_t op, void* operator_data) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Diterate(buf, type_id, space_id, op, operator_data)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":552
 *         set_default_error_handler()
 *         r = _hdf5.H5Diterate(buf, type_id, space_id, op, operator_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":553
 *         r = _hdf5.H5Diterate(buf, type_id, space_id, op, operator_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 553, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":554
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Diterate (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":553
 *         r = _hdf5.H5Diterate(buf, type_id, space_id, op, operator_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":556
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Diterate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 556, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":552
 *         set_default_error_handler()
 *         r = _hdf5.H5Diterate(buf, type_id, space_id, op, operator_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":557
 *         else:
 *             raise RuntimeError("Unspecified error in H5Diterate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Dset_extent(hid_t dset_id, hsize_t* size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":547
 *     return r
 * 
 * cdef herr_t H5Diterate(void *buf, hid_t type_id, hid_t space_id,  H5D_operator_t op, void* operator_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Diterate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":559
 *     return r
 * 
 * cdef herr_t H5Dset_extent(hid_t dset_id, hsize_t* size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Dset_extent(hid_t __pyx_v_dset_id, hsize_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dset_extent", 0);

  /* "h5py/defs.pyx":561
 * cdef herr_t H5Dset_extent(hid_t dset_id, hsize_t* size) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dset_extent(dset_id, size)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":562
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dset_extent(dset_id, size)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":563
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Dset_extent(dset_id, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Dset_extent(__pyx_v_dset_id, __pyx_v_size);
      }

      /* "h5py/defs.pyx":561
 * cdef herr_t H5Dset_extent(hid_t dset_id, hsize_t* size) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Dset_extent(dset_id, size)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":564
 *         set_default_error_handler()
 *         r = _hdf5.H5Dset_extent(dset_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":565
 *         r = _hdf5.H5Dset_extent(dset_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 565, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":566
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dset_extent (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":565
 *         r = _hdf5.H5Dset_extent(dset_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":568
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dset_extent (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 568, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":564
 *         set_default_error_handler()
 *         r = _hdf5.H5Dset_extent(dset_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":569
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dset_extent (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 178):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":559
 *     return r
 * 
 * cdef herr_t H5Dset_extent(hid_t dset_id, hsize_t* size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dset_extent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":572
 * 
 * IF HDF5_VERSION >= (1, 9, 178):
 *     cdef herr_t H5Dflush(hid_t dataset_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Dflush(hid_t __pyx_v_dataset_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dflush", 0);

  /* "h5py/defs.pyx":574
 *     cdef herr_t H5Dflush(hid_t dataset_id) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5Dflush(dataset_id)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":575
 *         cdef herr_t r
 *         with nogil:
 *             set_default_error_handler()             # <<<<<<<<<<<<<<
 *             r = _hdf5.H5Dflush(dataset_id)
 *         if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":576
 *         with nogil:
 *             set_default_error_handler()
 *             r = _hdf5.H5Dflush(dataset_id)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
        __pyx_v_r = H5Dflush(__pyx_v_dataset_id);
      }

      /* "h5py/defs.pyx":574
 *     cdef herr_t H5Dflush(hid_t dataset_id) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5Dflush(dataset_id)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":577
 *             set_default_error_handler()
 *             r = _hdf5.H5Dflush(dataset_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":578
 *             r = _hdf5.H5Dflush(dataset_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 578, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":579
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dflush (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":578
 *             r = _hdf5.H5Dflush(dataset_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":581
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dflush (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 581, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":577
 *             set_default_error_handler()
 *             r = _hdf5.H5Dflush(dataset_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":582
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dflush (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 178):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":572
 * 
 * IF HDF5_VERSION >= (1, 9, 178):
 *     cdef herr_t H5Dflush(hid_t dataset_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dflush", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":585
 * 
 * IF HDF5_VERSION >= (1, 9, 178):
 *     cdef herr_t H5Drefresh(hid_t dataset_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Drefresh(hid_t __pyx_v_dataset_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Drefresh", 0);

  /* "h5py/defs.pyx":587
 *     cdef herr_t H5Drefresh(hid_t dataset_id) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5Drefresh(dataset_id)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":588
 *         cdef herr_t r
 *         with nogil:
 *             set_default_error_handler()             # <<<<<<<<<<<<<<
 *             r = _hdf5.H5Drefresh(dataset_id)
 *         if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":589
 *         with nogil:
 *             set_default_error_handler()
 *             r = _hdf5.H5Drefresh(dataset_id)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
        __pyx_v_r = H5Drefresh(__pyx_v_dataset_id);
      }

      /* "h5py/defs.pyx":587
 *     cdef herr_t H5Drefresh(hid_t dataset_id) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5Drefresh(dataset_id)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":590
 *             set_default_error_handler()
 *             r = _hdf5.H5Drefresh(dataset_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":591
 *             r = _hdf5.H5Drefresh(dataset_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 591, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":592
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Drefresh (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":591
 *             r = _hdf5.H5Drefresh(dataset_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":594
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Drefresh (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 594, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":590
 *             set_default_error_handler()
 *             r = _hdf5.H5Drefresh(dataset_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":595
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Drefresh (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 11):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":585
 * 
 * IF HDF5_VERSION >= (1, 9, 178):
 *     cdef herr_t H5Drefresh(hid_t dataset_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Drefresh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":598
 * 
 * IF HDF5_VERSION >= (1, 8, 11):
 *     cdef herr_t H5DOwrite_chunk(hid_t dset_id, hid_t dxpl_id, uint32_t filters, const hsize_t *offset, size_t data_size, const void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5DOwrite_chunk(hid_t __pyx_v_dset_id, hid_t __pyx_v_dxpl_id, __pyx_t_5numpy_uint32_t __pyx_v_filters, hsize_t const *__pyx_v_offset, size_t __pyx_v_data_size, void const *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DOwrite_chunk", 0);

  /* "h5py/defs.pyx":600
 *     cdef herr_t H5DOwrite_chunk(hid_t dset_id, hid_t dxpl_id, uint32_t filters, const hsize_t *offset, size_t data_size, const void *buf) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5DOwrite_chunk(dset_id, dxpl_id, filters, offset, data_size, buf)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":601
 *         cdef herr_t r
 *         with nogil:
 *             set_default_error_handler()             # <<<<<<<<<<<<<<
 *             r = _hdf5.H5DOwrite_chunk(dset_id, dxpl_id, filters, offset, data_size, buf)
 *         if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":602
 *         with nogil:
 *             set_default_error_handler()
 *             r = _hdf5.H5DOwrite_chunk(dset_id, dxpl_id, filters, offset, data_size, buf)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
        __pyx_v_r = H5DOwrite_chunk(__pyx_v_dset_id, __pyx_v_dxpl_id, __pyx_v_filters, __pyx_v_offset, __pyx_v_data_size, __pyx_v_buf);
      }

      /* "h5py/defs.pyx":600
 *     cdef herr_t H5DOwrite_chunk(hid_t dset_id, hid_t dxpl_id, uint32_t filters, const hsize_t *offset, size_t data_size, const void *buf) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5DOwrite_chunk(dset_id, dxpl_id, filters, offset, data_size, buf)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":603
 *             set_default_error_handler()
 *             r = _hdf5.H5DOwrite_chunk(dset_id, dxpl_id, filters, offset, data_size, buf)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":604
 *             r = _hdf5.H5DOwrite_chunk(dset_id, dxpl_id, filters, offset, data_size, buf)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 604, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":605
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5DOwrite_chunk (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":604
 *             r = _hdf5.H5DOwrite_chunk(dset_id, dxpl_id, filters, offset, data_size, buf)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":607
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5DOwrite_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__52, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 607, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":603
 *             set_default_error_handler()
 *             r = _hdf5.H5DOwrite_chunk(dset_id, dxpl_id, filters, offset, data_size, buf)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":608
 *             else:
 *                 raise RuntimeError("Unspecified error in H5DOwrite_chunk (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":598
 * 
 * IF HDF5_VERSION >= (1, 8, 11):
 *     cdef herr_t H5DOwrite_chunk(hid_t dset_id, hid_t dxpl_id, uint32_t filters, const hsize_t *offset, size_t data_size, const void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DOwrite_chunk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":611
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 *     cdef herr_t H5Dget_chunk_storage_size(hid_t dset_id, const hsize_t *offset, hsize_t *chunk_nbytes) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Dget_chunk_storage_size(hid_t __pyx_v_dset_id, hsize_t const *__pyx_v_offset, hsize_t *__pyx_v_chunk_nbytes) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_chunk_storage_size", 0);

  /* "h5py/defs.pyx":613
 *     cdef herr_t H5Dget_chunk_storage_size(hid_t dset_id, const hsize_t *offset, hsize_t *chunk_nbytes) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5Dget_chunk_storage_size(dset_id, offset, chunk_nbytes)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":614
 *         cdef herr_t r
 *         with nogil:
 *             set_default_error_handler()             # <<<<<<<<<<<<<<
 *             r = _hdf5.H5Dget_chunk_storage_size(dset_id, offset, chunk_nbytes)
 *         if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":615
 *         with nogil:
 *             set_default_error_handler()
 *             r = _hdf5.H5Dget_chunk_storage_size(dset_id, offset, chunk_nbytes)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
        __pyx_v_r = H5Dget_chunk_storage_size(__pyx_v_dset_id, __pyx_v_offset, __pyx_v_chunk_nbytes);
      }

      /* "h5py/defs.pyx":613
 *     cdef herr_t H5Dget_chunk_storage_size(hid_t dset_id, const hsize_t *offset, hsize_t *chunk_nbytes) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5Dget_chunk_storage_size(dset_id, offset, chunk_nbytes)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":616
 *             set_default_error_handler()
 *             r = _hdf5.H5Dget_chunk_storage_size(dset_id, offset, chunk_nbytes)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":617
 *             r = _hdf5.H5Dget_chunk_storage_size(dset_id, offset, chunk_nbytes)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 617, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":618
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_storage_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":617
 *             r = _hdf5.H5Dget_chunk_storage_size(dset_id, offset, chunk_nbytes)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":620
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_storage_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__53, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 620, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 620, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":616
 *             set_default_error_handler()
 *             r = _hdf5.H5Dget_chunk_storage_size(dset_id, offset, chunk_nbytes)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":621
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_storage_size (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":611
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 *     cdef herr_t H5Dget_chunk_storage_size(hid_t dset_id, const hsize_t *offset, hsize_t *chunk_nbytes) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_chunk_storage_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":624
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 *     cdef herr_t H5DOread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5DOread_chunk(hid_t __pyx_v_dset_id, hid_t __pyx_v_dxpl_id, hsize_t const *__pyx_v_offset, __pyx_t_5numpy_uint32_t *__pyx_v_filters, void *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DOread_chunk", 0);

  /* "h5py/defs.pyx":626
 *     cdef herr_t H5DOread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5DOread_chunk(dset_id, dxpl_id, offset, filters, buf)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":627
 *         cdef herr_t r
 *         with nogil:
 *             set_default_error_handler()             # <<<<<<<<<<<<<<
 *             r = _hdf5.H5DOread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":628
 *         with nogil:
 *             set_default_error_handler()
 *             r = _hdf5.H5DOread_chunk(dset_id, dxpl_id, offset, filters, buf)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
        __pyx_v_r = H5DOread_chunk(__pyx_v_dset_id, __pyx_v_dxpl_id, __pyx_v_offset, __pyx_v_filters, __pyx_v_buf);
      }

      /* "h5py/defs.pyx":626
 *     cdef herr_t H5DOread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5DOread_chunk(dset_id, dxpl_id, offset, filters, buf)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":629
 *             set_default_error_handler()
 *             r = _hdf5.H5DOread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":630
 *             r = _hdf5.H5DOread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 630, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":631
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5DOread_chunk (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":630
 *             r = _hdf5.H5DOread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":633
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5DOread_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 633, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":629
 *             set_default_error_handler()
 *             r = _hdf5.H5DOread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":634
 *             else:
 *                 raise RuntimeError("Unspecified error in H5DOread_chunk (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 3):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":624
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 *     cdef herr_t H5DOread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DOread_chunk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":637
 * 
 * IF HDF5_VERSION >= (1, 10, 3):
 *     cdef herr_t H5Dread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Dread_chunk(hid_t __pyx_v_dset_id, hid_t __pyx_v_dxpl_id, hsize_t const *__pyx_v_offset, __pyx_t_5numpy_uint32_t *__pyx_v_filters, void *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dread_chunk", 0);

  /* "h5py/defs.pyx":639
 *     cdef herr_t H5Dread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5Dread_chunk(dset_id, dxpl_id, offset, filters, buf)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":640
 *         cdef herr_t r
 *         with nogil:
 *             set_default_error_handler()             # <<<<<<<<<<<<<<
 *             r = _hdf5.H5Dread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":641
 *         with nogil:
 *             set_default_error_handler()
 *             r = _hdf5.H5Dread_chunk(dset_id, dxpl_id, offset, filters, buf)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
        __pyx_v_r = H5Dread_chunk(__pyx_v_dset_id, __pyx_v_dxpl_id, __pyx_v_offset, __pyx_v_filters, __pyx_v_buf);
      }

      /* "h5py/defs.pyx":639
 *     cdef herr_t H5Dread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf) except <herr_t>-1:
 *         cdef herr_t r
 *         with nogil:             # <<<<<<<<<<<<<<
 *             set_default_error_handler()
 *             r = _hdf5.H5Dread_chunk(dset_id, dxpl_id, offset, filters, buf)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":642
 *             set_default_error_handler()
 *             r = _hdf5.H5Dread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":643
 *             r = _hdf5.H5Dread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 643, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":644
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dread_chunk (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":643
 *             r = _hdf5.H5Dread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":646
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dread_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__55, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 646, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":642
 *             set_default_error_handler()
 *             r = _hdf5.H5Dread_chunk(dset_id, dxpl_id, offset, filters, buf)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":647
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dread_chunk (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":637
 * 
 * IF HDF5_VERSION >= (1, 10, 3):
 *     cdef herr_t H5Dread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dread_chunk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":650
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 *     cdef herr_t H5Dget_num_chunks(hid_t dset_id, hid_t fspace_id, hsize_t *nchunks) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Dget_num_chunks(hid_t __pyx_v_dset_id, hid_t __pyx_v_fspace_id, hsize_t *__pyx_v_nchunks) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_num_chunks", 0);

  /* "h5py/defs.pyx":652
 *     cdef herr_t H5Dget_num_chunks(hid_t dset_id, hid_t fspace_id, hsize_t *nchunks) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dget_num_chunks(dset_id, fspace_id, nchunks)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":653
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_num_chunks(dset_id, fspace_id, nchunks)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Dget_num_chunks(__pyx_v_dset_id, __pyx_v_fspace_id, __pyx_v_nchunks);

  /* "h5py/defs.pyx":654
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_num_chunks(dset_id, fspace_id, nchunks)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":655
 *         r = _hdf5.H5Dget_num_chunks(dset_id, fspace_id, nchunks)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 655, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":656
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_num_chunks (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":655
 *         r = _hdf5.H5Dget_num_chunks(dset_id, fspace_id, nchunks)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":658
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_num_chunks (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__56, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 658, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 658, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":654
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_num_chunks(dset_id, fspace_id, nchunks)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":659
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_num_chunks (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":650
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 *     cdef herr_t H5Dget_num_chunks(hid_t dset_id, hid_t fspace_id, hsize_t *nchunks) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_num_chunks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":662
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 *     cdef herr_t H5Dget_chunk_info(hid_t dset_id, hid_t fspace_id, hsize_t chk_idx, hsize_t *offset, unsigned *filter_mask, haddr_t *addr, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Dget_chunk_info(hid_t __pyx_v_dset_id, hid_t __pyx_v_fspace_id, hsize_t __pyx_v_chk_idx, hsize_t *__pyx_v_offset, unsigned int *__pyx_v_filter_mask, haddr_t *__pyx_v_addr, hsize_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_chunk_info", 0);

  /* "h5py/defs.pyx":664
 *     cdef herr_t H5Dget_chunk_info(hid_t dset_id, hid_t fspace_id, hsize_t chk_idx, hsize_t *offset, unsigned *filter_mask, haddr_t *addr, hsize_t *size) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dget_chunk_info(dset_id, fspace_id, chk_idx, offset, filter_mask, addr, size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":665
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_chunk_info(dset_id, fspace_id, chk_idx, offset, filter_mask, addr, size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Dget_chunk_info(__pyx_v_dset_id, __pyx_v_fspace_id, __pyx_v_chk_idx, __pyx_v_offset, __pyx_v_filter_mask, __pyx_v_addr, __pyx_v_size);

  /* "h5py/defs.pyx":666
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_chunk_info(dset_id, fspace_id, chk_idx, offset, filter_mask, addr, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":667
 *         r = _hdf5.H5Dget_chunk_info(dset_id, fspace_id, chk_idx, offset, filter_mask, addr, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 667, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":668
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_info (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":667
 *         r = _hdf5.H5Dget_chunk_info(dset_id, fspace_id, chk_idx, offset, filter_mask, addr, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":670
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_info (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__57, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 670, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":666
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_chunk_info(dset_id, fspace_id, chk_idx, offset, filter_mask, addr, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":671
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_info (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":662
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 *     cdef herr_t H5Dget_chunk_info(hid_t dset_id, hid_t fspace_id, hsize_t chk_idx, hsize_t *offset, unsigned *filter_mask, haddr_t *addr, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_chunk_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":674
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 *     cdef herr_t H5Dget_chunk_info_by_coord(hid_t dset_id, const hsize_t *offset, unsigned *filter_mask, haddr_t *addr, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Dget_chunk_info_by_coord(hid_t __pyx_v_dset_id, hsize_t const *__pyx_v_offset, unsigned int *__pyx_v_filter_mask, haddr_t *__pyx_v_addr, hsize_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Dget_chunk_info_by_coord", 0);

  /* "h5py/defs.pyx":676
 *     cdef herr_t H5Dget_chunk_info_by_coord(hid_t dset_id, const hsize_t *offset, unsigned *filter_mask, haddr_t *addr, hsize_t *size) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Dget_chunk_info_by_coord(dset_id, offset, filter_mask, addr, size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":677
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_chunk_info_by_coord(dset_id, offset, filter_mask, addr, size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Dget_chunk_info_by_coord(__pyx_v_dset_id, __pyx_v_offset, __pyx_v_filter_mask, __pyx_v_addr, __pyx_v_size);

  /* "h5py/defs.pyx":678
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_chunk_info_by_coord(dset_id, offset, filter_mask, addr, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":679
 *         r = _hdf5.H5Dget_chunk_info_by_coord(dset_id, offset, filter_mask, addr, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 679, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":680
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_info_by_coord (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":679
 *         r = _hdf5.H5Dget_chunk_info_by_coord(dset_id, offset, filter_mask, addr, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":682
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_info_by_coord (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__58, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 682, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":678
 *         set_default_error_handler()
 *         r = _hdf5.H5Dget_chunk_info_by_coord(dset_id, offset, filter_mask, addr, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":683
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_info_by_coord (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Fcreate(char *filename, unsigned int flags, hid_t create_plist, hid_t access_plist) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":674
 * 
 * IF HDF5_VERSION >= (1, 10, 5):
 *     cdef herr_t H5Dget_chunk_info_by_coord(hid_t dset_id, const hsize_t *offset, unsigned *filter_mask, haddr_t *addr, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Dget_chunk_info_by_coord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":685
 *         return r
 * 
 * cdef hid_t H5Fcreate(char *filename, unsigned int flags, hid_t create_plist, hid_t access_plist) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Fcreate(char *__pyx_v_filename, unsigned int __pyx_v_flags, hid_t __pyx_v_create_plist, hid_t __pyx_v_access_plist) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fcreate", 0);

  /* "h5py/defs.pyx":687
 * cdef hid_t H5Fcreate(char *filename, unsigned int flags, hid_t create_plist, hid_t access_plist) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fcreate(filename, flags, create_plist, access_plist)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":688
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fcreate(filename, flags, create_plist, access_plist)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fcreate(__pyx_v_filename, __pyx_v_flags, __pyx_v_create_plist, __pyx_v_access_plist);

  /* "h5py/defs.pyx":689
 *     set_default_error_handler()
 *     r = _hdf5.H5Fcreate(filename, flags, create_plist, access_plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":690
 *     r = _hdf5.H5Fcreate(filename, flags, create_plist, access_plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 690, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":691
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fcreate (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":690
 *     r = _hdf5.H5Fcreate(filename, flags, create_plist, access_plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":693
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 693, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 693, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":689
 *     set_default_error_handler()
 *     r = _hdf5.H5Fcreate(filename, flags, create_plist, access_plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":694
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fcreate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Fopen(char *name, unsigned flags, hid_t access_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":685
 *         return r
 * 
 * cdef hid_t H5Fcreate(char *filename, unsigned int flags, hid_t create_plist, hid_t access_plist) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fcreate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":696
 *     return r
 * 
 * cdef hid_t H5Fopen(char *name, unsigned flags, hid_t access_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Fopen(char *__pyx_v_name, unsigned int __pyx_v_flags, hid_t __pyx_v_access_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fopen", 0);

  /* "h5py/defs.pyx":698
 * cdef hid_t H5Fopen(char *name, unsigned flags, hid_t access_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fopen(name, flags, access_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":699
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fopen(name, flags, access_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fopen(__pyx_v_name, __pyx_v_flags, __pyx_v_access_id);

  /* "h5py/defs.pyx":700
 *     set_default_error_handler()
 *     r = _hdf5.H5Fopen(name, flags, access_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":701
 *     r = _hdf5.H5Fopen(name, flags, access_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 701, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":702
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fopen (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":701
 *     r = _hdf5.H5Fopen(name, flags, access_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":704
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__60, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 704, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":700
 *     set_default_error_handler()
 *     r = _hdf5.H5Fopen(name, flags, access_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":705
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fopen (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fclose(hid_t file_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":696
 *     return r
 * 
 * cdef hid_t H5Fopen(char *name, unsigned flags, hid_t access_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fopen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":707
 *     return r
 * 
 * cdef herr_t H5Fclose(hid_t file_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fclose(hid_t __pyx_v_file_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fclose", 0);

  /* "h5py/defs.pyx":709
 * cdef herr_t H5Fclose(hid_t file_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fclose(file_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":710
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fclose(file_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fclose(__pyx_v_file_id);

  /* "h5py/defs.pyx":711
 *     set_default_error_handler()
 *     r = _hdf5.H5Fclose(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":712
 *     r = _hdf5.H5Fclose(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 712, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":713
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fclose (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":712
 *     r = _hdf5.H5Fclose(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":715
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 715, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":711
 *     set_default_error_handler()
 *     r = _hdf5.H5Fclose(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":716
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fclose (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Fis_hdf5(char *name) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":707
 *     return r
 * 
 * cdef herr_t H5Fclose(hid_t file_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":718
 *     return r
 * 
 * cdef htri_t H5Fis_hdf5(char *name) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Fis_hdf5(char *__pyx_v_name) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fis_hdf5", 0);

  /* "h5py/defs.pyx":720
 * cdef htri_t H5Fis_hdf5(char *name) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fis_hdf5(name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":721
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fis_hdf5(name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fis_hdf5(__pyx_v_name);

  /* "h5py/defs.pyx":722
 *     set_default_error_handler()
 *     r = _hdf5.H5Fis_hdf5(name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":723
 *     r = _hdf5.H5Fis_hdf5(name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 723, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":724
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fis_hdf5 (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":723
 *     r = _hdf5.H5Fis_hdf5(name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":726
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fis_hdf5 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__62, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 726, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":722
 *     set_default_error_handler()
 *     r = _hdf5.H5Fis_hdf5(name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":727
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fis_hdf5 (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fflush(hid_t object_id, H5F_scope_t scope) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":718
 *     return r
 * 
 * cdef htri_t H5Fis_hdf5(char *name) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fis_hdf5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":729
 *     return r
 * 
 * cdef herr_t H5Fflush(hid_t object_id, H5F_scope_t scope) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Fflush(hid_t __pyx_v_object_id, enum H5F_scope_t __pyx_v_scope) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fflush", 0);

  /* "h5py/defs.pyx":731
 * cdef herr_t H5Fflush(hid_t object_id, H5F_scope_t scope) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Fflush(object_id, scope)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":732
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Fflush(object_id, scope)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":733
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Fflush(object_id, scope)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Fflush(__pyx_v_object_id, __pyx_v_scope);
      }

      /* "h5py/defs.pyx":731
 * cdef herr_t H5Fflush(hid_t object_id, H5F_scope_t scope) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Fflush(object_id, scope)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":734
 *         set_default_error_handler()
 *         r = _hdf5.H5Fflush(object_id, scope)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":735
 *         r = _hdf5.H5Fflush(object_id, scope)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 735, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":736
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fflush (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":735
 *         r = _hdf5.H5Fflush(object_id, scope)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":738
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fflush (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__63, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 738, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":734
 *         set_default_error_handler()
 *         r = _hdf5.H5Fflush(object_id, scope)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":739
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fflush (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Freopen(hid_t file_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":729
 *     return r
 * 
 * cdef herr_t H5Fflush(hid_t object_id, H5F_scope_t scope) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fflush", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":741
 *     return r
 * 
 * cdef hid_t H5Freopen(hid_t file_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Freopen(hid_t __pyx_v_file_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Freopen", 0);

  /* "h5py/defs.pyx":743
 * cdef hid_t H5Freopen(hid_t file_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Freopen(file_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":744
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Freopen(file_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Freopen(__pyx_v_file_id);

  /* "h5py/defs.pyx":745
 *     set_default_error_handler()
 *     r = _hdf5.H5Freopen(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":746
 *     r = _hdf5.H5Freopen(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 746, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":747
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Freopen (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":746
 *     r = _hdf5.H5Freopen(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":749
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Freopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__64, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 749, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 749, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":745
 *     set_default_error_handler()
 *     r = _hdf5.H5Freopen(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":750
 *         else:
 *             raise RuntimeError("Unspecified error in H5Freopen (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fmount(hid_t loc_id, char *name, hid_t child_id, hid_t plist_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":741
 *     return r
 * 
 * cdef hid_t H5Freopen(hid_t file_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Freopen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":752
 *     return r
 * 
 * cdef herr_t H5Fmount(hid_t loc_id, char *name, hid_t child_id, hid_t plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fmount(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_child_id, hid_t __pyx_v_plist_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fmount", 0);

  /* "h5py/defs.pyx":754
 * cdef herr_t H5Fmount(hid_t loc_id, char *name, hid_t child_id, hid_t plist_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fmount(loc_id, name, child_id, plist_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":755
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fmount(loc_id, name, child_id, plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fmount(__pyx_v_loc_id, __pyx_v_name, __pyx_v_child_id, __pyx_v_plist_id);

  /* "h5py/defs.pyx":756
 *     set_default_error_handler()
 *     r = _hdf5.H5Fmount(loc_id, name, child_id, plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":757
 *     r = _hdf5.H5Fmount(loc_id, name, child_id, plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 757, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":758
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fmount (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":757
 *     r = _hdf5.H5Fmount(loc_id, name, child_id, plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":760
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fmount (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 760, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":756
 *     set_default_error_handler()
 *     r = _hdf5.H5Fmount(loc_id, name, child_id, plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":761
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fmount (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Funmount(hid_t loc_id, char *name) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":752
 *     return r
 * 
 * cdef herr_t H5Fmount(hid_t loc_id, char *name, hid_t child_id, hid_t plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fmount", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":763
 *     return r
 * 
 * cdef herr_t H5Funmount(hid_t loc_id, char *name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Funmount(hid_t __pyx_v_loc_id, char *__pyx_v_name) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Funmount", 0);

  /* "h5py/defs.pyx":765
 * cdef herr_t H5Funmount(hid_t loc_id, char *name) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Funmount(loc_id, name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":766
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Funmount(loc_id, name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Funmount(__pyx_v_loc_id, __pyx_v_name);

  /* "h5py/defs.pyx":767
 *     set_default_error_handler()
 *     r = _hdf5.H5Funmount(loc_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":768
 *     r = _hdf5.H5Funmount(loc_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 768, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":769
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Funmount (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":768
 *     r = _hdf5.H5Funmount(loc_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":771
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Funmount (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 771, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 771, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":767
 *     set_default_error_handler()
 *     r = _hdf5.H5Funmount(loc_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":772
 *         else:
 *             raise RuntimeError("Unspecified error in H5Funmount (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fget_filesize(hid_t file_id, hsize_t *size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":763
 *     return r
 * 
 * cdef herr_t H5Funmount(hid_t loc_id, char *name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Funmount", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":774
 *     return r
 * 
 * cdef herr_t H5Fget_filesize(hid_t file_id, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fget_filesize(hid_t __pyx_v_file_id, hsize_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_filesize", 0);

  /* "h5py/defs.pyx":776
 * cdef herr_t H5Fget_filesize(hid_t file_id, hsize_t *size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_filesize(file_id, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":777
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_filesize(file_id, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_filesize(__pyx_v_file_id, __pyx_v_size);

  /* "h5py/defs.pyx":778
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_filesize(file_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":779
 *     r = _hdf5.H5Fget_filesize(file_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 779, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":780
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_filesize (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":779
 *     r = _hdf5.H5Fget_filesize(file_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":782
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_filesize (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__67, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 782, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 782, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":778
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_filesize(file_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":783
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_filesize (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Fget_create_plist(hid_t file_id ) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":774
 *     return r
 * 
 * cdef herr_t H5Fget_filesize(hid_t file_id, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_filesize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":785
 *     return r
 * 
 * cdef hid_t H5Fget_create_plist(hid_t file_id ) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Fget_create_plist(hid_t __pyx_v_file_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_create_plist", 0);

  /* "h5py/defs.pyx":787
 * cdef hid_t H5Fget_create_plist(hid_t file_id ) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_create_plist(file_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":788
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_create_plist(file_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_create_plist(__pyx_v_file_id);

  /* "h5py/defs.pyx":789
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_create_plist(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":790
 *     r = _hdf5.H5Fget_create_plist(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 790, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":791
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_create_plist (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":790
 *     r = _hdf5.H5Fget_create_plist(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":793
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_create_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__68, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 793, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":789
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_create_plist(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":794
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_create_plist (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Fget_access_plist(hid_t file_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":785
 *     return r
 * 
 * cdef hid_t H5Fget_create_plist(hid_t file_id ) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_create_plist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":796
 *     return r
 * 
 * cdef hid_t H5Fget_access_plist(hid_t file_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Fget_access_plist(hid_t __pyx_v_file_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_access_plist", 0);

  /* "h5py/defs.pyx":798
 * cdef hid_t H5Fget_access_plist(hid_t file_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_access_plist(file_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":799
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_access_plist(file_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_access_plist(__pyx_v_file_id);

  /* "h5py/defs.pyx":800
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_access_plist(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":801
 *     r = _hdf5.H5Fget_access_plist(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 801, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":802
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_access_plist (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":801
 *     r = _hdf5.H5Fget_access_plist(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":804
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_access_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__69, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 804, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":800
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_access_plist(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":805
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_access_plist (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hssize_t H5Fget_freespace(hid_t file_id) except <hssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":796
 *     return r
 * 
 * cdef hid_t H5Fget_access_plist(hid_t file_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_access_plist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":807
 *     return r
 * 
 * cdef hssize_t H5Fget_freespace(hid_t file_id) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

static hssize_t __pyx_f_4h5py_4defs_H5Fget_freespace(hid_t __pyx_v_file_id) {
  hssize_t __pyx_v_r;
  hssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_freespace", 0);

  /* "h5py/defs.pyx":809
 * cdef hssize_t H5Fget_freespace(hid_t file_id) except <hssize_t>-1:
 *     cdef hssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_freespace(file_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":810
 *     cdef hssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_freespace(file_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_freespace(__pyx_v_file_id);

  /* "h5py/defs.pyx":811
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_freespace(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":812
 *     r = _hdf5.H5Fget_freespace(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 812, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":813
 *     if r<0:
 *         if set_exception():
 *             return <hssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_freespace (return value <0)")
 */
      __pyx_r = ((hssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":812
 *     r = _hdf5.H5Fget_freespace(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":815
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_freespace (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__70, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 815, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 815, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":811
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_freespace(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  }

  /* "h5py/defs.pyx":816
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_freespace (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5Fget_name(hid_t obj_id, char *name, size_t size) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":807
 *     return r
 * 
 * cdef hssize_t H5Fget_freespace(hid_t file_id) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_freespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":818
 *     return r
 * 
 * cdef ssize_t H5Fget_name(hid_t obj_id, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Fget_name(hid_t __pyx_v_obj_id, char *__pyx_v_name, size_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_name", 0);

  /* "h5py/defs.pyx":820
 * cdef ssize_t H5Fget_name(hid_t obj_id, char *name, size_t size) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_name(obj_id, name, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":821
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_name(obj_id, name, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_name(__pyx_v_obj_id, __pyx_v_name, __pyx_v_size);

  /* "h5py/defs.pyx":822
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_name(obj_id, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":823
 *     r = _hdf5.H5Fget_name(obj_id, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 823, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":824
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_name (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":823
 *     r = _hdf5.H5Fget_name(obj_id, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":826
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 826, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 826, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":822
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_name(obj_id, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":827
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Fget_obj_count(hid_t file_id, unsigned int types) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":818
 *     return r
 * 
 * cdef ssize_t H5Fget_name(hid_t obj_id, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":829
 *     return r
 * 
 * cdef int H5Fget_obj_count(hid_t file_id, unsigned int types) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Fget_obj_count(hid_t __pyx_v_file_id, unsigned int __pyx_v_types) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_obj_count", 0);

  /* "h5py/defs.pyx":831
 * cdef int H5Fget_obj_count(hid_t file_id, unsigned int types) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_obj_count(file_id, types)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":832
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_obj_count(file_id, types)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_obj_count(__pyx_v_file_id, __pyx_v_types);

  /* "h5py/defs.pyx":833
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_obj_count(file_id, types)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":834
 *     r = _hdf5.H5Fget_obj_count(file_id, types)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 834, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":835
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_obj_count (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":834
 *     r = _hdf5.H5Fget_obj_count(file_id, types)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":837
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_obj_count (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 837, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":833
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_obj_count(file_id, types)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":838
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_obj_count (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Fget_obj_ids(hid_t file_id, unsigned int types, int max_objs, hid_t *obj_id_list) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":829
 *     return r
 * 
 * cdef int H5Fget_obj_count(hid_t file_id, unsigned int types) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_obj_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":840
 *     return r
 * 
 * cdef int H5Fget_obj_ids(hid_t file_id, unsigned int types, int max_objs, hid_t *obj_id_list) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Fget_obj_ids(hid_t __pyx_v_file_id, unsigned int __pyx_v_types, int __pyx_v_max_objs, hid_t *__pyx_v_obj_id_list) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_obj_ids", 0);

  /* "h5py/defs.pyx":842
 * cdef int H5Fget_obj_ids(hid_t file_id, unsigned int types, int max_objs, hid_t *obj_id_list) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_obj_ids(file_id, types, max_objs, obj_id_list)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":843
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_obj_ids(file_id, types, max_objs, obj_id_list)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_obj_ids(__pyx_v_file_id, __pyx_v_types, __pyx_v_max_objs, __pyx_v_obj_id_list);

  /* "h5py/defs.pyx":844
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_obj_ids(file_id, types, max_objs, obj_id_list)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":845
 *     r = _hdf5.H5Fget_obj_ids(file_id, types, max_objs, obj_id_list)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 845, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":846
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_obj_ids (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":845
 *     r = _hdf5.H5Fget_obj_ids(file_id, types, max_objs, obj_id_list)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":848
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_obj_ids (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__73, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 848, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 848, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":844
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_obj_ids(file_id, types, max_objs, obj_id_list)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":849
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_obj_ids (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fget_vfd_handle(hid_t file_id, hid_t fapl_id, void **file_handle) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":840
 *     return r
 * 
 * cdef int H5Fget_obj_ids(hid_t file_id, unsigned int types, int max_objs, hid_t *obj_id_list) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_obj_ids", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":851
 *     return r
 * 
 * cdef herr_t H5Fget_vfd_handle(hid_t file_id, hid_t fapl_id, void **file_handle) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fget_vfd_handle(hid_t __pyx_v_file_id, hid_t __pyx_v_fapl_id, void **__pyx_v_file_handle) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_vfd_handle", 0);

  /* "h5py/defs.pyx":853
 * cdef herr_t H5Fget_vfd_handle(hid_t file_id, hid_t fapl_id, void **file_handle) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_vfd_handle(file_id, fapl_id, file_handle)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":854
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_vfd_handle(file_id, fapl_id, file_handle)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_vfd_handle(__pyx_v_file_id, __pyx_v_fapl_id, __pyx_v_file_handle);

  /* "h5py/defs.pyx":855
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_vfd_handle(file_id, fapl_id, file_handle)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":856
 *     r = _hdf5.H5Fget_vfd_handle(file_id, fapl_id, file_handle)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 856, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":857
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_vfd_handle (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":856
 *     r = _hdf5.H5Fget_vfd_handle(file_id, fapl_id, file_handle)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":859
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_vfd_handle (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__74, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 859, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":855
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_vfd_handle(file_id, fapl_id, file_handle)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":860
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_vfd_handle (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fget_intent(hid_t file_id, unsigned int *intent) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":851
 *     return r
 * 
 * cdef herr_t H5Fget_vfd_handle(hid_t file_id, hid_t fapl_id, void **file_handle) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_vfd_handle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":862
 *     return r
 * 
 * cdef herr_t H5Fget_intent(hid_t file_id, unsigned int *intent) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fget_intent(hid_t __pyx_v_file_id, unsigned int *__pyx_v_intent) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_intent", 0);

  /* "h5py/defs.pyx":864
 * cdef herr_t H5Fget_intent(hid_t file_id, unsigned int *intent) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_intent(file_id, intent)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":865
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_intent(file_id, intent)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_intent(__pyx_v_file_id, __pyx_v_intent);

  /* "h5py/defs.pyx":866
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_intent(file_id, intent)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":867
 *     r = _hdf5.H5Fget_intent(file_id, intent)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 867, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":868
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_intent (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":867
 *     r = _hdf5.H5Fget_intent(file_id, intent)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":870
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_intent (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__75, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 870, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 870, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":866
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_intent(file_id, intent)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":871
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_intent (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fget_mdc_config(hid_t file_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":862
 *     return r
 * 
 * cdef herr_t H5Fget_intent(hid_t file_id, unsigned int *intent) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_intent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":873
 *     return r
 * 
 * cdef herr_t H5Fget_mdc_config(hid_t file_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fget_mdc_config(hid_t __pyx_v_file_id, H5AC_cache_config_t *__pyx_v_config_ptr) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_mdc_config", 0);

  /* "h5py/defs.pyx":875
 * cdef herr_t H5Fget_mdc_config(hid_t file_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_mdc_config(file_id, config_ptr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":876
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_config(file_id, config_ptr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_mdc_config(__pyx_v_file_id, __pyx_v_config_ptr);

  /* "h5py/defs.pyx":877
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_config(file_id, config_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":878
 *     r = _hdf5.H5Fget_mdc_config(file_id, config_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 878, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":879
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_config (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":878
 *     r = _hdf5.H5Fget_mdc_config(file_id, config_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":881
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_config (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__76, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 881, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":877
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_config(file_id, config_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":882
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_config (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fget_mdc_hit_rate(hid_t file_id, double *hit_rate_ptr) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":873
 *     return r
 * 
 * cdef herr_t H5Fget_mdc_config(hid_t file_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_mdc_config", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":884
 *     return r
 * 
 * cdef herr_t H5Fget_mdc_hit_rate(hid_t file_id, double *hit_rate_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fget_mdc_hit_rate(hid_t __pyx_v_file_id, double *__pyx_v_hit_rate_ptr) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_mdc_hit_rate", 0);

  /* "h5py/defs.pyx":886
 * cdef herr_t H5Fget_mdc_hit_rate(hid_t file_id, double *hit_rate_ptr) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_mdc_hit_rate(file_id, hit_rate_ptr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":887
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_hit_rate(file_id, hit_rate_ptr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_mdc_hit_rate(__pyx_v_file_id, __pyx_v_hit_rate_ptr);

  /* "h5py/defs.pyx":888
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_hit_rate(file_id, hit_rate_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":889
 *     r = _hdf5.H5Fget_mdc_hit_rate(file_id, hit_rate_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 889, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":890
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_hit_rate (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":889
 *     r = _hdf5.H5Fget_mdc_hit_rate(file_id, hit_rate_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":892
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_hit_rate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__77, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 892, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":888
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_hit_rate(file_id, hit_rate_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":893
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_hit_rate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fget_mdc_size(hid_t file_id, size_t *max_size_ptr, size_t *min_clean_size_ptr, size_t *cur_size_ptr, int *cur_num_entries_ptr) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":884
 *     return r
 * 
 * cdef herr_t H5Fget_mdc_hit_rate(hid_t file_id, double *hit_rate_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_mdc_hit_rate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":895
 *     return r
 * 
 * cdef herr_t H5Fget_mdc_size(hid_t file_id, size_t *max_size_ptr, size_t *min_clean_size_ptr, size_t *cur_size_ptr, int *cur_num_entries_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fget_mdc_size(hid_t __pyx_v_file_id, size_t *__pyx_v_max_size_ptr, size_t *__pyx_v_min_clean_size_ptr, size_t *__pyx_v_cur_size_ptr, int *__pyx_v_cur_num_entries_ptr) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_mdc_size", 0);

  /* "h5py/defs.pyx":897
 * cdef herr_t H5Fget_mdc_size(hid_t file_id, size_t *max_size_ptr, size_t *min_clean_size_ptr, size_t *cur_size_ptr, int *cur_num_entries_ptr) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fget_mdc_size(file_id, max_size_ptr, min_clean_size_ptr, cur_size_ptr, cur_num_entries_ptr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":898
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_size(file_id, max_size_ptr, min_clean_size_ptr, cur_size_ptr, cur_num_entries_ptr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fget_mdc_size(__pyx_v_file_id, __pyx_v_max_size_ptr, __pyx_v_min_clean_size_ptr, __pyx_v_cur_size_ptr, __pyx_v_cur_num_entries_ptr);

  /* "h5py/defs.pyx":899
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_size(file_id, max_size_ptr, min_clean_size_ptr, cur_size_ptr, cur_num_entries_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":900
 *     r = _hdf5.H5Fget_mdc_size(file_id, max_size_ptr, min_clean_size_ptr, cur_size_ptr, cur_num_entries_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 900, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":901
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":900
 *     r = _hdf5.H5Fget_mdc_size(file_id, max_size_ptr, min_clean_size_ptr, cur_size_ptr, cur_num_entries_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":903
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__78, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 903, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":899
 *     set_default_error_handler()
 *     r = _hdf5.H5Fget_mdc_size(file_id, max_size_ptr, min_clean_size_ptr, cur_size_ptr, cur_num_entries_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":904
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_size (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Freset_mdc_hit_rate_stats(hid_t file_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":895
 *     return r
 * 
 * cdef herr_t H5Fget_mdc_size(hid_t file_id, size_t *max_size_ptr, size_t *min_clean_size_ptr, size_t *cur_size_ptr, int *cur_num_entries_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_mdc_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":906
 *     return r
 * 
 * cdef herr_t H5Freset_mdc_hit_rate_stats(hid_t file_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Freset_mdc_hit_rate_stats(hid_t __pyx_v_file_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Freset_mdc_hit_rate_stats", 0);

  /* "h5py/defs.pyx":908
 * cdef herr_t H5Freset_mdc_hit_rate_stats(hid_t file_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Freset_mdc_hit_rate_stats(file_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":909
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Freset_mdc_hit_rate_stats(file_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Freset_mdc_hit_rate_stats(__pyx_v_file_id);

  /* "h5py/defs.pyx":910
 *     set_default_error_handler()
 *     r = _hdf5.H5Freset_mdc_hit_rate_stats(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":911
 *     r = _hdf5.H5Freset_mdc_hit_rate_stats(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 911, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":912
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Freset_mdc_hit_rate_stats (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":911
 *     r = _hdf5.H5Freset_mdc_hit_rate_stats(file_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":914
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Freset_mdc_hit_rate_stats (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__79, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 914, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":910
 *     set_default_error_handler()
 *     r = _hdf5.H5Freset_mdc_hit_rate_stats(file_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":915
 *         else:
 *             raise RuntimeError("Unspecified error in H5Freset_mdc_hit_rate_stats (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Fset_mdc_config(hid_t file_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":906
 *     return r
 * 
 * cdef herr_t H5Freset_mdc_hit_rate_stats(hid_t file_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Freset_mdc_hit_rate_stats", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":917
 *     return r
 * 
 * cdef herr_t H5Fset_mdc_config(hid_t file_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fset_mdc_config(hid_t __pyx_v_file_id, H5AC_cache_config_t *__pyx_v_config_ptr) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fset_mdc_config", 0);

  /* "h5py/defs.pyx":919
 * cdef herr_t H5Fset_mdc_config(hid_t file_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Fset_mdc_config(file_id, config_ptr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":920
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Fset_mdc_config(file_id, config_ptr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Fset_mdc_config(__pyx_v_file_id, __pyx_v_config_ptr);

  /* "h5py/defs.pyx":921
 *     set_default_error_handler()
 *     r = _hdf5.H5Fset_mdc_config(file_id, config_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":922
 *     r = _hdf5.H5Fset_mdc_config(file_id, config_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 922, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":923
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fset_mdc_config (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":922
 *     r = _hdf5.H5Fset_mdc_config(file_id, config_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":925
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fset_mdc_config (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__80, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 925, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 925, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":921
 *     set_default_error_handler()
 *     r = _hdf5.H5Fset_mdc_config(file_id, config_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":926
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fset_mdc_config (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":917
 *     return r
 * 
 * cdef herr_t H5Fset_mdc_config(hid_t file_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fset_mdc_config", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":929
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 *     cdef ssize_t H5Fget_file_image(hid_t file_id, void *buf_ptr, size_t buf_len) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Fget_file_image(hid_t __pyx_v_file_id, void *__pyx_v_buf_ptr, size_t __pyx_v_buf_len) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_file_image", 0);

  /* "h5py/defs.pyx":931
 *     cdef ssize_t H5Fget_file_image(hid_t file_id, void *buf_ptr, size_t buf_len) except <ssize_t>-1:
 *         cdef ssize_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Fget_file_image(file_id, buf_ptr, buf_len)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":932
 *         cdef ssize_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Fget_file_image(file_id, buf_ptr, buf_len)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Fget_file_image(__pyx_v_file_id, __pyx_v_buf_ptr, __pyx_v_buf_len);

  /* "h5py/defs.pyx":933
 *         set_default_error_handler()
 *         r = _hdf5.H5Fget_file_image(file_id, buf_ptr, buf_len)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":934
 *         r = _hdf5.H5Fget_file_image(file_id, buf_ptr, buf_len)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 934, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":935
 *         if r<0:
 *             if set_exception():
 *                 return <ssize_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fget_file_image (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":934
 *         r = _hdf5.H5Fget_file_image(file_id, buf_ptr, buf_len)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":937
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fget_file_image (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__81, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 937, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 937, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":933
 *         set_default_error_handler()
 *         r = _hdf5.H5Fget_file_image(file_id, buf_ptr, buf_len)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":938
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fget_file_image (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":929
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 *     cdef ssize_t H5Fget_file_image(hid_t file_id, void *buf_ptr, size_t buf_len) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_file_image", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":941
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 *     cdef hid_t H5LTopen_file_image(void *buf_ptr, size_t buf_len, unsigned int flags) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *         cdef hid_t r
 *         set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5LTopen_file_image(void *__pyx_v_buf_ptr, size_t __pyx_v_buf_len, unsigned int __pyx_v_flags) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5LTopen_file_image", 0);

  /* "h5py/defs.pyx":943
 *     cdef hid_t H5LTopen_file_image(void *buf_ptr, size_t buf_len, unsigned int flags) except <hid_t>-1:
 *         cdef hid_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5LTopen_file_image(buf_ptr, buf_len, flags)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":944
 *         cdef hid_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5LTopen_file_image(buf_ptr, buf_len, flags)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5LTopen_file_image(__pyx_v_buf_ptr, __pyx_v_buf_len, __pyx_v_flags);

  /* "h5py/defs.pyx":945
 *         set_default_error_handler()
 *         r = _hdf5.H5LTopen_file_image(buf_ptr, buf_len, flags)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":946
 *         r = _hdf5.H5LTopen_file_image(buf_ptr, buf_len, flags)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <hid_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 946, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":947
 *         if r<0:
 *             if set_exception():
 *                 return <hid_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5LTopen_file_image (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":946
 *         r = _hdf5.H5LTopen_file_image(buf_ptr, buf_len, flags)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <hid_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":949
 *                 return <hid_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5LTopen_file_image (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__82, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 949, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":945
 *         set_default_error_handler()
 *         r = _hdf5.H5LTopen_file_image(buf_ptr, buf_len, flags)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":950
 *             else:
 *                 raise RuntimeError("Unspecified error in H5LTopen_file_image (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":941
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 *     cdef hid_t H5LTopen_file_image(void *buf_ptr, size_t buf_len, unsigned int flags) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *         cdef hid_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5LTopen_file_image", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":979
 * 
 * IF HDF5_VERSION >= (1, 9, 178):
 *     cdef herr_t H5Fstart_swmr_write(hid_t file_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fstart_swmr_write(hid_t __pyx_v_file_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fstart_swmr_write", 0);

  /* "h5py/defs.pyx":981
 *     cdef herr_t H5Fstart_swmr_write(hid_t file_id) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Fstart_swmr_write(file_id)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":982
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Fstart_swmr_write(file_id)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Fstart_swmr_write(__pyx_v_file_id);

  /* "h5py/defs.pyx":983
 *         set_default_error_handler()
 *         r = _hdf5.H5Fstart_swmr_write(file_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":984
 *         r = _hdf5.H5Fstart_swmr_write(file_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 984, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":985
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fstart_swmr_write (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":984
 *         r = _hdf5.H5Fstart_swmr_write(file_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":987
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fstart_swmr_write (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__83, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 987, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 987, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":983
 *         set_default_error_handler()
 *         r = _hdf5.H5Fstart_swmr_write(file_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":988
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fstart_swmr_write (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":979
 * 
 * IF HDF5_VERSION >= (1, 9, 178):
 *     cdef herr_t H5Fstart_swmr_write(hid_t file_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fstart_swmr_write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":991
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Freset_page_buffering_stats(hid_t file_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Freset_page_buffering_stats(hid_t __pyx_v_file_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Freset_page_buffering_stats", 0);

  /* "h5py/defs.pyx":993
 *     cdef herr_t H5Freset_page_buffering_stats(hid_t file_id) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Freset_page_buffering_stats(file_id)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":994
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Freset_page_buffering_stats(file_id)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Freset_page_buffering_stats(__pyx_v_file_id);

  /* "h5py/defs.pyx":995
 *         set_default_error_handler()
 *         r = _hdf5.H5Freset_page_buffering_stats(file_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":996
 *         r = _hdf5.H5Freset_page_buffering_stats(file_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 996, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":997
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Freset_page_buffering_stats (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":996
 *         r = _hdf5.H5Freset_page_buffering_stats(file_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":999
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Freset_page_buffering_stats (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__84, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 999, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 999, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":995
 *         set_default_error_handler()
 *         r = _hdf5.H5Freset_page_buffering_stats(file_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1000
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Freset_page_buffering_stats (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":991
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Freset_page_buffering_stats(hid_t file_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Freset_page_buffering_stats", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1003
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Fget_page_buffering_stats(hid_t file_id, unsigned *accesses, unsigned *hits, unsigned *misses, unsigned *evictions, unsigned *bypasses) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Fget_page_buffering_stats(hid_t __pyx_v_file_id, unsigned int *__pyx_v_accesses, unsigned int *__pyx_v_hits, unsigned int *__pyx_v_misses, unsigned int *__pyx_v_evictions, unsigned int *__pyx_v_bypasses) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Fget_page_buffering_stats", 0);

  /* "h5py/defs.pyx":1005
 *     cdef herr_t H5Fget_page_buffering_stats(hid_t file_id, unsigned *accesses, unsigned *hits, unsigned *misses, unsigned *evictions, unsigned *bypasses) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Fget_page_buffering_stats(file_id, accesses, hits, misses, evictions, bypasses)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1006
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Fget_page_buffering_stats(file_id, accesses, hits, misses, evictions, bypasses)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Fget_page_buffering_stats(__pyx_v_file_id, __pyx_v_accesses, __pyx_v_hits, __pyx_v_misses, __pyx_v_evictions, __pyx_v_bypasses);

  /* "h5py/defs.pyx":1007
 *         set_default_error_handler()
 *         r = _hdf5.H5Fget_page_buffering_stats(file_id, accesses, hits, misses, evictions, bypasses)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1008
 *         r = _hdf5.H5Fget_page_buffering_stats(file_id, accesses, hits, misses, evictions, bypasses)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1008, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1009
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fget_page_buffering_stats (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1008
 *         r = _hdf5.H5Fget_page_buffering_stats(file_id, accesses, hits, misses, evictions, bypasses)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":1011
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fget_page_buffering_stats (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__85, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1011, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1007
 *         set_default_error_handler()
 *         r = _hdf5.H5Fget_page_buffering_stats(file_id, accesses, hits, misses, evictions, bypasses)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1012
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fget_page_buffering_stats (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5FDregister(H5FD_class_t *cls_ptr) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1003
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Fget_page_buffering_stats(hid_t file_id, unsigned *accesses, unsigned *hits, unsigned *misses, unsigned *evictions, unsigned *bypasses) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Fget_page_buffering_stats", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1014
 *         return r
 * 
 * cdef hid_t H5FDregister(H5FD_class_t *cls_ptr) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5FDregister(H5FD_class_t *__pyx_v_cls_ptr) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5FDregister", 0);

  /* "h5py/defs.pyx":1016
 * cdef hid_t H5FDregister(H5FD_class_t *cls_ptr) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5FDregister(cls_ptr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1017
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5FDregister(cls_ptr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5FDregister(__pyx_v_cls_ptr);

  /* "h5py/defs.pyx":1018
 *     set_default_error_handler()
 *     r = _hdf5.H5FDregister(cls_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1019
 *     r = _hdf5.H5FDregister(cls_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1019, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1020
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5FDregister (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1019
 *     r = _hdf5.H5FDregister(cls_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1022
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5FDregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1022, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1018
 *     set_default_error_handler()
 *     r = _hdf5.H5FDregister(cls_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1023
 *         else:
 *             raise RuntimeError("Unspecified error in H5FDregister (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5FDunregister(hid_t driver_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1014
 *         return r
 * 
 * cdef hid_t H5FDregister(H5FD_class_t *cls_ptr) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5FDregister", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1025
 *     return r
 * 
 * cdef herr_t H5FDunregister(hid_t driver_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5FDunregister(hid_t __pyx_v_driver_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5FDunregister", 0);

  /* "h5py/defs.pyx":1027
 * cdef herr_t H5FDunregister(hid_t driver_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5FDunregister(driver_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1028
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5FDunregister(driver_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5FDunregister(__pyx_v_driver_id);

  /* "h5py/defs.pyx":1029
 *     set_default_error_handler()
 *     r = _hdf5.H5FDunregister(driver_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1030
 *     r = _hdf5.H5FDunregister(driver_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1030, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1031
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5FDunregister (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1030
 *     r = _hdf5.H5FDunregister(driver_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1033
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5FDunregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__87, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1033, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1033, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1029
 *     set_default_error_handler()
 *     r = _hdf5.H5FDunregister(driver_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1034
 *         else:
 *             raise RuntimeError("Unspecified error in H5FDunregister (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gclose(hid_t group_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1025
 *     return r
 * 
 * cdef herr_t H5FDunregister(hid_t driver_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5FDunregister", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1036
 *     return r
 * 
 * cdef herr_t H5Gclose(hid_t group_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gclose(hid_t __pyx_v_group_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gclose", 0);

  /* "h5py/defs.pyx":1038
 * cdef herr_t H5Gclose(hid_t group_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gclose(group_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1039
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gclose(group_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gclose(__pyx_v_group_id);

  /* "h5py/defs.pyx":1040
 *     set_default_error_handler()
 *     r = _hdf5.H5Gclose(group_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1041
 *     r = _hdf5.H5Gclose(group_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1041, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1042
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gclose (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1041
 *     r = _hdf5.H5Gclose(group_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1044
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__88, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1044, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1044, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1040
 *     set_default_error_handler()
 *     r = _hdf5.H5Gclose(group_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1045
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gclose (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Glink2( hid_t curr_loc_id, char *current_name, H5G_link_t link_type, hid_t new_loc_id, char *new_name) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1036
 *     return r
 * 
 * cdef herr_t H5Gclose(hid_t group_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1047
 *     return r
 * 
 * cdef herr_t H5Glink2( hid_t curr_loc_id, char *current_name, H5G_link_t link_type, hid_t new_loc_id, char *new_name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Glink2(hid_t __pyx_v_curr_loc_id, char *__pyx_v_current_name, H5G_link_t __pyx_v_link_type, hid_t __pyx_v_new_loc_id, char *__pyx_v_new_name) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Glink2", 0);

  /* "h5py/defs.pyx":1049
 * cdef herr_t H5Glink2( hid_t curr_loc_id, char *current_name, H5G_link_t link_type, hid_t new_loc_id, char *new_name) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Glink2(curr_loc_id, current_name, link_type, new_loc_id, new_name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1050
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Glink2(curr_loc_id, current_name, link_type, new_loc_id, new_name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Glink2(__pyx_v_curr_loc_id, __pyx_v_current_name, __pyx_v_link_type, __pyx_v_new_loc_id, __pyx_v_new_name);

  /* "h5py/defs.pyx":1051
 *     set_default_error_handler()
 *     r = _hdf5.H5Glink2(curr_loc_id, current_name, link_type, new_loc_id, new_name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1052
 *     r = _hdf5.H5Glink2(curr_loc_id, current_name, link_type, new_loc_id, new_name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1052, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1053
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Glink2 (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1052
 *     r = _hdf5.H5Glink2(curr_loc_id, current_name, link_type, new_loc_id, new_name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1055
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Glink2 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__89, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1055, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1055, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1051
 *     set_default_error_handler()
 *     r = _hdf5.H5Glink2(curr_loc_id, current_name, link_type, new_loc_id, new_name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1056
 *         else:
 *             raise RuntimeError("Unspecified error in H5Glink2 (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gunlink(hid_t file_id, char *name) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1047
 *     return r
 * 
 * cdef herr_t H5Glink2( hid_t curr_loc_id, char *current_name, H5G_link_t link_type, hid_t new_loc_id, char *new_name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Glink2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1058
 *     return r
 * 
 * cdef herr_t H5Gunlink(hid_t file_id, char *name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gunlink(hid_t __pyx_v_file_id, char *__pyx_v_name) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gunlink", 0);

  /* "h5py/defs.pyx":1060
 * cdef herr_t H5Gunlink(hid_t file_id, char *name) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gunlink(file_id, name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1061
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gunlink(file_id, name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gunlink(__pyx_v_file_id, __pyx_v_name);

  /* "h5py/defs.pyx":1062
 *     set_default_error_handler()
 *     r = _hdf5.H5Gunlink(file_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1063
 *     r = _hdf5.H5Gunlink(file_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1063, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1064
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gunlink (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1063
 *     r = _hdf5.H5Gunlink(file_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1066
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gunlink (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__90, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1066, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1066, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1062
 *     set_default_error_handler()
 *     r = _hdf5.H5Gunlink(file_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1067
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gunlink (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gmove2(hid_t src_loc_id, char *src_name, hid_t dst_loc_id, char *dst_name) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1058
 *     return r
 * 
 * cdef herr_t H5Gunlink(hid_t file_id, char *name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gunlink", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1069
 *     return r
 * 
 * cdef herr_t H5Gmove2(hid_t src_loc_id, char *src_name, hid_t dst_loc_id, char *dst_name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gmove2(hid_t __pyx_v_src_loc_id, char *__pyx_v_src_name, hid_t __pyx_v_dst_loc_id, char *__pyx_v_dst_name) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gmove2", 0);

  /* "h5py/defs.pyx":1071
 * cdef herr_t H5Gmove2(hid_t src_loc_id, char *src_name, hid_t dst_loc_id, char *dst_name) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gmove2(src_loc_id, src_name, dst_loc_id, dst_name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1072
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gmove2(src_loc_id, src_name, dst_loc_id, dst_name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gmove2(__pyx_v_src_loc_id, __pyx_v_src_name, __pyx_v_dst_loc_id, __pyx_v_dst_name);

  /* "h5py/defs.pyx":1073
 *     set_default_error_handler()
 *     r = _hdf5.H5Gmove2(src_loc_id, src_name, dst_loc_id, dst_name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1074
 *     r = _hdf5.H5Gmove2(src_loc_id, src_name, dst_loc_id, dst_name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1074, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1075
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gmove2 (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1074
 *     r = _hdf5.H5Gmove2(src_loc_id, src_name, dst_loc_id, dst_name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1077
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gmove2 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__91, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1077, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1077, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1073
 *     set_default_error_handler()
 *     r = _hdf5.H5Gmove2(src_loc_id, src_name, dst_loc_id, dst_name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1078
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gmove2 (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gget_num_objs(hid_t loc_id, hsize_t*  num_obj) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1069
 *     return r
 * 
 * cdef herr_t H5Gmove2(hid_t src_loc_id, char *src_name, hid_t dst_loc_id, char *dst_name) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gmove2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1080
 *     return r
 * 
 * cdef herr_t H5Gget_num_objs(hid_t loc_id, hsize_t*  num_obj) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gget_num_objs(hid_t __pyx_v_loc_id, hsize_t *__pyx_v_num_obj) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_num_objs", 0);

  /* "h5py/defs.pyx":1082
 * cdef herr_t H5Gget_num_objs(hid_t loc_id, hsize_t*  num_obj) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_num_objs(loc_id, num_obj)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1083
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_num_objs(loc_id, num_obj)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_num_objs(__pyx_v_loc_id, __pyx_v_num_obj);

  /* "h5py/defs.pyx":1084
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_num_objs(loc_id, num_obj)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1085
 *     r = _hdf5.H5Gget_num_objs(loc_id, num_obj)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1085, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1086
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_num_objs (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1085
 *     r = _hdf5.H5Gget_num_objs(loc_id, num_obj)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1088
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_num_objs (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__92, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1088, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1088, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1084
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_num_objs(loc_id, num_obj)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1089
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_num_objs (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Gget_objname_by_idx(hid_t loc_id, hsize_t idx, char *name, size_t size) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1080
 *     return r
 * 
 * cdef herr_t H5Gget_num_objs(hid_t loc_id, hsize_t*  num_obj) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_num_objs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1091
 *     return r
 * 
 * cdef int H5Gget_objname_by_idx(hid_t loc_id, hsize_t idx, char *name, size_t size) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Gget_objname_by_idx(hid_t __pyx_v_loc_id, hsize_t __pyx_v_idx, char *__pyx_v_name, size_t __pyx_v_size) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_objname_by_idx", 0);

  /* "h5py/defs.pyx":1093
 * cdef int H5Gget_objname_by_idx(hid_t loc_id, hsize_t idx, char *name, size_t size) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_objname_by_idx(loc_id, idx, name, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1094
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objname_by_idx(loc_id, idx, name, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_objname_by_idx(__pyx_v_loc_id, __pyx_v_idx, __pyx_v_name, __pyx_v_size);

  /* "h5py/defs.pyx":1095
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objname_by_idx(loc_id, idx, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1096
 *     r = _hdf5.H5Gget_objname_by_idx(loc_id, idx, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1096, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1097
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objname_by_idx (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1096
 *     r = _hdf5.H5Gget_objname_by_idx(loc_id, idx, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1099
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objname_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__93, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1099, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1099, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1095
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objname_by_idx(loc_id, idx, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":1100
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objname_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Gget_objtype_by_idx(hid_t loc_id, hsize_t idx) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1091
 *     return r
 * 
 * cdef int H5Gget_objname_by_idx(hid_t loc_id, hsize_t idx, char *name, size_t size) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_objname_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1102
 *     return r
 * 
 * cdef int H5Gget_objtype_by_idx(hid_t loc_id, hsize_t idx) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Gget_objtype_by_idx(hid_t __pyx_v_loc_id, hsize_t __pyx_v_idx) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_objtype_by_idx", 0);

  /* "h5py/defs.pyx":1104
 * cdef int H5Gget_objtype_by_idx(hid_t loc_id, hsize_t idx) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_objtype_by_idx(loc_id, idx)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1105
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objtype_by_idx(loc_id, idx)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_objtype_by_idx(__pyx_v_loc_id, __pyx_v_idx);

  /* "h5py/defs.pyx":1106
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objtype_by_idx(loc_id, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1107
 *     r = _hdf5.H5Gget_objtype_by_idx(loc_id, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1107, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1108
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objtype_by_idx (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1107
 *     r = _hdf5.H5Gget_objtype_by_idx(loc_id, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1110
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objtype_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__94, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1110, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1106
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objtype_by_idx(loc_id, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":1111
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objtype_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Giterate(hid_t loc_id, char *name, int *idx, H5G_iterate_t op, void* data) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1102
 *     return r
 * 
 * cdef int H5Gget_objtype_by_idx(hid_t loc_id, hsize_t idx) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_objtype_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1113
 *     return r
 * 
 * cdef herr_t H5Giterate(hid_t loc_id, char *name, int *idx, H5G_iterate_t op, void* data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Giterate(hid_t __pyx_v_loc_id, char *__pyx_v_name, int *__pyx_v_idx, H5G_iterate_t __pyx_v_op, void *__pyx_v_data) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Giterate", 0);

  /* "h5py/defs.pyx":1115
 * cdef herr_t H5Giterate(hid_t loc_id, char *name, int *idx, H5G_iterate_t op, void* data) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Giterate(loc_id, name, idx, op, data)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1116
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Giterate(loc_id, name, idx, op, data)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Giterate(__pyx_v_loc_id, __pyx_v_name, __pyx_v_idx, __pyx_v_op, __pyx_v_data);

  /* "h5py/defs.pyx":1117
 *     set_default_error_handler()
 *     r = _hdf5.H5Giterate(loc_id, name, idx, op, data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1118
 *     r = _hdf5.H5Giterate(loc_id, name, idx, op, data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1118, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1119
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Giterate (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1118
 *     r = _hdf5.H5Giterate(loc_id, name, idx, op, data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1121
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Giterate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1121, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1121, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1117
 *     set_default_error_handler()
 *     r = _hdf5.H5Giterate(loc_id, name, idx, op, data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1122
 *         else:
 *             raise RuntimeError("Unspecified error in H5Giterate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gget_objinfo(hid_t loc_id, char* name, int follow_link, H5G_stat_t *statbuf) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1113
 *     return r
 * 
 * cdef herr_t H5Giterate(hid_t loc_id, char *name, int *idx, H5G_iterate_t op, void* data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Giterate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1124
 *     return r
 * 
 * cdef herr_t H5Gget_objinfo(hid_t loc_id, char* name, int follow_link, H5G_stat_t *statbuf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gget_objinfo(hid_t __pyx_v_loc_id, char *__pyx_v_name, int __pyx_v_follow_link, H5G_stat_t *__pyx_v_statbuf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_objinfo", 0);

  /* "h5py/defs.pyx":1126
 * cdef herr_t H5Gget_objinfo(hid_t loc_id, char* name, int follow_link, H5G_stat_t *statbuf) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_objinfo(loc_id, name, follow_link, statbuf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1127
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objinfo(loc_id, name, follow_link, statbuf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_objinfo(__pyx_v_loc_id, __pyx_v_name, __pyx_v_follow_link, __pyx_v_statbuf);

  /* "h5py/defs.pyx":1128
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objinfo(loc_id, name, follow_link, statbuf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1129
 *     r = _hdf5.H5Gget_objinfo(loc_id, name, follow_link, statbuf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1129, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1130
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objinfo (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1129
 *     r = _hdf5.H5Gget_objinfo(loc_id, name, follow_link, statbuf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1132
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objinfo (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__96, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1132, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1132, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1128
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_objinfo(loc_id, name, follow_link, statbuf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1133
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objinfo (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gget_linkval(hid_t loc_id, char *name, size_t size, char *value) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1124
 *     return r
 * 
 * cdef herr_t H5Gget_objinfo(hid_t loc_id, char* name, int follow_link, H5G_stat_t *statbuf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_objinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1135
 *     return r
 * 
 * cdef herr_t H5Gget_linkval(hid_t loc_id, char *name, size_t size, char *value) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gget_linkval(hid_t __pyx_v_loc_id, char *__pyx_v_name, size_t __pyx_v_size, char *__pyx_v_value) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_linkval", 0);

  /* "h5py/defs.pyx":1137
 * cdef herr_t H5Gget_linkval(hid_t loc_id, char *name, size_t size, char *value) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_linkval(loc_id, name, size, value)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1138
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_linkval(loc_id, name, size, value)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_linkval(__pyx_v_loc_id, __pyx_v_name, __pyx_v_size, __pyx_v_value);

  /* "h5py/defs.pyx":1139
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_linkval(loc_id, name, size, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1140
 *     r = _hdf5.H5Gget_linkval(loc_id, name, size, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1140, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1141
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_linkval (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1140
 *     r = _hdf5.H5Gget_linkval(loc_id, name, size, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1143
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_linkval (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__97, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1143, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1143, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1139
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_linkval(loc_id, name, size, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1144
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_linkval (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gset_comment(hid_t loc_id, char *name, char *comment) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1135
 *     return r
 * 
 * cdef herr_t H5Gget_linkval(hid_t loc_id, char *name, size_t size, char *value) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_linkval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1146
 *     return r
 * 
 * cdef herr_t H5Gset_comment(hid_t loc_id, char *name, char *comment) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gset_comment(hid_t __pyx_v_loc_id, char *__pyx_v_name, char *__pyx_v_comment) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gset_comment", 0);

  /* "h5py/defs.pyx":1148
 * cdef herr_t H5Gset_comment(hid_t loc_id, char *name, char *comment) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gset_comment(loc_id, name, comment)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1149
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gset_comment(loc_id, name, comment)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gset_comment(__pyx_v_loc_id, __pyx_v_name, __pyx_v_comment);

  /* "h5py/defs.pyx":1150
 *     set_default_error_handler()
 *     r = _hdf5.H5Gset_comment(loc_id, name, comment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1151
 *     r = _hdf5.H5Gset_comment(loc_id, name, comment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1151, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1152
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gset_comment (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1151
 *     r = _hdf5.H5Gset_comment(loc_id, name, comment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1154
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gset_comment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__98, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1154, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1150
 *     set_default_error_handler()
 *     r = _hdf5.H5Gset_comment(loc_id, name, comment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1155
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gset_comment (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Gget_comment(hid_t loc_id, char *name, size_t bufsize, char *comment) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1146
 *     return r
 * 
 * cdef herr_t H5Gset_comment(hid_t loc_id, char *name, char *comment) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gset_comment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1157
 *     return r
 * 
 * cdef int H5Gget_comment(hid_t loc_id, char *name, size_t bufsize, char *comment) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Gget_comment(hid_t __pyx_v_loc_id, char *__pyx_v_name, size_t __pyx_v_bufsize, char *__pyx_v_comment) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_comment", 0);

  /* "h5py/defs.pyx":1159
 * cdef int H5Gget_comment(hid_t loc_id, char *name, size_t bufsize, char *comment) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_comment(loc_id, name, bufsize, comment)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1160
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_comment(loc_id, name, bufsize, comment)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_comment(__pyx_v_loc_id, __pyx_v_name, __pyx_v_bufsize, __pyx_v_comment);

  /* "h5py/defs.pyx":1161
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_comment(loc_id, name, bufsize, comment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1162
 *     r = _hdf5.H5Gget_comment(loc_id, name, bufsize, comment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1162, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1163
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_comment (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1162
 *     r = _hdf5.H5Gget_comment(loc_id, name, bufsize, comment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1165
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_comment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__99, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1165, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1165, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1161
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_comment(loc_id, name, bufsize, comment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":1166
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_comment (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Gcreate_anon( hid_t loc_id, hid_t gcpl_id, hid_t gapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1157
 *     return r
 * 
 * cdef int H5Gget_comment(hid_t loc_id, char *name, size_t bufsize, char *comment) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_comment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1168
 *     return r
 * 
 * cdef hid_t H5Gcreate_anon( hid_t loc_id, hid_t gcpl_id, hid_t gapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Gcreate_anon(hid_t __pyx_v_loc_id, hid_t __pyx_v_gcpl_id, hid_t __pyx_v_gapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gcreate_anon", 0);

  /* "h5py/defs.pyx":1170
 * cdef hid_t H5Gcreate_anon( hid_t loc_id, hid_t gcpl_id, hid_t gapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gcreate_anon(loc_id, gcpl_id, gapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1171
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gcreate_anon(loc_id, gcpl_id, gapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gcreate_anon(__pyx_v_loc_id, __pyx_v_gcpl_id, __pyx_v_gapl_id);

  /* "h5py/defs.pyx":1172
 *     set_default_error_handler()
 *     r = _hdf5.H5Gcreate_anon(loc_id, gcpl_id, gapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1173
 *     r = _hdf5.H5Gcreate_anon(loc_id, gcpl_id, gapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1173, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1174
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gcreate_anon (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1173
 *     r = _hdf5.H5Gcreate_anon(loc_id, gcpl_id, gapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1176
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gcreate_anon (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__100, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1176, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1172
 *     set_default_error_handler()
 *     r = _hdf5.H5Gcreate_anon(loc_id, gcpl_id, gapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1177
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gcreate_anon (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Gcreate(hid_t loc_id, char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1168
 *     return r
 * 
 * cdef hid_t H5Gcreate_anon( hid_t loc_id, hid_t gcpl_id, hid_t gapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gcreate_anon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1179
 *     return r
 * 
 * cdef hid_t H5Gcreate(hid_t loc_id, char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Gcreate(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_gcpl_id, hid_t __pyx_v_gapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gcreate", 0);

  /* "h5py/defs.pyx":1181
 * cdef hid_t H5Gcreate(hid_t loc_id, char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gcreate(loc_id, name, lcpl_id, gcpl_id, gapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1182
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gcreate(loc_id, name, lcpl_id, gcpl_id, gapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gcreate(__pyx_v_loc_id, __pyx_v_name, __pyx_v_lcpl_id, __pyx_v_gcpl_id, __pyx_v_gapl_id);

  /* "h5py/defs.pyx":1183
 *     set_default_error_handler()
 *     r = _hdf5.H5Gcreate(loc_id, name, lcpl_id, gcpl_id, gapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1184
 *     r = _hdf5.H5Gcreate(loc_id, name, lcpl_id, gcpl_id, gapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1184, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1185
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gcreate (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1184
 *     r = _hdf5.H5Gcreate(loc_id, name, lcpl_id, gcpl_id, gapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1187
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__101, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1187, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1187, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1183
 *     set_default_error_handler()
 *     r = _hdf5.H5Gcreate(loc_id, name, lcpl_id, gcpl_id, gapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1188
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gcreate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Gopen( hid_t loc_id, char * name, hid_t gapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1179
 *     return r
 * 
 * cdef hid_t H5Gcreate(hid_t loc_id, char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gcreate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1190
 *     return r
 * 
 * cdef hid_t H5Gopen( hid_t loc_id, char * name, hid_t gapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Gopen(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_gapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gopen", 0);

  /* "h5py/defs.pyx":1192
 * cdef hid_t H5Gopen( hid_t loc_id, char * name, hid_t gapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gopen(loc_id, name, gapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1193
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gopen(loc_id, name, gapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gopen(__pyx_v_loc_id, __pyx_v_name, __pyx_v_gapl_id);

  /* "h5py/defs.pyx":1194
 *     set_default_error_handler()
 *     r = _hdf5.H5Gopen(loc_id, name, gapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1195
 *     r = _hdf5.H5Gopen(loc_id, name, gapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1195, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1196
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gopen (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1195
 *     r = _hdf5.H5Gopen(loc_id, name, gapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1198
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__102, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1198, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1194
 *     set_default_error_handler()
 *     r = _hdf5.H5Gopen(loc_id, name, gapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1199
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gopen (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gget_info( hid_t group_id, H5G_info_t *group_info) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1190
 *     return r
 * 
 * cdef hid_t H5Gopen( hid_t loc_id, char * name, hid_t gapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gopen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1201
 *     return r
 * 
 * cdef herr_t H5Gget_info( hid_t group_id, H5G_info_t *group_info) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gget_info(hid_t __pyx_v_group_id, H5G_info_t *__pyx_v_group_info) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_info", 0);

  /* "h5py/defs.pyx":1203
 * cdef herr_t H5Gget_info( hid_t group_id, H5G_info_t *group_info) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_info(group_id, group_info)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1204
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_info(group_id, group_info)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_info(__pyx_v_group_id, __pyx_v_group_info);

  /* "h5py/defs.pyx":1205
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_info(group_id, group_info)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1206
 *     r = _hdf5.H5Gget_info(group_id, group_info)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1206, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1207
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_info (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1206
 *     r = _hdf5.H5Gget_info(group_id, group_info)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1209
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__103, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1209, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1205
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_info(group_id, group_info)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1210
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_info (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Gget_info_by_name( hid_t loc_id, char *group_name, H5G_info_t *group_info, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1201
 *     return r
 * 
 * cdef herr_t H5Gget_info( hid_t group_id, H5G_info_t *group_info) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1212
 *     return r
 * 
 * cdef herr_t H5Gget_info_by_name( hid_t loc_id, char *group_name, H5G_info_t *group_info, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Gget_info_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5G_info_t *__pyx_v_group_info, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_info_by_name", 0);

  /* "h5py/defs.pyx":1214
 * cdef herr_t H5Gget_info_by_name( hid_t loc_id, char *group_name, H5G_info_t *group_info, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_info_by_name(loc_id, group_name, group_info, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1215
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_info_by_name(loc_id, group_name, group_info, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_info_by_name(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_group_info, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1216
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_info_by_name(loc_id, group_name, group_info, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1217
 *     r = _hdf5.H5Gget_info_by_name(loc_id, group_name, group_info, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1217, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1218
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_info_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1217
 *     r = _hdf5.H5Gget_info_by_name(loc_id, group_name, group_info, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1220
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_info_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__104, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1220, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1220, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1216
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_info_by_name(loc_id, group_name, group_info, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1221
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_info_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Gget_create_plist(hid_t group_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1212
 *     return r
 * 
 * cdef herr_t H5Gget_info_by_name( hid_t loc_id, char *group_name, H5G_info_t *group_info, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_info_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1223
 *     return r
 * 
 * cdef hid_t H5Gget_create_plist(hid_t group_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Gget_create_plist(hid_t __pyx_v_group_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Gget_create_plist", 0);

  /* "h5py/defs.pyx":1225
 * cdef hid_t H5Gget_create_plist(hid_t group_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Gget_create_plist(group_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1226
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_create_plist(group_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Gget_create_plist(__pyx_v_group_id);

  /* "h5py/defs.pyx":1227
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_create_plist(group_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1228
 *     r = _hdf5.H5Gget_create_plist(group_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1228, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1229
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_create_plist (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1228
 *     r = _hdf5.H5Gget_create_plist(group_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1231
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_create_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__105, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1231, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1227
 *     set_default_error_handler()
 *     r = _hdf5.H5Gget_create_plist(group_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1232
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_create_plist (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5I_type_t H5Iget_type(hid_t obj_id) except <H5I_type_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1223
 *     return r
 * 
 * cdef hid_t H5Gget_create_plist(hid_t group_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Gget_create_plist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1234
 *     return r
 * 
 * cdef H5I_type_t H5Iget_type(hid_t obj_id) except <H5I_type_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5I_type_t r
 *     set_default_error_handler()
 */

static H5I_type_t __pyx_f_4h5py_4defs_H5Iget_type(hid_t __pyx_v_obj_id) {
  H5I_type_t __pyx_v_r;
  H5I_type_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Iget_type", 0);

  /* "h5py/defs.pyx":1236
 * cdef H5I_type_t H5Iget_type(hid_t obj_id) except <H5I_type_t>-1:
 *     cdef H5I_type_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Iget_type(obj_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1237
 *     cdef H5I_type_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_type(obj_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Iget_type(__pyx_v_obj_id);

  /* "h5py/defs.pyx":1238
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_type(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5I_type_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1239
 *     r = _hdf5.H5Iget_type(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5I_type_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1239, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1240
 *     if r<0:
 *         if set_exception():
 *             return <H5I_type_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_type (return value <0)")
 */
      __pyx_r = ((H5I_type_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1239
 *     r = _hdf5.H5Iget_type(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5I_type_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1242
 *             return <H5I_type_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__106, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1242, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1238
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_type(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5I_type_t>-1
 */
  }

  /* "h5py/defs.pyx":1243
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_type (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5Iget_name( hid_t obj_id, char *name, size_t size) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1234
 *     return r
 * 
 * cdef H5I_type_t H5Iget_type(hid_t obj_id) except <H5I_type_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5I_type_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Iget_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5I_type_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1245
 *     return r
 * 
 * cdef ssize_t H5Iget_name( hid_t obj_id, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Iget_name(hid_t __pyx_v_obj_id, char *__pyx_v_name, size_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Iget_name", 0);

  /* "h5py/defs.pyx":1247
 * cdef ssize_t H5Iget_name( hid_t obj_id, char *name, size_t size) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Iget_name(obj_id, name, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1248
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_name(obj_id, name, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Iget_name(__pyx_v_obj_id, __pyx_v_name, __pyx_v_size);

  /* "h5py/defs.pyx":1249
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_name(obj_id, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1250
 *     r = _hdf5.H5Iget_name(obj_id, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1250, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1251
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_name (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1250
 *     r = _hdf5.H5Iget_name(obj_id, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1253
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__107, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1253, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1253, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1249
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_name(obj_id, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":1254
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Iget_file_id(hid_t obj_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1245
 *     return r
 * 
 * cdef ssize_t H5Iget_name( hid_t obj_id, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Iget_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1256
 *     return r
 * 
 * cdef hid_t H5Iget_file_id(hid_t obj_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Iget_file_id(hid_t __pyx_v_obj_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Iget_file_id", 0);

  /* "h5py/defs.pyx":1258
 * cdef hid_t H5Iget_file_id(hid_t obj_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Iget_file_id(obj_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1259
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_file_id(obj_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Iget_file_id(__pyx_v_obj_id);

  /* "h5py/defs.pyx":1260
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_file_id(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1261
 *     r = _hdf5.H5Iget_file_id(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1261, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1262
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_file_id (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1261
 *     r = _hdf5.H5Iget_file_id(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1264
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_file_id (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__108, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1264, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1264, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1260
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_file_id(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1265
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_file_id (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Idec_ref(hid_t obj_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1256
 *     return r
 * 
 * cdef hid_t H5Iget_file_id(hid_t obj_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Iget_file_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1267
 *     return r
 * 
 * cdef int H5Idec_ref(hid_t obj_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     with nogil:
 */

static int __pyx_f_4h5py_4defs_H5Idec_ref(hid_t __pyx_v_obj_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Idec_ref", 0);

  /* "h5py/defs.pyx":1269
 * cdef int H5Idec_ref(hid_t obj_id) except <int>-1:
 *     cdef int r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Idec_ref(obj_id)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":1270
 *     cdef int r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Idec_ref(obj_id)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":1271
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Idec_ref(obj_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Idec_ref(__pyx_v_obj_id);
      }

      /* "h5py/defs.pyx":1269
 * cdef int H5Idec_ref(hid_t obj_id) except <int>-1:
 *     cdef int r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Idec_ref(obj_id)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":1272
 *         set_default_error_handler()
 *         r = _hdf5.H5Idec_ref(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1273
 *         r = _hdf5.H5Idec_ref(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1273, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1274
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Idec_ref (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1273
 *         r = _hdf5.H5Idec_ref(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1276
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Idec_ref (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__109, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1276, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1272
 *         set_default_error_handler()
 *         r = _hdf5.H5Idec_ref(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":1277
 *         else:
 *             raise RuntimeError("Unspecified error in H5Idec_ref (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Iget_ref(hid_t obj_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1267
 *     return r
 * 
 * cdef int H5Idec_ref(hid_t obj_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Idec_ref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1279
 *     return r
 * 
 * cdef int H5Iget_ref(hid_t obj_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Iget_ref(hid_t __pyx_v_obj_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Iget_ref", 0);

  /* "h5py/defs.pyx":1281
 * cdef int H5Iget_ref(hid_t obj_id) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Iget_ref(obj_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1282
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_ref(obj_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Iget_ref(__pyx_v_obj_id);

  /* "h5py/defs.pyx":1283
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_ref(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1284
 *     r = _hdf5.H5Iget_ref(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1284, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1285
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_ref (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1284
 *     r = _hdf5.H5Iget_ref(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1287
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_ref (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__110, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1287, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1287, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1283
 *     set_default_error_handler()
 *     r = _hdf5.H5Iget_ref(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":1288
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_ref (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Iinc_ref(hid_t obj_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1279
 *     return r
 * 
 * cdef int H5Iget_ref(hid_t obj_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Iget_ref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1290
 *     return r
 * 
 * cdef int H5Iinc_ref(hid_t obj_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Iinc_ref(hid_t __pyx_v_obj_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Iinc_ref", 0);

  /* "h5py/defs.pyx":1292
 * cdef int H5Iinc_ref(hid_t obj_id) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Iinc_ref(obj_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1293
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Iinc_ref(obj_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Iinc_ref(__pyx_v_obj_id);

  /* "h5py/defs.pyx":1294
 *     set_default_error_handler()
 *     r = _hdf5.H5Iinc_ref(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1295
 *     r = _hdf5.H5Iinc_ref(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1295, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1296
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iinc_ref (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1295
 *     r = _hdf5.H5Iinc_ref(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1298
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iinc_ref (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__111, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1298, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1294
 *     set_default_error_handler()
 *     r = _hdf5.H5Iinc_ref(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":1299
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iinc_ref (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Iis_valid( hid_t obj_id ) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1290
 *     return r
 * 
 * cdef int H5Iinc_ref(hid_t obj_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Iinc_ref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1301
 *     return r
 * 
 * cdef htri_t H5Iis_valid( hid_t obj_id ) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Iis_valid(hid_t __pyx_v_obj_id) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Iis_valid", 0);

  /* "h5py/defs.pyx":1303
 * cdef htri_t H5Iis_valid( hid_t obj_id ) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Iis_valid(obj_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1304
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Iis_valid(obj_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Iis_valid(__pyx_v_obj_id);

  /* "h5py/defs.pyx":1305
 *     set_default_error_handler()
 *     r = _hdf5.H5Iis_valid(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1306
 *     r = _hdf5.H5Iis_valid(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1306, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1307
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iis_valid (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1306
 *     r = _hdf5.H5Iis_valid(obj_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1309
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iis_valid (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__112, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1309, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1305
 *     set_default_error_handler()
 *     r = _hdf5.H5Iis_valid(obj_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":1310
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iis_valid (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lmove(hid_t src_loc, char *src_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1301
 *     return r
 * 
 * cdef htri_t H5Iis_valid( hid_t obj_id ) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Iis_valid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1312
 *     return r
 * 
 * cdef herr_t H5Lmove(hid_t src_loc, char *src_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lmove(hid_t __pyx_v_src_loc, char *__pyx_v_src_name, hid_t __pyx_v_dst_loc, char *__pyx_v_dst_name, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lmove", 0);

  /* "h5py/defs.pyx":1314
 * cdef herr_t H5Lmove(hid_t src_loc, char *src_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lmove(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1315
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lmove(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lmove(__pyx_v_src_loc, __pyx_v_src_name, __pyx_v_dst_loc, __pyx_v_dst_name, __pyx_v_lcpl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1316
 *     set_default_error_handler()
 *     r = _hdf5.H5Lmove(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1317
 *     r = _hdf5.H5Lmove(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1317, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1318
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lmove (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1317
 *     r = _hdf5.H5Lmove(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1320
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lmove (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__113, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1320, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1316
 *     set_default_error_handler()
 *     r = _hdf5.H5Lmove(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1321
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lmove (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lcopy(hid_t src_loc, char *src_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1312
 *     return r
 * 
 * cdef herr_t H5Lmove(hid_t src_loc, char *src_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lmove", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1323
 *     return r
 * 
 * cdef herr_t H5Lcopy(hid_t src_loc, char *src_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lcopy(hid_t __pyx_v_src_loc, char *__pyx_v_src_name, hid_t __pyx_v_dst_loc, char *__pyx_v_dst_name, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lcopy", 0);

  /* "h5py/defs.pyx":1325
 * cdef herr_t H5Lcopy(hid_t src_loc, char *src_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lcopy(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1326
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcopy(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lcopy(__pyx_v_src_loc, __pyx_v_src_name, __pyx_v_dst_loc, __pyx_v_dst_name, __pyx_v_lcpl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1327
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcopy(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1328
 *     r = _hdf5.H5Lcopy(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1328, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1329
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcopy (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1328
 *     r = _hdf5.H5Lcopy(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1331
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__114, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1331, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1331, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1327
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcopy(src_loc, src_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1332
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcopy (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lcreate_hard(hid_t cur_loc, char *cur_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1323
 *     return r
 * 
 * cdef herr_t H5Lcopy(hid_t src_loc, char *src_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lcopy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1334
 *     return r
 * 
 * cdef herr_t H5Lcreate_hard(hid_t cur_loc, char *cur_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lcreate_hard(hid_t __pyx_v_cur_loc, char *__pyx_v_cur_name, hid_t __pyx_v_dst_loc, char *__pyx_v_dst_name, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lcreate_hard", 0);

  /* "h5py/defs.pyx":1336
 * cdef herr_t H5Lcreate_hard(hid_t cur_loc, char *cur_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lcreate_hard(cur_loc, cur_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1337
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_hard(cur_loc, cur_name, dst_loc, dst_name, lcpl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lcreate_hard(__pyx_v_cur_loc, __pyx_v_cur_name, __pyx_v_dst_loc, __pyx_v_dst_name, __pyx_v_lcpl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1338
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_hard(cur_loc, cur_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1339
 *     r = _hdf5.H5Lcreate_hard(cur_loc, cur_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1339, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1340
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_hard (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1339
 *     r = _hdf5.H5Lcreate_hard(cur_loc, cur_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1342
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_hard (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__115, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1342, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1342, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1338
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_hard(cur_loc, cur_name, dst_loc, dst_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1343
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_hard (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lcreate_soft(char *link_target, hid_t link_loc_id, char *link_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1334
 *     return r
 * 
 * cdef herr_t H5Lcreate_hard(hid_t cur_loc, char *cur_name, hid_t dst_loc, char *dst_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lcreate_hard", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1345
 *     return r
 * 
 * cdef herr_t H5Lcreate_soft(char *link_target, hid_t link_loc_id, char *link_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lcreate_soft(char *__pyx_v_link_target, hid_t __pyx_v_link_loc_id, char *__pyx_v_link_name, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lcreate_soft", 0);

  /* "h5py/defs.pyx":1347
 * cdef herr_t H5Lcreate_soft(char *link_target, hid_t link_loc_id, char *link_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lcreate_soft(link_target, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1348
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_soft(link_target, link_loc_id, link_name, lcpl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lcreate_soft(__pyx_v_link_target, __pyx_v_link_loc_id, __pyx_v_link_name, __pyx_v_lcpl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1349
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_soft(link_target, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1350
 *     r = _hdf5.H5Lcreate_soft(link_target, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1350, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1351
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_soft (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1350
 *     r = _hdf5.H5Lcreate_soft(link_target, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1353
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_soft (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__116, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1353, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1353, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1349
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_soft(link_target, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1354
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_soft (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Ldelete(hid_t loc_id, char *name, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1345
 *     return r
 * 
 * cdef herr_t H5Lcreate_soft(char *link_target, hid_t link_loc_id, char *link_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lcreate_soft", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1356
 *     return r
 * 
 * cdef herr_t H5Ldelete(hid_t loc_id, char *name, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Ldelete(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Ldelete", 0);

  /* "h5py/defs.pyx":1358
 * cdef herr_t H5Ldelete(hid_t loc_id, char *name, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Ldelete(loc_id, name, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1359
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Ldelete(loc_id, name, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Ldelete(__pyx_v_loc_id, __pyx_v_name, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1360
 *     set_default_error_handler()
 *     r = _hdf5.H5Ldelete(loc_id, name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1361
 *     r = _hdf5.H5Ldelete(loc_id, name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1361, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1362
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ldelete (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1361
 *     r = _hdf5.H5Ldelete(loc_id, name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1364
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ldelete (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__117, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1364, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1360
 *     set_default_error_handler()
 *     r = _hdf5.H5Ldelete(loc_id, name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1365
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ldelete (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Ldelete_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1356
 *     return r
 * 
 * cdef herr_t H5Ldelete(hid_t loc_id, char *name, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Ldelete", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1367
 *     return r
 * 
 * cdef herr_t H5Ldelete_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Ldelete_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Ldelete_by_idx", 0);

  /* "h5py/defs.pyx":1369
 * cdef herr_t H5Ldelete_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Ldelete_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1370
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Ldelete_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Ldelete_by_idx(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1371
 *     set_default_error_handler()
 *     r = _hdf5.H5Ldelete_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1372
 *     r = _hdf5.H5Ldelete_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1372, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1373
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ldelete_by_idx (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1372
 *     r = _hdf5.H5Ldelete_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1375
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ldelete_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__118, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1375, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1375, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1371
 *     set_default_error_handler()
 *     r = _hdf5.H5Ldelete_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1376
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ldelete_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lget_val(hid_t loc_id, char *name, void *bufout, size_t size, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1367
 *     return r
 * 
 * cdef herr_t H5Ldelete_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Ldelete_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1378
 *     return r
 * 
 * cdef herr_t H5Lget_val(hid_t loc_id, char *name, void *bufout, size_t size, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lget_val(hid_t __pyx_v_loc_id, char *__pyx_v_name, void *__pyx_v_bufout, size_t __pyx_v_size, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lget_val", 0);

  /* "h5py/defs.pyx":1380
 * cdef herr_t H5Lget_val(hid_t loc_id, char *name, void *bufout, size_t size, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lget_val(loc_id, name, bufout, size, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1381
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_val(loc_id, name, bufout, size, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lget_val(__pyx_v_loc_id, __pyx_v_name, __pyx_v_bufout, __pyx_v_size, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1382
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_val(loc_id, name, bufout, size, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1383
 *     r = _hdf5.H5Lget_val(loc_id, name, bufout, size, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1383, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1384
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_val (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1383
 *     r = _hdf5.H5Lget_val(loc_id, name, bufout, size, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1386
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_val (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__119, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1386, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1382
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_val(loc_id, name, bufout, size, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1387
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_val (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lget_val_by_idx(hid_t loc_id, char *group_name,  H5_index_t idx_type, H5_iter_order_t order, hsize_t n, void *bufout, size_t size, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1378
 *     return r
 * 
 * cdef herr_t H5Lget_val(hid_t loc_id, char *name, void *bufout, size_t size, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lget_val", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1389
 *     return r
 * 
 * cdef herr_t H5Lget_val_by_idx(hid_t loc_id, char *group_name,  H5_index_t idx_type, H5_iter_order_t order, hsize_t n, void *bufout, size_t size, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lget_val_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, void *__pyx_v_bufout, size_t __pyx_v_size, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lget_val_by_idx", 0);

  /* "h5py/defs.pyx":1391
 * cdef herr_t H5Lget_val_by_idx(hid_t loc_id, char *group_name,  H5_index_t idx_type, H5_iter_order_t order, hsize_t n, void *bufout, size_t size, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lget_val_by_idx(loc_id, group_name, idx_type, order, n, bufout, size, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1392
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_val_by_idx(loc_id, group_name, idx_type, order, n, bufout, size, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lget_val_by_idx(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_bufout, __pyx_v_size, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1393
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_val_by_idx(loc_id, group_name, idx_type, order, n, bufout, size, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1394
 *     r = _hdf5.H5Lget_val_by_idx(loc_id, group_name, idx_type, order, n, bufout, size, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1394, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1395
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_val_by_idx (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1394
 *     r = _hdf5.H5Lget_val_by_idx(loc_id, group_name, idx_type, order, n, bufout, size, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1397
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_val_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__120, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1397, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1397, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1393
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_val_by_idx(loc_id, group_name, idx_type, order, n, bufout, size, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1398
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_val_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Lexists(hid_t loc_id, char *name, hid_t lapl_id) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1389
 *     return r
 * 
 * cdef herr_t H5Lget_val_by_idx(hid_t loc_id, char *group_name,  H5_index_t idx_type, H5_iter_order_t order, hsize_t n, void *bufout, size_t size, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lget_val_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1400
 *     return r
 * 
 * cdef htri_t H5Lexists(hid_t loc_id, char *name, hid_t lapl_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Lexists(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_lapl_id) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lexists", 0);

  /* "h5py/defs.pyx":1402
 * cdef htri_t H5Lexists(hid_t loc_id, char *name, hid_t lapl_id) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lexists(loc_id, name, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1403
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lexists(loc_id, name, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lexists(__pyx_v_loc_id, __pyx_v_name, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1404
 *     set_default_error_handler()
 *     r = _hdf5.H5Lexists(loc_id, name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1405
 *     r = _hdf5.H5Lexists(loc_id, name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1405, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1406
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lexists (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1405
 *     r = _hdf5.H5Lexists(loc_id, name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1408
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lexists (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__121, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1408, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1408, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1404
 *     set_default_error_handler()
 *     r = _hdf5.H5Lexists(loc_id, name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":1409
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lexists (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lget_info(hid_t loc_id, char *name, H5L_info_t *linfo, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1400
 *     return r
 * 
 * cdef htri_t H5Lexists(hid_t loc_id, char *name, hid_t lapl_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lexists", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1411
 *     return r
 * 
 * cdef herr_t H5Lget_info(hid_t loc_id, char *name, H5L_info_t *linfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lget_info(hid_t __pyx_v_loc_id, char *__pyx_v_name, H5L_info_t *__pyx_v_linfo, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lget_info", 0);

  /* "h5py/defs.pyx":1413
 * cdef herr_t H5Lget_info(hid_t loc_id, char *name, H5L_info_t *linfo, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lget_info(loc_id, name, linfo, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1414
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_info(loc_id, name, linfo, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lget_info(__pyx_v_loc_id, __pyx_v_name, __pyx_v_linfo, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1415
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_info(loc_id, name, linfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1416
 *     r = _hdf5.H5Lget_info(loc_id, name, linfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1416, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1417
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_info (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1416
 *     r = _hdf5.H5Lget_info(loc_id, name, linfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1419
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__122, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1419, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1415
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_info(loc_id, name, linfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1420
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_info (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lget_info_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5L_info_t *linfo, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1411
 *     return r
 * 
 * cdef herr_t H5Lget_info(hid_t loc_id, char *name, H5L_info_t *linfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lget_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1422
 *     return r
 * 
 * cdef herr_t H5Lget_info_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5L_info_t *linfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lget_info_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, H5L_info_t *__pyx_v_linfo, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lget_info_by_idx", 0);

  /* "h5py/defs.pyx":1424
 * cdef herr_t H5Lget_info_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5L_info_t *linfo, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lget_info_by_idx(loc_id, group_name, idx_type, order, n, linfo, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1425
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_info_by_idx(loc_id, group_name, idx_type, order, n, linfo, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lget_info_by_idx(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_linfo, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1426
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_info_by_idx(loc_id, group_name, idx_type, order, n, linfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1427
 *     r = _hdf5.H5Lget_info_by_idx(loc_id, group_name, idx_type, order, n, linfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1427, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1428
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_info_by_idx (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1427
 *     r = _hdf5.H5Lget_info_by_idx(loc_id, group_name, idx_type, order, n, linfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1430
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_info_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__123, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1430, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1430, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1426
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_info_by_idx(loc_id, group_name, idx_type, order, n, linfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1431
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_info_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5Lget_name_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, char *name, size_t size, hid_t lapl_id) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1422
 *     return r
 * 
 * cdef herr_t H5Lget_info_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5L_info_t *linfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lget_info_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1433
 *     return r
 * 
 * cdef ssize_t H5Lget_name_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, char *name, size_t size, hid_t lapl_id) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Lget_name_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, char *__pyx_v_name, size_t __pyx_v_size, hid_t __pyx_v_lapl_id) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lget_name_by_idx", 0);

  /* "h5py/defs.pyx":1435
 * cdef ssize_t H5Lget_name_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, char *name, size_t size, hid_t lapl_id) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lget_name_by_idx(loc_id, group_name, idx_type, order, n, name, size, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1436
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_name_by_idx(loc_id, group_name, idx_type, order, n, name, size, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lget_name_by_idx(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_name, __pyx_v_size, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1437
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_name_by_idx(loc_id, group_name, idx_type, order, n, name, size, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1438
 *     r = _hdf5.H5Lget_name_by_idx(loc_id, group_name, idx_type, order, n, name, size, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1438, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1439
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_name_by_idx (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1438
 *     r = _hdf5.H5Lget_name_by_idx(loc_id, group_name, idx_type, order, n, name, size, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1441
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_name_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__124, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1441, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1437
 *     set_default_error_handler()
 *     r = _hdf5.H5Lget_name_by_idx(loc_id, group_name, idx_type, order, n, name, size, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":1442
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_name_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Literate(hid_t grp_id, H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1433
 *     return r
 * 
 * cdef ssize_t H5Lget_name_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, char *name, size_t size, hid_t lapl_id) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lget_name_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1444
 *     return r
 * 
 * cdef herr_t H5Literate(hid_t grp_id, H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Literate(hid_t __pyx_v_grp_id, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t *__pyx_v_idx, H5L_iterate_t __pyx_v_op, void *__pyx_v_op_data) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Literate", 0);

  /* "h5py/defs.pyx":1446
 * cdef herr_t H5Literate(hid_t grp_id, H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Literate(grp_id, idx_type, order, idx, op, op_data)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1447
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Literate(grp_id, idx_type, order, idx, op, op_data)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Literate(__pyx_v_grp_id, __pyx_v_idx_type, __pyx_v_order, __pyx_v_idx, __pyx_v_op, __pyx_v_op_data);

  /* "h5py/defs.pyx":1448
 *     set_default_error_handler()
 *     r = _hdf5.H5Literate(grp_id, idx_type, order, idx, op, op_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1449
 *     r = _hdf5.H5Literate(grp_id, idx_type, order, idx, op, op_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1449, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1450
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Literate (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1449
 *     r = _hdf5.H5Literate(grp_id, idx_type, order, idx, op, op_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1452
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Literate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__125, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1452, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1452, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1448
 *     set_default_error_handler()
 *     r = _hdf5.H5Literate(grp_id, idx_type, order, idx, op, op_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1453
 *         else:
 *             raise RuntimeError("Unspecified error in H5Literate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Literate_by_name(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1444
 *     return r
 * 
 * cdef herr_t H5Literate(hid_t grp_id, H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Literate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1455
 *     return r
 * 
 * cdef herr_t H5Literate_by_name(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Literate_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t *__pyx_v_idx, H5L_iterate_t __pyx_v_op, void *__pyx_v_op_data, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Literate_by_name", 0);

  /* "h5py/defs.pyx":1457
 * cdef herr_t H5Literate_by_name(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Literate_by_name(loc_id, group_name, idx_type, order, idx, op, op_data, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1458
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Literate_by_name(loc_id, group_name, idx_type, order, idx, op, op_data, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Literate_by_name(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_idx, __pyx_v_op, __pyx_v_op_data, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1459
 *     set_default_error_handler()
 *     r = _hdf5.H5Literate_by_name(loc_id, group_name, idx_type, order, idx, op, op_data, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1460
 *     r = _hdf5.H5Literate_by_name(loc_id, group_name, idx_type, order, idx, op, op_data, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1460, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1461
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Literate_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1460
 *     r = _hdf5.H5Literate_by_name(loc_id, group_name, idx_type, order, idx, op, op_data, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1463
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Literate_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__126, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1463, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1459
 *     set_default_error_handler()
 *     r = _hdf5.H5Literate_by_name(loc_id, group_name, idx_type, order, idx, op, op_data, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1464
 *         else:
 *             raise RuntimeError("Unspecified error in H5Literate_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lvisit(hid_t grp_id, H5_index_t idx_type, H5_iter_order_t order, H5L_iterate_t op, void *op_data) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1455
 *     return r
 * 
 * cdef herr_t H5Literate_by_name(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Literate_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1466
 *     return r
 * 
 * cdef herr_t H5Lvisit(hid_t grp_id, H5_index_t idx_type, H5_iter_order_t order, H5L_iterate_t op, void *op_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lvisit(hid_t __pyx_v_grp_id, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, H5L_iterate_t __pyx_v_op, void *__pyx_v_op_data) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lvisit", 0);

  /* "h5py/defs.pyx":1468
 * cdef herr_t H5Lvisit(hid_t grp_id, H5_index_t idx_type, H5_iter_order_t order, H5L_iterate_t op, void *op_data) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lvisit(grp_id, idx_type, order, op, op_data)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1469
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lvisit(grp_id, idx_type, order, op, op_data)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lvisit(__pyx_v_grp_id, __pyx_v_idx_type, __pyx_v_order, __pyx_v_op, __pyx_v_op_data);

  /* "h5py/defs.pyx":1470
 *     set_default_error_handler()
 *     r = _hdf5.H5Lvisit(grp_id, idx_type, order, op, op_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1471
 *     r = _hdf5.H5Lvisit(grp_id, idx_type, order, op, op_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1471, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1472
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lvisit (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1471
 *     r = _hdf5.H5Lvisit(grp_id, idx_type, order, op, op_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1474
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lvisit (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__127, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1474, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1474, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1470
 *     set_default_error_handler()
 *     r = _hdf5.H5Lvisit(grp_id, idx_type, order, op, op_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1475
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lvisit (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lvisit_by_name(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, H5L_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1466
 *     return r
 * 
 * cdef herr_t H5Lvisit(hid_t grp_id, H5_index_t idx_type, H5_iter_order_t order, H5L_iterate_t op, void *op_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lvisit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1477
 *     return r
 * 
 * cdef herr_t H5Lvisit_by_name(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, H5L_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lvisit_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, H5L_iterate_t __pyx_v_op, void *__pyx_v_op_data, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lvisit_by_name", 0);

  /* "h5py/defs.pyx":1479
 * cdef herr_t H5Lvisit_by_name(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, H5L_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lvisit_by_name(loc_id, group_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1480
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lvisit_by_name(loc_id, group_name, idx_type, order, op, op_data, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lvisit_by_name(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_op, __pyx_v_op_data, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1481
 *     set_default_error_handler()
 *     r = _hdf5.H5Lvisit_by_name(loc_id, group_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1482
 *     r = _hdf5.H5Lvisit_by_name(loc_id, group_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1482, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1483
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lvisit_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1482
 *     r = _hdf5.H5Lvisit_by_name(loc_id, group_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1485
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lvisit_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__128, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1485, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1485, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1481
 *     set_default_error_handler()
 *     r = _hdf5.H5Lvisit_by_name(loc_id, group_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1486
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lvisit_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lunpack_elink_val(void *ext_linkval, size_t link_size, unsigned *flags, const char **filename, const char **obj_path) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1477
 *     return r
 * 
 * cdef herr_t H5Lvisit_by_name(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, H5L_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lvisit_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1488
 *     return r
 * 
 * cdef herr_t H5Lunpack_elink_val(void *ext_linkval, size_t link_size, unsigned *flags, const char **filename, const char **obj_path) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lunpack_elink_val(void *__pyx_v_ext_linkval, size_t __pyx_v_link_size, unsigned int *__pyx_v_flags, char const **__pyx_v_filename, char const **__pyx_v_obj_path) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lunpack_elink_val", 0);

  /* "h5py/defs.pyx":1490
 * cdef herr_t H5Lunpack_elink_val(void *ext_linkval, size_t link_size, unsigned *flags, const char **filename, const char **obj_path) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lunpack_elink_val(ext_linkval, link_size, flags, filename, obj_path)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1491
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lunpack_elink_val(ext_linkval, link_size, flags, filename, obj_path)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lunpack_elink_val(__pyx_v_ext_linkval, __pyx_v_link_size, __pyx_v_flags, __pyx_v_filename, __pyx_v_obj_path);

  /* "h5py/defs.pyx":1492
 *     set_default_error_handler()
 *     r = _hdf5.H5Lunpack_elink_val(ext_linkval, link_size, flags, filename, obj_path)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1493
 *     r = _hdf5.H5Lunpack_elink_val(ext_linkval, link_size, flags, filename, obj_path)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1493, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1494
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lunpack_elink_val (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1493
 *     r = _hdf5.H5Lunpack_elink_val(ext_linkval, link_size, flags, filename, obj_path)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1496
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lunpack_elink_val (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__129, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1496, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1496, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1492
 *     set_default_error_handler()
 *     r = _hdf5.H5Lunpack_elink_val(ext_linkval, link_size, flags, filename, obj_path)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1497
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lunpack_elink_val (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Lcreate_external(char *file_name, char *obj_name, hid_t link_loc_id, char *link_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1488
 *     return r
 * 
 * cdef herr_t H5Lunpack_elink_val(void *ext_linkval, size_t link_size, unsigned *flags, const char **filename, const char **obj_path) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lunpack_elink_val", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1499
 *     return r
 * 
 * cdef herr_t H5Lcreate_external(char *file_name, char *obj_name, hid_t link_loc_id, char *link_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Lcreate_external(char *__pyx_v_file_name, char *__pyx_v_obj_name, hid_t __pyx_v_link_loc_id, char *__pyx_v_link_name, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Lcreate_external", 0);

  /* "h5py/defs.pyx":1501
 * cdef herr_t H5Lcreate_external(char *file_name, char *obj_name, hid_t link_loc_id, char *link_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Lcreate_external(file_name, obj_name, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1502
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_external(file_name, obj_name, link_loc_id, link_name, lcpl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Lcreate_external(__pyx_v_file_name, __pyx_v_obj_name, __pyx_v_link_loc_id, __pyx_v_link_name, __pyx_v_lcpl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1503
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_external(file_name, obj_name, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1504
 *     r = _hdf5.H5Lcreate_external(file_name, obj_name, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1504, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1505
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_external (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1504
 *     r = _hdf5.H5Lcreate_external(file_name, obj_name, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1507
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_external (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__130, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1507, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1507, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1503
 *     set_default_error_handler()
 *     r = _hdf5.H5Lcreate_external(file_name, obj_name, link_loc_id, link_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1508
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_external (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Oopen(hid_t loc_id, char *name, hid_t lapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1499
 *     return r
 * 
 * cdef herr_t H5Lcreate_external(char *file_name, char *obj_name, hid_t link_loc_id, char *link_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Lcreate_external", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1510
 *     return r
 * 
 * cdef hid_t H5Oopen(hid_t loc_id, char *name, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Oopen(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_lapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oopen", 0);

  /* "h5py/defs.pyx":1512
 * cdef hid_t H5Oopen(hid_t loc_id, char *name, hid_t lapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oopen(loc_id, name, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1513
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen(loc_id, name, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oopen(__pyx_v_loc_id, __pyx_v_name, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1514
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen(loc_id, name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1515
 *     r = _hdf5.H5Oopen(loc_id, name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1515, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1516
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1515
 *     r = _hdf5.H5Oopen(loc_id, name, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1518
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__131, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1518, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1518, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1514
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen(loc_id, name, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1519
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Oopen_by_addr(hid_t loc_id, haddr_t addr) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1510
 *     return r
 * 
 * cdef hid_t H5Oopen(hid_t loc_id, char *name, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oopen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1521
 *     return r
 * 
 * cdef hid_t H5Oopen_by_addr(hid_t loc_id, haddr_t addr) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Oopen_by_addr(hid_t __pyx_v_loc_id, haddr_t __pyx_v_addr) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oopen_by_addr", 0);

  /* "h5py/defs.pyx":1523
 * cdef hid_t H5Oopen_by_addr(hid_t loc_id, haddr_t addr) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oopen_by_addr(loc_id, addr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1524
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen_by_addr(loc_id, addr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oopen_by_addr(__pyx_v_loc_id, __pyx_v_addr);

  /* "h5py/defs.pyx":1525
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen_by_addr(loc_id, addr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1526
 *     r = _hdf5.H5Oopen_by_addr(loc_id, addr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1526, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1527
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen_by_addr (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1526
 *     r = _hdf5.H5Oopen_by_addr(loc_id, addr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1529
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen_by_addr (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__132, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1529, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1525
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen_by_addr(loc_id, addr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1530
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen_by_addr (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Oopen_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1521
 *     return r
 * 
 * cdef hid_t H5Oopen_by_addr(hid_t loc_id, haddr_t addr) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oopen_by_addr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1532
 *     return r
 * 
 * cdef hid_t H5Oopen_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Oopen_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, hid_t __pyx_v_lapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oopen_by_idx", 0);

  /* "h5py/defs.pyx":1534
 * cdef hid_t H5Oopen_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oopen_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1535
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oopen_by_idx(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1536
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1537
 *     r = _hdf5.H5Oopen_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1537, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1538
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen_by_idx (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1537
 *     r = _hdf5.H5Oopen_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1540
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__133, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1540, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1536
 *     set_default_error_handler()
 *     r = _hdf5.H5Oopen_by_idx(loc_id, group_name, idx_type, order, n, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1541
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Oget_info(hid_t loc_id, H5O_info_t *oinfo) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1532
 *     return r
 * 
 * cdef hid_t H5Oopen_by_idx(hid_t loc_id, char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oopen_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1543
 *     return r
 * 
 * cdef herr_t H5Oget_info(hid_t loc_id, H5O_info_t *oinfo) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Oget_info(hid_t __pyx_v_loc_id, H5O_info_t *__pyx_v_oinfo) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oget_info", 0);

  /* "h5py/defs.pyx":1545
 * cdef herr_t H5Oget_info(hid_t loc_id, H5O_info_t *oinfo) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oget_info(loc_id, oinfo)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1546
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info(loc_id, oinfo)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oget_info(__pyx_v_loc_id, __pyx_v_oinfo);

  /* "h5py/defs.pyx":1547
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info(loc_id, oinfo)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1548
 *     r = _hdf5.H5Oget_info(loc_id, oinfo)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1548, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1549
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1548
 *     r = _hdf5.H5Oget_info(loc_id, oinfo)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1551
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__134, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1551, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1547
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info(loc_id, oinfo)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1552
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Oget_info_by_name(hid_t loc_id, char *name, H5O_info_t *oinfo, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1543
 *     return r
 * 
 * cdef herr_t H5Oget_info(hid_t loc_id, H5O_info_t *oinfo) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oget_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1554
 *     return r
 * 
 * cdef herr_t H5Oget_info_by_name(hid_t loc_id, char *name, H5O_info_t *oinfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Oget_info_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_name, H5O_info_t *__pyx_v_oinfo, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oget_info_by_name", 0);

  /* "h5py/defs.pyx":1556
 * cdef herr_t H5Oget_info_by_name(hid_t loc_id, char *name, H5O_info_t *oinfo, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oget_info_by_name(loc_id, name, oinfo, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1557
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info_by_name(loc_id, name, oinfo, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oget_info_by_name(__pyx_v_loc_id, __pyx_v_name, __pyx_v_oinfo, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1558
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info_by_name(loc_id, name, oinfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1559
 *     r = _hdf5.H5Oget_info_by_name(loc_id, name, oinfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1559, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1560
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1559
 *     r = _hdf5.H5Oget_info_by_name(loc_id, name, oinfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1562
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__135, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1562, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1558
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info_by_name(loc_id, name, oinfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1563
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Oget_info_by_idx(hid_t loc_id, char *group_name,  H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5O_info_t *oinfo, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1554
 *     return r
 * 
 * cdef herr_t H5Oget_info_by_name(hid_t loc_id, char *name, H5O_info_t *oinfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oget_info_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1565
 *     return r
 * 
 * cdef herr_t H5Oget_info_by_idx(hid_t loc_id, char *group_name,  H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5O_info_t *oinfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Oget_info_by_idx(hid_t __pyx_v_loc_id, char *__pyx_v_group_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, hsize_t __pyx_v_n, H5O_info_t *__pyx_v_oinfo, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oget_info_by_idx", 0);

  /* "h5py/defs.pyx":1567
 * cdef herr_t H5Oget_info_by_idx(hid_t loc_id, char *group_name,  H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5O_info_t *oinfo, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oget_info_by_idx(loc_id, group_name, idx_type, order, n, oinfo, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1568
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info_by_idx(loc_id, group_name, idx_type, order, n, oinfo, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oget_info_by_idx(__pyx_v_loc_id, __pyx_v_group_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_n, __pyx_v_oinfo, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1569
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info_by_idx(loc_id, group_name, idx_type, order, n, oinfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1570
 *     r = _hdf5.H5Oget_info_by_idx(loc_id, group_name, idx_type, order, n, oinfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1570, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1571
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info_by_idx (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1570
 *     r = _hdf5.H5Oget_info_by_idx(loc_id, group_name, idx_type, order, n, oinfo, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1573
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__136, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1573, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1569
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_info_by_idx(loc_id, group_name, idx_type, order, n, oinfo, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1574
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info_by_idx (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Olink(hid_t obj_id, hid_t new_loc_id, char *new_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1565
 *     return r
 * 
 * cdef herr_t H5Oget_info_by_idx(hid_t loc_id, char *group_name,  H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5O_info_t *oinfo, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oget_info_by_idx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1576
 *     return r
 * 
 * cdef herr_t H5Olink(hid_t obj_id, hid_t new_loc_id, char *new_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Olink(hid_t __pyx_v_obj_id, hid_t __pyx_v_new_loc_id, char *__pyx_v_new_name, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Olink", 0);

  /* "h5py/defs.pyx":1578
 * cdef herr_t H5Olink(hid_t obj_id, hid_t new_loc_id, char *new_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Olink(obj_id, new_loc_id, new_name, lcpl_id, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1579
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Olink(obj_id, new_loc_id, new_name, lcpl_id, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Olink(__pyx_v_obj_id, __pyx_v_new_loc_id, __pyx_v_new_name, __pyx_v_lcpl_id, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1580
 *     set_default_error_handler()
 *     r = _hdf5.H5Olink(obj_id, new_loc_id, new_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1581
 *     r = _hdf5.H5Olink(obj_id, new_loc_id, new_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1581, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1582
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Olink (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1581
 *     r = _hdf5.H5Olink(obj_id, new_loc_id, new_name, lcpl_id, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1584
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Olink (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__137, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1584, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1580
 *     set_default_error_handler()
 *     r = _hdf5.H5Olink(obj_id, new_loc_id, new_name, lcpl_id, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1585
 *         else:
 *             raise RuntimeError("Unspecified error in H5Olink (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Ocopy(hid_t src_loc_id, char *src_name, hid_t dst_loc_id,  char *dst_name, hid_t ocpypl_id, hid_t lcpl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1576
 *     return r
 * 
 * cdef herr_t H5Olink(hid_t obj_id, hid_t new_loc_id, char *new_name, hid_t lcpl_id, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Olink", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1587
 *     return r
 * 
 * cdef herr_t H5Ocopy(hid_t src_loc_id, char *src_name, hid_t dst_loc_id,  char *dst_name, hid_t ocpypl_id, hid_t lcpl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Ocopy(hid_t __pyx_v_src_loc_id, char *__pyx_v_src_name, hid_t __pyx_v_dst_loc_id, char *__pyx_v_dst_name, hid_t __pyx_v_ocpypl_id, hid_t __pyx_v_lcpl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Ocopy", 0);

  /* "h5py/defs.pyx":1589
 * cdef herr_t H5Ocopy(hid_t src_loc_id, char *src_name, hid_t dst_loc_id,  char *dst_name, hid_t ocpypl_id, hid_t lcpl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Ocopy(src_loc_id, src_name, dst_loc_id, dst_name, ocpypl_id, lcpl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1590
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Ocopy(src_loc_id, src_name, dst_loc_id, dst_name, ocpypl_id, lcpl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Ocopy(__pyx_v_src_loc_id, __pyx_v_src_name, __pyx_v_dst_loc_id, __pyx_v_dst_name, __pyx_v_ocpypl_id, __pyx_v_lcpl_id);

  /* "h5py/defs.pyx":1591
 *     set_default_error_handler()
 *     r = _hdf5.H5Ocopy(src_loc_id, src_name, dst_loc_id, dst_name, ocpypl_id, lcpl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1592
 *     r = _hdf5.H5Ocopy(src_loc_id, src_name, dst_loc_id, dst_name, ocpypl_id, lcpl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1592, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1593
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ocopy (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1592
 *     r = _hdf5.H5Ocopy(src_loc_id, src_name, dst_loc_id, dst_name, ocpypl_id, lcpl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1595
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ocopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__138, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1595, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1595, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1591
 *     set_default_error_handler()
 *     r = _hdf5.H5Ocopy(src_loc_id, src_name, dst_loc_id, dst_name, ocpypl_id, lcpl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1596
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ocopy (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Oincr_refcount(hid_t object_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1587
 *     return r
 * 
 * cdef herr_t H5Ocopy(hid_t src_loc_id, char *src_name, hid_t dst_loc_id,  char *dst_name, hid_t ocpypl_id, hid_t lcpl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Ocopy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1598
 *     return r
 * 
 * cdef herr_t H5Oincr_refcount(hid_t object_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Oincr_refcount(hid_t __pyx_v_object_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oincr_refcount", 0);

  /* "h5py/defs.pyx":1600
 * cdef herr_t H5Oincr_refcount(hid_t object_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oincr_refcount(object_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1601
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oincr_refcount(object_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oincr_refcount(__pyx_v_object_id);

  /* "h5py/defs.pyx":1602
 *     set_default_error_handler()
 *     r = _hdf5.H5Oincr_refcount(object_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1603
 *     r = _hdf5.H5Oincr_refcount(object_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1603, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1604
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oincr_refcount (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1603
 *     r = _hdf5.H5Oincr_refcount(object_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1606
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oincr_refcount (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__139, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1606, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1602
 *     set_default_error_handler()
 *     r = _hdf5.H5Oincr_refcount(object_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1607
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oincr_refcount (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Odecr_refcount(hid_t object_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1598
 *     return r
 * 
 * cdef herr_t H5Oincr_refcount(hid_t object_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oincr_refcount", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1609
 *     return r
 * 
 * cdef herr_t H5Odecr_refcount(hid_t object_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Odecr_refcount(hid_t __pyx_v_object_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Odecr_refcount", 0);

  /* "h5py/defs.pyx":1611
 * cdef herr_t H5Odecr_refcount(hid_t object_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Odecr_refcount(object_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1612
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Odecr_refcount(object_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Odecr_refcount(__pyx_v_object_id);

  /* "h5py/defs.pyx":1613
 *     set_default_error_handler()
 *     r = _hdf5.H5Odecr_refcount(object_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1614
 *     r = _hdf5.H5Odecr_refcount(object_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1614, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1615
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Odecr_refcount (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1614
 *     r = _hdf5.H5Odecr_refcount(object_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1617
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Odecr_refcount (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__140, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1617, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1617, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1613
 *     set_default_error_handler()
 *     r = _hdf5.H5Odecr_refcount(object_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1618
 *         else:
 *             raise RuntimeError("Unspecified error in H5Odecr_refcount (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Oset_comment(hid_t obj_id, char *comment) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1609
 *     return r
 * 
 * cdef herr_t H5Odecr_refcount(hid_t object_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Odecr_refcount", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1620
 *     return r
 * 
 * cdef herr_t H5Oset_comment(hid_t obj_id, char *comment) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Oset_comment(hid_t __pyx_v_obj_id, char *__pyx_v_comment) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oset_comment", 0);

  /* "h5py/defs.pyx":1622
 * cdef herr_t H5Oset_comment(hid_t obj_id, char *comment) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oset_comment(obj_id, comment)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1623
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oset_comment(obj_id, comment)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oset_comment(__pyx_v_obj_id, __pyx_v_comment);

  /* "h5py/defs.pyx":1624
 *     set_default_error_handler()
 *     r = _hdf5.H5Oset_comment(obj_id, comment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1625
 *     r = _hdf5.H5Oset_comment(obj_id, comment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1625, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1626
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oset_comment (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1625
 *     r = _hdf5.H5Oset_comment(obj_id, comment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1628
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oset_comment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__141, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1628, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1628, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1624
 *     set_default_error_handler()
 *     r = _hdf5.H5Oset_comment(obj_id, comment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1629
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oset_comment (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Oset_comment_by_name(hid_t loc_id, char *name,  char *comment, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1620
 *     return r
 * 
 * cdef herr_t H5Oset_comment(hid_t obj_id, char *comment) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oset_comment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1631
 *     return r
 * 
 * cdef herr_t H5Oset_comment_by_name(hid_t loc_id, char *name,  char *comment, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Oset_comment_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_name, char *__pyx_v_comment, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oset_comment_by_name", 0);

  /* "h5py/defs.pyx":1633
 * cdef herr_t H5Oset_comment_by_name(hid_t loc_id, char *name,  char *comment, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oset_comment_by_name(loc_id, name, comment, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1634
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oset_comment_by_name(loc_id, name, comment, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oset_comment_by_name(__pyx_v_loc_id, __pyx_v_name, __pyx_v_comment, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1635
 *     set_default_error_handler()
 *     r = _hdf5.H5Oset_comment_by_name(loc_id, name, comment, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1636
 *     r = _hdf5.H5Oset_comment_by_name(loc_id, name, comment, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1636, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1637
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oset_comment_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1636
 *     r = _hdf5.H5Oset_comment_by_name(loc_id, name, comment, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1639
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oset_comment_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__142, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1639, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1635
 *     set_default_error_handler()
 *     r = _hdf5.H5Oset_comment_by_name(loc_id, name, comment, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1640
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oset_comment_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5Oget_comment(hid_t obj_id, char *comment, size_t bufsize) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1631
 *     return r
 * 
 * cdef herr_t H5Oset_comment_by_name(hid_t loc_id, char *name,  char *comment, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oset_comment_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1642
 *     return r
 * 
 * cdef ssize_t H5Oget_comment(hid_t obj_id, char *comment, size_t bufsize) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Oget_comment(hid_t __pyx_v_obj_id, char *__pyx_v_comment, size_t __pyx_v_bufsize) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oget_comment", 0);

  /* "h5py/defs.pyx":1644
 * cdef ssize_t H5Oget_comment(hid_t obj_id, char *comment, size_t bufsize) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oget_comment(obj_id, comment, bufsize)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1645
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_comment(obj_id, comment, bufsize)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oget_comment(__pyx_v_obj_id, __pyx_v_comment, __pyx_v_bufsize);

  /* "h5py/defs.pyx":1646
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_comment(obj_id, comment, bufsize)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1647
 *     r = _hdf5.H5Oget_comment(obj_id, comment, bufsize)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1647, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1648
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_comment (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1647
 *     r = _hdf5.H5Oget_comment(obj_id, comment, bufsize)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1650
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_comment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__143, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1650, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1650, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1646
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_comment(obj_id, comment, bufsize)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":1651
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_comment (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5Oget_comment_by_name(hid_t loc_id, char *name, char *comment, size_t bufsize, hid_t lapl_id) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1642
 *     return r
 * 
 * cdef ssize_t H5Oget_comment(hid_t obj_id, char *comment, size_t bufsize) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oget_comment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1653
 *     return r
 * 
 * cdef ssize_t H5Oget_comment_by_name(hid_t loc_id, char *name, char *comment, size_t bufsize, hid_t lapl_id) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Oget_comment_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_name, char *__pyx_v_comment, size_t __pyx_v_bufsize, hid_t __pyx_v_lapl_id) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oget_comment_by_name", 0);

  /* "h5py/defs.pyx":1655
 * cdef ssize_t H5Oget_comment_by_name(hid_t loc_id, char *name, char *comment, size_t bufsize, hid_t lapl_id) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oget_comment_by_name(loc_id, name, comment, bufsize, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1656
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_comment_by_name(loc_id, name, comment, bufsize, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oget_comment_by_name(__pyx_v_loc_id, __pyx_v_name, __pyx_v_comment, __pyx_v_bufsize, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1657
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_comment_by_name(loc_id, name, comment, bufsize, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1658
 *     r = _hdf5.H5Oget_comment_by_name(loc_id, name, comment, bufsize, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1658, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1659
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_comment_by_name (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1658
 *     r = _hdf5.H5Oget_comment_by_name(loc_id, name, comment, bufsize, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1661
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_comment_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__144, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1661, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1657
 *     set_default_error_handler()
 *     r = _hdf5.H5Oget_comment_by_name(loc_id, name, comment, bufsize, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":1662
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_comment_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Ovisit(hid_t obj_id, H5_index_t idx_type, H5_iter_order_t order,  H5O_iterate_t op, void *op_data) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1653
 *     return r
 * 
 * cdef ssize_t H5Oget_comment_by_name(hid_t loc_id, char *name, char *comment, size_t bufsize, hid_t lapl_id) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oget_comment_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1664
 *     return r
 * 
 * cdef herr_t H5Ovisit(hid_t obj_id, H5_index_t idx_type, H5_iter_order_t order,  H5O_iterate_t op, void *op_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Ovisit(hid_t __pyx_v_obj_id, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, H5O_iterate_t __pyx_v_op, void *__pyx_v_op_data) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Ovisit", 0);

  /* "h5py/defs.pyx":1666
 * cdef herr_t H5Ovisit(hid_t obj_id, H5_index_t idx_type, H5_iter_order_t order,  H5O_iterate_t op, void *op_data) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Ovisit(obj_id, idx_type, order, op, op_data)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1667
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Ovisit(obj_id, idx_type, order, op, op_data)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Ovisit(__pyx_v_obj_id, __pyx_v_idx_type, __pyx_v_order, __pyx_v_op, __pyx_v_op_data);

  /* "h5py/defs.pyx":1668
 *     set_default_error_handler()
 *     r = _hdf5.H5Ovisit(obj_id, idx_type, order, op, op_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1669
 *     r = _hdf5.H5Ovisit(obj_id, idx_type, order, op, op_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1669, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1670
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ovisit (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1669
 *     r = _hdf5.H5Ovisit(obj_id, idx_type, order, op, op_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1672
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ovisit (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__145, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1672, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1672, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1668
 *     set_default_error_handler()
 *     r = _hdf5.H5Ovisit(obj_id, idx_type, order, op, op_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1673
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ovisit (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Ovisit_by_name(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, H5O_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1664
 *     return r
 * 
 * cdef herr_t H5Ovisit(hid_t obj_id, H5_index_t idx_type, H5_iter_order_t order,  H5O_iterate_t op, void *op_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Ovisit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1675
 *     return r
 * 
 * cdef herr_t H5Ovisit_by_name(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, H5O_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Ovisit_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_obj_name, H5_index_t __pyx_v_idx_type, H5_iter_order_t __pyx_v_order, H5O_iterate_t __pyx_v_op, void *__pyx_v_op_data, hid_t __pyx_v_lapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Ovisit_by_name", 0);

  /* "h5py/defs.pyx":1677
 * cdef herr_t H5Ovisit_by_name(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, H5O_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Ovisit_by_name(loc_id, obj_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1678
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Ovisit_by_name(loc_id, obj_name, idx_type, order, op, op_data, lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Ovisit_by_name(__pyx_v_loc_id, __pyx_v_obj_name, __pyx_v_idx_type, __pyx_v_order, __pyx_v_op, __pyx_v_op_data, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1679
 *     set_default_error_handler()
 *     r = _hdf5.H5Ovisit_by_name(loc_id, obj_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1680
 *     r = _hdf5.H5Ovisit_by_name(loc_id, obj_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1680, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1681
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ovisit_by_name (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1680
 *     r = _hdf5.H5Ovisit_by_name(loc_id, obj_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1683
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ovisit_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__146, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1683, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1679
 *     set_default_error_handler()
 *     r = _hdf5.H5Ovisit_by_name(loc_id, obj_name, idx_type, order, op, op_data, lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1684
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ovisit_by_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Oclose(hid_t object_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1675
 *     return r
 * 
 * cdef herr_t H5Ovisit_by_name(hid_t loc_id, char *obj_name, H5_index_t idx_type, H5_iter_order_t order, H5O_iterate_t op, void *op_data, hid_t lapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Ovisit_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1686
 *     return r
 * 
 * cdef herr_t H5Oclose(hid_t object_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Oclose(hid_t __pyx_v_object_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oclose", 0);

  /* "h5py/defs.pyx":1688
 * cdef herr_t H5Oclose(hid_t object_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Oclose(object_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1689
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Oclose(object_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Oclose(__pyx_v_object_id);

  /* "h5py/defs.pyx":1690
 *     set_default_error_handler()
 *     r = _hdf5.H5Oclose(object_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1691
 *     r = _hdf5.H5Oclose(object_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1691, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1692
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oclose (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1691
 *     r = _hdf5.H5Oclose(object_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1694
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__147, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1694, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1694, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1690
 *     set_default_error_handler()
 *     r = _hdf5.H5Oclose(object_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1695
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oclose (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 5):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1686
 *     return r
 * 
 * cdef herr_t H5Oclose(hid_t object_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1698
 * 
 * IF HDF5_VERSION >= (1, 8, 5):
 *     cdef htri_t H5Oexists_by_name(hid_t loc_id, char * name, hid_t lapl_id ) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *         cdef htri_t r
 *         set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Oexists_by_name(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_lapl_id) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Oexists_by_name", 0);

  /* "h5py/defs.pyx":1700
 *     cdef htri_t H5Oexists_by_name(hid_t loc_id, char * name, hid_t lapl_id ) except <htri_t>-1:
 *         cdef htri_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Oexists_by_name(loc_id, name, lapl_id)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1701
 *         cdef htri_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Oexists_by_name(loc_id, name, lapl_id)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Oexists_by_name(__pyx_v_loc_id, __pyx_v_name, __pyx_v_lapl_id);

  /* "h5py/defs.pyx":1702
 *         set_default_error_handler()
 *         r = _hdf5.H5Oexists_by_name(loc_id, name, lapl_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1703
 *         r = _hdf5.H5Oexists_by_name(loc_id, name, lapl_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <htri_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1703, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1704
 *         if r<0:
 *             if set_exception():
 *                 return <htri_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Oexists_by_name (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1703
 *         r = _hdf5.H5Oexists_by_name(loc_id, name, lapl_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <htri_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":1706
 *                 return <htri_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Oexists_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__148, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1706, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1706, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1702
 *         set_default_error_handler()
 *         r = _hdf5.H5Oexists_by_name(loc_id, name, lapl_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":1707
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Oexists_by_name (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Pcreate(hid_t plist_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1698
 * 
 * IF HDF5_VERSION >= (1, 8, 5):
 *     cdef htri_t H5Oexists_by_name(hid_t loc_id, char * name, hid_t lapl_id ) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *         cdef htri_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Oexists_by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1709
 *         return r
 * 
 * cdef hid_t H5Pcreate(hid_t plist_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Pcreate(hid_t __pyx_v_plist_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pcreate", 0);

  /* "h5py/defs.pyx":1711
 * cdef hid_t H5Pcreate(hid_t plist_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pcreate(plist_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1712
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pcreate(plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pcreate(__pyx_v_plist_id);

  /* "h5py/defs.pyx":1713
 *     set_default_error_handler()
 *     r = _hdf5.H5Pcreate(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1714
 *     r = _hdf5.H5Pcreate(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1714, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1715
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pcreate (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1714
 *     r = _hdf5.H5Pcreate(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1717
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__149, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1717, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1717, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1713
 *     set_default_error_handler()
 *     r = _hdf5.H5Pcreate(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1718
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pcreate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Pcopy(hid_t plist_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1709
 *         return r
 * 
 * cdef hid_t H5Pcreate(hid_t plist_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pcreate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1720
 *     return r
 * 
 * cdef hid_t H5Pcopy(hid_t plist_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Pcopy(hid_t __pyx_v_plist_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pcopy", 0);

  /* "h5py/defs.pyx":1722
 * cdef hid_t H5Pcopy(hid_t plist_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pcopy(plist_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1723
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pcopy(plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pcopy(__pyx_v_plist_id);

  /* "h5py/defs.pyx":1724
 *     set_default_error_handler()
 *     r = _hdf5.H5Pcopy(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1725
 *     r = _hdf5.H5Pcopy(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1725, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1726
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pcopy (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1725
 *     r = _hdf5.H5Pcopy(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1728
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pcopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__150, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1728, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1728, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1724
 *     set_default_error_handler()
 *     r = _hdf5.H5Pcopy(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1729
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pcopy (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Pget_class(hid_t plist_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1720
 *     return r
 * 
 * cdef hid_t H5Pcopy(hid_t plist_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pcopy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1731
 *     return r
 * 
 * cdef hid_t H5Pget_class(hid_t plist_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Pget_class(hid_t __pyx_v_plist_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_class", 0);

  /* "h5py/defs.pyx":1733
 * cdef hid_t H5Pget_class(hid_t plist_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_class(plist_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1734
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_class(plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_class(__pyx_v_plist_id);

  /* "h5py/defs.pyx":1735
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_class(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1736
 *     r = _hdf5.H5Pget_class(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1736, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1737
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_class (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1736
 *     r = _hdf5.H5Pget_class(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1739
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__151, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1739, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1739, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1735
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_class(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":1740
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_class (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pclose(hid_t plist_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1731
 *     return r
 * 
 * cdef hid_t H5Pget_class(hid_t plist_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1742
 *     return r
 * 
 * cdef herr_t H5Pclose(hid_t plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pclose(hid_t __pyx_v_plist_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pclose", 0);

  /* "h5py/defs.pyx":1744
 * cdef herr_t H5Pclose(hid_t plist_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pclose(plist_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1745
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pclose(plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pclose(__pyx_v_plist_id);

  /* "h5py/defs.pyx":1746
 *     set_default_error_handler()
 *     r = _hdf5.H5Pclose(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1747
 *     r = _hdf5.H5Pclose(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1747, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1748
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pclose (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1747
 *     r = _hdf5.H5Pclose(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1750
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__152, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1750, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1746
 *     set_default_error_handler()
 *     r = _hdf5.H5Pclose(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1751
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pclose (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Pequal( hid_t id1, hid_t id2 ) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1742
 *     return r
 * 
 * cdef herr_t H5Pclose(hid_t plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1753
 *     return r
 * 
 * cdef htri_t H5Pequal( hid_t id1, hid_t id2 ) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Pequal(hid_t __pyx_v_id1, hid_t __pyx_v_id2) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pequal", 0);

  /* "h5py/defs.pyx":1755
 * cdef htri_t H5Pequal( hid_t id1, hid_t id2 ) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pequal(id1, id2)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1756
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pequal(id1, id2)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pequal(__pyx_v_id1, __pyx_v_id2);

  /* "h5py/defs.pyx":1757
 *     set_default_error_handler()
 *     r = _hdf5.H5Pequal(id1, id2)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1758
 *     r = _hdf5.H5Pequal(id1, id2)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1758, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1759
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pequal (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1758
 *     r = _hdf5.H5Pequal(id1, id2)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1761
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pequal (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__153, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1761, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1761, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1757
 *     set_default_error_handler()
 *     r = _hdf5.H5Pequal(id1, id2)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":1762
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pequal (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pclose_class(hid_t id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1753
 *     return r
 * 
 * cdef htri_t H5Pequal( hid_t id1, hid_t id2 ) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pequal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1764
 *     return r
 * 
 * cdef herr_t H5Pclose_class(hid_t id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pclose_class(hid_t __pyx_v_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pclose_class", 0);

  /* "h5py/defs.pyx":1766
 * cdef herr_t H5Pclose_class(hid_t id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pclose_class(id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1767
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pclose_class(id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pclose_class(__pyx_v_id);

  /* "h5py/defs.pyx":1768
 *     set_default_error_handler()
 *     r = _hdf5.H5Pclose_class(id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1769
 *     r = _hdf5.H5Pclose_class(id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1769, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1770
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pclose_class (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1769
 *     r = _hdf5.H5Pclose_class(id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1772
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pclose_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__154, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1772, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1768
 *     set_default_error_handler()
 *     r = _hdf5.H5Pclose_class(id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1773
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pclose_class (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_version(hid_t plist, unsigned int *super_, unsigned int* freelist,  unsigned int *stab, unsigned int *shhdr) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1764
 *     return r
 * 
 * cdef herr_t H5Pclose_class(hid_t id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pclose_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1775
 *     return r
 * 
 * cdef herr_t H5Pget_version(hid_t plist, unsigned int *super_, unsigned int* freelist,  unsigned int *stab, unsigned int *shhdr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_version(hid_t __pyx_v_plist, unsigned int *__pyx_v_super_, unsigned int *__pyx_v_freelist, unsigned int *__pyx_v_stab, unsigned int *__pyx_v_shhdr) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_version", 0);

  /* "h5py/defs.pyx":1777
 * cdef herr_t H5Pget_version(hid_t plist, unsigned int *super_, unsigned int* freelist,  unsigned int *stab, unsigned int *shhdr) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_version(plist, super_, freelist, stab, shhdr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1778
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_version(plist, super_, freelist, stab, shhdr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_version(__pyx_v_plist, __pyx_v_super_, __pyx_v_freelist, __pyx_v_stab, __pyx_v_shhdr);

  /* "h5py/defs.pyx":1779
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_version(plist, super_, freelist, stab, shhdr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1780
 *     r = _hdf5.H5Pget_version(plist, super_, freelist, stab, shhdr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1780, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1781
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_version (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1780
 *     r = _hdf5.H5Pget_version(plist, super_, freelist, stab, shhdr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1783
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_version (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__155, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1783, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1783, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1779
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_version(plist, super_, freelist, stab, shhdr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1784
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_version (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_userblock(hid_t plist, hsize_t size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1775
 *     return r
 * 
 * cdef herr_t H5Pget_version(hid_t plist, unsigned int *super_, unsigned int* freelist,  unsigned int *stab, unsigned int *shhdr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1786
 *     return r
 * 
 * cdef herr_t H5Pset_userblock(hid_t plist, hsize_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_userblock(hid_t __pyx_v_plist, hsize_t __pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_userblock", 0);

  /* "h5py/defs.pyx":1788
 * cdef herr_t H5Pset_userblock(hid_t plist, hsize_t size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_userblock(plist, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1789
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_userblock(plist, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_userblock(__pyx_v_plist, __pyx_v_size);

  /* "h5py/defs.pyx":1790
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_userblock(plist, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1791
 *     r = _hdf5.H5Pset_userblock(plist, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1791, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1792
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_userblock (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1791
 *     r = _hdf5.H5Pset_userblock(plist, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1794
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_userblock (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__156, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1794, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1794, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1790
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_userblock(plist, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1795
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_userblock (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_userblock(hid_t plist, hsize_t * size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1786
 *     return r
 * 
 * cdef herr_t H5Pset_userblock(hid_t plist, hsize_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_userblock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1797
 *     return r
 * 
 * cdef herr_t H5Pget_userblock(hid_t plist, hsize_t * size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_userblock(hid_t __pyx_v_plist, hsize_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_userblock", 0);

  /* "h5py/defs.pyx":1799
 * cdef herr_t H5Pget_userblock(hid_t plist, hsize_t * size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_userblock(plist, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1800
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_userblock(plist, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_userblock(__pyx_v_plist, __pyx_v_size);

  /* "h5py/defs.pyx":1801
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_userblock(plist, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1802
 *     r = _hdf5.H5Pget_userblock(plist, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1802, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1803
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_userblock (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1802
 *     r = _hdf5.H5Pget_userblock(plist, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1805
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_userblock (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__157, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1805, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1801
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_userblock(plist, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1806
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_userblock (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_sizes(hid_t plist, size_t sizeof_addr, size_t sizeof_size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1797
 *     return r
 * 
 * cdef herr_t H5Pget_userblock(hid_t plist, hsize_t * size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_userblock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1808
 *     return r
 * 
 * cdef herr_t H5Pset_sizes(hid_t plist, size_t sizeof_addr, size_t sizeof_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_sizes(hid_t __pyx_v_plist, size_t __pyx_v_sizeof_addr, size_t __pyx_v_sizeof_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_sizes", 0);

  /* "h5py/defs.pyx":1810
 * cdef herr_t H5Pset_sizes(hid_t plist, size_t sizeof_addr, size_t sizeof_size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1811
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sizes(plist, sizeof_addr, sizeof_size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_sizes(__pyx_v_plist, __pyx_v_sizeof_addr, __pyx_v_sizeof_size);

  /* "h5py/defs.pyx":1812
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1813
 *     r = _hdf5.H5Pset_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1813, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1814
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sizes (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1813
 *     r = _hdf5.H5Pset_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1816
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sizes (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__158, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1816, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1812
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1817
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sizes (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_sizes(hid_t plist, size_t *sizeof_addr, size_t *sizeof_size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1808
 *     return r
 * 
 * cdef herr_t H5Pset_sizes(hid_t plist, size_t sizeof_addr, size_t sizeof_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_sizes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1819
 *     return r
 * 
 * cdef herr_t H5Pget_sizes(hid_t plist, size_t *sizeof_addr, size_t *sizeof_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_sizes(hid_t __pyx_v_plist, size_t *__pyx_v_sizeof_addr, size_t *__pyx_v_sizeof_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_sizes", 0);

  /* "h5py/defs.pyx":1821
 * cdef herr_t H5Pget_sizes(hid_t plist, size_t *sizeof_addr, size_t *sizeof_size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1822
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sizes(plist, sizeof_addr, sizeof_size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_sizes(__pyx_v_plist, __pyx_v_sizeof_addr, __pyx_v_sizeof_size);

  /* "h5py/defs.pyx":1823
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1824
 *     r = _hdf5.H5Pget_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1824, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1825
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sizes (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1824
 *     r = _hdf5.H5Pget_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1827
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sizes (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__159, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1827, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1823
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sizes(plist, sizeof_addr, sizeof_size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1828
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sizes (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_sym_k(hid_t plist, unsigned int ik, unsigned int lk) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1819
 *     return r
 * 
 * cdef herr_t H5Pget_sizes(hid_t plist, size_t *sizeof_addr, size_t *sizeof_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_sizes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1830
 *     return r
 * 
 * cdef herr_t H5Pset_sym_k(hid_t plist, unsigned int ik, unsigned int lk) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_sym_k(hid_t __pyx_v_plist, unsigned int __pyx_v_ik, unsigned int __pyx_v_lk) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_sym_k", 0);

  /* "h5py/defs.pyx":1832
 * cdef herr_t H5Pset_sym_k(hid_t plist, unsigned int ik, unsigned int lk) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_sym_k(plist, ik, lk)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1833
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sym_k(plist, ik, lk)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_sym_k(__pyx_v_plist, __pyx_v_ik, __pyx_v_lk);

  /* "h5py/defs.pyx":1834
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sym_k(plist, ik, lk)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1835
 *     r = _hdf5.H5Pset_sym_k(plist, ik, lk)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1835, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1836
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sym_k (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1835
 *     r = _hdf5.H5Pset_sym_k(plist, ik, lk)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1838
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sym_k (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__160, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1838, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1838, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1834
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sym_k(plist, ik, lk)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1839
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sym_k (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_sym_k(hid_t plist, unsigned int *ik, unsigned int *lk) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1830
 *     return r
 * 
 * cdef herr_t H5Pset_sym_k(hid_t plist, unsigned int ik, unsigned int lk) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_sym_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1841
 *     return r
 * 
 * cdef herr_t H5Pget_sym_k(hid_t plist, unsigned int *ik, unsigned int *lk) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_sym_k(hid_t __pyx_v_plist, unsigned int *__pyx_v_ik, unsigned int *__pyx_v_lk) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_sym_k", 0);

  /* "h5py/defs.pyx":1843
 * cdef herr_t H5Pget_sym_k(hid_t plist, unsigned int *ik, unsigned int *lk) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_sym_k(plist, ik, lk)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1844
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sym_k(plist, ik, lk)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_sym_k(__pyx_v_plist, __pyx_v_ik, __pyx_v_lk);

  /* "h5py/defs.pyx":1845
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sym_k(plist, ik, lk)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1846
 *     r = _hdf5.H5Pget_sym_k(plist, ik, lk)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1846, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1847
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sym_k (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1846
 *     r = _hdf5.H5Pget_sym_k(plist, ik, lk)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1849
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sym_k (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__161, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1849, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1849, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1845
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sym_k(plist, ik, lk)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1850
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sym_k (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_istore_k(hid_t plist, unsigned int ik) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1841
 *     return r
 * 
 * cdef herr_t H5Pget_sym_k(hid_t plist, unsigned int *ik, unsigned int *lk) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_sym_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1852
 *     return r
 * 
 * cdef herr_t H5Pset_istore_k(hid_t plist, unsigned int ik) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_istore_k(hid_t __pyx_v_plist, unsigned int __pyx_v_ik) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_istore_k", 0);

  /* "h5py/defs.pyx":1854
 * cdef herr_t H5Pset_istore_k(hid_t plist, unsigned int ik) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_istore_k(plist, ik)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1855
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_istore_k(plist, ik)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_istore_k(__pyx_v_plist, __pyx_v_ik);

  /* "h5py/defs.pyx":1856
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_istore_k(plist, ik)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1857
 *     r = _hdf5.H5Pset_istore_k(plist, ik)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1857, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1858
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_istore_k (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1857
 *     r = _hdf5.H5Pset_istore_k(plist, ik)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1860
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_istore_k (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__162, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1860, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1860, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1856
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_istore_k(plist, ik)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1861
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_istore_k (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_istore_k(hid_t plist, unsigned int *ik) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1852
 *     return r
 * 
 * cdef herr_t H5Pset_istore_k(hid_t plist, unsigned int ik) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_istore_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1863
 *     return r
 * 
 * cdef herr_t H5Pget_istore_k(hid_t plist, unsigned int *ik) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_istore_k(hid_t __pyx_v_plist, unsigned int *__pyx_v_ik) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_istore_k", 0);

  /* "h5py/defs.pyx":1865
 * cdef herr_t H5Pget_istore_k(hid_t plist, unsigned int *ik) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_istore_k(plist, ik)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1866
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_istore_k(plist, ik)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_istore_k(__pyx_v_plist, __pyx_v_ik);

  /* "h5py/defs.pyx":1867
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_istore_k(plist, ik)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1868
 *     r = _hdf5.H5Pget_istore_k(plist, ik)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1868, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1869
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_istore_k (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1868
 *     r = _hdf5.H5Pget_istore_k(plist, ik)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1871
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_istore_k (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__163, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1871, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1871, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1867
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_istore_k(plist, ik)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1872
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_istore_k (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1863
 *     return r
 * 
 * cdef herr_t H5Pget_istore_k(hid_t plist, unsigned int *ik) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_istore_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1875
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pset_file_space_strategy(hid_t fcpl, H5F_fspace_strategy_t strategy, hbool_t persist, hsize_t threshold) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_file_space_strategy(hid_t __pyx_v_fcpl, enum H5F_fspace_strategy_t __pyx_v_strategy, hbool_t __pyx_v_persist, hsize_t __pyx_v_threshold) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_file_space_strategy", 0);

  /* "h5py/defs.pyx":1877
 *     cdef herr_t H5Pset_file_space_strategy(hid_t fcpl, H5F_fspace_strategy_t strategy, hbool_t persist, hsize_t threshold) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1878
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_space_strategy(fcpl, strategy, persist, threshold)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_file_space_strategy(__pyx_v_fcpl, __pyx_v_strategy, __pyx_v_persist, __pyx_v_threshold);

  /* "h5py/defs.pyx":1879
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1880
 *         r = _hdf5.H5Pset_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1880, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1881
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_space_strategy (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1880
 *         r = _hdf5.H5Pset_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":1883
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_space_strategy (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__164, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1883, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1879
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1884
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_space_strategy (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1875
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pset_file_space_strategy(hid_t fcpl, H5F_fspace_strategy_t strategy, hbool_t persist, hsize_t threshold) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_file_space_strategy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1887
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pget_file_space_strategy(hid_t fcpl, H5F_fspace_strategy_t *strategy, hbool_t *persist, hsize_t *threshold) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_file_space_strategy(hid_t __pyx_v_fcpl, enum H5F_fspace_strategy_t *__pyx_v_strategy, hbool_t *__pyx_v_persist, hsize_t *__pyx_v_threshold) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_file_space_strategy", 0);

  /* "h5py/defs.pyx":1889
 *     cdef herr_t H5Pget_file_space_strategy(hid_t fcpl, H5F_fspace_strategy_t *strategy, hbool_t *persist, hsize_t *threshold) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1890
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_space_strategy(fcpl, strategy, persist, threshold)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_file_space_strategy(__pyx_v_fcpl, __pyx_v_strategy, __pyx_v_persist, __pyx_v_threshold);

  /* "h5py/defs.pyx":1891
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1892
 *         r = _hdf5.H5Pget_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1892, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1893
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_space_strategy (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1892
 *         r = _hdf5.H5Pget_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":1895
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_space_strategy (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__165, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1895, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1895, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1891
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_space_strategy(fcpl, strategy, persist, threshold)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1896
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_space_strategy (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1887
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pget_file_space_strategy(hid_t fcpl, H5F_fspace_strategy_t *strategy, hbool_t *persist, hsize_t *threshold) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_file_space_strategy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1899
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pset_file_space_page_size(hid_t plist_id, hsize_t fsp_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_file_space_page_size(hid_t __pyx_v_plist_id, hsize_t __pyx_v_fsp_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_file_space_page_size", 0);

  /* "h5py/defs.pyx":1901
 *     cdef herr_t H5Pset_file_space_page_size(hid_t plist_id, hsize_t fsp_size) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_file_space_page_size(plist_id, fsp_size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1902
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_space_page_size(plist_id, fsp_size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_file_space_page_size(__pyx_v_plist_id, __pyx_v_fsp_size);

  /* "h5py/defs.pyx":1903
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_space_page_size(plist_id, fsp_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1904
 *         r = _hdf5.H5Pset_file_space_page_size(plist_id, fsp_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1904, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1905
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_space_page_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1904
 *         r = _hdf5.H5Pset_file_space_page_size(plist_id, fsp_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":1907
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_space_page_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__166, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1907, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1907, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1903
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_space_page_size(plist_id, fsp_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1908
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_space_page_size (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1899
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pset_file_space_page_size(hid_t plist_id, hsize_t fsp_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_file_space_page_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1911
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pget_file_space_page_size(hid_t plist_id, hsize_t *fsp_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_file_space_page_size(hid_t __pyx_v_plist_id, hsize_t *__pyx_v_fsp_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_file_space_page_size", 0);

  /* "h5py/defs.pyx":1913
 *     cdef herr_t H5Pget_file_space_page_size(hid_t plist_id, hsize_t *fsp_size) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_file_space_page_size(plist_id, fsp_size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1914
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_space_page_size(plist_id, fsp_size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_file_space_page_size(__pyx_v_plist_id, __pyx_v_fsp_size);

  /* "h5py/defs.pyx":1915
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_space_page_size(plist_id, fsp_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1916
 *         r = _hdf5.H5Pget_file_space_page_size(plist_id, fsp_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1916, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1917
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_space_page_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1916
 *         r = _hdf5.H5Pget_file_space_page_size(plist_id, fsp_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":1919
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_space_page_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__167, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1919, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1919, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1915
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_space_page_size(plist_id, fsp_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1920
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_space_page_size (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fclose_degree(hid_t fapl_id, H5F_close_degree_t fc_degree) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1911
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pget_file_space_page_size(hid_t plist_id, hsize_t *fsp_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_file_space_page_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1922
 *         return r
 * 
 * cdef herr_t H5Pset_fclose_degree(hid_t fapl_id, H5F_close_degree_t fc_degree) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fclose_degree(hid_t __pyx_v_fapl_id, enum H5F_close_degree_t __pyx_v_fc_degree) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fclose_degree", 0);

  /* "h5py/defs.pyx":1924
 * cdef herr_t H5Pset_fclose_degree(hid_t fapl_id, H5F_close_degree_t fc_degree) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fclose_degree(fapl_id, fc_degree)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1925
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fclose_degree(fapl_id, fc_degree)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fclose_degree(__pyx_v_fapl_id, __pyx_v_fc_degree);

  /* "h5py/defs.pyx":1926
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fclose_degree(fapl_id, fc_degree)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1927
 *     r = _hdf5.H5Pset_fclose_degree(fapl_id, fc_degree)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1927, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1928
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fclose_degree (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1927
 *     r = _hdf5.H5Pset_fclose_degree(fapl_id, fc_degree)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1930
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fclose_degree (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__168, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1930, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1930, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1926
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fclose_degree(fapl_id, fc_degree)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1931
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fclose_degree (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_fclose_degree(hid_t fapl_id, H5F_close_degree_t *fc_degree) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1922
 *         return r
 * 
 * cdef herr_t H5Pset_fclose_degree(hid_t fapl_id, H5F_close_degree_t fc_degree) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fclose_degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1933
 *     return r
 * 
 * cdef herr_t H5Pget_fclose_degree(hid_t fapl_id, H5F_close_degree_t *fc_degree) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_fclose_degree(hid_t __pyx_v_fapl_id, enum H5F_close_degree_t *__pyx_v_fc_degree) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_fclose_degree", 0);

  /* "h5py/defs.pyx":1935
 * cdef herr_t H5Pget_fclose_degree(hid_t fapl_id, H5F_close_degree_t *fc_degree) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_fclose_degree(fapl_id, fc_degree)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1936
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fclose_degree(fapl_id, fc_degree)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_fclose_degree(__pyx_v_fapl_id, __pyx_v_fc_degree);

  /* "h5py/defs.pyx":1937
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fclose_degree(fapl_id, fc_degree)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1938
 *     r = _hdf5.H5Pget_fclose_degree(fapl_id, fc_degree)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1938, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1939
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fclose_degree (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1938
 *     r = _hdf5.H5Pget_fclose_degree(fapl_id, fc_degree)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1941
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fclose_degree (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__169, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1941, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1941, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1937
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fclose_degree(fapl_id, fc_degree)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1942
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fclose_degree (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fapl_core( hid_t fapl_id, size_t increment, hbool_t backing_store) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1933
 *     return r
 * 
 * cdef herr_t H5Pget_fclose_degree(hid_t fapl_id, H5F_close_degree_t *fc_degree) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_fclose_degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1944
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_core( hid_t fapl_id, size_t increment, hbool_t backing_store) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fapl_core(hid_t __pyx_v_fapl_id, size_t __pyx_v_increment, hbool_t __pyx_v_backing_store) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fapl_core", 0);

  /* "h5py/defs.pyx":1946
 * cdef herr_t H5Pset_fapl_core( hid_t fapl_id, size_t increment, hbool_t backing_store) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1947
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_core(fapl_id, increment, backing_store)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fapl_core(__pyx_v_fapl_id, __pyx_v_increment, __pyx_v_backing_store);

  /* "h5py/defs.pyx":1948
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1949
 *     r = _hdf5.H5Pset_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1949, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1950
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_core (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1949
 *     r = _hdf5.H5Pset_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1952
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_core (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__170, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1952, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1952, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1948
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1953
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_core (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_fapl_core( hid_t fapl_id, size_t *increment, hbool_t *backing_store) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1944
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_core( hid_t fapl_id, size_t increment, hbool_t backing_store) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fapl_core", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1955
 *     return r
 * 
 * cdef herr_t H5Pget_fapl_core( hid_t fapl_id, size_t *increment, hbool_t *backing_store) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_fapl_core(hid_t __pyx_v_fapl_id, size_t *__pyx_v_increment, hbool_t *__pyx_v_backing_store) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_fapl_core", 0);

  /* "h5py/defs.pyx":1957
 * cdef herr_t H5Pget_fapl_core( hid_t fapl_id, size_t *increment, hbool_t *backing_store) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1958
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fapl_core(fapl_id, increment, backing_store)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_fapl_core(__pyx_v_fapl_id, __pyx_v_increment, __pyx_v_backing_store);

  /* "h5py/defs.pyx":1959
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1960
 *     r = _hdf5.H5Pget_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1960, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1961
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fapl_core (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1960
 *     r = _hdf5.H5Pget_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1963
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fapl_core (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__171, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1963, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1963, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1959
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fapl_core(fapl_id, increment, backing_store)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1964
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fapl_core (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fapl_family( hid_t fapl_id,  hsize_t memb_size, hid_t memb_fapl_id ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1955
 *     return r
 * 
 * cdef herr_t H5Pget_fapl_core( hid_t fapl_id, size_t *increment, hbool_t *backing_store) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_fapl_core", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1966
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_family( hid_t fapl_id,  hsize_t memb_size, hid_t memb_fapl_id ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fapl_family(hid_t __pyx_v_fapl_id, hsize_t __pyx_v_memb_size, hid_t __pyx_v_memb_fapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fapl_family", 0);

  /* "h5py/defs.pyx":1968
 * cdef herr_t H5Pset_fapl_family( hid_t fapl_id,  hsize_t memb_size, hid_t memb_fapl_id ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1969
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_family(fapl_id, memb_size, memb_fapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fapl_family(__pyx_v_fapl_id, __pyx_v_memb_size, __pyx_v_memb_fapl_id);

  /* "h5py/defs.pyx":1970
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1971
 *     r = _hdf5.H5Pset_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1971, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1972
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_family (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1971
 *     r = _hdf5.H5Pset_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1974
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_family (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__172, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1974, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1974, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1970
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1975
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_family (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_fapl_family( hid_t fapl_id, hsize_t *memb_size, hid_t *memb_fapl_id ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1966
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_family( hid_t fapl_id,  hsize_t memb_size, hid_t memb_fapl_id ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fapl_family", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1977
 *     return r
 * 
 * cdef herr_t H5Pget_fapl_family( hid_t fapl_id, hsize_t *memb_size, hid_t *memb_fapl_id ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_fapl_family(hid_t __pyx_v_fapl_id, hsize_t *__pyx_v_memb_size, hid_t *__pyx_v_memb_fapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_fapl_family", 0);

  /* "h5py/defs.pyx":1979
 * cdef herr_t H5Pget_fapl_family( hid_t fapl_id, hsize_t *memb_size, hid_t *memb_fapl_id ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1980
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fapl_family(fapl_id, memb_size, memb_fapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_fapl_family(__pyx_v_fapl_id, __pyx_v_memb_size, __pyx_v_memb_fapl_id);

  /* "h5py/defs.pyx":1981
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1982
 *     r = _hdf5.H5Pget_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1982, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1983
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fapl_family (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1982
 *     r = _hdf5.H5Pget_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1985
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fapl_family (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__173, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1985, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1985, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1981
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fapl_family(fapl_id, memb_size, memb_fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1986
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fapl_family (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_family_offset( hid_t fapl_id, hsize_t offset) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1977
 *     return r
 * 
 * cdef herr_t H5Pget_fapl_family( hid_t fapl_id, hsize_t *memb_size, hid_t *memb_fapl_id ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_fapl_family", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1988
 *     return r
 * 
 * cdef herr_t H5Pset_family_offset( hid_t fapl_id, hsize_t offset) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_family_offset(hid_t __pyx_v_fapl_id, hsize_t __pyx_v_offset) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_family_offset", 0);

  /* "h5py/defs.pyx":1990
 * cdef herr_t H5Pset_family_offset( hid_t fapl_id, hsize_t offset) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_family_offset(fapl_id, offset)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":1991
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_family_offset(fapl_id, offset)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_family_offset(__pyx_v_fapl_id, __pyx_v_offset);

  /* "h5py/defs.pyx":1992
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_family_offset(fapl_id, offset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":1993
 *     r = _hdf5.H5Pset_family_offset(fapl_id, offset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1993, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":1994
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_family_offset (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":1993
 *     r = _hdf5.H5Pset_family_offset(fapl_id, offset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":1996
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_family_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__174, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1996, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1996, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":1992
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_family_offset(fapl_id, offset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":1997
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_family_offset (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_family_offset( hid_t fapl_id, hsize_t *offset) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1988
 *     return r
 * 
 * cdef herr_t H5Pset_family_offset( hid_t fapl_id, hsize_t offset) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_family_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":1999
 *     return r
 * 
 * cdef herr_t H5Pget_family_offset( hid_t fapl_id, hsize_t *offset) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_family_offset(hid_t __pyx_v_fapl_id, hsize_t *__pyx_v_offset) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_family_offset", 0);

  /* "h5py/defs.pyx":2001
 * cdef herr_t H5Pget_family_offset( hid_t fapl_id, hsize_t *offset) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_family_offset(fapl_id, offset)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2002
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_family_offset(fapl_id, offset)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_family_offset(__pyx_v_fapl_id, __pyx_v_offset);

  /* "h5py/defs.pyx":2003
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_family_offset(fapl_id, offset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2004
 *     r = _hdf5.H5Pget_family_offset(fapl_id, offset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2004, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2005
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_family_offset (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2004
 *     r = _hdf5.H5Pget_family_offset(fapl_id, offset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2007
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_family_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__175, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2007, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2007, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2003
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_family_offset(fapl_id, offset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2008
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_family_offset (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF ROS3:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":1999
 *     return r
 * 
 * cdef herr_t H5Pget_family_offset( hid_t fapl_id, hsize_t *offset) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_family_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2060
 *             return r
 * 
 * cdef herr_t H5Pset_fapl_log(hid_t fapl_id, char *logfile, unsigned int flags, size_t buf_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fapl_log(hid_t __pyx_v_fapl_id, char *__pyx_v_logfile, unsigned int __pyx_v_flags, size_t __pyx_v_buf_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fapl_log", 0);

  /* "h5py/defs.pyx":2062
 * cdef herr_t H5Pset_fapl_log(hid_t fapl_id, char *logfile, unsigned int flags, size_t buf_size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fapl_log(fapl_id, logfile, flags, buf_size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2063
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_log(fapl_id, logfile, flags, buf_size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fapl_log(__pyx_v_fapl_id, __pyx_v_logfile, __pyx_v_flags, __pyx_v_buf_size);

  /* "h5py/defs.pyx":2064
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_log(fapl_id, logfile, flags, buf_size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2065
 *     r = _hdf5.H5Pset_fapl_log(fapl_id, logfile, flags, buf_size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2065, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2066
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_log (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2065
 *     r = _hdf5.H5Pset_fapl_log(fapl_id, logfile, flags, buf_size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2068
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_log (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__176, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2068, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2068, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2064
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_log(fapl_id, logfile, flags, buf_size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2069
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_log (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fapl_multi(hid_t fapl_id, H5FD_mem_t *memb_map, hid_t *memb_fapl, const char * const *memb_name, haddr_t *memb_addr, hbool_t relax) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2060
 *             return r
 * 
 * cdef herr_t H5Pset_fapl_log(hid_t fapl_id, char *logfile, unsigned int flags, size_t buf_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fapl_log", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2071
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_multi(hid_t fapl_id, H5FD_mem_t *memb_map, hid_t *memb_fapl, const char * const *memb_name, haddr_t *memb_addr, hbool_t relax) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fapl_multi(hid_t __pyx_v_fapl_id, H5FD_mem_t *__pyx_v_memb_map, hid_t *__pyx_v_memb_fapl, char const *const *__pyx_v_memb_name, haddr_t *__pyx_v_memb_addr, hbool_t __pyx_v_relax) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fapl_multi", 0);

  /* "h5py/defs.pyx":2073
 * cdef herr_t H5Pset_fapl_multi(hid_t fapl_id, H5FD_mem_t *memb_map, hid_t *memb_fapl, const char * const *memb_name, haddr_t *memb_addr, hbool_t relax) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fapl_multi(fapl_id, memb_map, memb_fapl, memb_name, memb_addr, relax)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2074
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_multi(fapl_id, memb_map, memb_fapl, memb_name, memb_addr, relax)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fapl_multi(__pyx_v_fapl_id, __pyx_v_memb_map, __pyx_v_memb_fapl, __pyx_v_memb_name, __pyx_v_memb_addr, __pyx_v_relax);

  /* "h5py/defs.pyx":2075
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_multi(fapl_id, memb_map, memb_fapl, memb_name, memb_addr, relax)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2076
 *     r = _hdf5.H5Pset_fapl_multi(fapl_id, memb_map, memb_fapl, memb_name, memb_addr, relax)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2076, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2077
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_multi (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2076
 *     r = _hdf5.H5Pset_fapl_multi(fapl_id, memb_map, memb_fapl, memb_name, memb_addr, relax)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2079
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_multi (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__177, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2079, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2079, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2075
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_multi(fapl_id, memb_map, memb_fapl, memb_name, memb_addr, relax)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2080
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_multi (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_cache(hid_t plist_id, int mdc_nelmts, int rdcc_nelmts,  size_t rdcc_nbytes, double rdcc_w0) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2071
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_multi(hid_t fapl_id, H5FD_mem_t *memb_map, hid_t *memb_fapl, const char * const *memb_name, haddr_t *memb_addr, hbool_t relax) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fapl_multi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2082
 *     return r
 * 
 * cdef herr_t H5Pset_cache(hid_t plist_id, int mdc_nelmts, int rdcc_nelmts,  size_t rdcc_nbytes, double rdcc_w0) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_cache(hid_t __pyx_v_plist_id, int __pyx_v_mdc_nelmts, int __pyx_v_rdcc_nelmts, size_t __pyx_v_rdcc_nbytes, double __pyx_v_rdcc_w0) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_cache", 0);

  /* "h5py/defs.pyx":2084
 * cdef herr_t H5Pset_cache(hid_t plist_id, int mdc_nelmts, int rdcc_nelmts,  size_t rdcc_nbytes, double rdcc_w0) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2085
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_cache(__pyx_v_plist_id, __pyx_v_mdc_nelmts, __pyx_v_rdcc_nelmts, __pyx_v_rdcc_nbytes, __pyx_v_rdcc_w0);

  /* "h5py/defs.pyx":2086
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2087
 *     r = _hdf5.H5Pset_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2087, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2088
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_cache (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2087
 *     r = _hdf5.H5Pset_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2090
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_cache (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__178, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2090, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2090, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2086
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2091
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_cache (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_cache(hid_t plist_id, int *mdc_nelmts, size_t *rdcc_nelmts, size_t *rdcc_nbytes, double *rdcc_w0) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2082
 *     return r
 * 
 * cdef herr_t H5Pset_cache(hid_t plist_id, int mdc_nelmts, int rdcc_nelmts,  size_t rdcc_nbytes, double rdcc_w0) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_cache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2093
 *     return r
 * 
 * cdef herr_t H5Pget_cache(hid_t plist_id, int *mdc_nelmts, size_t *rdcc_nelmts, size_t *rdcc_nbytes, double *rdcc_w0) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_cache(hid_t __pyx_v_plist_id, int *__pyx_v_mdc_nelmts, size_t *__pyx_v_rdcc_nelmts, size_t *__pyx_v_rdcc_nbytes, double *__pyx_v_rdcc_w0) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_cache", 0);

  /* "h5py/defs.pyx":2095
 * cdef herr_t H5Pget_cache(hid_t plist_id, int *mdc_nelmts, size_t *rdcc_nelmts, size_t *rdcc_nbytes, double *rdcc_w0) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2096
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_cache(__pyx_v_plist_id, __pyx_v_mdc_nelmts, __pyx_v_rdcc_nelmts, __pyx_v_rdcc_nbytes, __pyx_v_rdcc_w0);

  /* "h5py/defs.pyx":2097
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2098
 *     r = _hdf5.H5Pget_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2098, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2099
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_cache (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2098
 *     r = _hdf5.H5Pget_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2101
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_cache (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__179, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2101, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2101, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2097
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_cache(plist_id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2102
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_cache (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fapl_sec2(hid_t fapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2093
 *     return r
 * 
 * cdef herr_t H5Pget_cache(hid_t plist_id, int *mdc_nelmts, size_t *rdcc_nelmts, size_t *rdcc_nbytes, double *rdcc_w0) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_cache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2104
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_sec2(hid_t fapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fapl_sec2(hid_t __pyx_v_fapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fapl_sec2", 0);

  /* "h5py/defs.pyx":2106
 * cdef herr_t H5Pset_fapl_sec2(hid_t fapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fapl_sec2(fapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2107
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_sec2(fapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fapl_sec2(__pyx_v_fapl_id);

  /* "h5py/defs.pyx":2108
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_sec2(fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2109
 *     r = _hdf5.H5Pset_fapl_sec2(fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2109, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2110
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_sec2 (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2109
 *     r = _hdf5.H5Pset_fapl_sec2(fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2112
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_sec2 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__180, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2112, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2108
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_sec2(fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2113
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_sec2 (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fapl_stdio(hid_t fapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2104
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_sec2(hid_t fapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fapl_sec2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2115
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_stdio(hid_t fapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fapl_stdio(hid_t __pyx_v_fapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fapl_stdio", 0);

  /* "h5py/defs.pyx":2117
 * cdef herr_t H5Pset_fapl_stdio(hid_t fapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fapl_stdio(fapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2118
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_stdio(fapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fapl_stdio(__pyx_v_fapl_id);

  /* "h5py/defs.pyx":2119
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_stdio(fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2120
 *     r = _hdf5.H5Pset_fapl_stdio(fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2120, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2121
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_stdio (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2120
 *     r = _hdf5.H5Pset_fapl_stdio(fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2123
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_stdio (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__181, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2123, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2123, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2119
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_stdio(fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2124
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_stdio (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fapl_split(hid_t fapl_id, const char *meta_ext, hid_t meta_plist_id, const char *raw_ext, hid_t raw_plist_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2115
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_stdio(hid_t fapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fapl_stdio", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2126
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_split(hid_t fapl_id, const char *meta_ext, hid_t meta_plist_id, const char *raw_ext, hid_t raw_plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fapl_split(hid_t __pyx_v_fapl_id, char const *__pyx_v_meta_ext, hid_t __pyx_v_meta_plist_id, char const *__pyx_v_raw_ext, hid_t __pyx_v_raw_plist_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fapl_split", 0);

  /* "h5py/defs.pyx":2128
 * cdef herr_t H5Pset_fapl_split(hid_t fapl_id, const char *meta_ext, hid_t meta_plist_id, const char *raw_ext, hid_t raw_plist_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fapl_split(fapl_id, meta_ext, meta_plist_id, raw_ext, raw_plist_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2129
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_split(fapl_id, meta_ext, meta_plist_id, raw_ext, raw_plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fapl_split(__pyx_v_fapl_id, __pyx_v_meta_ext, __pyx_v_meta_plist_id, __pyx_v_raw_ext, __pyx_v_raw_plist_id);

  /* "h5py/defs.pyx":2130
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_split(fapl_id, meta_ext, meta_plist_id, raw_ext, raw_plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2131
 *     r = _hdf5.H5Pset_fapl_split(fapl_id, meta_ext, meta_plist_id, raw_ext, raw_plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2131, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2132
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_split (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2131
 *     r = _hdf5.H5Pset_fapl_split(fapl_id, meta_ext, meta_plist_id, raw_ext, raw_plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2134
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_split (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__182, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2134, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2134, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2130
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fapl_split(fapl_id, meta_ext, meta_plist_id, raw_ext, raw_plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2135
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_split (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_driver(hid_t plist_id, hid_t driver_id, void *driver_info) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2126
 *     return r
 * 
 * cdef herr_t H5Pset_fapl_split(hid_t fapl_id, const char *meta_ext, hid_t meta_plist_id, const char *raw_ext, hid_t raw_plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fapl_split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2137
 *     return r
 * 
 * cdef herr_t H5Pset_driver(hid_t plist_id, hid_t driver_id, void *driver_info) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_driver(hid_t __pyx_v_plist_id, hid_t __pyx_v_driver_id, void *__pyx_v_driver_info) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_driver", 0);

  /* "h5py/defs.pyx":2139
 * cdef herr_t H5Pset_driver(hid_t plist_id, hid_t driver_id, void *driver_info) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_driver(plist_id, driver_id, driver_info)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2140
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_driver(plist_id, driver_id, driver_info)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_driver(__pyx_v_plist_id, __pyx_v_driver_id, __pyx_v_driver_info);

  /* "h5py/defs.pyx":2141
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_driver(plist_id, driver_id, driver_info)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2142
 *     r = _hdf5.H5Pset_driver(plist_id, driver_id, driver_info)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2142, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2143
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_driver (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2142
 *     r = _hdf5.H5Pset_driver(plist_id, driver_id, driver_info)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2145
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_driver (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__183, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2145, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2141
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_driver(plist_id, driver_id, driver_info)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2146
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_driver (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Pget_driver(hid_t fapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2137
 *     return r
 * 
 * cdef herr_t H5Pset_driver(hid_t plist_id, hid_t driver_id, void *driver_info) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_driver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2148
 *     return r
 * 
 * cdef hid_t H5Pget_driver(hid_t fapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Pget_driver(hid_t __pyx_v_fapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_driver", 0);

  /* "h5py/defs.pyx":2150
 * cdef hid_t H5Pget_driver(hid_t fapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_driver(fapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2151
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_driver(fapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_driver(__pyx_v_fapl_id);

  /* "h5py/defs.pyx":2152
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_driver(fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2153
 *     r = _hdf5.H5Pget_driver(fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2153, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2154
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_driver (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2153
 *     r = _hdf5.H5Pget_driver(fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2156
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_driver (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__184, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2156, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2156, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2152
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_driver(fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":2157
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_driver (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef void* H5Pget_driver_info(hid_t plist_id) except <void*>NULL:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2148
 *     return r
 * 
 * cdef hid_t H5Pget_driver(hid_t fapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_driver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2159
 *     return r
 * 
 * cdef void* H5Pget_driver_info(hid_t plist_id) except <void*>NULL:             # <<<<<<<<<<<<<<
 *     cdef void* r
 *     set_default_error_handler()
 */

static void *__pyx_f_4h5py_4defs_H5Pget_driver_info(hid_t __pyx_v_plist_id) {
  void *__pyx_v_r;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_driver_info", 0);

  /* "h5py/defs.pyx":2161
 * cdef void* H5Pget_driver_info(hid_t plist_id) except <void*>NULL:
 *     cdef void* r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_driver_info(plist_id)
 *     if r==NULL:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2162
 *     cdef void* r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_driver_info(plist_id)             # <<<<<<<<<<<<<<
 *     if r==NULL:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_driver_info(__pyx_v_plist_id);

  /* "h5py/defs.pyx":2163
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_driver_info(plist_id)
 *     if r==NULL:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <void*>NULL
 */
  __pyx_t_1 = ((__pyx_v_r == NULL) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2164
 *     r = _hdf5.H5Pget_driver_info(plist_id)
 *     if r==NULL:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <void*>NULL
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2164, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2165
 *     if r==NULL:
 *         if set_exception():
 *             return <void*>NULL             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_driver_info (return value ==NULL)")
 */
      __pyx_r = ((void *)NULL);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2164
 *     r = _hdf5.H5Pget_driver_info(plist_id)
 *     if r==NULL:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <void*>NULL
 *         else:
 */
    }

    /* "h5py/defs.pyx":2167
 *             return <void*>NULL
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_driver_info (return value ==NULL)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__185, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2167, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2167, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2163
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_driver_info(plist_id)
 *     if r==NULL:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <void*>NULL
 */
  }

  /* "h5py/defs.pyx":2168
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_driver_info (return value ==NULL)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_mdc_config(hid_t plist_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2159
 *     return r
 * 
 * cdef void* H5Pget_driver_info(hid_t plist_id) except <void*>NULL:             # <<<<<<<<<<<<<<
 *     cdef void* r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_driver_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((void *)NULL);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2170
 *     return r
 * 
 * cdef herr_t H5Pget_mdc_config(hid_t plist_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_mdc_config(hid_t __pyx_v_plist_id, H5AC_cache_config_t *__pyx_v_config_ptr) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_mdc_config", 0);

  /* "h5py/defs.pyx":2172
 * cdef herr_t H5Pget_mdc_config(hid_t plist_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_mdc_config(plist_id, config_ptr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2173
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_mdc_config(plist_id, config_ptr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_mdc_config(__pyx_v_plist_id, __pyx_v_config_ptr);

  /* "h5py/defs.pyx":2174
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_mdc_config(plist_id, config_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2175
 *     r = _hdf5.H5Pget_mdc_config(plist_id, config_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2175, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2176
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_mdc_config (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2175
 *     r = _hdf5.H5Pget_mdc_config(plist_id, config_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2178
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_mdc_config (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__186, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2178, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2174
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_mdc_config(plist_id, config_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2179
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_mdc_config (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_mdc_config(hid_t plist_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2170
 *     return r
 * 
 * cdef herr_t H5Pget_mdc_config(hid_t plist_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_mdc_config", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2181
 *     return r
 * 
 * cdef herr_t H5Pset_mdc_config(hid_t plist_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_mdc_config(hid_t __pyx_v_plist_id, H5AC_cache_config_t *__pyx_v_config_ptr) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_mdc_config", 0);

  /* "h5py/defs.pyx":2183
 * cdef herr_t H5Pset_mdc_config(hid_t plist_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_mdc_config(plist_id, config_ptr)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2184
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_mdc_config(plist_id, config_ptr)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_mdc_config(__pyx_v_plist_id, __pyx_v_config_ptr);

  /* "h5py/defs.pyx":2185
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_mdc_config(plist_id, config_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2186
 *     r = _hdf5.H5Pset_mdc_config(plist_id, config_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2186, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2187
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_mdc_config (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2186
 *     r = _hdf5.H5Pset_mdc_config(plist_id, config_ptr)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2189
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_mdc_config (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__187, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2189, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2189, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2185
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_mdc_config(plist_id, config_ptr)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2190
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_mdc_config (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2181
 *     return r
 * 
 * cdef herr_t H5Pset_mdc_config(hid_t plist_id, H5AC_cache_config_t *config_ptr) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_mdc_config", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2193
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 *     cdef herr_t H5Pset_file_image(hid_t plist_id, void *buf_ptr, size_t buf_len) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_file_image(hid_t __pyx_v_plist_id, void *__pyx_v_buf_ptr, size_t __pyx_v_buf_len) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_file_image", 0);

  /* "h5py/defs.pyx":2195
 *     cdef herr_t H5Pset_file_image(hid_t plist_id, void *buf_ptr, size_t buf_len) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_file_image(plist_id, buf_ptr, buf_len)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2196
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_image(plist_id, buf_ptr, buf_len)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_file_image(__pyx_v_plist_id, __pyx_v_buf_ptr, __pyx_v_buf_len);

  /* "h5py/defs.pyx":2197
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_image(plist_id, buf_ptr, buf_len)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2198
 *         r = _hdf5.H5Pset_file_image(plist_id, buf_ptr, buf_len)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2198, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2199
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_image (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2198
 *         r = _hdf5.H5Pset_file_image(plist_id, buf_ptr, buf_len)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2201
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_image (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__188, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2201, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2197
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_image(plist_id, buf_ptr, buf_len)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2202
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_image (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2193
 * 
 * IF HDF5_VERSION >= (1, 8, 9):
 *     cdef herr_t H5Pset_file_image(hid_t plist_id, void *buf_ptr, size_t buf_len) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_file_image", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2205
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pset_page_buffer_size(hid_t plist_id, size_t buf_size, unsigned min_meta_per, unsigned min_raw_per) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_page_buffer_size(hid_t __pyx_v_plist_id, size_t __pyx_v_buf_size, unsigned int __pyx_v_min_meta_per, unsigned int __pyx_v_min_raw_per) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_page_buffer_size", 0);

  /* "h5py/defs.pyx":2207
 *     cdef herr_t H5Pset_page_buffer_size(hid_t plist_id, size_t buf_size, unsigned min_meta_per, unsigned min_raw_per) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2208
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_page_buffer_size(__pyx_v_plist_id, __pyx_v_buf_size, __pyx_v_min_meta_per, __pyx_v_min_raw_per);

  /* "h5py/defs.pyx":2209
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2210
 *         r = _hdf5.H5Pset_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2210, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2211
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_page_buffer_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2210
 *         r = _hdf5.H5Pset_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2213
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_page_buffer_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__189, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2213, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2209
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2214
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_page_buffer_size (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2205
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pset_page_buffer_size(hid_t plist_id, size_t buf_size, unsigned min_meta_per, unsigned min_raw_per) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_page_buffer_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2217
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pget_page_buffer_size(hid_t plist_id, size_t *buf_size, unsigned *min_meta_per, unsigned *min_raw_per) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_page_buffer_size(hid_t __pyx_v_plist_id, size_t *__pyx_v_buf_size, unsigned int *__pyx_v_min_meta_per, unsigned int *__pyx_v_min_raw_per) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_page_buffer_size", 0);

  /* "h5py/defs.pyx":2219
 *     cdef herr_t H5Pget_page_buffer_size(hid_t plist_id, size_t *buf_size, unsigned *min_meta_per, unsigned *min_raw_per) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2220
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_page_buffer_size(__pyx_v_plist_id, __pyx_v_buf_size, __pyx_v_min_meta_per, __pyx_v_min_raw_per);

  /* "h5py/defs.pyx":2221
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2222
 *         r = _hdf5.H5Pget_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2222, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2223
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_page_buffer_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2222
 *         r = _hdf5.H5Pget_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2225
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_page_buffer_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__190, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2225, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2221
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_page_buffer_size(plist_id, buf_size, min_meta_per, min_raw_per)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2226
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_page_buffer_size (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 7) and HDF5_VERSION <= (1, 10, 99):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2217
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5Pget_page_buffer_size(hid_t plist_id, size_t *buf_size, unsigned *min_meta_per, unsigned *min_raw_per) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_page_buffer_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2241
 * 
 * IF HDF5_VERSION >= (1, 12, 1):
 *     cdef herr_t H5Pget_file_locking(hid_t fapl_id, hbool_t *use_file_locking, hbool_t *ignore_when_disabled) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_file_locking(hid_t __pyx_v_fapl_id, hbool_t *__pyx_v_use_file_locking, hbool_t *__pyx_v_ignore_when_disabled) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_file_locking", 0);

  /* "h5py/defs.pyx":2243
 *     cdef herr_t H5Pget_file_locking(hid_t fapl_id, hbool_t *use_file_locking, hbool_t *ignore_when_disabled) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2244
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_locking(fapl_id, use_file_locking, ignore_when_disabled)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_file_locking(__pyx_v_fapl_id, __pyx_v_use_file_locking, __pyx_v_ignore_when_disabled);

  /* "h5py/defs.pyx":2245
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2246
 *         r = _hdf5.H5Pget_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2246, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2247
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_locking (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2246
 *         r = _hdf5.H5Pget_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2249
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_locking (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__191, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2249, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2249, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2245
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2250
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_locking (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 7) and HDF5_VERSION <= (1, 10, 99):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2241
 * 
 * IF HDF5_VERSION >= (1, 12, 1):
 *     cdef herr_t H5Pget_file_locking(hid_t fapl_id, hbool_t *use_file_locking, hbool_t *ignore_when_disabled) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_file_locking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2265
 * 
 * IF HDF5_VERSION >= (1, 12, 1):
 *     cdef herr_t H5Pset_file_locking(hid_t fapl_id, hbool_t use_file_locking, hbool_t ignore_when_disabled) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_file_locking(hid_t __pyx_v_fapl_id, hbool_t __pyx_v_use_file_locking, hbool_t __pyx_v_ignore_when_disabled) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_file_locking", 0);

  /* "h5py/defs.pyx":2267
 *     cdef herr_t H5Pset_file_locking(hid_t fapl_id, hbool_t use_file_locking, hbool_t ignore_when_disabled) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2268
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_locking(fapl_id, use_file_locking, ignore_when_disabled)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_file_locking(__pyx_v_fapl_id, __pyx_v_use_file_locking, __pyx_v_ignore_when_disabled);

  /* "h5py/defs.pyx":2269
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2270
 *         r = _hdf5.H5Pset_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2270, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2271
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_locking (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2270
 *         r = _hdf5.H5Pset_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2273
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_locking (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__192, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2273, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2269
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_file_locking(fapl_id, use_file_locking, ignore_when_disabled)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2274
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_locking (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_layout(hid_t plist, int layout) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2265
 * 
 * IF HDF5_VERSION >= (1, 12, 1):
 *     cdef herr_t H5Pset_file_locking(hid_t fapl_id, hbool_t use_file_locking, hbool_t ignore_when_disabled) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_file_locking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2276
 *         return r
 * 
 * cdef herr_t H5Pset_layout(hid_t plist, int layout) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_layout(hid_t __pyx_v_plist, int __pyx_v_layout) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_layout", 0);

  /* "h5py/defs.pyx":2278
 * cdef herr_t H5Pset_layout(hid_t plist, int layout) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_layout(plist, layout)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2279
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_layout(plist, layout)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_layout(__pyx_v_plist, __pyx_v_layout);

  /* "h5py/defs.pyx":2280
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_layout(plist, layout)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2281
 *     r = _hdf5.H5Pset_layout(plist, layout)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2281, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2282
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_layout (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2281
 *     r = _hdf5.H5Pset_layout(plist, layout)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2284
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_layout (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__193, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2284, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2284, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2280
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_layout(plist, layout)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2285
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_layout (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5D_layout_t H5Pget_layout(hid_t plist) except <H5D_layout_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2276
 *         return r
 * 
 * cdef herr_t H5Pset_layout(hid_t plist, int layout) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_layout", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2287
 *     return r
 * 
 * cdef H5D_layout_t H5Pget_layout(hid_t plist) except <H5D_layout_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5D_layout_t r
 *     set_default_error_handler()
 */

static H5D_layout_t __pyx_f_4h5py_4defs_H5Pget_layout(hid_t __pyx_v_plist) {
  H5D_layout_t __pyx_v_r;
  H5D_layout_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_layout", 0);

  /* "h5py/defs.pyx":2289
 * cdef H5D_layout_t H5Pget_layout(hid_t plist) except <H5D_layout_t>-1:
 *     cdef H5D_layout_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_layout(plist)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2290
 *     cdef H5D_layout_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_layout(plist)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_layout(__pyx_v_plist);

  /* "h5py/defs.pyx":2291
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_layout(plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5D_layout_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2292
 *     r = _hdf5.H5Pget_layout(plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5D_layout_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2292, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2293
 *     if r<0:
 *         if set_exception():
 *             return <H5D_layout_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_layout (return value <0)")
 */
      __pyx_r = ((H5D_layout_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2292
 *     r = _hdf5.H5Pget_layout(plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5D_layout_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2295
 *             return <H5D_layout_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_layout (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__194, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2295, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2295, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2291
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_layout(plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5D_layout_t>-1
 */
  }

  /* "h5py/defs.pyx":2296
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_layout (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_chunk(hid_t plist, int ndims, hsize_t * dim) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2287
 *     return r
 * 
 * cdef H5D_layout_t H5Pget_layout(hid_t plist) except <H5D_layout_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5D_layout_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_layout", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5D_layout_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2298
 *     return r
 * 
 * cdef herr_t H5Pset_chunk(hid_t plist, int ndims, hsize_t * dim) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_chunk(hid_t __pyx_v_plist, int __pyx_v_ndims, hsize_t *__pyx_v_dim) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_chunk", 0);

  /* "h5py/defs.pyx":2300
 * cdef herr_t H5Pset_chunk(hid_t plist, int ndims, hsize_t * dim) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_chunk(plist, ndims, dim)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2301
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_chunk(plist, ndims, dim)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_chunk(__pyx_v_plist, __pyx_v_ndims, __pyx_v_dim);

  /* "h5py/defs.pyx":2302
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_chunk(plist, ndims, dim)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2303
 *     r = _hdf5.H5Pset_chunk(plist, ndims, dim)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2303, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2304
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_chunk (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2303
 *     r = _hdf5.H5Pset_chunk(plist, ndims, dim)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2306
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__195, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2306, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2302
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_chunk(plist, ndims, dim)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2307
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_chunk (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Pget_chunk(hid_t plist, int max_ndims, hsize_t * dims ) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2298
 *     return r
 * 
 * cdef herr_t H5Pset_chunk(hid_t plist, int ndims, hsize_t * dim) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_chunk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2309
 *     return r
 * 
 * cdef int H5Pget_chunk(hid_t plist, int max_ndims, hsize_t * dims ) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Pget_chunk(hid_t __pyx_v_plist, int __pyx_v_max_ndims, hsize_t *__pyx_v_dims) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_chunk", 0);

  /* "h5py/defs.pyx":2311
 * cdef int H5Pget_chunk(hid_t plist, int max_ndims, hsize_t * dims ) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_chunk(plist, max_ndims, dims)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2312
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_chunk(plist, max_ndims, dims)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_chunk(__pyx_v_plist, __pyx_v_max_ndims, __pyx_v_dims);

  /* "h5py/defs.pyx":2313
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_chunk(plist, max_ndims, dims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2314
 *     r = _hdf5.H5Pget_chunk(plist, max_ndims, dims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2314, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2315
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_chunk (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2314
 *     r = _hdf5.H5Pget_chunk(plist, max_ndims, dims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2317
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__196, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2317, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2317, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2313
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_chunk(plist, max_ndims, dims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":2318
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_chunk (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_deflate( hid_t plist, int level) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2309
 *     return r
 * 
 * cdef int H5Pget_chunk(hid_t plist, int max_ndims, hsize_t * dims ) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_chunk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2320
 *     return r
 * 
 * cdef herr_t H5Pset_deflate( hid_t plist, int level) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_deflate(hid_t __pyx_v_plist, int __pyx_v_level) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_deflate", 0);

  /* "h5py/defs.pyx":2322
 * cdef herr_t H5Pset_deflate( hid_t plist, int level) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_deflate(plist, level)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2323
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_deflate(plist, level)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_deflate(__pyx_v_plist, __pyx_v_level);

  /* "h5py/defs.pyx":2324
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_deflate(plist, level)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2325
 *     r = _hdf5.H5Pset_deflate(plist, level)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2325, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2326
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_deflate (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2325
 *     r = _hdf5.H5Pset_deflate(plist, level)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2328
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_deflate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__197, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2328, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2328, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2324
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_deflate(plist, level)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2329
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_deflate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fill_value(hid_t plist_id, hid_t type_id, void *value ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2320
 *     return r
 * 
 * cdef herr_t H5Pset_deflate( hid_t plist, int level) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_deflate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2331
 *     return r
 * 
 * cdef herr_t H5Pset_fill_value(hid_t plist_id, hid_t type_id, void *value ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fill_value(hid_t __pyx_v_plist_id, hid_t __pyx_v_type_id, void *__pyx_v_value) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fill_value", 0);

  /* "h5py/defs.pyx":2333
 * cdef herr_t H5Pset_fill_value(hid_t plist_id, hid_t type_id, void *value ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fill_value(plist_id, type_id, value)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2334
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fill_value(plist_id, type_id, value)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fill_value(__pyx_v_plist_id, __pyx_v_type_id, __pyx_v_value);

  /* "h5py/defs.pyx":2335
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fill_value(plist_id, type_id, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2336
 *     r = _hdf5.H5Pset_fill_value(plist_id, type_id, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2336, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2337
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fill_value (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2336
 *     r = _hdf5.H5Pset_fill_value(plist_id, type_id, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2339
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fill_value (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__198, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2339, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2339, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2335
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fill_value(plist_id, type_id, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2340
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fill_value (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_fill_value(hid_t plist_id, hid_t type_id, void *value ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2331
 *     return r
 * 
 * cdef herr_t H5Pset_fill_value(hid_t plist_id, hid_t type_id, void *value ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fill_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2342
 *     return r
 * 
 * cdef herr_t H5Pget_fill_value(hid_t plist_id, hid_t type_id, void *value ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_fill_value(hid_t __pyx_v_plist_id, hid_t __pyx_v_type_id, void *__pyx_v_value) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_fill_value", 0);

  /* "h5py/defs.pyx":2344
 * cdef herr_t H5Pget_fill_value(hid_t plist_id, hid_t type_id, void *value ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_fill_value(plist_id, type_id, value)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2345
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fill_value(plist_id, type_id, value)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_fill_value(__pyx_v_plist_id, __pyx_v_type_id, __pyx_v_value);

  /* "h5py/defs.pyx":2346
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fill_value(plist_id, type_id, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2347
 *     r = _hdf5.H5Pget_fill_value(plist_id, type_id, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2347, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2348
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fill_value (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2347
 *     r = _hdf5.H5Pget_fill_value(plist_id, type_id, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2350
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fill_value (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__199, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2350, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2350, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2346
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fill_value(plist_id, type_id, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2351
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fill_value (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pfill_value_defined(hid_t plist_id, H5D_fill_value_t *status ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2342
 *     return r
 * 
 * cdef herr_t H5Pget_fill_value(hid_t plist_id, hid_t type_id, void *value ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_fill_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2353
 *     return r
 * 
 * cdef herr_t H5Pfill_value_defined(hid_t plist_id, H5D_fill_value_t *status ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pfill_value_defined(hid_t __pyx_v_plist_id, H5D_fill_value_t *__pyx_v_status) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pfill_value_defined", 0);

  /* "h5py/defs.pyx":2355
 * cdef herr_t H5Pfill_value_defined(hid_t plist_id, H5D_fill_value_t *status ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pfill_value_defined(plist_id, status)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2356
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pfill_value_defined(plist_id, status)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pfill_value_defined(__pyx_v_plist_id, __pyx_v_status);

  /* "h5py/defs.pyx":2357
 *     set_default_error_handler()
 *     r = _hdf5.H5Pfill_value_defined(plist_id, status)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2358
 *     r = _hdf5.H5Pfill_value_defined(plist_id, status)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2358, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2359
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pfill_value_defined (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2358
 *     r = _hdf5.H5Pfill_value_defined(plist_id, status)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2361
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pfill_value_defined (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__200, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2361, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2361, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2357
 *     set_default_error_handler()
 *     r = _hdf5.H5Pfill_value_defined(plist_id, status)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2362
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pfill_value_defined (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fill_time(hid_t plist_id, H5D_fill_time_t fill_time ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2353
 *     return r
 * 
 * cdef herr_t H5Pfill_value_defined(hid_t plist_id, H5D_fill_value_t *status ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pfill_value_defined", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2364
 *     return r
 * 
 * cdef herr_t H5Pset_fill_time(hid_t plist_id, H5D_fill_time_t fill_time ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fill_time(hid_t __pyx_v_plist_id, H5D_fill_time_t __pyx_v_fill_time) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fill_time", 0);

  /* "h5py/defs.pyx":2366
 * cdef herr_t H5Pset_fill_time(hid_t plist_id, H5D_fill_time_t fill_time ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fill_time(plist_id, fill_time)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2367
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fill_time(plist_id, fill_time)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fill_time(__pyx_v_plist_id, __pyx_v_fill_time);

  /* "h5py/defs.pyx":2368
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fill_time(plist_id, fill_time)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2369
 *     r = _hdf5.H5Pset_fill_time(plist_id, fill_time)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2369, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2370
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fill_time (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2369
 *     r = _hdf5.H5Pset_fill_time(plist_id, fill_time)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2372
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fill_time (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__201, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2372, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2372, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2368
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fill_time(plist_id, fill_time)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2373
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fill_time (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_fill_time(hid_t plist_id, H5D_fill_time_t *fill_time ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2364
 *     return r
 * 
 * cdef herr_t H5Pset_fill_time(hid_t plist_id, H5D_fill_time_t fill_time ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fill_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2375
 *     return r
 * 
 * cdef herr_t H5Pget_fill_time(hid_t plist_id, H5D_fill_time_t *fill_time ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_fill_time(hid_t __pyx_v_plist_id, H5D_fill_time_t *__pyx_v_fill_time) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_fill_time", 0);

  /* "h5py/defs.pyx":2377
 * cdef herr_t H5Pget_fill_time(hid_t plist_id, H5D_fill_time_t *fill_time ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_fill_time(plist_id, fill_time)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2378
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fill_time(plist_id, fill_time)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_fill_time(__pyx_v_plist_id, __pyx_v_fill_time);

  /* "h5py/defs.pyx":2379
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fill_time(plist_id, fill_time)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2380
 *     r = _hdf5.H5Pget_fill_time(plist_id, fill_time)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2380, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2381
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fill_time (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2380
 *     r = _hdf5.H5Pget_fill_time(plist_id, fill_time)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2383
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fill_time (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__202, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2383, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2379
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_fill_time(plist_id, fill_time)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2384
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fill_time (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_alloc_time(hid_t plist_id, H5D_alloc_time_t alloc_time ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2375
 *     return r
 * 
 * cdef herr_t H5Pget_fill_time(hid_t plist_id, H5D_fill_time_t *fill_time ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_fill_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2386
 *     return r
 * 
 * cdef herr_t H5Pset_alloc_time(hid_t plist_id, H5D_alloc_time_t alloc_time ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_alloc_time(hid_t __pyx_v_plist_id, H5D_alloc_time_t __pyx_v_alloc_time) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_alloc_time", 0);

  /* "h5py/defs.pyx":2388
 * cdef herr_t H5Pset_alloc_time(hid_t plist_id, H5D_alloc_time_t alloc_time ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_alloc_time(plist_id, alloc_time)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2389
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_alloc_time(plist_id, alloc_time)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_alloc_time(__pyx_v_plist_id, __pyx_v_alloc_time);

  /* "h5py/defs.pyx":2390
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_alloc_time(plist_id, alloc_time)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2391
 *     r = _hdf5.H5Pset_alloc_time(plist_id, alloc_time)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2391, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2392
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_alloc_time (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2391
 *     r = _hdf5.H5Pset_alloc_time(plist_id, alloc_time)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2394
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_alloc_time (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__203, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2394, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2390
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_alloc_time(plist_id, alloc_time)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2395
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_alloc_time (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_alloc_time(hid_t plist_id, H5D_alloc_time_t *alloc_time ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2386
 *     return r
 * 
 * cdef herr_t H5Pset_alloc_time(hid_t plist_id, H5D_alloc_time_t alloc_time ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_alloc_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2397
 *     return r
 * 
 * cdef herr_t H5Pget_alloc_time(hid_t plist_id, H5D_alloc_time_t *alloc_time ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_alloc_time(hid_t __pyx_v_plist_id, H5D_alloc_time_t *__pyx_v_alloc_time) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_alloc_time", 0);

  /* "h5py/defs.pyx":2399
 * cdef herr_t H5Pget_alloc_time(hid_t plist_id, H5D_alloc_time_t *alloc_time ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_alloc_time(plist_id, alloc_time)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2400
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_alloc_time(plist_id, alloc_time)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_alloc_time(__pyx_v_plist_id, __pyx_v_alloc_time);

  /* "h5py/defs.pyx":2401
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_alloc_time(plist_id, alloc_time)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2402
 *     r = _hdf5.H5Pget_alloc_time(plist_id, alloc_time)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2402, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2403
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_alloc_time (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2402
 *     r = _hdf5.H5Pget_alloc_time(plist_id, alloc_time)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2405
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_alloc_time (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__204, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2405, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2405, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2401
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_alloc_time(plist_id, alloc_time)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2406
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_alloc_time (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_filter(hid_t plist, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, unsigned int* cd_values ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2397
 *     return r
 * 
 * cdef herr_t H5Pget_alloc_time(hid_t plist_id, H5D_alloc_time_t *alloc_time ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_alloc_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2408
 *     return r
 * 
 * cdef herr_t H5Pset_filter(hid_t plist, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, unsigned int* cd_values ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_filter(hid_t __pyx_v_plist, H5Z_filter_t __pyx_v_filter, unsigned int __pyx_v_flags, size_t __pyx_v_cd_nelmts, unsigned int *__pyx_v_cd_values) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_filter", 0);

  /* "h5py/defs.pyx":2410
 * cdef herr_t H5Pset_filter(hid_t plist, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, unsigned int* cd_values ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2411
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_filter(plist, filter, flags, cd_nelmts, cd_values)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_filter(__pyx_v_plist, __pyx_v_filter, __pyx_v_flags, __pyx_v_cd_nelmts, __pyx_v_cd_values);

  /* "h5py/defs.pyx":2412
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2413
 *     r = _hdf5.H5Pset_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2413, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2414
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_filter (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2413
 *     r = _hdf5.H5Pset_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2416
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_filter (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__205, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2416, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2412
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2417
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_filter (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Pall_filters_avail(hid_t dcpl_id) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2408
 *     return r
 * 
 * cdef herr_t H5Pset_filter(hid_t plist, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, unsigned int* cd_values ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2419
 *     return r
 * 
 * cdef htri_t H5Pall_filters_avail(hid_t dcpl_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Pall_filters_avail(hid_t __pyx_v_dcpl_id) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pall_filters_avail", 0);

  /* "h5py/defs.pyx":2421
 * cdef htri_t H5Pall_filters_avail(hid_t dcpl_id) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pall_filters_avail(dcpl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2422
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pall_filters_avail(dcpl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pall_filters_avail(__pyx_v_dcpl_id);

  /* "h5py/defs.pyx":2423
 *     set_default_error_handler()
 *     r = _hdf5.H5Pall_filters_avail(dcpl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2424
 *     r = _hdf5.H5Pall_filters_avail(dcpl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2424, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2425
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pall_filters_avail (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2424
 *     r = _hdf5.H5Pall_filters_avail(dcpl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2427
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pall_filters_avail (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__206, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2427, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2427, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2423
 *     set_default_error_handler()
 *     r = _hdf5.H5Pall_filters_avail(dcpl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":2428
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pall_filters_avail (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Pget_nfilters(hid_t plist) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2419
 *     return r
 * 
 * cdef htri_t H5Pall_filters_avail(hid_t dcpl_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pall_filters_avail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2430
 *     return r
 * 
 * cdef int H5Pget_nfilters(hid_t plist) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Pget_nfilters(hid_t __pyx_v_plist) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_nfilters", 0);

  /* "h5py/defs.pyx":2432
 * cdef int H5Pget_nfilters(hid_t plist) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_nfilters(plist)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2433
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_nfilters(plist)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_nfilters(__pyx_v_plist);

  /* "h5py/defs.pyx":2434
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_nfilters(plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2435
 *     r = _hdf5.H5Pget_nfilters(plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2435, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2436
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_nfilters (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2435
 *     r = _hdf5.H5Pget_nfilters(plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2438
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_nfilters (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__207, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2438, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2434
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_nfilters(plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":2439
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_nfilters (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5Z_filter_t H5Pget_filter(hid_t plist, unsigned int filter_number,   unsigned int *flags, size_t *cd_nelmts,  unsigned int* cd_values, size_t namelen, char* name, unsigned int* filter_config) except <H5Z_filter_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2430
 *     return r
 * 
 * cdef int H5Pget_nfilters(hid_t plist) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_nfilters", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2441
 *     return r
 * 
 * cdef H5Z_filter_t H5Pget_filter(hid_t plist, unsigned int filter_number,   unsigned int *flags, size_t *cd_nelmts,  unsigned int* cd_values, size_t namelen, char* name, unsigned int* filter_config) except <H5Z_filter_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5Z_filter_t r
 *     set_default_error_handler()
 */

static H5Z_filter_t __pyx_f_4h5py_4defs_H5Pget_filter(hid_t __pyx_v_plist, unsigned int __pyx_v_filter_number, unsigned int *__pyx_v_flags, size_t *__pyx_v_cd_nelmts, unsigned int *__pyx_v_cd_values, size_t __pyx_v_namelen, char *__pyx_v_name, unsigned int *__pyx_v_filter_config) {
  H5Z_filter_t __pyx_v_r;
  H5Z_filter_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_filter", 0);

  /* "h5py/defs.pyx":2443
 * cdef H5Z_filter_t H5Pget_filter(hid_t plist, unsigned int filter_number,   unsigned int *flags, size_t *cd_nelmts,  unsigned int* cd_values, size_t namelen, char* name, unsigned int* filter_config) except <H5Z_filter_t>-1:
 *     cdef H5Z_filter_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_filter(plist, filter_number, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2444
 *     cdef H5Z_filter_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_filter(plist, filter_number, flags, cd_nelmts, cd_values, namelen, name, filter_config)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_filter(__pyx_v_plist, __pyx_v_filter_number, __pyx_v_flags, __pyx_v_cd_nelmts, __pyx_v_cd_values, __pyx_v_namelen, __pyx_v_name, __pyx_v_filter_config);

  /* "h5py/defs.pyx":2445
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_filter(plist, filter_number, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5Z_filter_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2446
 *     r = _hdf5.H5Pget_filter(plist, filter_number, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5Z_filter_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2446, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2447
 *     if r<0:
 *         if set_exception():
 *             return <H5Z_filter_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_filter (return value <0)")
 */
      __pyx_r = ((H5Z_filter_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2446
 *     r = _hdf5.H5Pget_filter(plist, filter_number, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5Z_filter_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2449
 *             return <H5Z_filter_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_filter (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__208, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2449, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2449, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2445
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_filter(plist, filter_number, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5Z_filter_t>-1
 */
  }

  /* "h5py/defs.pyx":2450
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_filter (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_filter_by_id( hid_t plist_id, H5Z_filter_t filter,  unsigned int *flags, size_t *cd_nelmts,  unsigned int* cd_values, size_t namelen, char* name, unsigned int* filter_config) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2441
 *     return r
 * 
 * cdef H5Z_filter_t H5Pget_filter(hid_t plist, unsigned int filter_number,   unsigned int *flags, size_t *cd_nelmts,  unsigned int* cd_values, size_t namelen, char* name, unsigned int* filter_config) except <H5Z_filter_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5Z_filter_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5Z_filter_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2452
 *     return r
 * 
 * cdef herr_t H5Pget_filter_by_id( hid_t plist_id, H5Z_filter_t filter,  unsigned int *flags, size_t *cd_nelmts,  unsigned int* cd_values, size_t namelen, char* name, unsigned int* filter_config) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_filter_by_id(hid_t __pyx_v_plist_id, H5Z_filter_t __pyx_v_filter, unsigned int *__pyx_v_flags, size_t *__pyx_v_cd_nelmts, unsigned int *__pyx_v_cd_values, size_t __pyx_v_namelen, char *__pyx_v_name, unsigned int *__pyx_v_filter_config) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_filter_by_id", 0);

  /* "h5py/defs.pyx":2454
 * cdef herr_t H5Pget_filter_by_id( hid_t plist_id, H5Z_filter_t filter,  unsigned int *flags, size_t *cd_nelmts,  unsigned int* cd_values, size_t namelen, char* name, unsigned int* filter_config) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_filter_by_id(plist_id, filter, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2455
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_filter_by_id(plist_id, filter, flags, cd_nelmts, cd_values, namelen, name, filter_config)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_filter_by_id(__pyx_v_plist_id, __pyx_v_filter, __pyx_v_flags, __pyx_v_cd_nelmts, __pyx_v_cd_values, __pyx_v_namelen, __pyx_v_name, __pyx_v_filter_config);

  /* "h5py/defs.pyx":2456
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_filter_by_id(plist_id, filter, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2457
 *     r = _hdf5.H5Pget_filter_by_id(plist_id, filter, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2457, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2458
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_filter_by_id (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2457
 *     r = _hdf5.H5Pget_filter_by_id(plist_id, filter, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2460
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_filter_by_id (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__209, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2460, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2456
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_filter_by_id(plist_id, filter, flags, cd_nelmts, cd_values, namelen, name, filter_config)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2461
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_filter_by_id (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pmodify_filter(hid_t plist, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, unsigned int *cd_values) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2452
 *     return r
 * 
 * cdef herr_t H5Pget_filter_by_id( hid_t plist_id, H5Z_filter_t filter,  unsigned int *flags, size_t *cd_nelmts,  unsigned int* cd_values, size_t namelen, char* name, unsigned int* filter_config) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_filter_by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2463
 *     return r
 * 
 * cdef herr_t H5Pmodify_filter(hid_t plist, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, unsigned int *cd_values) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pmodify_filter(hid_t __pyx_v_plist, H5Z_filter_t __pyx_v_filter, unsigned int __pyx_v_flags, size_t __pyx_v_cd_nelmts, unsigned int *__pyx_v_cd_values) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pmodify_filter", 0);

  /* "h5py/defs.pyx":2465
 * cdef herr_t H5Pmodify_filter(hid_t plist, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, unsigned int *cd_values) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pmodify_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2466
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pmodify_filter(plist, filter, flags, cd_nelmts, cd_values)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pmodify_filter(__pyx_v_plist, __pyx_v_filter, __pyx_v_flags, __pyx_v_cd_nelmts, __pyx_v_cd_values);

  /* "h5py/defs.pyx":2467
 *     set_default_error_handler()
 *     r = _hdf5.H5Pmodify_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2468
 *     r = _hdf5.H5Pmodify_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2468, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2469
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pmodify_filter (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2468
 *     r = _hdf5.H5Pmodify_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2471
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pmodify_filter (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__210, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2471, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2471, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2467
 *     set_default_error_handler()
 *     r = _hdf5.H5Pmodify_filter(plist, filter, flags, cd_nelmts, cd_values)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2472
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pmodify_filter (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Premove_filter(hid_t plist, H5Z_filter_t filter ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2463
 *     return r
 * 
 * cdef herr_t H5Pmodify_filter(hid_t plist, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, unsigned int *cd_values) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pmodify_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2474
 *     return r
 * 
 * cdef herr_t H5Premove_filter(hid_t plist, H5Z_filter_t filter ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Premove_filter(hid_t __pyx_v_plist, H5Z_filter_t __pyx_v_filter) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Premove_filter", 0);

  /* "h5py/defs.pyx":2476
 * cdef herr_t H5Premove_filter(hid_t plist, H5Z_filter_t filter ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Premove_filter(plist, filter)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2477
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Premove_filter(plist, filter)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Premove_filter(__pyx_v_plist, __pyx_v_filter);

  /* "h5py/defs.pyx":2478
 *     set_default_error_handler()
 *     r = _hdf5.H5Premove_filter(plist, filter)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2479
 *     r = _hdf5.H5Premove_filter(plist, filter)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2479, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2480
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Premove_filter (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2479
 *     r = _hdf5.H5Premove_filter(plist, filter)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2482
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Premove_filter (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__211, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2482, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2478
 *     set_default_error_handler()
 *     r = _hdf5.H5Premove_filter(plist, filter)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2483
 *         else:
 *             raise RuntimeError("Unspecified error in H5Premove_filter (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_fletcher32(hid_t plist) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2474
 *     return r
 * 
 * cdef herr_t H5Premove_filter(hid_t plist, H5Z_filter_t filter ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Premove_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2485
 *     return r
 * 
 * cdef herr_t H5Pset_fletcher32(hid_t plist) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_fletcher32(hid_t __pyx_v_plist) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_fletcher32", 0);

  /* "h5py/defs.pyx":2487
 * cdef herr_t H5Pset_fletcher32(hid_t plist) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_fletcher32(plist)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2488
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fletcher32(plist)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_fletcher32(__pyx_v_plist);

  /* "h5py/defs.pyx":2489
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fletcher32(plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2490
 *     r = _hdf5.H5Pset_fletcher32(plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2490, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2491
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fletcher32 (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2490
 *     r = _hdf5.H5Pset_fletcher32(plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2493
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fletcher32 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__212, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2493, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2493, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2489
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_fletcher32(plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2494
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fletcher32 (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_shuffle(hid_t plist_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2485
 *     return r
 * 
 * cdef herr_t H5Pset_fletcher32(hid_t plist) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_fletcher32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2496
 *     return r
 * 
 * cdef herr_t H5Pset_shuffle(hid_t plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_shuffle(hid_t __pyx_v_plist_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_shuffle", 0);

  /* "h5py/defs.pyx":2498
 * cdef herr_t H5Pset_shuffle(hid_t plist_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_shuffle(plist_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2499
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_shuffle(plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_shuffle(__pyx_v_plist_id);

  /* "h5py/defs.pyx":2500
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_shuffle(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2501
 *     r = _hdf5.H5Pset_shuffle(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2501, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2502
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_shuffle (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2501
 *     r = _hdf5.H5Pset_shuffle(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2504
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_shuffle (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__213, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2504, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2504, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2500
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_shuffle(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2505
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_shuffle (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_szip(hid_t plist, unsigned int options_mask, unsigned int pixels_per_block) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2496
 *     return r
 * 
 * cdef herr_t H5Pset_shuffle(hid_t plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_shuffle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2507
 *     return r
 * 
 * cdef herr_t H5Pset_szip(hid_t plist, unsigned int options_mask, unsigned int pixels_per_block) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_szip(hid_t __pyx_v_plist, unsigned int __pyx_v_options_mask, unsigned int __pyx_v_pixels_per_block) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_szip", 0);

  /* "h5py/defs.pyx":2509
 * cdef herr_t H5Pset_szip(hid_t plist, unsigned int options_mask, unsigned int pixels_per_block) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_szip(plist, options_mask, pixels_per_block)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2510
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_szip(plist, options_mask, pixels_per_block)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_szip(__pyx_v_plist, __pyx_v_options_mask, __pyx_v_pixels_per_block);

  /* "h5py/defs.pyx":2511
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_szip(plist, options_mask, pixels_per_block)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2512
 *     r = _hdf5.H5Pset_szip(plist, options_mask, pixels_per_block)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2512, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2513
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_szip (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2512
 *     r = _hdf5.H5Pset_szip(plist, options_mask, pixels_per_block)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2515
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_szip (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__214, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2515, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2511
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_szip(plist, options_mask, pixels_per_block)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2516
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_szip (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_scaleoffset(hid_t plist, H5Z_SO_scale_type_t scale_type, int scale_factor) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2507
 *     return r
 * 
 * cdef herr_t H5Pset_szip(hid_t plist, unsigned int options_mask, unsigned int pixels_per_block) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_szip", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2518
 *     return r
 * 
 * cdef herr_t H5Pset_scaleoffset(hid_t plist, H5Z_SO_scale_type_t scale_type, int scale_factor) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_scaleoffset(hid_t __pyx_v_plist, enum H5Z_SO_scale_type_t __pyx_v_scale_type, int __pyx_v_scale_factor) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_scaleoffset", 0);

  /* "h5py/defs.pyx":2520
 * cdef herr_t H5Pset_scaleoffset(hid_t plist, H5Z_SO_scale_type_t scale_type, int scale_factor) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_scaleoffset(plist, scale_type, scale_factor)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2521
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_scaleoffset(plist, scale_type, scale_factor)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_scaleoffset(__pyx_v_plist, __pyx_v_scale_type, __pyx_v_scale_factor);

  /* "h5py/defs.pyx":2522
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_scaleoffset(plist, scale_type, scale_factor)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2523
 *     r = _hdf5.H5Pset_scaleoffset(plist, scale_type, scale_factor)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2523, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2524
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_scaleoffset (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2523
 *     r = _hdf5.H5Pset_scaleoffset(plist, scale_type, scale_factor)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2526
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_scaleoffset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__215, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2526, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2526, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2522
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_scaleoffset(plist, scale_type, scale_factor)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2527
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_scaleoffset (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_external(hid_t plist_id, const char *name, off_t offset, hsize_t size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2518
 *     return r
 * 
 * cdef herr_t H5Pset_scaleoffset(hid_t plist, H5Z_SO_scale_type_t scale_type, int scale_factor) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_scaleoffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2529
 *     return r
 * 
 * cdef herr_t H5Pset_external(hid_t plist_id, const char *name, off_t offset, hsize_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_external(hid_t __pyx_v_plist_id, char const *__pyx_v_name, off_t __pyx_v_offset, hsize_t __pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_external", 0);

  /* "h5py/defs.pyx":2531
 * cdef herr_t H5Pset_external(hid_t plist_id, const char *name, off_t offset, hsize_t size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_external(plist_id, name, offset, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2532
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_external(plist_id, name, offset, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_external(__pyx_v_plist_id, __pyx_v_name, __pyx_v_offset, __pyx_v_size);

  /* "h5py/defs.pyx":2533
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_external(plist_id, name, offset, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2534
 *     r = _hdf5.H5Pset_external(plist_id, name, offset, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2534, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2535
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_external (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2534
 *     r = _hdf5.H5Pset_external(plist_id, name, offset, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2537
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_external (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__216, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2537, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2533
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_external(plist_id, name, offset, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2538
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_external (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Pget_external_count(hid_t plist_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2529
 *     return r
 * 
 * cdef herr_t H5Pset_external(hid_t plist_id, const char *name, off_t offset, hsize_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_external", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2540
 *     return r
 * 
 * cdef int H5Pget_external_count(hid_t plist_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Pget_external_count(hid_t __pyx_v_plist_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_external_count", 0);

  /* "h5py/defs.pyx":2542
 * cdef int H5Pget_external_count(hid_t plist_id) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_external_count(plist_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2543
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_external_count(plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_external_count(__pyx_v_plist_id);

  /* "h5py/defs.pyx":2544
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_external_count(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2545
 *     r = _hdf5.H5Pget_external_count(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2545, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2546
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_external_count (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2545
 *     r = _hdf5.H5Pget_external_count(plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2548
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_external_count (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__217, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2548, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2544
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_external_count(plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":2549
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_external_count (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_external(hid_t plist, unsigned idx, size_t name_size, char *name, off_t *offset, hsize_t *size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2540
 *     return r
 * 
 * cdef int H5Pget_external_count(hid_t plist_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_external_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2551
 *     return r
 * 
 * cdef herr_t H5Pget_external(hid_t plist, unsigned idx, size_t name_size, char *name, off_t *offset, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_external(hid_t __pyx_v_plist, unsigned int __pyx_v_idx, size_t __pyx_v_name_size, char *__pyx_v_name, off_t *__pyx_v_offset, hsize_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_external", 0);

  /* "h5py/defs.pyx":2553
 * cdef herr_t H5Pget_external(hid_t plist, unsigned idx, size_t name_size, char *name, off_t *offset, hsize_t *size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_external(plist, idx, name_size, name, offset, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2554
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_external(plist, idx, name_size, name, offset, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_external(__pyx_v_plist, __pyx_v_idx, __pyx_v_name_size, __pyx_v_name, __pyx_v_offset, __pyx_v_size);

  /* "h5py/defs.pyx":2555
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_external(plist, idx, name_size, name, offset, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2556
 *     r = _hdf5.H5Pget_external(plist, idx, name_size, name, offset, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2556, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2557
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_external (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2556
 *     r = _hdf5.H5Pget_external(plist, idx, name_size, name, offset, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2559
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_external (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__218, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2559, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2559, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2555
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_external(plist, idx, name_size, name, offset, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2560
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_external (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2551
 *     return r
 * 
 * cdef herr_t H5Pget_external(hid_t plist, unsigned idx, size_t name_size, char *name, off_t *offset, hsize_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_external", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2563
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef ssize_t H5Pget_virtual_dsetname(hid_t dcpl_id, size_t index, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Pget_virtual_dsetname(hid_t __pyx_v_dcpl_id, size_t __pyx_v_index, char *__pyx_v_name, size_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_virtual_dsetname", 0);

  /* "h5py/defs.pyx":2565
 *     cdef ssize_t H5Pget_virtual_dsetname(hid_t dcpl_id, size_t index, char *name, size_t size) except <ssize_t>-1:
 *         cdef ssize_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_virtual_dsetname(dcpl_id, index, name, size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2566
 *         cdef ssize_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_dsetname(dcpl_id, index, name, size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_virtual_dsetname(__pyx_v_dcpl_id, __pyx_v_index, __pyx_v_name, __pyx_v_size);

  /* "h5py/defs.pyx":2567
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_dsetname(dcpl_id, index, name, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2568
 *         r = _hdf5.H5Pget_virtual_dsetname(dcpl_id, index, name, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2568, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2569
 *         if r<0:
 *             if set_exception():
 *                 return <ssize_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_dsetname (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2568
 *         r = _hdf5.H5Pget_virtual_dsetname(dcpl_id, index, name, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2571
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_dsetname (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__219, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2571, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2567
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_dsetname(dcpl_id, index, name, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":2572
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_dsetname (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2563
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef ssize_t H5Pget_virtual_dsetname(hid_t dcpl_id, size_t index, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_virtual_dsetname", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2575
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef ssize_t H5Pget_virtual_filename(hid_t dcpl_id, size_t index, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Pget_virtual_filename(hid_t __pyx_v_dcpl_id, size_t __pyx_v_index, char *__pyx_v_name, size_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_virtual_filename", 0);

  /* "h5py/defs.pyx":2577
 *     cdef ssize_t H5Pget_virtual_filename(hid_t dcpl_id, size_t index, char *name, size_t size) except <ssize_t>-1:
 *         cdef ssize_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_virtual_filename(dcpl_id, index, name, size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2578
 *         cdef ssize_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_filename(dcpl_id, index, name, size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_virtual_filename(__pyx_v_dcpl_id, __pyx_v_index, __pyx_v_name, __pyx_v_size);

  /* "h5py/defs.pyx":2579
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_filename(dcpl_id, index, name, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2580
 *         r = _hdf5.H5Pget_virtual_filename(dcpl_id, index, name, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2580, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2581
 *         if r<0:
 *             if set_exception():
 *                 return <ssize_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_filename (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2580
 *         r = _hdf5.H5Pget_virtual_filename(dcpl_id, index, name, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2583
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_filename (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__220, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2583, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2579
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_filename(dcpl_id, index, name, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":2584
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_filename (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2575
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef ssize_t H5Pget_virtual_filename(hid_t dcpl_id, size_t index, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_virtual_filename", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2587
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pget_virtual_count(hid_t dcpl_id, size_t *count) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_virtual_count(hid_t __pyx_v_dcpl_id, size_t *__pyx_v_count) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_virtual_count", 0);

  /* "h5py/defs.pyx":2589
 *     cdef herr_t H5Pget_virtual_count(hid_t dcpl_id, size_t *count) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_virtual_count(dcpl_id, count)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2590
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_count(dcpl_id, count)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_virtual_count(__pyx_v_dcpl_id, __pyx_v_count);

  /* "h5py/defs.pyx":2591
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_count(dcpl_id, count)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2592
 *         r = _hdf5.H5Pget_virtual_count(dcpl_id, count)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2592, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2593
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_count (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2592
 *         r = _hdf5.H5Pget_virtual_count(dcpl_id, count)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2595
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_count (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__221, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2595, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2595, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2591
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_count(dcpl_id, count)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2596
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_count (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2587
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pget_virtual_count(hid_t dcpl_id, size_t *count) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_virtual_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2599
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pset_virtual(hid_t dcpl_id, hid_t vspace_id, const char *src_file_name, const char *src_dset_name, hid_t src_space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_virtual(hid_t __pyx_v_dcpl_id, hid_t __pyx_v_vspace_id, char const *__pyx_v_src_file_name, char const *__pyx_v_src_dset_name, hid_t __pyx_v_src_space_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_virtual", 0);

  /* "h5py/defs.pyx":2601
 *     cdef herr_t H5Pset_virtual(hid_t dcpl_id, hid_t vspace_id, const char *src_file_name, const char *src_dset_name, hid_t src_space_id) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_virtual(dcpl_id, vspace_id, src_file_name, src_dset_name, src_space_id)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2602
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual(dcpl_id, vspace_id, src_file_name, src_dset_name, src_space_id)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_virtual(__pyx_v_dcpl_id, __pyx_v_vspace_id, __pyx_v_src_file_name, __pyx_v_src_dset_name, __pyx_v_src_space_id);

  /* "h5py/defs.pyx":2603
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual(dcpl_id, vspace_id, src_file_name, src_dset_name, src_space_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2604
 *         r = _hdf5.H5Pset_virtual(dcpl_id, vspace_id, src_file_name, src_dset_name, src_space_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2604, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2605
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2604
 *         r = _hdf5.H5Pset_virtual(dcpl_id, vspace_id, src_file_name, src_dset_name, src_space_id)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2607
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__222, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2607, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2603
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual(dcpl_id, vspace_id, src_file_name, src_dset_name, src_space_id)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2608
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2599
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pset_virtual(hid_t dcpl_id, hid_t vspace_id, const char *src_file_name, const char *src_dset_name, hid_t src_space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_virtual", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2611
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef hid_t H5Pget_virtual_vspace(hid_t dcpl_id, size_t index) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *         cdef hid_t r
 *         set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Pget_virtual_vspace(hid_t __pyx_v_dcpl_id, size_t __pyx_v_index) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_virtual_vspace", 0);

  /* "h5py/defs.pyx":2613
 *     cdef hid_t H5Pget_virtual_vspace(hid_t dcpl_id, size_t index) except <hid_t>-1:
 *         cdef hid_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_virtual_vspace(dcpl_id, index)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2614
 *         cdef hid_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_vspace(dcpl_id, index)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_virtual_vspace(__pyx_v_dcpl_id, __pyx_v_index);

  /* "h5py/defs.pyx":2615
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_vspace(dcpl_id, index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2616
 *         r = _hdf5.H5Pget_virtual_vspace(dcpl_id, index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <hid_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2616, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2617
 *         if r<0:
 *             if set_exception():
 *                 return <hid_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_vspace (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2616
 *         r = _hdf5.H5Pget_virtual_vspace(dcpl_id, index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <hid_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2619
 *                 return <hid_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_vspace (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__223, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2619, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2615
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_vspace(dcpl_id, index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":2620
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_vspace (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2611
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef hid_t H5Pget_virtual_vspace(hid_t dcpl_id, size_t index) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *         cdef hid_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_virtual_vspace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2623
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef hid_t H5Pget_virtual_srcspace(hid_t dcpl_id, size_t index) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *         cdef hid_t r
 *         set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Pget_virtual_srcspace(hid_t __pyx_v_dcpl_id, size_t __pyx_v_index) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_virtual_srcspace", 0);

  /* "h5py/defs.pyx":2625
 *     cdef hid_t H5Pget_virtual_srcspace(hid_t dcpl_id, size_t index) except <hid_t>-1:
 *         cdef hid_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_virtual_srcspace(dcpl_id, index)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2626
 *         cdef hid_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_srcspace(dcpl_id, index)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_virtual_srcspace(__pyx_v_dcpl_id, __pyx_v_index);

  /* "h5py/defs.pyx":2627
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_srcspace(dcpl_id, index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2628
 *         r = _hdf5.H5Pget_virtual_srcspace(dcpl_id, index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <hid_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2628, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2629
 *         if r<0:
 *             if set_exception():
 *                 return <hid_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_srcspace (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2628
 *         r = _hdf5.H5Pget_virtual_srcspace(dcpl_id, index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <hid_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2631
 *                 return <hid_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_srcspace (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__224, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2631, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2631, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2627
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_srcspace(dcpl_id, index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":2632
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_srcspace (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_edc_check(hid_t plist, H5Z_EDC_t check) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2623
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef hid_t H5Pget_virtual_srcspace(hid_t dcpl_id, size_t index) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *         cdef hid_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_virtual_srcspace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2634
 *         return r
 * 
 * cdef herr_t H5Pset_edc_check(hid_t plist, H5Z_EDC_t check) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_edc_check(hid_t __pyx_v_plist, enum H5Z_EDC_t __pyx_v_check) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_edc_check", 0);

  /* "h5py/defs.pyx":2636
 * cdef herr_t H5Pset_edc_check(hid_t plist, H5Z_EDC_t check) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_edc_check(plist, check)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2637
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_edc_check(plist, check)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_edc_check(__pyx_v_plist, __pyx_v_check);

  /* "h5py/defs.pyx":2638
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_edc_check(plist, check)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2639
 *     r = _hdf5.H5Pset_edc_check(plist, check)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2639, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2640
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_edc_check (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2639
 *     r = _hdf5.H5Pset_edc_check(plist, check)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2642
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_edc_check (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__225, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2642, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2638
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_edc_check(plist, check)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2643
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_edc_check (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5Z_EDC_t H5Pget_edc_check(hid_t plist) except <H5Z_EDC_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2634
 *         return r
 * 
 * cdef herr_t H5Pset_edc_check(hid_t plist, H5Z_EDC_t check) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_edc_check", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2645
 *     return r
 * 
 * cdef H5Z_EDC_t H5Pget_edc_check(hid_t plist) except <H5Z_EDC_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5Z_EDC_t r
 *     set_default_error_handler()
 */

static enum H5Z_EDC_t __pyx_f_4h5py_4defs_H5Pget_edc_check(hid_t __pyx_v_plist) {
  enum H5Z_EDC_t __pyx_v_r;
  enum H5Z_EDC_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_edc_check", 0);

  /* "h5py/defs.pyx":2647
 * cdef H5Z_EDC_t H5Pget_edc_check(hid_t plist) except <H5Z_EDC_t>-1:
 *     cdef H5Z_EDC_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_edc_check(plist)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2648
 *     cdef H5Z_EDC_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_edc_check(plist)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_edc_check(__pyx_v_plist);

  /* "h5py/defs.pyx":2649
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_edc_check(plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5Z_EDC_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2650
 *     r = _hdf5.H5Pget_edc_check(plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5Z_EDC_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2650, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2651
 *     if r<0:
 *         if set_exception():
 *             return <H5Z_EDC_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_edc_check (return value <0)")
 */
      __pyx_r = ((enum H5Z_EDC_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2650
 *     r = _hdf5.H5Pget_edc_check(plist)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5Z_EDC_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2653
 *             return <H5Z_EDC_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_edc_check (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__226, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2653, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2649
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_edc_check(plist)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5Z_EDC_t>-1
 */
  }

  /* "h5py/defs.pyx":2654
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_edc_check (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_chunk_cache( hid_t dapl_id, size_t rdcc_nslots, size_t rdcc_nbytes, double rdcc_w0 ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2645
 *     return r
 * 
 * cdef H5Z_EDC_t H5Pget_edc_check(hid_t plist) except <H5Z_EDC_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5Z_EDC_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_edc_check", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((enum H5Z_EDC_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2656
 *     return r
 * 
 * cdef herr_t H5Pset_chunk_cache( hid_t dapl_id, size_t rdcc_nslots, size_t rdcc_nbytes, double rdcc_w0 ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_chunk_cache(hid_t __pyx_v_dapl_id, size_t __pyx_v_rdcc_nslots, size_t __pyx_v_rdcc_nbytes, double __pyx_v_rdcc_w0) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_chunk_cache", 0);

  /* "h5py/defs.pyx":2658
 * cdef herr_t H5Pset_chunk_cache( hid_t dapl_id, size_t rdcc_nslots, size_t rdcc_nbytes, double rdcc_w0 ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2659
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_chunk_cache(__pyx_v_dapl_id, __pyx_v_rdcc_nslots, __pyx_v_rdcc_nbytes, __pyx_v_rdcc_w0);

  /* "h5py/defs.pyx":2660
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2661
 *     r = _hdf5.H5Pset_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2661, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2662
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_chunk_cache (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2661
 *     r = _hdf5.H5Pset_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2664
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_chunk_cache (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__227, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2664, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2664, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2660
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2665
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_chunk_cache (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_chunk_cache( hid_t dapl_id, size_t *rdcc_nslots, size_t *rdcc_nbytes, double *rdcc_w0 ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2656
 *     return r
 * 
 * cdef herr_t H5Pset_chunk_cache( hid_t dapl_id, size_t rdcc_nslots, size_t rdcc_nbytes, double rdcc_w0 ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_chunk_cache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2667
 *     return r
 * 
 * cdef herr_t H5Pget_chunk_cache( hid_t dapl_id, size_t *rdcc_nslots, size_t *rdcc_nbytes, double *rdcc_w0 ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_chunk_cache(hid_t __pyx_v_dapl_id, size_t *__pyx_v_rdcc_nslots, size_t *__pyx_v_rdcc_nbytes, double *__pyx_v_rdcc_w0) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_chunk_cache", 0);

  /* "h5py/defs.pyx":2669
 * cdef herr_t H5Pget_chunk_cache( hid_t dapl_id, size_t *rdcc_nslots, size_t *rdcc_nbytes, double *rdcc_w0 ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2670
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_chunk_cache(__pyx_v_dapl_id, __pyx_v_rdcc_nslots, __pyx_v_rdcc_nbytes, __pyx_v_rdcc_w0);

  /* "h5py/defs.pyx":2671
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2672
 *     r = _hdf5.H5Pget_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2672, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2673
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_chunk_cache (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2672
 *     r = _hdf5.H5Pget_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2675
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_chunk_cache (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__228, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2675, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2671
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_chunk_cache(dapl_id, rdcc_nslots, rdcc_nbytes, rdcc_w0)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2676
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_chunk_cache (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 17):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2667
 *     return r
 * 
 * cdef herr_t H5Pget_chunk_cache( hid_t dapl_id, size_t *rdcc_nslots, size_t *rdcc_nbytes, double *rdcc_w0 ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_chunk_cache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2679
 * 
 * IF HDF5_VERSION >= (1, 8, 17):
 *     cdef herr_t H5Pget_efile_prefix(hid_t dapl_id, char *prefix, ssize_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_efile_prefix(hid_t __pyx_v_dapl_id, char *__pyx_v_prefix, Py_ssize_t __pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_efile_prefix", 0);

  /* "h5py/defs.pyx":2681
 *     cdef herr_t H5Pget_efile_prefix(hid_t dapl_id, char *prefix, ssize_t size) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_efile_prefix(dapl_id, prefix, size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2682
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_efile_prefix(dapl_id, prefix, size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_efile_prefix(__pyx_v_dapl_id, __pyx_v_prefix, __pyx_v_size);

  /* "h5py/defs.pyx":2683
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_efile_prefix(dapl_id, prefix, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2684
 *         r = _hdf5.H5Pget_efile_prefix(dapl_id, prefix, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2684, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2685
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_efile_prefix (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2684
 *         r = _hdf5.H5Pget_efile_prefix(dapl_id, prefix, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2687
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_efile_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__229, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2687, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2687, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2683
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_efile_prefix(dapl_id, prefix, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2688
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_efile_prefix (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 8, 17):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2679
 * 
 * IF HDF5_VERSION >= (1, 8, 17):
 *     cdef herr_t H5Pget_efile_prefix(hid_t dapl_id, char *prefix, ssize_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_efile_prefix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2691
 * 
 * IF HDF5_VERSION >= (1, 8, 17):
 *     cdef herr_t H5Pset_efile_prefix(hid_t dapl_id, char *prefix) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_efile_prefix(hid_t __pyx_v_dapl_id, char *__pyx_v_prefix) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_efile_prefix", 0);

  /* "h5py/defs.pyx":2693
 *     cdef herr_t H5Pset_efile_prefix(hid_t dapl_id, char *prefix) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_efile_prefix(dapl_id, prefix)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2694
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_efile_prefix(dapl_id, prefix)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_efile_prefix(__pyx_v_dapl_id, __pyx_v_prefix);

  /* "h5py/defs.pyx":2695
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_efile_prefix(dapl_id, prefix)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2696
 *         r = _hdf5.H5Pset_efile_prefix(dapl_id, prefix)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2696, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2697
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_efile_prefix (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2696
 *         r = _hdf5.H5Pset_efile_prefix(dapl_id, prefix)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2699
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_efile_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__230, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2699, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2699, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2695
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_efile_prefix(dapl_id, prefix)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2700
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_efile_prefix (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2691
 * 
 * IF HDF5_VERSION >= (1, 8, 17):
 *     cdef herr_t H5Pset_efile_prefix(hid_t dapl_id, char *prefix) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_efile_prefix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2703
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pset_virtual_view(hid_t plist_id, H5D_vds_view_t view) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_virtual_view(hid_t __pyx_v_plist_id, H5D_vds_view_t __pyx_v_view) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_virtual_view", 0);

  /* "h5py/defs.pyx":2705
 *     cdef herr_t H5Pset_virtual_view(hid_t plist_id, H5D_vds_view_t view) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_virtual_view(plist_id, view)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2706
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_view(plist_id, view)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_virtual_view(__pyx_v_plist_id, __pyx_v_view);

  /* "h5py/defs.pyx":2707
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_view(plist_id, view)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2708
 *         r = _hdf5.H5Pset_virtual_view(plist_id, view)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2708, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2709
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_view (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2708
 *         r = _hdf5.H5Pset_virtual_view(plist_id, view)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2711
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_view (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__231, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2711, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2711, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2707
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_view(plist_id, view)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2712
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_view (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2703
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pset_virtual_view(hid_t plist_id, H5D_vds_view_t view) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_virtual_view", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2715
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pget_virtual_view(hid_t plist_id, H5D_vds_view_t *view) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_virtual_view(hid_t __pyx_v_plist_id, H5D_vds_view_t *__pyx_v_view) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_virtual_view", 0);

  /* "h5py/defs.pyx":2717
 *     cdef herr_t H5Pget_virtual_view(hid_t plist_id, H5D_vds_view_t *view) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_virtual_view(plist_id, view)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2718
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_view(plist_id, view)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_virtual_view(__pyx_v_plist_id, __pyx_v_view);

  /* "h5py/defs.pyx":2719
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_view(plist_id, view)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2720
 *         r = _hdf5.H5Pget_virtual_view(plist_id, view)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2720, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2721
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_view (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2720
 *         r = _hdf5.H5Pget_virtual_view(plist_id, view)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2723
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_view (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__232, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2723, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2723, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2719
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_view(plist_id, view)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2724
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_view (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2715
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pget_virtual_view(hid_t plist_id, H5D_vds_view_t *view) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_virtual_view", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2727
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pset_virtual_printf_gap(hid_t plist_id, hsize_t gap_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_virtual_printf_gap(hid_t __pyx_v_plist_id, hsize_t __pyx_v_gap_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_virtual_printf_gap", 0);

  /* "h5py/defs.pyx":2729
 *     cdef herr_t H5Pset_virtual_printf_gap(hid_t plist_id, hsize_t gap_size) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2730
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_printf_gap(plist_id, gap_size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_virtual_printf_gap(__pyx_v_plist_id, __pyx_v_gap_size);

  /* "h5py/defs.pyx":2731
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2732
 *         r = _hdf5.H5Pset_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2732, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2733
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_printf_gap (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2732
 *         r = _hdf5.H5Pset_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2735
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_printf_gap (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__233, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2735, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2735, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2731
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2736
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_printf_gap (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2727
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pset_virtual_printf_gap(hid_t plist_id, hsize_t gap_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_virtual_printf_gap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2739
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pget_virtual_printf_gap(hid_t plist_id, hsize_t *gap_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_virtual_printf_gap(hid_t __pyx_v_plist_id, hsize_t *__pyx_v_gap_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_virtual_printf_gap", 0);

  /* "h5py/defs.pyx":2741
 *     cdef herr_t H5Pget_virtual_printf_gap(hid_t plist_id, hsize_t *gap_size) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2742
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_printf_gap(plist_id, gap_size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_virtual_printf_gap(__pyx_v_plist_id, __pyx_v_gap_size);

  /* "h5py/defs.pyx":2743
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2744
 *         r = _hdf5.H5Pget_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2744, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2745
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_printf_gap (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2744
 *         r = _hdf5.H5Pget_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2747
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_printf_gap (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__234, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2747, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2747, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2743
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_printf_gap(plist_id, gap_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2748
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_printf_gap (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2739
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef herr_t H5Pget_virtual_printf_gap(hid_t plist_id, hsize_t *gap_size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_virtual_printf_gap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2751
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 *     cdef ssize_t H5Pget_virtual_prefix(hid_t dapl_id, char *prefix, ssize_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Pget_virtual_prefix(hid_t __pyx_v_dapl_id, char *__pyx_v_prefix, Py_ssize_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_virtual_prefix", 0);

  /* "h5py/defs.pyx":2753
 *     cdef ssize_t H5Pget_virtual_prefix(hid_t dapl_id, char *prefix, ssize_t size) except <ssize_t>-1:
 *         cdef ssize_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pget_virtual_prefix(dapl_id, prefix, size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2754
 *         cdef ssize_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_prefix(dapl_id, prefix, size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pget_virtual_prefix(__pyx_v_dapl_id, __pyx_v_prefix, __pyx_v_size);

  /* "h5py/defs.pyx":2755
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_prefix(dapl_id, prefix, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2756
 *         r = _hdf5.H5Pget_virtual_prefix(dapl_id, prefix, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2756, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2757
 *         if r<0:
 *             if set_exception():
 *                 return <ssize_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_prefix (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2756
 *         r = _hdf5.H5Pget_virtual_prefix(dapl_id, prefix, size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2759
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__235, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2759, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2759, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2755
 *         set_default_error_handler()
 *         r = _hdf5.H5Pget_virtual_prefix(dapl_id, prefix, size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":2760
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_prefix (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2751
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 *     cdef ssize_t H5Pget_virtual_prefix(hid_t dapl_id, char *prefix, ssize_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_virtual_prefix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2763
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 *     cdef herr_t H5Pset_virtual_prefix(hid_t dapl_id, char *prefix) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_virtual_prefix(hid_t __pyx_v_dapl_id, char *__pyx_v_prefix) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_virtual_prefix", 0);

  /* "h5py/defs.pyx":2765
 *     cdef herr_t H5Pset_virtual_prefix(hid_t dapl_id, char *prefix) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Pset_virtual_prefix(dapl_id, prefix)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2766
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_prefix(dapl_id, prefix)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Pset_virtual_prefix(__pyx_v_dapl_id, __pyx_v_prefix);

  /* "h5py/defs.pyx":2767
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_prefix(dapl_id, prefix)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2768
 *         r = _hdf5.H5Pset_virtual_prefix(dapl_id, prefix)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2768, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2769
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_prefix (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2768
 *         r = _hdf5.H5Pset_virtual_prefix(dapl_id, prefix)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":2771
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__236, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2771, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2771, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2767
 *         set_default_error_handler()
 *         r = _hdf5.H5Pset_virtual_prefix(dapl_id, prefix)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2772
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_prefix (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF MPI:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2763
 * 
 * IF HDF5_VERSION >= (1, 10, 2):
 *     cdef herr_t H5Pset_virtual_prefix(hid_t dapl_id, char *prefix) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_virtual_prefix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2798
 *         return r
 * 
 * cdef herr_t H5Pset_sieve_buf_size(hid_t fapl_id, size_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_sieve_buf_size(hid_t __pyx_v_fapl_id, size_t __pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_sieve_buf_size", 0);

  /* "h5py/defs.pyx":2800
 * cdef herr_t H5Pset_sieve_buf_size(hid_t fapl_id, size_t size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_sieve_buf_size(fapl_id, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2801
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sieve_buf_size(fapl_id, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_sieve_buf_size(__pyx_v_fapl_id, __pyx_v_size);

  /* "h5py/defs.pyx":2802
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sieve_buf_size(fapl_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2803
 *     r = _hdf5.H5Pset_sieve_buf_size(fapl_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2803, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2804
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sieve_buf_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2803
 *     r = _hdf5.H5Pset_sieve_buf_size(fapl_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2806
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sieve_buf_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__237, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2806, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2806, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2802
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_sieve_buf_size(fapl_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2807
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sieve_buf_size (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_sieve_buf_size(hid_t fapl_id, size_t *size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2798
 *         return r
 * 
 * cdef herr_t H5Pset_sieve_buf_size(hid_t fapl_id, size_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_sieve_buf_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2809
 *     return r
 * 
 * cdef herr_t H5Pget_sieve_buf_size(hid_t fapl_id, size_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_sieve_buf_size(hid_t __pyx_v_fapl_id, size_t *__pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_sieve_buf_size", 0);

  /* "h5py/defs.pyx":2811
 * cdef herr_t H5Pget_sieve_buf_size(hid_t fapl_id, size_t *size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_sieve_buf_size(fapl_id, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2812
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sieve_buf_size(fapl_id, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_sieve_buf_size(__pyx_v_fapl_id, __pyx_v_size);

  /* "h5py/defs.pyx":2813
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sieve_buf_size(fapl_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2814
 *     r = _hdf5.H5Pget_sieve_buf_size(fapl_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2814, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2815
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sieve_buf_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2814
 *     r = _hdf5.H5Pget_sieve_buf_size(fapl_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2817
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sieve_buf_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__238, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2817, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2813
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_sieve_buf_size(fapl_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2818
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sieve_buf_size (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_nlinks(hid_t plist_id, size_t nlinks) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2809
 *     return r
 * 
 * cdef herr_t H5Pget_sieve_buf_size(hid_t fapl_id, size_t *size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_sieve_buf_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2820
 *     return r
 * 
 * cdef herr_t H5Pset_nlinks(hid_t plist_id, size_t nlinks) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_nlinks(hid_t __pyx_v_plist_id, size_t __pyx_v_nlinks) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_nlinks", 0);

  /* "h5py/defs.pyx":2822
 * cdef herr_t H5Pset_nlinks(hid_t plist_id, size_t nlinks) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_nlinks(plist_id, nlinks)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2823
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_nlinks(plist_id, nlinks)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_nlinks(__pyx_v_plist_id, __pyx_v_nlinks);

  /* "h5py/defs.pyx":2824
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_nlinks(plist_id, nlinks)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2825
 *     r = _hdf5.H5Pset_nlinks(plist_id, nlinks)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2825, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2826
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_nlinks (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2825
 *     r = _hdf5.H5Pset_nlinks(plist_id, nlinks)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2828
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_nlinks (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__239, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2828, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2824
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_nlinks(plist_id, nlinks)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2829
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_nlinks (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_nlinks(hid_t plist_id, size_t *nlinks) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2820
 *     return r
 * 
 * cdef herr_t H5Pset_nlinks(hid_t plist_id, size_t nlinks) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_nlinks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2831
 *     return r
 * 
 * cdef herr_t H5Pget_nlinks(hid_t plist_id, size_t *nlinks) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_nlinks(hid_t __pyx_v_plist_id, size_t *__pyx_v_nlinks) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_nlinks", 0);

  /* "h5py/defs.pyx":2833
 * cdef herr_t H5Pget_nlinks(hid_t plist_id, size_t *nlinks) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_nlinks(plist_id, nlinks)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2834
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_nlinks(plist_id, nlinks)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_nlinks(__pyx_v_plist_id, __pyx_v_nlinks);

  /* "h5py/defs.pyx":2835
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_nlinks(plist_id, nlinks)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2836
 *     r = _hdf5.H5Pget_nlinks(plist_id, nlinks)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2836, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2837
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_nlinks (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2836
 *     r = _hdf5.H5Pget_nlinks(plist_id, nlinks)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2839
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_nlinks (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__240, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2839, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2839, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2835
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_nlinks(plist_id, nlinks)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2840
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_nlinks (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_elink_prefix(hid_t plist_id, char *prefix) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2831
 *     return r
 * 
 * cdef herr_t H5Pget_nlinks(hid_t plist_id, size_t *nlinks) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_nlinks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2842
 *     return r
 * 
 * cdef herr_t H5Pset_elink_prefix(hid_t plist_id, char *prefix) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_elink_prefix(hid_t __pyx_v_plist_id, char *__pyx_v_prefix) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_elink_prefix", 0);

  /* "h5py/defs.pyx":2844
 * cdef herr_t H5Pset_elink_prefix(hid_t plist_id, char *prefix) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_elink_prefix(plist_id, prefix)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2845
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_elink_prefix(plist_id, prefix)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_elink_prefix(__pyx_v_plist_id, __pyx_v_prefix);

  /* "h5py/defs.pyx":2846
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_elink_prefix(plist_id, prefix)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2847
 *     r = _hdf5.H5Pset_elink_prefix(plist_id, prefix)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2847, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2848
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_elink_prefix (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2847
 *     r = _hdf5.H5Pset_elink_prefix(plist_id, prefix)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2850
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_elink_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__241, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2850, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2846
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_elink_prefix(plist_id, prefix)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2851
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_elink_prefix (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5Pget_elink_prefix(hid_t plist_id, char *prefix, size_t size) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2842
 *     return r
 * 
 * cdef herr_t H5Pset_elink_prefix(hid_t plist_id, char *prefix) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_elink_prefix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2853
 *     return r
 * 
 * cdef ssize_t H5Pget_elink_prefix(hid_t plist_id, char *prefix, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Pget_elink_prefix(hid_t __pyx_v_plist_id, char *__pyx_v_prefix, size_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_elink_prefix", 0);

  /* "h5py/defs.pyx":2855
 * cdef ssize_t H5Pget_elink_prefix(hid_t plist_id, char *prefix, size_t size) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_elink_prefix(plist_id, prefix, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2856
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_elink_prefix(plist_id, prefix, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_elink_prefix(__pyx_v_plist_id, __pyx_v_prefix, __pyx_v_size);

  /* "h5py/defs.pyx":2857
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_elink_prefix(plist_id, prefix, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2858
 *     r = _hdf5.H5Pget_elink_prefix(plist_id, prefix, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2858, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2859
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_elink_prefix (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2858
 *     r = _hdf5.H5Pget_elink_prefix(plist_id, prefix, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2861
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_elink_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__242, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2861, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2861, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2857
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_elink_prefix(plist_id, prefix, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":2862
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_elink_prefix (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Pget_elink_fapl(hid_t lapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2853
 *     return r
 * 
 * cdef ssize_t H5Pget_elink_prefix(hid_t plist_id, char *prefix, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_elink_prefix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2864
 *     return r
 * 
 * cdef hid_t H5Pget_elink_fapl(hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Pget_elink_fapl(hid_t __pyx_v_lapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_elink_fapl", 0);

  /* "h5py/defs.pyx":2866
 * cdef hid_t H5Pget_elink_fapl(hid_t lapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_elink_fapl(lapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2867
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_elink_fapl(lapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_elink_fapl(__pyx_v_lapl_id);

  /* "h5py/defs.pyx":2868
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_elink_fapl(lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2869
 *     r = _hdf5.H5Pget_elink_fapl(lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2869, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2870
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_elink_fapl (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2869
 *     r = _hdf5.H5Pget_elink_fapl(lapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2872
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_elink_fapl (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__243, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2872, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2868
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_elink_fapl(lapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":2873
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_elink_fapl (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_elink_fapl(hid_t lapl_id, hid_t fapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2864
 *     return r
 * 
 * cdef hid_t H5Pget_elink_fapl(hid_t lapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_elink_fapl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2875
 *     return r
 * 
 * cdef herr_t H5Pset_elink_fapl(hid_t lapl_id, hid_t fapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_elink_fapl(hid_t __pyx_v_lapl_id, hid_t __pyx_v_fapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_elink_fapl", 0);

  /* "h5py/defs.pyx":2877
 * cdef herr_t H5Pset_elink_fapl(hid_t lapl_id, hid_t fapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_elink_fapl(lapl_id, fapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2878
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_elink_fapl(lapl_id, fapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_elink_fapl(__pyx_v_lapl_id, __pyx_v_fapl_id);

  /* "h5py/defs.pyx":2879
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_elink_fapl(lapl_id, fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2880
 *     r = _hdf5.H5Pset_elink_fapl(lapl_id, fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2880, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2881
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_elink_fapl (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2880
 *     r = _hdf5.H5Pset_elink_fapl(lapl_id, fapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2883
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_elink_fapl (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__244, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2883, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2879
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_elink_fapl(lapl_id, fapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2884
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_elink_fapl (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_create_intermediate_group(hid_t plist_id, unsigned crt_intmd) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2875
 *     return r
 * 
 * cdef herr_t H5Pset_elink_fapl(hid_t lapl_id, hid_t fapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_elink_fapl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2886
 *     return r
 * 
 * cdef herr_t H5Pset_create_intermediate_group(hid_t plist_id, unsigned crt_intmd) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_create_intermediate_group(hid_t __pyx_v_plist_id, unsigned int __pyx_v_crt_intmd) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_create_intermediate_group", 0);

  /* "h5py/defs.pyx":2888
 * cdef herr_t H5Pset_create_intermediate_group(hid_t plist_id, unsigned crt_intmd) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2889
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_create_intermediate_group(plist_id, crt_intmd)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_create_intermediate_group(__pyx_v_plist_id, __pyx_v_crt_intmd);

  /* "h5py/defs.pyx":2890
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2891
 *     r = _hdf5.H5Pset_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2891, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2892
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_create_intermediate_group (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2891
 *     r = _hdf5.H5Pset_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2894
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_create_intermediate_group (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__245, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2894, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2890
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2895
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_create_intermediate_group (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_create_intermediate_group(hid_t plist_id, unsigned *crt_intmd) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2886
 *     return r
 * 
 * cdef herr_t H5Pset_create_intermediate_group(hid_t plist_id, unsigned crt_intmd) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_create_intermediate_group", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2897
 *     return r
 * 
 * cdef herr_t H5Pget_create_intermediate_group(hid_t plist_id, unsigned *crt_intmd) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_create_intermediate_group(hid_t __pyx_v_plist_id, unsigned int *__pyx_v_crt_intmd) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_create_intermediate_group", 0);

  /* "h5py/defs.pyx":2899
 * cdef herr_t H5Pget_create_intermediate_group(hid_t plist_id, unsigned *crt_intmd) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2900
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_create_intermediate_group(plist_id, crt_intmd)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_create_intermediate_group(__pyx_v_plist_id, __pyx_v_crt_intmd);

  /* "h5py/defs.pyx":2901
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2902
 *     r = _hdf5.H5Pget_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2902, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2903
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_create_intermediate_group (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2902
 *     r = _hdf5.H5Pget_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2905
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_create_intermediate_group (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__246, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2905, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2901
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_create_intermediate_group(plist_id, crt_intmd)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2906
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_create_intermediate_group (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_copy_object(hid_t plist_id, unsigned crt_intmd) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2897
 *     return r
 * 
 * cdef herr_t H5Pget_create_intermediate_group(hid_t plist_id, unsigned *crt_intmd) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_create_intermediate_group", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2908
 *     return r
 * 
 * cdef herr_t H5Pset_copy_object(hid_t plist_id, unsigned crt_intmd) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_copy_object(hid_t __pyx_v_plist_id, unsigned int __pyx_v_crt_intmd) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_copy_object", 0);

  /* "h5py/defs.pyx":2910
 * cdef herr_t H5Pset_copy_object(hid_t plist_id, unsigned crt_intmd) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_copy_object(plist_id, crt_intmd)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2911
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_copy_object(plist_id, crt_intmd)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_copy_object(__pyx_v_plist_id, __pyx_v_crt_intmd);

  /* "h5py/defs.pyx":2912
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_copy_object(plist_id, crt_intmd)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2913
 *     r = _hdf5.H5Pset_copy_object(plist_id, crt_intmd)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2913, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2914
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_copy_object (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2913
 *     r = _hdf5.H5Pset_copy_object(plist_id, crt_intmd)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2916
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_copy_object (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__247, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2916, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2916, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2912
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_copy_object(plist_id, crt_intmd)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2917
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_copy_object (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_copy_object(hid_t plist_id, unsigned *crt_intmd) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2908
 *     return r
 * 
 * cdef herr_t H5Pset_copy_object(hid_t plist_id, unsigned crt_intmd) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_copy_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2919
 *     return r
 * 
 * cdef herr_t H5Pget_copy_object(hid_t plist_id, unsigned *crt_intmd) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_copy_object(hid_t __pyx_v_plist_id, unsigned int *__pyx_v_crt_intmd) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_copy_object", 0);

  /* "h5py/defs.pyx":2921
 * cdef herr_t H5Pget_copy_object(hid_t plist_id, unsigned *crt_intmd) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_copy_object(plist_id, crt_intmd)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2922
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_copy_object(plist_id, crt_intmd)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_copy_object(__pyx_v_plist_id, __pyx_v_crt_intmd);

  /* "h5py/defs.pyx":2923
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_copy_object(plist_id, crt_intmd)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2924
 *     r = _hdf5.H5Pget_copy_object(plist_id, crt_intmd)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2924, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2925
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_copy_object (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2924
 *     r = _hdf5.H5Pget_copy_object(plist_id, crt_intmd)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2927
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_copy_object (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__248, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2927, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2927, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2923
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_copy_object(plist_id, crt_intmd)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2928
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_copy_object (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_char_encoding(hid_t plist_id, H5T_cset_t encoding) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2919
 *     return r
 * 
 * cdef herr_t H5Pget_copy_object(hid_t plist_id, unsigned *crt_intmd) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_copy_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2930
 *     return r
 * 
 * cdef herr_t H5Pset_char_encoding(hid_t plist_id, H5T_cset_t encoding) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_char_encoding(hid_t __pyx_v_plist_id, H5T_cset_t __pyx_v_encoding) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_char_encoding", 0);

  /* "h5py/defs.pyx":2932
 * cdef herr_t H5Pset_char_encoding(hid_t plist_id, H5T_cset_t encoding) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_char_encoding(plist_id, encoding)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2933
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_char_encoding(plist_id, encoding)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_char_encoding(__pyx_v_plist_id, __pyx_v_encoding);

  /* "h5py/defs.pyx":2934
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_char_encoding(plist_id, encoding)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2935
 *     r = _hdf5.H5Pset_char_encoding(plist_id, encoding)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2935, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2936
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_char_encoding (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2935
 *     r = _hdf5.H5Pset_char_encoding(plist_id, encoding)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2938
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_char_encoding (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__249, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2938, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2938, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2934
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_char_encoding(plist_id, encoding)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2939
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_char_encoding (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_char_encoding(hid_t plist_id, H5T_cset_t *encoding) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2930
 *     return r
 * 
 * cdef herr_t H5Pset_char_encoding(hid_t plist_id, H5T_cset_t encoding) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_char_encoding", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2941
 *     return r
 * 
 * cdef herr_t H5Pget_char_encoding(hid_t plist_id, H5T_cset_t *encoding) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_char_encoding(hid_t __pyx_v_plist_id, H5T_cset_t *__pyx_v_encoding) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_char_encoding", 0);

  /* "h5py/defs.pyx":2943
 * cdef herr_t H5Pget_char_encoding(hid_t plist_id, H5T_cset_t *encoding) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_char_encoding(plist_id, encoding)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2944
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_char_encoding(plist_id, encoding)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_char_encoding(__pyx_v_plist_id, __pyx_v_encoding);

  /* "h5py/defs.pyx":2945
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_char_encoding(plist_id, encoding)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2946
 *     r = _hdf5.H5Pget_char_encoding(plist_id, encoding)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2946, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2947
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_char_encoding (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2946
 *     r = _hdf5.H5Pget_char_encoding(plist_id, encoding)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2949
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_char_encoding (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__250, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2949, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2945
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_char_encoding(plist_id, encoding)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2950
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_char_encoding (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_attr_creation_order(hid_t plist_id, unsigned crt_order_flags) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2941
 *     return r
 * 
 * cdef herr_t H5Pget_char_encoding(hid_t plist_id, H5T_cset_t *encoding) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_char_encoding", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2952
 *     return r
 * 
 * cdef herr_t H5Pset_attr_creation_order(hid_t plist_id, unsigned crt_order_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_attr_creation_order(hid_t __pyx_v_plist_id, unsigned int __pyx_v_crt_order_flags) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_attr_creation_order", 0);

  /* "h5py/defs.pyx":2954
 * cdef herr_t H5Pset_attr_creation_order(hid_t plist_id, unsigned crt_order_flags) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2955
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_attr_creation_order(plist_id, crt_order_flags)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_attr_creation_order(__pyx_v_plist_id, __pyx_v_crt_order_flags);

  /* "h5py/defs.pyx":2956
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2957
 *     r = _hdf5.H5Pset_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2957, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2958
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_attr_creation_order (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2957
 *     r = _hdf5.H5Pset_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2960
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_attr_creation_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__251, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2960, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2960, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2956
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2961
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_attr_creation_order (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_attr_creation_order(hid_t plist_id, unsigned *crt_order_flags) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2952
 *     return r
 * 
 * cdef herr_t H5Pset_attr_creation_order(hid_t plist_id, unsigned crt_order_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_attr_creation_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2963
 *     return r
 * 
 * cdef herr_t H5Pget_attr_creation_order(hid_t plist_id, unsigned *crt_order_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_attr_creation_order(hid_t __pyx_v_plist_id, unsigned int *__pyx_v_crt_order_flags) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_attr_creation_order", 0);

  /* "h5py/defs.pyx":2965
 * cdef herr_t H5Pget_attr_creation_order(hid_t plist_id, unsigned *crt_order_flags) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2966
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_attr_creation_order(plist_id, crt_order_flags)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_attr_creation_order(__pyx_v_plist_id, __pyx_v_crt_order_flags);

  /* "h5py/defs.pyx":2967
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2968
 *     r = _hdf5.H5Pget_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2968, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2969
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_attr_creation_order (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2968
 *     r = _hdf5.H5Pget_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2971
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_attr_creation_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__252, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2971, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2971, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2967
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_attr_creation_order(plist_id, crt_order_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2972
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_attr_creation_order (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_obj_track_times( hid_t ocpl_id, hbool_t track_times ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2963
 *     return r
 * 
 * cdef herr_t H5Pget_attr_creation_order(hid_t plist_id, unsigned *crt_order_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_attr_creation_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2974
 *     return r
 * 
 * cdef herr_t H5Pset_obj_track_times( hid_t ocpl_id, hbool_t track_times ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_obj_track_times(hid_t __pyx_v_ocpl_id, hbool_t __pyx_v_track_times) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_obj_track_times", 0);

  /* "h5py/defs.pyx":2976
 * cdef herr_t H5Pset_obj_track_times( hid_t ocpl_id, hbool_t track_times ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_obj_track_times(ocpl_id, track_times)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2977
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_obj_track_times(ocpl_id, track_times)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_obj_track_times(__pyx_v_ocpl_id, __pyx_v_track_times);

  /* "h5py/defs.pyx":2978
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_obj_track_times(ocpl_id, track_times)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2979
 *     r = _hdf5.H5Pset_obj_track_times(ocpl_id, track_times)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2979, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2980
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_obj_track_times (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2979
 *     r = _hdf5.H5Pset_obj_track_times(ocpl_id, track_times)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2982
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_obj_track_times (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__253, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2982, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2978
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_obj_track_times(ocpl_id, track_times)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2983
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_obj_track_times (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_obj_track_times( hid_t ocpl_id, hbool_t *track_times ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2974
 *     return r
 * 
 * cdef herr_t H5Pset_obj_track_times( hid_t ocpl_id, hbool_t track_times ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_obj_track_times", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2985
 *     return r
 * 
 * cdef herr_t H5Pget_obj_track_times( hid_t ocpl_id, hbool_t *track_times ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_obj_track_times(hid_t __pyx_v_ocpl_id, hbool_t *__pyx_v_track_times) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_obj_track_times", 0);

  /* "h5py/defs.pyx":2987
 * cdef herr_t H5Pget_obj_track_times( hid_t ocpl_id, hbool_t *track_times ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_obj_track_times(ocpl_id, track_times)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2988
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_obj_track_times(ocpl_id, track_times)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_obj_track_times(__pyx_v_ocpl_id, __pyx_v_track_times);

  /* "h5py/defs.pyx":2989
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_obj_track_times(ocpl_id, track_times)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":2990
 *     r = _hdf5.H5Pget_obj_track_times(ocpl_id, track_times)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2990, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":2991
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_obj_track_times (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":2990
 *     r = _hdf5.H5Pget_obj_track_times(ocpl_id, track_times)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":2993
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_obj_track_times (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__254, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2993, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":2989
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_obj_track_times(ocpl_id, track_times)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":2994
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_obj_track_times (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_local_heap_size_hint(hid_t plist_id, size_t size_hint) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2985
 *     return r
 * 
 * cdef herr_t H5Pget_obj_track_times( hid_t ocpl_id, hbool_t *track_times ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_obj_track_times", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":2996
 *     return r
 * 
 * cdef herr_t H5Pset_local_heap_size_hint(hid_t plist_id, size_t size_hint) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_local_heap_size_hint(hid_t __pyx_v_plist_id, size_t __pyx_v_size_hint) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_local_heap_size_hint", 0);

  /* "h5py/defs.pyx":2998
 * cdef herr_t H5Pset_local_heap_size_hint(hid_t plist_id, size_t size_hint) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":2999
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_local_heap_size_hint(plist_id, size_hint)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_local_heap_size_hint(__pyx_v_plist_id, __pyx_v_size_hint);

  /* "h5py/defs.pyx":3000
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3001
 *     r = _hdf5.H5Pset_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3001, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3002
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_local_heap_size_hint (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3001
 *     r = _hdf5.H5Pset_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3004
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_local_heap_size_hint (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__255, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3004, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3004, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3000
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3005
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_local_heap_size_hint (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_local_heap_size_hint(hid_t plist_id, size_t *size_hint) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":2996
 *     return r
 * 
 * cdef herr_t H5Pset_local_heap_size_hint(hid_t plist_id, size_t size_hint) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_local_heap_size_hint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3007
 *     return r
 * 
 * cdef herr_t H5Pget_local_heap_size_hint(hid_t plist_id, size_t *size_hint) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_local_heap_size_hint(hid_t __pyx_v_plist_id, size_t *__pyx_v_size_hint) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_local_heap_size_hint", 0);

  /* "h5py/defs.pyx":3009
 * cdef herr_t H5Pget_local_heap_size_hint(hid_t plist_id, size_t *size_hint) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3010
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_local_heap_size_hint(plist_id, size_hint)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_local_heap_size_hint(__pyx_v_plist_id, __pyx_v_size_hint);

  /* "h5py/defs.pyx":3011
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3012
 *     r = _hdf5.H5Pget_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3012, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3013
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_local_heap_size_hint (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3012
 *     r = _hdf5.H5Pget_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3015
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_local_heap_size_hint (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__256, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3015, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3011
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_local_heap_size_hint(plist_id, size_hint)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3016
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_local_heap_size_hint (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_link_phase_change(hid_t plist_id, unsigned max_compact, unsigned min_dense) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3007
 *     return r
 * 
 * cdef herr_t H5Pget_local_heap_size_hint(hid_t plist_id, size_t *size_hint) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_local_heap_size_hint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3018
 *     return r
 * 
 * cdef herr_t H5Pset_link_phase_change(hid_t plist_id, unsigned max_compact, unsigned min_dense) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_link_phase_change(hid_t __pyx_v_plist_id, unsigned int __pyx_v_max_compact, unsigned int __pyx_v_min_dense) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_link_phase_change", 0);

  /* "h5py/defs.pyx":3020
 * cdef herr_t H5Pset_link_phase_change(hid_t plist_id, unsigned max_compact, unsigned min_dense) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3021
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_link_phase_change(plist_id, max_compact, min_dense)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_link_phase_change(__pyx_v_plist_id, __pyx_v_max_compact, __pyx_v_min_dense);

  /* "h5py/defs.pyx":3022
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3023
 *     r = _hdf5.H5Pset_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3023, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3024
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_link_phase_change (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3023
 *     r = _hdf5.H5Pset_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3026
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_link_phase_change (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__257, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3026, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3026, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3022
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3027
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_link_phase_change (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_link_phase_change(hid_t plist_id, unsigned *max_compact , unsigned *min_dense) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3018
 *     return r
 * 
 * cdef herr_t H5Pset_link_phase_change(hid_t plist_id, unsigned max_compact, unsigned min_dense) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_link_phase_change", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3029
 *     return r
 * 
 * cdef herr_t H5Pget_link_phase_change(hid_t plist_id, unsigned *max_compact , unsigned *min_dense) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_link_phase_change(hid_t __pyx_v_plist_id, unsigned int *__pyx_v_max_compact, unsigned int *__pyx_v_min_dense) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_link_phase_change", 0);

  /* "h5py/defs.pyx":3031
 * cdef herr_t H5Pget_link_phase_change(hid_t plist_id, unsigned *max_compact , unsigned *min_dense) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3032
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_link_phase_change(plist_id, max_compact, min_dense)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_link_phase_change(__pyx_v_plist_id, __pyx_v_max_compact, __pyx_v_min_dense);

  /* "h5py/defs.pyx":3033
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3034
 *     r = _hdf5.H5Pget_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3034, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3035
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_link_phase_change (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3034
 *     r = _hdf5.H5Pget_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3037
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_link_phase_change (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__258, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3037, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3037, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3033
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_link_phase_change(plist_id, max_compact, min_dense)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3038
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_link_phase_change (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_attr_phase_change(hid_t ocpl_id, unsigned max_compact, unsigned min_dense) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3029
 *     return r
 * 
 * cdef herr_t H5Pget_link_phase_change(hid_t plist_id, unsigned *max_compact , unsigned *min_dense) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_link_phase_change", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3040
 *     return r
 * 
 * cdef herr_t H5Pset_attr_phase_change(hid_t ocpl_id, unsigned max_compact, unsigned min_dense) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_attr_phase_change(hid_t __pyx_v_ocpl_id, unsigned int __pyx_v_max_compact, unsigned int __pyx_v_min_dense) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_attr_phase_change", 0);

  /* "h5py/defs.pyx":3042
 * cdef herr_t H5Pset_attr_phase_change(hid_t ocpl_id, unsigned max_compact, unsigned min_dense) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3043
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_attr_phase_change(ocpl_id, max_compact, min_dense)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_attr_phase_change(__pyx_v_ocpl_id, __pyx_v_max_compact, __pyx_v_min_dense);

  /* "h5py/defs.pyx":3044
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3045
 *     r = _hdf5.H5Pset_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3045, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3046
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_attr_phase_change (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3045
 *     r = _hdf5.H5Pset_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3048
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_attr_phase_change (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__259, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3048, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3048, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3044
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3049
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_attr_phase_change (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_attr_phase_change(hid_t ocpl_id, unsigned *max_compact , unsigned *min_dense) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3040
 *     return r
 * 
 * cdef herr_t H5Pset_attr_phase_change(hid_t ocpl_id, unsigned max_compact, unsigned min_dense) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_attr_phase_change", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3051
 *     return r
 * 
 * cdef herr_t H5Pget_attr_phase_change(hid_t ocpl_id, unsigned *max_compact , unsigned *min_dense) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_attr_phase_change(hid_t __pyx_v_ocpl_id, unsigned int *__pyx_v_max_compact, unsigned int *__pyx_v_min_dense) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_attr_phase_change", 0);

  /* "h5py/defs.pyx":3053
 * cdef herr_t H5Pget_attr_phase_change(hid_t ocpl_id, unsigned *max_compact , unsigned *min_dense) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3054
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_attr_phase_change(ocpl_id, max_compact, min_dense)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_attr_phase_change(__pyx_v_ocpl_id, __pyx_v_max_compact, __pyx_v_min_dense);

  /* "h5py/defs.pyx":3055
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3056
 *     r = _hdf5.H5Pget_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3056, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3057
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_attr_phase_change (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3056
 *     r = _hdf5.H5Pget_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3059
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_attr_phase_change (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__260, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3059, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3059, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3055
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_attr_phase_change(ocpl_id, max_compact, min_dense)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3060
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_attr_phase_change (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_est_link_info(hid_t plist_id, unsigned est_num_entries, unsigned est_name_len) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3051
 *     return r
 * 
 * cdef herr_t H5Pget_attr_phase_change(hid_t ocpl_id, unsigned *max_compact , unsigned *min_dense) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_attr_phase_change", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3062
 *     return r
 * 
 * cdef herr_t H5Pset_est_link_info(hid_t plist_id, unsigned est_num_entries, unsigned est_name_len) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_est_link_info(hid_t __pyx_v_plist_id, unsigned int __pyx_v_est_num_entries, unsigned int __pyx_v_est_name_len) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_est_link_info", 0);

  /* "h5py/defs.pyx":3064
 * cdef herr_t H5Pset_est_link_info(hid_t plist_id, unsigned est_num_entries, unsigned est_name_len) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3065
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_est_link_info(plist_id, est_num_entries, est_name_len)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_est_link_info(__pyx_v_plist_id, __pyx_v_est_num_entries, __pyx_v_est_name_len);

  /* "h5py/defs.pyx":3066
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3067
 *     r = _hdf5.H5Pset_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3067, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3068
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_est_link_info (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3067
 *     r = _hdf5.H5Pset_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3070
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_est_link_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__261, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3070, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3070, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3066
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3071
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_est_link_info (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_est_link_info(hid_t plist_id, unsigned *est_num_entries , unsigned *est_name_len) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3062
 *     return r
 * 
 * cdef herr_t H5Pset_est_link_info(hid_t plist_id, unsigned est_num_entries, unsigned est_name_len) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_est_link_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3073
 *     return r
 * 
 * cdef herr_t H5Pget_est_link_info(hid_t plist_id, unsigned *est_num_entries , unsigned *est_name_len) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_est_link_info(hid_t __pyx_v_plist_id, unsigned int *__pyx_v_est_num_entries, unsigned int *__pyx_v_est_name_len) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_est_link_info", 0);

  /* "h5py/defs.pyx":3075
 * cdef herr_t H5Pget_est_link_info(hid_t plist_id, unsigned *est_num_entries , unsigned *est_name_len) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3076
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_est_link_info(plist_id, est_num_entries, est_name_len)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_est_link_info(__pyx_v_plist_id, __pyx_v_est_num_entries, __pyx_v_est_name_len);

  /* "h5py/defs.pyx":3077
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3078
 *     r = _hdf5.H5Pget_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3078, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3079
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_est_link_info (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3078
 *     r = _hdf5.H5Pget_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3081
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_est_link_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__262, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3081, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3077
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_est_link_info(plist_id, est_num_entries, est_name_len)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3082
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_est_link_info (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_link_creation_order(hid_t plist_id, unsigned crt_order_flags) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3073
 *     return r
 * 
 * cdef herr_t H5Pget_est_link_info(hid_t plist_id, unsigned *est_num_entries , unsigned *est_name_len) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_est_link_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3084
 *     return r
 * 
 * cdef herr_t H5Pset_link_creation_order(hid_t plist_id, unsigned crt_order_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_link_creation_order(hid_t __pyx_v_plist_id, unsigned int __pyx_v_crt_order_flags) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_link_creation_order", 0);

  /* "h5py/defs.pyx":3086
 * cdef herr_t H5Pset_link_creation_order(hid_t plist_id, unsigned crt_order_flags) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3087
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_link_creation_order(plist_id, crt_order_flags)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_link_creation_order(__pyx_v_plist_id, __pyx_v_crt_order_flags);

  /* "h5py/defs.pyx":3088
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3089
 *     r = _hdf5.H5Pset_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3089, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3090
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_link_creation_order (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3089
 *     r = _hdf5.H5Pset_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3092
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_link_creation_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__263, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3092, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3092, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3088
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3093
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_link_creation_order (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_link_creation_order(hid_t plist_id, unsigned *crt_order_flags) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3084
 *     return r
 * 
 * cdef herr_t H5Pset_link_creation_order(hid_t plist_id, unsigned crt_order_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_link_creation_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3095
 *     return r
 * 
 * cdef herr_t H5Pget_link_creation_order(hid_t plist_id, unsigned *crt_order_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_link_creation_order(hid_t __pyx_v_plist_id, unsigned int *__pyx_v_crt_order_flags) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_link_creation_order", 0);

  /* "h5py/defs.pyx":3097
 * cdef herr_t H5Pget_link_creation_order(hid_t plist_id, unsigned *crt_order_flags) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3098
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_link_creation_order(plist_id, crt_order_flags)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_link_creation_order(__pyx_v_plist_id, __pyx_v_crt_order_flags);

  /* "h5py/defs.pyx":3099
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3100
 *     r = _hdf5.H5Pget_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3100, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3101
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_link_creation_order (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3100
 *     r = _hdf5.H5Pget_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3103
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_link_creation_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__264, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3103, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3103, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3099
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_link_creation_order(plist_id, crt_order_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3104
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_link_creation_order (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_libver_bounds(hid_t fapl_id, H5F_libver_t libver_low, H5F_libver_t libver_high) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3095
 *     return r
 * 
 * cdef herr_t H5Pget_link_creation_order(hid_t plist_id, unsigned *crt_order_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_link_creation_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3106
 *     return r
 * 
 * cdef herr_t H5Pset_libver_bounds(hid_t fapl_id, H5F_libver_t libver_low, H5F_libver_t libver_high) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_libver_bounds(hid_t __pyx_v_fapl_id, H5F_libver_t __pyx_v_libver_low, H5F_libver_t __pyx_v_libver_high) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_libver_bounds", 0);

  /* "h5py/defs.pyx":3108
 * cdef herr_t H5Pset_libver_bounds(hid_t fapl_id, H5F_libver_t libver_low, H5F_libver_t libver_high) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3109
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_libver_bounds(fapl_id, libver_low, libver_high)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_libver_bounds(__pyx_v_fapl_id, __pyx_v_libver_low, __pyx_v_libver_high);

  /* "h5py/defs.pyx":3110
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3111
 *     r = _hdf5.H5Pset_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3111, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3112
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_libver_bounds (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3111
 *     r = _hdf5.H5Pset_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3114
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_libver_bounds (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__265, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3114, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3110
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3115
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_libver_bounds (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_libver_bounds(hid_t fapl_id, H5F_libver_t *libver_low, H5F_libver_t *libver_high) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3106
 *     return r
 * 
 * cdef herr_t H5Pset_libver_bounds(hid_t fapl_id, H5F_libver_t libver_low, H5F_libver_t libver_high) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_libver_bounds", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3117
 *     return r
 * 
 * cdef herr_t H5Pget_libver_bounds(hid_t fapl_id, H5F_libver_t *libver_low, H5F_libver_t *libver_high) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_libver_bounds(hid_t __pyx_v_fapl_id, H5F_libver_t *__pyx_v_libver_low, H5F_libver_t *__pyx_v_libver_high) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_libver_bounds", 0);

  /* "h5py/defs.pyx":3119
 * cdef herr_t H5Pget_libver_bounds(hid_t fapl_id, H5F_libver_t *libver_low, H5F_libver_t *libver_high) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3120
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_libver_bounds(fapl_id, libver_low, libver_high)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_libver_bounds(__pyx_v_fapl_id, __pyx_v_libver_low, __pyx_v_libver_high);

  /* "h5py/defs.pyx":3121
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3122
 *     r = _hdf5.H5Pget_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3122, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3123
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_libver_bounds (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3122
 *     r = _hdf5.H5Pget_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3125
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_libver_bounds (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__266, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3125, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3125, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3121
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_libver_bounds(fapl_id, libver_low, libver_high)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3126
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_libver_bounds (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pset_alignment(hid_t plist_id, hsize_t threshold, hsize_t alignment) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3117
 *     return r
 * 
 * cdef herr_t H5Pget_libver_bounds(hid_t fapl_id, H5F_libver_t *libver_low, H5F_libver_t *libver_high) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_libver_bounds", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3128
 *     return r
 * 
 * cdef herr_t H5Pset_alignment(hid_t plist_id, hsize_t threshold, hsize_t alignment) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pset_alignment(hid_t __pyx_v_plist_id, hsize_t __pyx_v_threshold, hsize_t __pyx_v_alignment) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pset_alignment", 0);

  /* "h5py/defs.pyx":3130
 * cdef herr_t H5Pset_alignment(hid_t plist_id, hsize_t threshold, hsize_t alignment) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pset_alignment(plist_id, threshold, alignment)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3131
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_alignment(plist_id, threshold, alignment)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pset_alignment(__pyx_v_plist_id, __pyx_v_threshold, __pyx_v_alignment);

  /* "h5py/defs.pyx":3132
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_alignment(plist_id, threshold, alignment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3133
 *     r = _hdf5.H5Pset_alignment(plist_id, threshold, alignment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3133, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3134
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_alignment (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3133
 *     r = _hdf5.H5Pset_alignment(plist_id, threshold, alignment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3136
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_alignment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__267, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3136, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3132
 *     set_default_error_handler()
 *     r = _hdf5.H5Pset_alignment(plist_id, threshold, alignment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3137
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_alignment (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Pget_alignment(hid_t plist_id, hsize_t *threshold, hsize_t *alignment) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3128
 *     return r
 * 
 * cdef herr_t H5Pset_alignment(hid_t plist_id, hsize_t threshold, hsize_t alignment) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pset_alignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3139
 *     return r
 * 
 * cdef herr_t H5Pget_alignment(hid_t plist_id, hsize_t *threshold, hsize_t *alignment) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Pget_alignment(hid_t __pyx_v_plist_id, hsize_t *__pyx_v_threshold, hsize_t *__pyx_v_alignment) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Pget_alignment", 0);

  /* "h5py/defs.pyx":3141
 * cdef herr_t H5Pget_alignment(hid_t plist_id, hsize_t *threshold, hsize_t *alignment) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Pget_alignment(plist_id, threshold, alignment)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3142
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_alignment(plist_id, threshold, alignment)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Pget_alignment(__pyx_v_plist_id, __pyx_v_threshold, __pyx_v_alignment);

  /* "h5py/defs.pyx":3143
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_alignment(plist_id, threshold, alignment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3144
 *     r = _hdf5.H5Pget_alignment(plist_id, threshold, alignment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3144, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3145
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_alignment (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3144
 *     r = _hdf5.H5Pget_alignment(plist_id, threshold, alignment)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3147
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_alignment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__268, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3147, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3143
 *     set_default_error_handler()
 *     r = _hdf5.H5Pget_alignment(plist_id, threshold, alignment)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3148
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_alignment (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF MPI:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3139
 *     return r
 * 
 * cdef herr_t H5Pget_alignment(hid_t plist_id, hsize_t *threshold, hsize_t *alignment) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Pget_alignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3175
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLappend(const char *search_path) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5PLappend(char const *__pyx_v_search_path) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5PLappend", 0);

  /* "h5py/defs.pyx":3177
 *     cdef herr_t H5PLappend(const char *search_path) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5PLappend(search_path)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3178
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5PLappend(search_path)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5PLappend(__pyx_v_search_path);

  /* "h5py/defs.pyx":3179
 *         set_default_error_handler()
 *         r = _hdf5.H5PLappend(search_path)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3180
 *         r = _hdf5.H5PLappend(search_path)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3180, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3181
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLappend (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3180
 *         r = _hdf5.H5PLappend(search_path)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3183
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLappend (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__269, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3183, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3179
 *         set_default_error_handler()
 *         r = _hdf5.H5PLappend(search_path)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3184
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLappend (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3175
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLappend(const char *search_path) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5PLappend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3187
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLprepend(const char *search_path) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5PLprepend(char const *__pyx_v_search_path) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5PLprepend", 0);

  /* "h5py/defs.pyx":3189
 *     cdef herr_t H5PLprepend(const char *search_path) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5PLprepend(search_path)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3190
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5PLprepend(search_path)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5PLprepend(__pyx_v_search_path);

  /* "h5py/defs.pyx":3191
 *         set_default_error_handler()
 *         r = _hdf5.H5PLprepend(search_path)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3192
 *         r = _hdf5.H5PLprepend(search_path)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3192, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3193
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLprepend (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3192
 *         r = _hdf5.H5PLprepend(search_path)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3195
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLprepend (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__270, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3195, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3191
 *         set_default_error_handler()
 *         r = _hdf5.H5PLprepend(search_path)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3196
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLprepend (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3187
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLprepend(const char *search_path) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5PLprepend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3199
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLreplace(const char *search_path, unsigned int index) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5PLreplace(char const *__pyx_v_search_path, unsigned int __pyx_v_index) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5PLreplace", 0);

  /* "h5py/defs.pyx":3201
 *     cdef herr_t H5PLreplace(const char *search_path, unsigned int index) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5PLreplace(search_path, index)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3202
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5PLreplace(search_path, index)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5PLreplace(__pyx_v_search_path, __pyx_v_index);

  /* "h5py/defs.pyx":3203
 *         set_default_error_handler()
 *         r = _hdf5.H5PLreplace(search_path, index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3204
 *         r = _hdf5.H5PLreplace(search_path, index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3204, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3205
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLreplace (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3204
 *         r = _hdf5.H5PLreplace(search_path, index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3207
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLreplace (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__271, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3207, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3203
 *         set_default_error_handler()
 *         r = _hdf5.H5PLreplace(search_path, index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3208
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLreplace (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3199
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLreplace(const char *search_path, unsigned int index) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5PLreplace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3211
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLinsert(const char *search_path, unsigned int index) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5PLinsert(char const *__pyx_v_search_path, unsigned int __pyx_v_index) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5PLinsert", 0);

  /* "h5py/defs.pyx":3213
 *     cdef herr_t H5PLinsert(const char *search_path, unsigned int index) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5PLinsert(search_path, index)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3214
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5PLinsert(search_path, index)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5PLinsert(__pyx_v_search_path, __pyx_v_index);

  /* "h5py/defs.pyx":3215
 *         set_default_error_handler()
 *         r = _hdf5.H5PLinsert(search_path, index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3216
 *         r = _hdf5.H5PLinsert(search_path, index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3216, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3217
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLinsert (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3216
 *         r = _hdf5.H5PLinsert(search_path, index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3219
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLinsert (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__272, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3219, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3215
 *         set_default_error_handler()
 *         r = _hdf5.H5PLinsert(search_path, index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3220
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLinsert (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3211
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLinsert(const char *search_path, unsigned int index) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5PLinsert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3223
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLremove(unsigned int index) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5PLremove(unsigned int __pyx_v_index) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5PLremove", 0);

  /* "h5py/defs.pyx":3225
 *     cdef herr_t H5PLremove(unsigned int index) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5PLremove(index)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3226
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5PLremove(index)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5PLremove(__pyx_v_index);

  /* "h5py/defs.pyx":3227
 *         set_default_error_handler()
 *         r = _hdf5.H5PLremove(index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3228
 *         r = _hdf5.H5PLremove(index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3228, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3229
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLremove (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3228
 *         r = _hdf5.H5PLremove(index)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3231
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLremove (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__273, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3231, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3227
 *         set_default_error_handler()
 *         r = _hdf5.H5PLremove(index)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3232
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLremove (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3223
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLremove(unsigned int index) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5PLremove", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3235
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef ssize_t H5PLget(unsigned int index, char *path_buf, size_t buf_size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5PLget(unsigned int __pyx_v_index, char *__pyx_v_path_buf, size_t __pyx_v_buf_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5PLget", 0);

  /* "h5py/defs.pyx":3237
 *     cdef ssize_t H5PLget(unsigned int index, char *path_buf, size_t buf_size) except <ssize_t>-1:
 *         cdef ssize_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5PLget(index, path_buf, buf_size)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3238
 *         cdef ssize_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5PLget(index, path_buf, buf_size)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5PLget(__pyx_v_index, __pyx_v_path_buf, __pyx_v_buf_size);

  /* "h5py/defs.pyx":3239
 *         set_default_error_handler()
 *         r = _hdf5.H5PLget(index, path_buf, buf_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3240
 *         r = _hdf5.H5PLget(index, path_buf, buf_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3240, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3241
 *         if r<0:
 *             if set_exception():
 *                 return <ssize_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLget (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3240
 *         r = _hdf5.H5PLget(index, path_buf, buf_size)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <ssize_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3243
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLget (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__274, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3243, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3243, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3239
 *         set_default_error_handler()
 *         r = _hdf5.H5PLget(index, path_buf, buf_size)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":3244
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLget (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3235
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef ssize_t H5PLget(unsigned int index, char *path_buf, size_t buf_size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *         cdef ssize_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5PLget", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3247
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLsize(unsigned int *num_paths) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5PLsize(unsigned int *__pyx_v_num_paths) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5PLsize", 0);

  /* "h5py/defs.pyx":3249
 *     cdef herr_t H5PLsize(unsigned int *num_paths) except <herr_t>-1:
 *         cdef herr_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5PLsize(num_paths)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3250
 *         cdef herr_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5PLsize(num_paths)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5PLsize(__pyx_v_num_paths);

  /* "h5py/defs.pyx":3251
 *         set_default_error_handler()
 *         r = _hdf5.H5PLsize(num_paths)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3252
 *         r = _hdf5.H5PLsize(num_paths)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3252, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3253
 *         if r<0:
 *             if set_exception():
 *                 return <herr_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLsize (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3252
 *         r = _hdf5.H5PLsize(num_paths)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <herr_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3255
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLsize (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__275, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3255, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3255, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3251
 *         set_default_error_handler()
 *         r = _hdf5.H5PLsize(num_paths)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3256
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLsize (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Rcreate(void *ref, hid_t loc_id, char *name, H5R_type_t ref_type,  hid_t space_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3247
 * 
 * IF HDF5_VERSION >= (1, 10, 1):
 *     cdef herr_t H5PLsize(unsigned int *num_paths) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *         cdef herr_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5PLsize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3258
 *         return r
 * 
 * cdef herr_t H5Rcreate(void *ref, hid_t loc_id, char *name, H5R_type_t ref_type,  hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Rcreate(void *__pyx_v_ref, hid_t __pyx_v_loc_id, char *__pyx_v_name, H5R_type_t __pyx_v_ref_type, hid_t __pyx_v_space_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Rcreate", 0);

  /* "h5py/defs.pyx":3260
 * cdef herr_t H5Rcreate(void *ref, hid_t loc_id, char *name, H5R_type_t ref_type,  hid_t space_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Rcreate(ref, loc_id, name, ref_type, space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3261
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Rcreate(ref, loc_id, name, ref_type, space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Rcreate(__pyx_v_ref, __pyx_v_loc_id, __pyx_v_name, __pyx_v_ref_type, __pyx_v_space_id);

  /* "h5py/defs.pyx":3262
 *     set_default_error_handler()
 *     r = _hdf5.H5Rcreate(ref, loc_id, name, ref_type, space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3263
 *     r = _hdf5.H5Rcreate(ref, loc_id, name, ref_type, space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3263, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3264
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rcreate (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3263
 *     r = _hdf5.H5Rcreate(ref, loc_id, name, ref_type, space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3266
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__276, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3266, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3262
 *     set_default_error_handler()
 *     r = _hdf5.H5Rcreate(ref, loc_id, name, ref_type, space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3267
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rcreate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Rdereference(hid_t obj_id, H5R_type_t ref_type, void *ref) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3258
 *         return r
 * 
 * cdef herr_t H5Rcreate(void *ref, hid_t loc_id, char *name, H5R_type_t ref_type,  hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Rcreate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3269
 *     return r
 * 
 * cdef hid_t H5Rdereference(hid_t obj_id, H5R_type_t ref_type, void *ref) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Rdereference(hid_t __pyx_v_obj_id, H5R_type_t __pyx_v_ref_type, void *__pyx_v_ref) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Rdereference", 0);

  /* "h5py/defs.pyx":3271
 * cdef hid_t H5Rdereference(hid_t obj_id, H5R_type_t ref_type, void *ref) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Rdereference(obj_id, ref_type, ref)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3272
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Rdereference(obj_id, ref_type, ref)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Rdereference(__pyx_v_obj_id, __pyx_v_ref_type, __pyx_v_ref);

  /* "h5py/defs.pyx":3273
 *     set_default_error_handler()
 *     r = _hdf5.H5Rdereference(obj_id, ref_type, ref)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3274
 *     r = _hdf5.H5Rdereference(obj_id, ref_type, ref)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3274, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3275
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rdereference (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3274
 *     r = _hdf5.H5Rdereference(obj_id, ref_type, ref)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3277
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rdereference (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__277, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3277, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3273
 *     set_default_error_handler()
 *     r = _hdf5.H5Rdereference(obj_id, ref_type, ref)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3278
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rdereference (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Rget_region(hid_t dataset, H5R_type_t ref_type, void *ref) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3269
 *     return r
 * 
 * cdef hid_t H5Rdereference(hid_t obj_id, H5R_type_t ref_type, void *ref) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Rdereference", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3280
 *     return r
 * 
 * cdef hid_t H5Rget_region(hid_t dataset, H5R_type_t ref_type, void *ref) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Rget_region(hid_t __pyx_v_dataset, H5R_type_t __pyx_v_ref_type, void *__pyx_v_ref) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Rget_region", 0);

  /* "h5py/defs.pyx":3282
 * cdef hid_t H5Rget_region(hid_t dataset, H5R_type_t ref_type, void *ref) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Rget_region(dataset, ref_type, ref)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3283
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_region(dataset, ref_type, ref)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Rget_region(__pyx_v_dataset, __pyx_v_ref_type, __pyx_v_ref);

  /* "h5py/defs.pyx":3284
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_region(dataset, ref_type, ref)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3285
 *     r = _hdf5.H5Rget_region(dataset, ref_type, ref)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3285, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3286
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_region (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3285
 *     r = _hdf5.H5Rget_region(dataset, ref_type, ref)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3288
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_region (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__278, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3288, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3288, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3284
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_region(dataset, ref_type, ref)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3289
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_region (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Rget_obj_type(hid_t id, H5R_type_t ref_type, void *ref, H5O_type_t *obj_type) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3280
 *     return r
 * 
 * cdef hid_t H5Rget_region(hid_t dataset, H5R_type_t ref_type, void *ref) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Rget_region", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3291
 *     return r
 * 
 * cdef herr_t H5Rget_obj_type(hid_t id, H5R_type_t ref_type, void *ref, H5O_type_t *obj_type) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Rget_obj_type(hid_t __pyx_v_id, H5R_type_t __pyx_v_ref_type, void *__pyx_v_ref, H5O_type_t *__pyx_v_obj_type) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Rget_obj_type", 0);

  /* "h5py/defs.pyx":3293
 * cdef herr_t H5Rget_obj_type(hid_t id, H5R_type_t ref_type, void *ref, H5O_type_t *obj_type) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Rget_obj_type(id, ref_type, ref, obj_type)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3294
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_obj_type(id, ref_type, ref, obj_type)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Rget_obj_type(__pyx_v_id, __pyx_v_ref_type, __pyx_v_ref, __pyx_v_obj_type);

  /* "h5py/defs.pyx":3295
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_obj_type(id, ref_type, ref, obj_type)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3296
 *     r = _hdf5.H5Rget_obj_type(id, ref_type, ref, obj_type)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3296, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3297
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_obj_type (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3296
 *     r = _hdf5.H5Rget_obj_type(id, ref_type, ref, obj_type)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3299
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_obj_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__279, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3299, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3299, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3295
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_obj_type(id, ref_type, ref, obj_type)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3300
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_obj_type (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5Rget_name(hid_t loc_id, H5R_type_t ref_type, void *ref, char *name, size_t size) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3291
 *     return r
 * 
 * cdef herr_t H5Rget_obj_type(hid_t id, H5R_type_t ref_type, void *ref, H5O_type_t *obj_type) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Rget_obj_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3302
 *     return r
 * 
 * cdef ssize_t H5Rget_name(hid_t loc_id, H5R_type_t ref_type, void *ref, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5Rget_name(hid_t __pyx_v_loc_id, H5R_type_t __pyx_v_ref_type, void *__pyx_v_ref, char *__pyx_v_name, size_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Rget_name", 0);

  /* "h5py/defs.pyx":3304
 * cdef ssize_t H5Rget_name(hid_t loc_id, H5R_type_t ref_type, void *ref, char *name, size_t size) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Rget_name(loc_id, ref_type, ref, name, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3305
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_name(loc_id, ref_type, ref, name, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Rget_name(__pyx_v_loc_id, __pyx_v_ref_type, __pyx_v_ref, __pyx_v_name, __pyx_v_size);

  /* "h5py/defs.pyx":3306
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_name(loc_id, ref_type, ref, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3307
 *     r = _hdf5.H5Rget_name(loc_id, ref_type, ref, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3307, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3308
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_name (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3307
 *     r = _hdf5.H5Rget_name(loc_id, ref_type, ref, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3310
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__280, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3310, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3306
 *     set_default_error_handler()
 *     r = _hdf5.H5Rget_name(loc_id, ref_type, ref, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":3311
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Screate(H5S_class_t type) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3302
 *     return r
 * 
 * cdef ssize_t H5Rget_name(hid_t loc_id, H5R_type_t ref_type, void *ref, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Rget_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3313
 *     return r
 * 
 * cdef hid_t H5Screate(H5S_class_t type) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Screate(H5S_class_t __pyx_v_type) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Screate", 0);

  /* "h5py/defs.pyx":3315
 * cdef hid_t H5Screate(H5S_class_t type) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Screate(type)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3316
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Screate(type)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Screate(__pyx_v_type);

  /* "h5py/defs.pyx":3317
 *     set_default_error_handler()
 *     r = _hdf5.H5Screate(type)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3318
 *     r = _hdf5.H5Screate(type)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3318, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3319
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Screate (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3318
 *     r = _hdf5.H5Screate(type)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3321
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Screate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__281, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3321, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3317
 *     set_default_error_handler()
 *     r = _hdf5.H5Screate(type)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3322
 *         else:
 *             raise RuntimeError("Unspecified error in H5Screate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Scopy(hid_t space_id ) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3313
 *     return r
 * 
 * cdef hid_t H5Screate(H5S_class_t type) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Screate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3324
 *     return r
 * 
 * cdef hid_t H5Scopy(hid_t space_id ) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Scopy(hid_t __pyx_v_space_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Scopy", 0);

  /* "h5py/defs.pyx":3326
 * cdef hid_t H5Scopy(hid_t space_id ) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Scopy(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3327
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Scopy(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Scopy(__pyx_v_space_id);

  /* "h5py/defs.pyx":3328
 *     set_default_error_handler()
 *     r = _hdf5.H5Scopy(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3329
 *     r = _hdf5.H5Scopy(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3329, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3330
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Scopy (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3329
 *     r = _hdf5.H5Scopy(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3332
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Scopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__282, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3332, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3332, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3328
 *     set_default_error_handler()
 *     r = _hdf5.H5Scopy(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3333
 *         else:
 *             raise RuntimeError("Unspecified error in H5Scopy (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sclose(hid_t space_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3324
 *     return r
 * 
 * cdef hid_t H5Scopy(hid_t space_id ) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Scopy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3335
 *     return r
 * 
 * cdef herr_t H5Sclose(hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sclose(hid_t __pyx_v_space_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sclose", 0);

  /* "h5py/defs.pyx":3337
 * cdef herr_t H5Sclose(hid_t space_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sclose(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3338
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sclose(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sclose(__pyx_v_space_id);

  /* "h5py/defs.pyx":3339
 *     set_default_error_handler()
 *     r = _hdf5.H5Sclose(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3340
 *     r = _hdf5.H5Sclose(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3340, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3341
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sclose (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3340
 *     r = _hdf5.H5Sclose(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3343
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__283, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3343, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3343, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3339
 *     set_default_error_handler()
 *     r = _hdf5.H5Sclose(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3344
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sclose (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Screate_simple(int rank, hsize_t *dims, hsize_t *maxdims) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3335
 *     return r
 * 
 * cdef herr_t H5Sclose(hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3346
 *     return r
 * 
 * cdef hid_t H5Screate_simple(int rank, hsize_t *dims, hsize_t *maxdims) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Screate_simple(int __pyx_v_rank, hsize_t *__pyx_v_dims, hsize_t *__pyx_v_maxdims) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Screate_simple", 0);

  /* "h5py/defs.pyx":3348
 * cdef hid_t H5Screate_simple(int rank, hsize_t *dims, hsize_t *maxdims) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Screate_simple(rank, dims, maxdims)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3349
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Screate_simple(rank, dims, maxdims)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Screate_simple(__pyx_v_rank, __pyx_v_dims, __pyx_v_maxdims);

  /* "h5py/defs.pyx":3350
 *     set_default_error_handler()
 *     r = _hdf5.H5Screate_simple(rank, dims, maxdims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3351
 *     r = _hdf5.H5Screate_simple(rank, dims, maxdims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3351, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3352
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Screate_simple (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3351
 *     r = _hdf5.H5Screate_simple(rank, dims, maxdims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3354
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Screate_simple (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__284, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3354, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3350
 *     set_default_error_handler()
 *     r = _hdf5.H5Screate_simple(rank, dims, maxdims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3355
 *         else:
 *             raise RuntimeError("Unspecified error in H5Screate_simple (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Sis_simple(hid_t space_id) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3346
 *     return r
 * 
 * cdef hid_t H5Screate_simple(int rank, hsize_t *dims, hsize_t *maxdims) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Screate_simple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3357
 *     return r
 * 
 * cdef htri_t H5Sis_simple(hid_t space_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Sis_simple(hid_t __pyx_v_space_id) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sis_simple", 0);

  /* "h5py/defs.pyx":3359
 * cdef htri_t H5Sis_simple(hid_t space_id) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sis_simple(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3360
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sis_simple(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sis_simple(__pyx_v_space_id);

  /* "h5py/defs.pyx":3361
 *     set_default_error_handler()
 *     r = _hdf5.H5Sis_simple(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3362
 *     r = _hdf5.H5Sis_simple(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3362, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3363
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sis_simple (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3362
 *     r = _hdf5.H5Sis_simple(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3365
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sis_simple (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__285, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3365, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3361
 *     set_default_error_handler()
 *     r = _hdf5.H5Sis_simple(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":3366
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sis_simple (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Soffset_simple(hid_t space_id, hssize_t *offset ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3357
 *     return r
 * 
 * cdef htri_t H5Sis_simple(hid_t space_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sis_simple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3368
 *     return r
 * 
 * cdef herr_t H5Soffset_simple(hid_t space_id, hssize_t *offset ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Soffset_simple(hid_t __pyx_v_space_id, hssize_t *__pyx_v_offset) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Soffset_simple", 0);

  /* "h5py/defs.pyx":3370
 * cdef herr_t H5Soffset_simple(hid_t space_id, hssize_t *offset ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Soffset_simple(space_id, offset)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3371
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Soffset_simple(space_id, offset)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Soffset_simple(__pyx_v_space_id, __pyx_v_offset);

  /* "h5py/defs.pyx":3372
 *     set_default_error_handler()
 *     r = _hdf5.H5Soffset_simple(space_id, offset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3373
 *     r = _hdf5.H5Soffset_simple(space_id, offset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3373, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3374
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Soffset_simple (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3373
 *     r = _hdf5.H5Soffset_simple(space_id, offset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3376
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Soffset_simple (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__286, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3376, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3376, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3372
 *     set_default_error_handler()
 *     r = _hdf5.H5Soffset_simple(space_id, offset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3377
 *         else:
 *             raise RuntimeError("Unspecified error in H5Soffset_simple (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Sget_simple_extent_ndims(hid_t space_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3368
 *     return r
 * 
 * cdef herr_t H5Soffset_simple(hid_t space_id, hssize_t *offset ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Soffset_simple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3379
 *     return r
 * 
 * cdef int H5Sget_simple_extent_ndims(hid_t space_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Sget_simple_extent_ndims(hid_t __pyx_v_space_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_simple_extent_ndims", 0);

  /* "h5py/defs.pyx":3381
 * cdef int H5Sget_simple_extent_ndims(hid_t space_id) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_simple_extent_ndims(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3382
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_ndims(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_simple_extent_ndims(__pyx_v_space_id);

  /* "h5py/defs.pyx":3383
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_ndims(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3384
 *     r = _hdf5.H5Sget_simple_extent_ndims(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3384, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3385
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_ndims (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3384
 *     r = _hdf5.H5Sget_simple_extent_ndims(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3387
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_ndims (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__287, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3387, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3383
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_ndims(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":3388
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_ndims (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Sget_simple_extent_dims(hid_t space_id, hsize_t *dims, hsize_t *maxdims) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3379
 *     return r
 * 
 * cdef int H5Sget_simple_extent_ndims(hid_t space_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_simple_extent_ndims", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3390
 *     return r
 * 
 * cdef int H5Sget_simple_extent_dims(hid_t space_id, hsize_t *dims, hsize_t *maxdims) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Sget_simple_extent_dims(hid_t __pyx_v_space_id, hsize_t *__pyx_v_dims, hsize_t *__pyx_v_maxdims) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_simple_extent_dims", 0);

  /* "h5py/defs.pyx":3392
 * cdef int H5Sget_simple_extent_dims(hid_t space_id, hsize_t *dims, hsize_t *maxdims) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_simple_extent_dims(space_id, dims, maxdims)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3393
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_dims(space_id, dims, maxdims)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_simple_extent_dims(__pyx_v_space_id, __pyx_v_dims, __pyx_v_maxdims);

  /* "h5py/defs.pyx":3394
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_dims(space_id, dims, maxdims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3395
 *     r = _hdf5.H5Sget_simple_extent_dims(space_id, dims, maxdims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3395, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3396
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_dims (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3395
 *     r = _hdf5.H5Sget_simple_extent_dims(space_id, dims, maxdims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3398
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_dims (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__288, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3398, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3394
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_dims(space_id, dims, maxdims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":3399
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_dims (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hssize_t H5Sget_simple_extent_npoints(hid_t space_id) except <hssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3390
 *     return r
 * 
 * cdef int H5Sget_simple_extent_dims(hid_t space_id, hsize_t *dims, hsize_t *maxdims) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_simple_extent_dims", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3401
 *     return r
 * 
 * cdef hssize_t H5Sget_simple_extent_npoints(hid_t space_id) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

static hssize_t __pyx_f_4h5py_4defs_H5Sget_simple_extent_npoints(hid_t __pyx_v_space_id) {
  hssize_t __pyx_v_r;
  hssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_simple_extent_npoints", 0);

  /* "h5py/defs.pyx":3403
 * cdef hssize_t H5Sget_simple_extent_npoints(hid_t space_id) except <hssize_t>-1:
 *     cdef hssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_simple_extent_npoints(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3404
 *     cdef hssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_npoints(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_simple_extent_npoints(__pyx_v_space_id);

  /* "h5py/defs.pyx":3405
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_npoints(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3406
 *     r = _hdf5.H5Sget_simple_extent_npoints(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3406, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3407
 *     if r<0:
 *         if set_exception():
 *             return <hssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_npoints (return value <0)")
 */
      __pyx_r = ((hssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3406
 *     r = _hdf5.H5Sget_simple_extent_npoints(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3409
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_npoints (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__289, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3409, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3405
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_npoints(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  }

  /* "h5py/defs.pyx":3410
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_npoints (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5S_class_t H5Sget_simple_extent_type(hid_t space_id) except <H5S_class_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3401
 *     return r
 * 
 * cdef hssize_t H5Sget_simple_extent_npoints(hid_t space_id) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_simple_extent_npoints", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3412
 *     return r
 * 
 * cdef H5S_class_t H5Sget_simple_extent_type(hid_t space_id) except <H5S_class_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5S_class_t r
 *     set_default_error_handler()
 */

static H5S_class_t __pyx_f_4h5py_4defs_H5Sget_simple_extent_type(hid_t __pyx_v_space_id) {
  H5S_class_t __pyx_v_r;
  H5S_class_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_simple_extent_type", 0);

  /* "h5py/defs.pyx":3414
 * cdef H5S_class_t H5Sget_simple_extent_type(hid_t space_id) except <H5S_class_t>-1:
 *     cdef H5S_class_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_simple_extent_type(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3415
 *     cdef H5S_class_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_type(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_simple_extent_type(__pyx_v_space_id);

  /* "h5py/defs.pyx":3416
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_type(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5S_class_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3417
 *     r = _hdf5.H5Sget_simple_extent_type(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5S_class_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3417, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3418
 *     if r<0:
 *         if set_exception():
 *             return <H5S_class_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_type (return value <0)")
 */
      __pyx_r = ((H5S_class_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3417
 *     r = _hdf5.H5Sget_simple_extent_type(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5S_class_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3420
 *             return <H5S_class_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__290, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3420, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3416
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_simple_extent_type(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5S_class_t>-1
 */
  }

  /* "h5py/defs.pyx":3421
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_type (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sextent_copy(hid_t dest_space_id, hid_t source_space_id ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3412
 *     return r
 * 
 * cdef H5S_class_t H5Sget_simple_extent_type(hid_t space_id) except <H5S_class_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5S_class_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_simple_extent_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5S_class_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3423
 *     return r
 * 
 * cdef herr_t H5Sextent_copy(hid_t dest_space_id, hid_t source_space_id ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sextent_copy(hid_t __pyx_v_dest_space_id, hid_t __pyx_v_source_space_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sextent_copy", 0);

  /* "h5py/defs.pyx":3425
 * cdef herr_t H5Sextent_copy(hid_t dest_space_id, hid_t source_space_id ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sextent_copy(dest_space_id, source_space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3426
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sextent_copy(dest_space_id, source_space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sextent_copy(__pyx_v_dest_space_id, __pyx_v_source_space_id);

  /* "h5py/defs.pyx":3427
 *     set_default_error_handler()
 *     r = _hdf5.H5Sextent_copy(dest_space_id, source_space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3428
 *     r = _hdf5.H5Sextent_copy(dest_space_id, source_space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3428, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3429
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sextent_copy (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3428
 *     r = _hdf5.H5Sextent_copy(dest_space_id, source_space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3431
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sextent_copy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__291, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3431, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3431, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3427
 *     set_default_error_handler()
 *     r = _hdf5.H5Sextent_copy(dest_space_id, source_space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3432
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sextent_copy (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sset_extent_simple(hid_t space_id, int rank, hsize_t *current_size, hsize_t *maximum_size ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3423
 *     return r
 * 
 * cdef herr_t H5Sextent_copy(hid_t dest_space_id, hid_t source_space_id ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sextent_copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3434
 *     return r
 * 
 * cdef herr_t H5Sset_extent_simple(hid_t space_id, int rank, hsize_t *current_size, hsize_t *maximum_size ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sset_extent_simple(hid_t __pyx_v_space_id, int __pyx_v_rank, hsize_t *__pyx_v_current_size, hsize_t *__pyx_v_maximum_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sset_extent_simple", 0);

  /* "h5py/defs.pyx":3436
 * cdef herr_t H5Sset_extent_simple(hid_t space_id, int rank, hsize_t *current_size, hsize_t *maximum_size ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sset_extent_simple(space_id, rank, current_size, maximum_size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3437
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sset_extent_simple(space_id, rank, current_size, maximum_size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sset_extent_simple(__pyx_v_space_id, __pyx_v_rank, __pyx_v_current_size, __pyx_v_maximum_size);

  /* "h5py/defs.pyx":3438
 *     set_default_error_handler()
 *     r = _hdf5.H5Sset_extent_simple(space_id, rank, current_size, maximum_size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3439
 *     r = _hdf5.H5Sset_extent_simple(space_id, rank, current_size, maximum_size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3439, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3440
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sset_extent_simple (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3439
 *     r = _hdf5.H5Sset_extent_simple(space_id, rank, current_size, maximum_size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3442
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sset_extent_simple (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__292, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3442, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3442, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3438
 *     set_default_error_handler()
 *     r = _hdf5.H5Sset_extent_simple(space_id, rank, current_size, maximum_size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3443
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sset_extent_simple (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sset_extent_none(hid_t space_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3434
 *     return r
 * 
 * cdef herr_t H5Sset_extent_simple(hid_t space_id, int rank, hsize_t *current_size, hsize_t *maximum_size ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sset_extent_simple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3445
 *     return r
 * 
 * cdef herr_t H5Sset_extent_none(hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sset_extent_none(hid_t __pyx_v_space_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sset_extent_none", 0);

  /* "h5py/defs.pyx":3447
 * cdef herr_t H5Sset_extent_none(hid_t space_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sset_extent_none(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3448
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sset_extent_none(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sset_extent_none(__pyx_v_space_id);

  /* "h5py/defs.pyx":3449
 *     set_default_error_handler()
 *     r = _hdf5.H5Sset_extent_none(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3450
 *     r = _hdf5.H5Sset_extent_none(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3450, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3451
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sset_extent_none (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3450
 *     r = _hdf5.H5Sset_extent_none(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3453
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sset_extent_none (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__293, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3453, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3449
 *     set_default_error_handler()
 *     r = _hdf5.H5Sset_extent_none(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3454
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sset_extent_none (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5S_sel_type H5Sget_select_type(hid_t space_id) except <H5S_sel_type>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3445
 *     return r
 * 
 * cdef herr_t H5Sset_extent_none(hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sset_extent_none", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3456
 *     return r
 * 
 * cdef H5S_sel_type H5Sget_select_type(hid_t space_id) except <H5S_sel_type>-1:             # <<<<<<<<<<<<<<
 *     cdef H5S_sel_type r
 *     set_default_error_handler()
 */

static H5S_sel_type __pyx_f_4h5py_4defs_H5Sget_select_type(hid_t __pyx_v_space_id) {
  H5S_sel_type __pyx_v_r;
  H5S_sel_type __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_select_type", 0);

  /* "h5py/defs.pyx":3458
 * cdef H5S_sel_type H5Sget_select_type(hid_t space_id) except <H5S_sel_type>-1:
 *     cdef H5S_sel_type r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_select_type(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3459
 *     cdef H5S_sel_type r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_type(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_select_type(__pyx_v_space_id);

  /* "h5py/defs.pyx":3460
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_type(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5S_sel_type>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3461
 *     r = _hdf5.H5Sget_select_type(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5S_sel_type>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3461, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3462
 *     if r<0:
 *         if set_exception():
 *             return <H5S_sel_type>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_type (return value <0)")
 */
      __pyx_r = ((H5S_sel_type)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3461
 *     r = _hdf5.H5Sget_select_type(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5S_sel_type>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3464
 *             return <H5S_sel_type>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__294, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3464, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3464, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3460
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_type(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5S_sel_type>-1
 */
  }

  /* "h5py/defs.pyx":3465
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_type (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hssize_t H5Sget_select_npoints(hid_t space_id) except <hssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3456
 *     return r
 * 
 * cdef H5S_sel_type H5Sget_select_type(hid_t space_id) except <H5S_sel_type>-1:             # <<<<<<<<<<<<<<
 *     cdef H5S_sel_type r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_select_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5S_sel_type)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3467
 *     return r
 * 
 * cdef hssize_t H5Sget_select_npoints(hid_t space_id) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

static hssize_t __pyx_f_4h5py_4defs_H5Sget_select_npoints(hid_t __pyx_v_space_id) {
  hssize_t __pyx_v_r;
  hssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_select_npoints", 0);

  /* "h5py/defs.pyx":3469
 * cdef hssize_t H5Sget_select_npoints(hid_t space_id) except <hssize_t>-1:
 *     cdef hssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_select_npoints(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3470
 *     cdef hssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_npoints(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_select_npoints(__pyx_v_space_id);

  /* "h5py/defs.pyx":3471
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_npoints(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3472
 *     r = _hdf5.H5Sget_select_npoints(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3472, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3473
 *     if r<0:
 *         if set_exception():
 *             return <hssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_npoints (return value <0)")
 */
      __pyx_r = ((hssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3472
 *     r = _hdf5.H5Sget_select_npoints(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3475
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_npoints (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__295, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3475, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3475, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3471
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_npoints(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  }

  /* "h5py/defs.pyx":3476
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_npoints (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sget_select_bounds(hid_t space_id, hsize_t *start, hsize_t *end) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3467
 *     return r
 * 
 * cdef hssize_t H5Sget_select_npoints(hid_t space_id) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_select_npoints", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3478
 *     return r
 * 
 * cdef herr_t H5Sget_select_bounds(hid_t space_id, hsize_t *start, hsize_t *end) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sget_select_bounds(hid_t __pyx_v_space_id, hsize_t *__pyx_v_start, hsize_t *__pyx_v_end) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_select_bounds", 0);

  /* "h5py/defs.pyx":3480
 * cdef herr_t H5Sget_select_bounds(hid_t space_id, hsize_t *start, hsize_t *end) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_select_bounds(space_id, start, end)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3481
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_bounds(space_id, start, end)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_select_bounds(__pyx_v_space_id, __pyx_v_start, __pyx_v_end);

  /* "h5py/defs.pyx":3482
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_bounds(space_id, start, end)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3483
 *     r = _hdf5.H5Sget_select_bounds(space_id, start, end)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3483, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3484
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_bounds (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3483
 *     r = _hdf5.H5Sget_select_bounds(space_id, start, end)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3486
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_bounds (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__296, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3486, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3482
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_bounds(space_id, start, end)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3487
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_bounds (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sselect_all(hid_t space_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3478
 *     return r
 * 
 * cdef herr_t H5Sget_select_bounds(hid_t space_id, hsize_t *start, hsize_t *end) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_select_bounds", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3489
 *     return r
 * 
 * cdef herr_t H5Sselect_all(hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sselect_all(hid_t __pyx_v_space_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sselect_all", 0);

  /* "h5py/defs.pyx":3491
 * cdef herr_t H5Sselect_all(hid_t space_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sselect_all(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3492
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_all(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sselect_all(__pyx_v_space_id);

  /* "h5py/defs.pyx":3493
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_all(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3494
 *     r = _hdf5.H5Sselect_all(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3494, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3495
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_all (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3494
 *     r = _hdf5.H5Sselect_all(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3497
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_all (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__297, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3497, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3497, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3493
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_all(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3498
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_all (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sselect_none(hid_t space_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3489
 *     return r
 * 
 * cdef herr_t H5Sselect_all(hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sselect_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3500
 *     return r
 * 
 * cdef herr_t H5Sselect_none(hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sselect_none(hid_t __pyx_v_space_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sselect_none", 0);

  /* "h5py/defs.pyx":3502
 * cdef herr_t H5Sselect_none(hid_t space_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sselect_none(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3503
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_none(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sselect_none(__pyx_v_space_id);

  /* "h5py/defs.pyx":3504
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_none(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3505
 *     r = _hdf5.H5Sselect_none(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3505, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3506
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_none (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3505
 *     r = _hdf5.H5Sselect_none(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3508
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_none (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__298, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3508, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3504
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_none(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3509
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_none (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Sselect_valid(hid_t space_id) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3500
 *     return r
 * 
 * cdef herr_t H5Sselect_none(hid_t space_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sselect_none", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3511
 *     return r
 * 
 * cdef htri_t H5Sselect_valid(hid_t space_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Sselect_valid(hid_t __pyx_v_space_id) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sselect_valid", 0);

  /* "h5py/defs.pyx":3513
 * cdef htri_t H5Sselect_valid(hid_t space_id) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sselect_valid(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3514
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_valid(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sselect_valid(__pyx_v_space_id);

  /* "h5py/defs.pyx":3515
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_valid(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3516
 *     r = _hdf5.H5Sselect_valid(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3516, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3517
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_valid (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3516
 *     r = _hdf5.H5Sselect_valid(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3519
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_valid (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__299, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3519, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3515
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_valid(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":3520
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_valid (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hssize_t H5Sget_select_elem_npoints(hid_t space_id) except <hssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3511
 *     return r
 * 
 * cdef htri_t H5Sselect_valid(hid_t space_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sselect_valid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3522
 *     return r
 * 
 * cdef hssize_t H5Sget_select_elem_npoints(hid_t space_id) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

static hssize_t __pyx_f_4h5py_4defs_H5Sget_select_elem_npoints(hid_t __pyx_v_space_id) {
  hssize_t __pyx_v_r;
  hssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_select_elem_npoints", 0);

  /* "h5py/defs.pyx":3524
 * cdef hssize_t H5Sget_select_elem_npoints(hid_t space_id) except <hssize_t>-1:
 *     cdef hssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_select_elem_npoints(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3525
 *     cdef hssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_elem_npoints(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_select_elem_npoints(__pyx_v_space_id);

  /* "h5py/defs.pyx":3526
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_elem_npoints(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3527
 *     r = _hdf5.H5Sget_select_elem_npoints(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3527, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3528
 *     if r<0:
 *         if set_exception():
 *             return <hssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_elem_npoints (return value <0)")
 */
      __pyx_r = ((hssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3527
 *     r = _hdf5.H5Sget_select_elem_npoints(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3530
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_elem_npoints (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__300, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3530, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3526
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_elem_npoints(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  }

  /* "h5py/defs.pyx":3531
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_elem_npoints (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sget_select_elem_pointlist(hid_t space_id, hsize_t startpoint,  hsize_t numpoints, hsize_t *buf) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3522
 *     return r
 * 
 * cdef hssize_t H5Sget_select_elem_npoints(hid_t space_id) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_select_elem_npoints", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3533
 *     return r
 * 
 * cdef herr_t H5Sget_select_elem_pointlist(hid_t space_id, hsize_t startpoint,  hsize_t numpoints, hsize_t *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sget_select_elem_pointlist(hid_t __pyx_v_space_id, hsize_t __pyx_v_startpoint, hsize_t __pyx_v_numpoints, hsize_t *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_select_elem_pointlist", 0);

  /* "h5py/defs.pyx":3535
 * cdef herr_t H5Sget_select_elem_pointlist(hid_t space_id, hsize_t startpoint,  hsize_t numpoints, hsize_t *buf) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_select_elem_pointlist(space_id, startpoint, numpoints, buf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3536
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_elem_pointlist(space_id, startpoint, numpoints, buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_select_elem_pointlist(__pyx_v_space_id, __pyx_v_startpoint, __pyx_v_numpoints, __pyx_v_buf);

  /* "h5py/defs.pyx":3537
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_elem_pointlist(space_id, startpoint, numpoints, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3538
 *     r = _hdf5.H5Sget_select_elem_pointlist(space_id, startpoint, numpoints, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3538, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3539
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_elem_pointlist (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3538
 *     r = _hdf5.H5Sget_select_elem_pointlist(space_id, startpoint, numpoints, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3541
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_elem_pointlist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__301, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3541, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3541, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3537
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_elem_pointlist(space_id, startpoint, numpoints, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3542
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_elem_pointlist (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sselect_elements(hid_t space_id, H5S_seloper_t op,  size_t num_elements, const hsize_t *coord) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3533
 *     return r
 * 
 * cdef herr_t H5Sget_select_elem_pointlist(hid_t space_id, hsize_t startpoint,  hsize_t numpoints, hsize_t *buf) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_select_elem_pointlist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3544
 *     return r
 * 
 * cdef herr_t H5Sselect_elements(hid_t space_id, H5S_seloper_t op,  size_t num_elements, const hsize_t *coord) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sselect_elements(hid_t __pyx_v_space_id, H5S_seloper_t __pyx_v_op, size_t __pyx_v_num_elements, hsize_t const *__pyx_v_coord) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sselect_elements", 0);

  /* "h5py/defs.pyx":3546
 * cdef herr_t H5Sselect_elements(hid_t space_id, H5S_seloper_t op,  size_t num_elements, const hsize_t *coord) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sselect_elements(space_id, op, num_elements, coord)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3547
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_elements(space_id, op, num_elements, coord)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sselect_elements(__pyx_v_space_id, __pyx_v_op, __pyx_v_num_elements, __pyx_v_coord);

  /* "h5py/defs.pyx":3548
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_elements(space_id, op, num_elements, coord)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3549
 *     r = _hdf5.H5Sselect_elements(space_id, op, num_elements, coord)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3549, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3550
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_elements (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3549
 *     r = _hdf5.H5Sselect_elements(space_id, op, num_elements, coord)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3552
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_elements (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__302, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3552, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3552, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3548
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_elements(space_id, op, num_elements, coord)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3553
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_elements (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hssize_t H5Sget_select_hyper_nblocks(hid_t space_id ) except <hssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3544
 *     return r
 * 
 * cdef herr_t H5Sselect_elements(hid_t space_id, H5S_seloper_t op,  size_t num_elements, const hsize_t *coord) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sselect_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3555
 *     return r
 * 
 * cdef hssize_t H5Sget_select_hyper_nblocks(hid_t space_id ) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

static hssize_t __pyx_f_4h5py_4defs_H5Sget_select_hyper_nblocks(hid_t __pyx_v_space_id) {
  hssize_t __pyx_v_r;
  hssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_select_hyper_nblocks", 0);

  /* "h5py/defs.pyx":3557
 * cdef hssize_t H5Sget_select_hyper_nblocks(hid_t space_id ) except <hssize_t>-1:
 *     cdef hssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_select_hyper_nblocks(space_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3558
 *     cdef hssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_hyper_nblocks(space_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_select_hyper_nblocks(__pyx_v_space_id);

  /* "h5py/defs.pyx":3559
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_hyper_nblocks(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3560
 *     r = _hdf5.H5Sget_select_hyper_nblocks(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3560, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3561
 *     if r<0:
 *         if set_exception():
 *             return <hssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_hyper_nblocks (return value <0)")
 */
      __pyx_r = ((hssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3560
 *     r = _hdf5.H5Sget_select_hyper_nblocks(space_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3563
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_hyper_nblocks (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__303, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3563, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3563, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3559
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_hyper_nblocks(space_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hssize_t>-1
 */
  }

  /* "h5py/defs.pyx":3564
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_hyper_nblocks (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sget_select_hyper_blocklist(hid_t space_id,  hsize_t startblock, hsize_t numblocks, hsize_t *buf ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3555
 *     return r
 * 
 * cdef hssize_t H5Sget_select_hyper_nblocks(hid_t space_id ) except <hssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_select_hyper_nblocks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3566
 *     return r
 * 
 * cdef herr_t H5Sget_select_hyper_blocklist(hid_t space_id,  hsize_t startblock, hsize_t numblocks, hsize_t *buf ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sget_select_hyper_blocklist(hid_t __pyx_v_space_id, hsize_t __pyx_v_startblock, hsize_t __pyx_v_numblocks, hsize_t *__pyx_v_buf) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_select_hyper_blocklist", 0);

  /* "h5py/defs.pyx":3568
 * cdef herr_t H5Sget_select_hyper_blocklist(hid_t space_id,  hsize_t startblock, hsize_t numblocks, hsize_t *buf ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sget_select_hyper_blocklist(space_id, startblock, numblocks, buf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3569
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_hyper_blocklist(space_id, startblock, numblocks, buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sget_select_hyper_blocklist(__pyx_v_space_id, __pyx_v_startblock, __pyx_v_numblocks, __pyx_v_buf);

  /* "h5py/defs.pyx":3570
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_hyper_blocklist(space_id, startblock, numblocks, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3571
 *     r = _hdf5.H5Sget_select_hyper_blocklist(space_id, startblock, numblocks, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3571, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3572
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_hyper_blocklist (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3571
 *     r = _hdf5.H5Sget_select_hyper_blocklist(space_id, startblock, numblocks, buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3574
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_hyper_blocklist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__304, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3574, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3574, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3570
 *     set_default_error_handler()
 *     r = _hdf5.H5Sget_select_hyper_blocklist(space_id, startblock, numblocks, buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3575
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_hyper_blocklist (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sselect_hyperslab(hid_t space_id, H5S_seloper_t op,  hsize_t *start, hsize_t *_stride, hsize_t *count, hsize_t *_block) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3566
 *     return r
 * 
 * cdef herr_t H5Sget_select_hyper_blocklist(hid_t space_id,  hsize_t startblock, hsize_t numblocks, hsize_t *buf ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_select_hyper_blocklist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3577
 *     return r
 * 
 * cdef herr_t H5Sselect_hyperslab(hid_t space_id, H5S_seloper_t op,  hsize_t *start, hsize_t *_stride, hsize_t *count, hsize_t *_block) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sselect_hyperslab(hid_t __pyx_v_space_id, H5S_seloper_t __pyx_v_op, hsize_t *__pyx_v_start, hsize_t *__pyx_v__stride, hsize_t *__pyx_v_count, hsize_t *__pyx_v__block) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sselect_hyperslab", 0);

  /* "h5py/defs.pyx":3579
 * cdef herr_t H5Sselect_hyperslab(hid_t space_id, H5S_seloper_t op,  hsize_t *start, hsize_t *_stride, hsize_t *count, hsize_t *_block) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sselect_hyperslab(space_id, op, start, _stride, count, _block)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3580
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_hyperslab(space_id, op, start, _stride, count, _block)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sselect_hyperslab(__pyx_v_space_id, __pyx_v_op, __pyx_v_start, __pyx_v__stride, __pyx_v_count, __pyx_v__block);

  /* "h5py/defs.pyx":3581
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_hyperslab(space_id, op, start, _stride, count, _block)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3582
 *     r = _hdf5.H5Sselect_hyperslab(space_id, op, start, _stride, count, _block)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3582, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3583
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_hyperslab (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3582
 *     r = _hdf5.H5Sselect_hyperslab(space_id, op, start, _stride, count, _block)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3585
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_hyperslab (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__305, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3585, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3585, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3581
 *     set_default_error_handler()
 *     r = _hdf5.H5Sselect_hyperslab(space_id, op, start, _stride, count, _block)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3586
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_hyperslab (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Sencode(hid_t obj_id, void *buf, size_t *nalloc) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3577
 *     return r
 * 
 * cdef herr_t H5Sselect_hyperslab(hid_t space_id, H5S_seloper_t op,  hsize_t *start, hsize_t *_stride, hsize_t *count, hsize_t *_block) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sselect_hyperslab", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3588
 *     return r
 * 
 * cdef herr_t H5Sencode(hid_t obj_id, void *buf, size_t *nalloc) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Sencode(hid_t __pyx_v_obj_id, void *__pyx_v_buf, size_t *__pyx_v_nalloc) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sencode", 0);

  /* "h5py/defs.pyx":3590
 * cdef herr_t H5Sencode(hid_t obj_id, void *buf, size_t *nalloc) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sencode(obj_id, buf, nalloc)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3591
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sencode(obj_id, buf, nalloc)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sencode(__pyx_v_obj_id, __pyx_v_buf, __pyx_v_nalloc);

  /* "h5py/defs.pyx":3592
 *     set_default_error_handler()
 *     r = _hdf5.H5Sencode(obj_id, buf, nalloc)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3593
 *     r = _hdf5.H5Sencode(obj_id, buf, nalloc)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3593, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3594
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sencode (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3593
 *     r = _hdf5.H5Sencode(obj_id, buf, nalloc)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3596
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sencode (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__306, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3596, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3592
 *     set_default_error_handler()
 *     r = _hdf5.H5Sencode(obj_id, buf, nalloc)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3597
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sencode (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Sdecode(void *buf) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3588
 *     return r
 * 
 * cdef herr_t H5Sencode(hid_t obj_id, void *buf, size_t *nalloc) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sencode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3599
 *     return r
 * 
 * cdef hid_t H5Sdecode(void *buf) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Sdecode(void *__pyx_v_buf) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sdecode", 0);

  /* "h5py/defs.pyx":3601
 * cdef hid_t H5Sdecode(void *buf) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Sdecode(buf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3602
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Sdecode(buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Sdecode(__pyx_v_buf);

  /* "h5py/defs.pyx":3603
 *     set_default_error_handler()
 *     r = _hdf5.H5Sdecode(buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3604
 *     r = _hdf5.H5Sdecode(buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3604, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3605
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sdecode (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3604
 *     r = _hdf5.H5Sdecode(buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3607
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sdecode (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__307, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3607, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3603
 *     set_default_error_handler()
 *     r = _hdf5.H5Sdecode(buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3608
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sdecode (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3599
 *     return r
 * 
 * cdef hid_t H5Sdecode(void *buf) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sdecode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3611
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef htri_t H5Sis_regular_hyperslab(hid_t spaceid) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *         cdef htri_t r
 *         set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Sis_regular_hyperslab(hid_t __pyx_v_spaceid) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sis_regular_hyperslab", 0);

  /* "h5py/defs.pyx":3613
 *     cdef htri_t H5Sis_regular_hyperslab(hid_t spaceid) except <htri_t>-1:
 *         cdef htri_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Sis_regular_hyperslab(spaceid)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3614
 *         cdef htri_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Sis_regular_hyperslab(spaceid)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Sis_regular_hyperslab(__pyx_v_spaceid);

  /* "h5py/defs.pyx":3615
 *         set_default_error_handler()
 *         r = _hdf5.H5Sis_regular_hyperslab(spaceid)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3616
 *         r = _hdf5.H5Sis_regular_hyperslab(spaceid)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <htri_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3616, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3617
 *         if r<0:
 *             if set_exception():
 *                 return <htri_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Sis_regular_hyperslab (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3616
 *         r = _hdf5.H5Sis_regular_hyperslab(spaceid)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <htri_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3619
 *                 return <htri_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Sis_regular_hyperslab (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__308, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3619, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3615
 *         set_default_error_handler()
 *         r = _hdf5.H5Sis_regular_hyperslab(spaceid)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":3620
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Sis_regular_hyperslab (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3611
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef htri_t H5Sis_regular_hyperslab(hid_t spaceid) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *         cdef htri_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sis_regular_hyperslab", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3623
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef htri_t H5Sget_regular_hyperslab(hid_t spaceid, hsize_t* start, hsize_t* stride, hsize_t* count, hsize_t* block) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *         cdef htri_t r
 *         set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Sget_regular_hyperslab(hid_t __pyx_v_spaceid, hsize_t *__pyx_v_start, hsize_t *__pyx_v_stride, hsize_t *__pyx_v_count, hsize_t *__pyx_v_block) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Sget_regular_hyperslab", 0);

  /* "h5py/defs.pyx":3625
 *     cdef htri_t H5Sget_regular_hyperslab(hid_t spaceid, hsize_t* start, hsize_t* stride, hsize_t* count, hsize_t* block) except <htri_t>-1:
 *         cdef htri_t r
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Sget_regular_hyperslab(spaceid, start, stride, count, block)
 *         if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3626
 *         cdef htri_t r
 *         set_default_error_handler()
 *         r = _hdf5.H5Sget_regular_hyperslab(spaceid, start, stride, count, block)             # <<<<<<<<<<<<<<
 *         if r<0:
 *             if set_exception():
 */
  __pyx_v_r = H5Sget_regular_hyperslab(__pyx_v_spaceid, __pyx_v_start, __pyx_v_stride, __pyx_v_count, __pyx_v_block);

  /* "h5py/defs.pyx":3627
 *         set_default_error_handler()
 *         r = _hdf5.H5Sget_regular_hyperslab(spaceid, start, stride, count, block)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3628
 *         r = _hdf5.H5Sget_regular_hyperslab(spaceid, start, stride, count, block)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <htri_t>-1
 *             else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3628, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3629
 *         if r<0:
 *             if set_exception():
 *                 return <htri_t>-1             # <<<<<<<<<<<<<<
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Sget_regular_hyperslab (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3628
 *         r = _hdf5.H5Sget_regular_hyperslab(spaceid, start, stride, count, block)
 *         if r<0:
 *             if set_exception():             # <<<<<<<<<<<<<<
 *                 return <htri_t>-1
 *             else:
 */
    }

    /* "h5py/defs.pyx":3631
 *                 return <htri_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Sget_regular_hyperslab (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__309, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3631, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3631, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3627
 *         set_default_error_handler()
 *         r = _hdf5.H5Sget_regular_hyperslab(spaceid, start, stride, count, block)
 *         if r<0:             # <<<<<<<<<<<<<<
 *             if set_exception():
 *                 return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":3632
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Sget_regular_hyperslab (return value <0)")
 *         return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tcreate(H5T_class_t type, size_t size) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3623
 * 
 * IF HDF5_VERSION >= (1, 9, 233):
 *     cdef htri_t H5Sget_regular_hyperslab(hid_t spaceid, hsize_t* start, hsize_t* stride, hsize_t* count, hsize_t* block) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *         cdef htri_t r
 *         set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Sget_regular_hyperslab", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3634
 *         return r
 * 
 * cdef hid_t H5Tcreate(H5T_class_t type, size_t size) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tcreate(enum H5T_class_t __pyx_v_type, size_t __pyx_v_size) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tcreate", 0);

  /* "h5py/defs.pyx":3636
 * cdef hid_t H5Tcreate(H5T_class_t type, size_t size) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tcreate(type, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3637
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcreate(type, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tcreate(__pyx_v_type, __pyx_v_size);

  /* "h5py/defs.pyx":3638
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcreate(type, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3639
 *     r = _hdf5.H5Tcreate(type, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3639, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3640
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcreate (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3639
 *     r = _hdf5.H5Tcreate(type, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3642
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__310, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3642, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3638
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcreate(type, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3643
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcreate (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Topen(hid_t loc, char* name, hid_t tapl_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3634
 *         return r
 * 
 * cdef hid_t H5Tcreate(H5T_class_t type, size_t size) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tcreate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3645
 *     return r
 * 
 * cdef hid_t H5Topen(hid_t loc, char* name, hid_t tapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Topen(hid_t __pyx_v_loc, char *__pyx_v_name, hid_t __pyx_v_tapl_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Topen", 0);

  /* "h5py/defs.pyx":3647
 * cdef hid_t H5Topen(hid_t loc, char* name, hid_t tapl_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Topen(loc, name, tapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3648
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Topen(loc, name, tapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Topen(__pyx_v_loc, __pyx_v_name, __pyx_v_tapl_id);

  /* "h5py/defs.pyx":3649
 *     set_default_error_handler()
 *     r = _hdf5.H5Topen(loc, name, tapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3650
 *     r = _hdf5.H5Topen(loc, name, tapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3650, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3651
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Topen (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3650
 *     r = _hdf5.H5Topen(loc, name, tapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3653
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Topen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__311, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3653, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3649
 *     set_default_error_handler()
 *     r = _hdf5.H5Topen(loc, name, tapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3654
 *         else:
 *             raise RuntimeError("Unspecified error in H5Topen (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Tcommitted(hid_t type) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3645
 *     return r
 * 
 * cdef hid_t H5Topen(hid_t loc, char* name, hid_t tapl_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Topen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3656
 *     return r
 * 
 * cdef htri_t H5Tcommitted(hid_t type) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Tcommitted(hid_t __pyx_v_type) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tcommitted", 0);

  /* "h5py/defs.pyx":3658
 * cdef htri_t H5Tcommitted(hid_t type) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tcommitted(type)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3659
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcommitted(type)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tcommitted(__pyx_v_type);

  /* "h5py/defs.pyx":3660
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcommitted(type)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3661
 *     r = _hdf5.H5Tcommitted(type)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3661, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3662
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcommitted (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3661
 *     r = _hdf5.H5Tcommitted(type)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3664
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcommitted (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__312, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3664, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3664, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3660
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcommitted(type)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":3665
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcommitted (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tcopy(hid_t type_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3656
 *     return r
 * 
 * cdef htri_t H5Tcommitted(hid_t type) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tcommitted", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3667
 *     return r
 * 
 * cdef hid_t H5Tcopy(hid_t type_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tcopy(hid_t __pyx_v_type_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tcopy", 0);

  /* "h5py/defs.pyx":3669
 * cdef hid_t H5Tcopy(hid_t type_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tcopy(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3670
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcopy(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tcopy(__pyx_v_type_id);

  /* "h5py/defs.pyx":3671
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcopy(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3672
 *     r = _hdf5.H5Tcopy(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3672, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3673
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcopy (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3672
 *     r = _hdf5.H5Tcopy(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3675
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__313, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3675, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3671
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcopy(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3676
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcopy (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Tequal(hid_t type_id1, hid_t type_id2 ) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3667
 *     return r
 * 
 * cdef hid_t H5Tcopy(hid_t type_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tcopy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3678
 *     return r
 * 
 * cdef htri_t H5Tequal(hid_t type_id1, hid_t type_id2 ) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Tequal(hid_t __pyx_v_type_id1, hid_t __pyx_v_type_id2) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tequal", 0);

  /* "h5py/defs.pyx":3680
 * cdef htri_t H5Tequal(hid_t type_id1, hid_t type_id2 ) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tequal(type_id1, type_id2)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3681
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tequal(type_id1, type_id2)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tequal(__pyx_v_type_id1, __pyx_v_type_id2);

  /* "h5py/defs.pyx":3682
 *     set_default_error_handler()
 *     r = _hdf5.H5Tequal(type_id1, type_id2)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3683
 *     r = _hdf5.H5Tequal(type_id1, type_id2)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3683, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3684
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tequal (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3683
 *     r = _hdf5.H5Tequal(type_id1, type_id2)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3686
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tequal (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__314, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3686, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3682
 *     set_default_error_handler()
 *     r = _hdf5.H5Tequal(type_id1, type_id2)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":3687
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tequal (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tlock(hid_t type_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3678
 *     return r
 * 
 * cdef htri_t H5Tequal(hid_t type_id1, hid_t type_id2 ) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tequal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3689
 *     return r
 * 
 * cdef herr_t H5Tlock(hid_t type_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tlock(hid_t __pyx_v_type_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tlock", 0);

  /* "h5py/defs.pyx":3691
 * cdef herr_t H5Tlock(hid_t type_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tlock(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3692
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tlock(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tlock(__pyx_v_type_id);

  /* "h5py/defs.pyx":3693
 *     set_default_error_handler()
 *     r = _hdf5.H5Tlock(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3694
 *     r = _hdf5.H5Tlock(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3694, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3695
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tlock (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3694
 *     r = _hdf5.H5Tlock(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3697
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tlock (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__315, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3697, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3697, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3693
 *     set_default_error_handler()
 *     r = _hdf5.H5Tlock(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3698
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tlock (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_class_t H5Tget_class(hid_t type_id) except <H5T_class_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3689
 *     return r
 * 
 * cdef herr_t H5Tlock(hid_t type_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3700
 *     return r
 * 
 * cdef H5T_class_t H5Tget_class(hid_t type_id) except <H5T_class_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_class_t r
 *     set_default_error_handler()
 */

static enum H5T_class_t __pyx_f_4h5py_4defs_H5Tget_class(hid_t __pyx_v_type_id) {
  enum H5T_class_t __pyx_v_r;
  enum H5T_class_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_class", 0);

  /* "h5py/defs.pyx":3702
 * cdef H5T_class_t H5Tget_class(hid_t type_id) except <H5T_class_t>-1:
 *     cdef H5T_class_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_class(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3703
 *     cdef H5T_class_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_class(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_class(__pyx_v_type_id);

  /* "h5py/defs.pyx":3704
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_class(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_class_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3705
 *     r = _hdf5.H5Tget_class(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_class_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3705, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3706
 *     if r<0:
 *         if set_exception():
 *             return <H5T_class_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_class (return value <0)")
 */
      __pyx_r = ((enum H5T_class_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3705
 *     r = _hdf5.H5Tget_class(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_class_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3708
 *             return <H5T_class_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__316, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3708, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3708, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3704
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_class(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_class_t>-1
 */
  }

  /* "h5py/defs.pyx":3709
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_class (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef size_t H5Tget_size(hid_t type_id) except <size_t>0:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3700
 *     return r
 * 
 * cdef H5T_class_t H5Tget_class(hid_t type_id) except <H5T_class_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_class_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((enum H5T_class_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3711
 *     return r
 * 
 * cdef size_t H5Tget_size(hid_t type_id) except <size_t>0:             # <<<<<<<<<<<<<<
 *     cdef size_t r
 *     set_default_error_handler()
 */

static size_t __pyx_f_4h5py_4defs_H5Tget_size(hid_t __pyx_v_type_id) {
  size_t __pyx_v_r;
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_size", 0);

  /* "h5py/defs.pyx":3713
 * cdef size_t H5Tget_size(hid_t type_id) except <size_t>0:
 *     cdef size_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_size(type_id)
 *     if r==0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3714
 *     cdef size_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_size(type_id)             # <<<<<<<<<<<<<<
 *     if r==0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_size(__pyx_v_type_id);

  /* "h5py/defs.pyx":3715
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_size(type_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <size_t>0
 */
  __pyx_t_1 = ((__pyx_v_r == 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3716
 *     r = _hdf5.H5Tget_size(type_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <size_t>0
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3716, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3717
 *     if r==0:
 *         if set_exception():
 *             return <size_t>0             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_size (return value ==0)")
 */
      __pyx_r = ((size_t)0);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3716
 *     r = _hdf5.H5Tget_size(type_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <size_t>0
 *         else:
 */
    }

    /* "h5py/defs.pyx":3719
 *             return <size_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_size (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__317, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3719, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3719, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3715
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_size(type_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <size_t>0
 */
  }

  /* "h5py/defs.pyx":3720
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_size (return value ==0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tget_super(hid_t type) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3711
 *     return r
 * 
 * cdef size_t H5Tget_size(hid_t type_id) except <size_t>0:             # <<<<<<<<<<<<<<
 *     cdef size_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((size_t)0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3722
 *     return r
 * 
 * cdef hid_t H5Tget_super(hid_t type) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tget_super(hid_t __pyx_v_type) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_super", 0);

  /* "h5py/defs.pyx":3724
 * cdef hid_t H5Tget_super(hid_t type) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_super(type)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3725
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_super(type)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_super(__pyx_v_type);

  /* "h5py/defs.pyx":3726
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_super(type)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3727
 *     r = _hdf5.H5Tget_super(type)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3727, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3728
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_super (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3727
 *     r = _hdf5.H5Tget_super(type)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3730
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_super (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__318, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3730, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3726
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_super(type)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3731
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_super (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Tdetect_class(hid_t type_id, H5T_class_t dtype_class) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3722
 *     return r
 * 
 * cdef hid_t H5Tget_super(hid_t type) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_super", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3733
 *     return r
 * 
 * cdef htri_t H5Tdetect_class(hid_t type_id, H5T_class_t dtype_class) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Tdetect_class(hid_t __pyx_v_type_id, enum H5T_class_t __pyx_v_dtype_class) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tdetect_class", 0);

  /* "h5py/defs.pyx":3735
 * cdef htri_t H5Tdetect_class(hid_t type_id, H5T_class_t dtype_class) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tdetect_class(type_id, dtype_class)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3736
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tdetect_class(type_id, dtype_class)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tdetect_class(__pyx_v_type_id, __pyx_v_dtype_class);

  /* "h5py/defs.pyx":3737
 *     set_default_error_handler()
 *     r = _hdf5.H5Tdetect_class(type_id, dtype_class)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3738
 *     r = _hdf5.H5Tdetect_class(type_id, dtype_class)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3738, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3739
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tdetect_class (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3738
 *     r = _hdf5.H5Tdetect_class(type_id, dtype_class)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3741
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tdetect_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__319, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3741, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3741, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3737
 *     set_default_error_handler()
 *     r = _hdf5.H5Tdetect_class(type_id, dtype_class)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":3742
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tdetect_class (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tclose(hid_t type_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3733
 *     return r
 * 
 * cdef htri_t H5Tdetect_class(hid_t type_id, H5T_class_t dtype_class) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tdetect_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3744
 *     return r
 * 
 * cdef herr_t H5Tclose(hid_t type_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tclose(hid_t __pyx_v_type_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tclose", 0);

  /* "h5py/defs.pyx":3746
 * cdef herr_t H5Tclose(hid_t type_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tclose(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3747
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tclose(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tclose(__pyx_v_type_id);

  /* "h5py/defs.pyx":3748
 *     set_default_error_handler()
 *     r = _hdf5.H5Tclose(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3749
 *     r = _hdf5.H5Tclose(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3749, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3750
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tclose (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3749
 *     r = _hdf5.H5Tclose(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3752
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__320, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3752, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3752, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3748
 *     set_default_error_handler()
 *     r = _hdf5.H5Tclose(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3753
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tclose (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tget_native_type(hid_t type_id, H5T_direction_t direction) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3744
 *     return r
 * 
 * cdef herr_t H5Tclose(hid_t type_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3755
 *     return r
 * 
 * cdef hid_t H5Tget_native_type(hid_t type_id, H5T_direction_t direction) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tget_native_type(hid_t __pyx_v_type_id, enum H5T_direction_t __pyx_v_direction) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_native_type", 0);

  /* "h5py/defs.pyx":3757
 * cdef hid_t H5Tget_native_type(hid_t type_id, H5T_direction_t direction) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_native_type(type_id, direction)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3758
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_native_type(type_id, direction)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_native_type(__pyx_v_type_id, __pyx_v_direction);

  /* "h5py/defs.pyx":3759
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_native_type(type_id, direction)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3760
 *     r = _hdf5.H5Tget_native_type(type_id, direction)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3760, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3761
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_native_type (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3760
 *     r = _hdf5.H5Tget_native_type(type_id, direction)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3763
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_native_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__321, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3763, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3759
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_native_type(type_id, direction)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3764
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_native_type (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tcommit(hid_t loc_id, char *name, hid_t dtype_id, hid_t lcpl_id, hid_t tcpl_id, hid_t tapl_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3755
 *     return r
 * 
 * cdef hid_t H5Tget_native_type(hid_t type_id, H5T_direction_t direction) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_native_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3766
 *     return r
 * 
 * cdef herr_t H5Tcommit(hid_t loc_id, char *name, hid_t dtype_id, hid_t lcpl_id, hid_t tcpl_id, hid_t tapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tcommit(hid_t __pyx_v_loc_id, char *__pyx_v_name, hid_t __pyx_v_dtype_id, hid_t __pyx_v_lcpl_id, hid_t __pyx_v_tcpl_id, hid_t __pyx_v_tapl_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tcommit", 0);

  /* "h5py/defs.pyx":3768
 * cdef herr_t H5Tcommit(hid_t loc_id, char *name, hid_t dtype_id, hid_t lcpl_id, hid_t tcpl_id, hid_t tapl_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tcommit(loc_id, name, dtype_id, lcpl_id, tcpl_id, tapl_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3769
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcommit(loc_id, name, dtype_id, lcpl_id, tcpl_id, tapl_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tcommit(__pyx_v_loc_id, __pyx_v_name, __pyx_v_dtype_id, __pyx_v_lcpl_id, __pyx_v_tcpl_id, __pyx_v_tapl_id);

  /* "h5py/defs.pyx":3770
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcommit(loc_id, name, dtype_id, lcpl_id, tcpl_id, tapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3771
 *     r = _hdf5.H5Tcommit(loc_id, name, dtype_id, lcpl_id, tcpl_id, tapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3771, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3772
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcommit (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3771
 *     r = _hdf5.H5Tcommit(loc_id, name, dtype_id, lcpl_id, tcpl_id, tapl_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3774
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcommit (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__322, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3774, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3774, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3770
 *     set_default_error_handler()
 *     r = _hdf5.H5Tcommit(loc_id, name, dtype_id, lcpl_id, tcpl_id, tapl_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3775
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcommit (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tget_create_plist(hid_t dtype_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3766
 *     return r
 * 
 * cdef herr_t H5Tcommit(hid_t loc_id, char *name, hid_t dtype_id, hid_t lcpl_id, hid_t tcpl_id, hid_t tapl_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tcommit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3777
 *     return r
 * 
 * cdef hid_t H5Tget_create_plist(hid_t dtype_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tget_create_plist(hid_t __pyx_v_dtype_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_create_plist", 0);

  /* "h5py/defs.pyx":3779
 * cdef hid_t H5Tget_create_plist(hid_t dtype_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_create_plist(dtype_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3780
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_create_plist(dtype_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_create_plist(__pyx_v_dtype_id);

  /* "h5py/defs.pyx":3781
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_create_plist(dtype_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3782
 *     r = _hdf5.H5Tget_create_plist(dtype_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3782, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3783
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_create_plist (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3782
 *     r = _hdf5.H5Tget_create_plist(dtype_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3785
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_create_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__323, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3785, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3785, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3781
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_create_plist(dtype_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3786
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_create_plist (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tdecode(unsigned char *buf) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3777
 *     return r
 * 
 * cdef hid_t H5Tget_create_plist(hid_t dtype_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_create_plist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3788
 *     return r
 * 
 * cdef hid_t H5Tdecode(unsigned char *buf) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tdecode(unsigned char *__pyx_v_buf) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tdecode", 0);

  /* "h5py/defs.pyx":3790
 * cdef hid_t H5Tdecode(unsigned char *buf) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tdecode(buf)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3791
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tdecode(buf)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tdecode(__pyx_v_buf);

  /* "h5py/defs.pyx":3792
 *     set_default_error_handler()
 *     r = _hdf5.H5Tdecode(buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3793
 *     r = _hdf5.H5Tdecode(buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3793, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3794
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tdecode (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3793
 *     r = _hdf5.H5Tdecode(buf)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3796
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tdecode (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__324, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3796, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3792
 *     set_default_error_handler()
 *     r = _hdf5.H5Tdecode(buf)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":3797
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tdecode (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tencode(hid_t obj_id, unsigned char *buf, size_t *nalloc) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3788
 *     return r
 * 
 * cdef hid_t H5Tdecode(unsigned char *buf) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tdecode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3799
 *     return r
 * 
 * cdef herr_t H5Tencode(hid_t obj_id, unsigned char *buf, size_t *nalloc) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tencode(hid_t __pyx_v_obj_id, unsigned char *__pyx_v_buf, size_t *__pyx_v_nalloc) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tencode", 0);

  /* "h5py/defs.pyx":3801
 * cdef herr_t H5Tencode(hid_t obj_id, unsigned char *buf, size_t *nalloc) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tencode(obj_id, buf, nalloc)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3802
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tencode(obj_id, buf, nalloc)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tencode(__pyx_v_obj_id, __pyx_v_buf, __pyx_v_nalloc);

  /* "h5py/defs.pyx":3803
 *     set_default_error_handler()
 *     r = _hdf5.H5Tencode(obj_id, buf, nalloc)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3804
 *     r = _hdf5.H5Tencode(obj_id, buf, nalloc)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3804, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3805
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tencode (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3804
 *     r = _hdf5.H5Tencode(obj_id, buf, nalloc)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3807
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tencode (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__325, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3807, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3807, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3803
 *     set_default_error_handler()
 *     r = _hdf5.H5Tencode(obj_id, buf, nalloc)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3808
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tencode (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_conv_t H5Tfind(hid_t src_id, hid_t dst_id, H5T_cdata_t **pcdata) except <H5T_conv_t>NULL:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3799
 *     return r
 * 
 * cdef herr_t H5Tencode(hid_t obj_id, unsigned char *buf, size_t *nalloc) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tencode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3810
 *     return r
 * 
 * cdef H5T_conv_t H5Tfind(hid_t src_id, hid_t dst_id, H5T_cdata_t **pcdata) except <H5T_conv_t>NULL:             # <<<<<<<<<<<<<<
 *     cdef H5T_conv_t r
 *     set_default_error_handler()
 */

static H5T_conv_t __pyx_f_4h5py_4defs_H5Tfind(hid_t __pyx_v_src_id, hid_t __pyx_v_dst_id, H5T_cdata_t **__pyx_v_pcdata) {
  H5T_conv_t __pyx_v_r;
  H5T_conv_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tfind", 0);

  /* "h5py/defs.pyx":3812
 * cdef H5T_conv_t H5Tfind(hid_t src_id, hid_t dst_id, H5T_cdata_t **pcdata) except <H5T_conv_t>NULL:
 *     cdef H5T_conv_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tfind(src_id, dst_id, pcdata)
 *     if r==NULL:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3813
 *     cdef H5T_conv_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tfind(src_id, dst_id, pcdata)             # <<<<<<<<<<<<<<
 *     if r==NULL:
 *         if set_exception():
 */
  __pyx_v_r = H5Tfind(__pyx_v_src_id, __pyx_v_dst_id, __pyx_v_pcdata);

  /* "h5py/defs.pyx":3814
 *     set_default_error_handler()
 *     r = _hdf5.H5Tfind(src_id, dst_id, pcdata)
 *     if r==NULL:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_conv_t>NULL
 */
  __pyx_t_1 = ((__pyx_v_r == NULL) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3815
 *     r = _hdf5.H5Tfind(src_id, dst_id, pcdata)
 *     if r==NULL:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_conv_t>NULL
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3815, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3816
 *     if r==NULL:
 *         if set_exception():
 *             return <H5T_conv_t>NULL             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tfind (return value ==NULL)")
 */
      __pyx_r = ((H5T_conv_t)NULL);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3815
 *     r = _hdf5.H5Tfind(src_id, dst_id, pcdata)
 *     if r==NULL:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_conv_t>NULL
 *         else:
 */
    }

    /* "h5py/defs.pyx":3818
 *             return <H5T_conv_t>NULL
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tfind (return value ==NULL)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__326, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3818, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3814
 *     set_default_error_handler()
 *     r = _hdf5.H5Tfind(src_id, dst_id, pcdata)
 *     if r==NULL:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_conv_t>NULL
 */
  }

  /* "h5py/defs.pyx":3819
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tfind (return value ==NULL)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tconvert(hid_t src_id, hid_t dst_id, size_t nelmts, void *buf, void *background, hid_t plist_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3810
 *     return r
 * 
 * cdef H5T_conv_t H5Tfind(hid_t src_id, hid_t dst_id, H5T_cdata_t **pcdata) except <H5T_conv_t>NULL:             # <<<<<<<<<<<<<<
 *     cdef H5T_conv_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tfind", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5T_conv_t)NULL);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3821
 *     return r
 * 
 * cdef herr_t H5Tconvert(hid_t src_id, hid_t dst_id, size_t nelmts, void *buf, void *background, hid_t plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Tconvert(hid_t __pyx_v_src_id, hid_t __pyx_v_dst_id, size_t __pyx_v_nelmts, void *__pyx_v_buf, void *__pyx_v_background, hid_t __pyx_v_plist_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tconvert", 0);

  /* "h5py/defs.pyx":3823
 * cdef herr_t H5Tconvert(hid_t src_id, hid_t dst_id, size_t nelmts, void *buf, void *background, hid_t plist_id) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Tconvert(src_id, dst_id, nelmts, buf, background, plist_id)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":3824
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Tconvert(src_id, dst_id, nelmts, buf, background, plist_id)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":3825
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Tconvert(src_id, dst_id, nelmts, buf, background, plist_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Tconvert(__pyx_v_src_id, __pyx_v_dst_id, __pyx_v_nelmts, __pyx_v_buf, __pyx_v_background, __pyx_v_plist_id);
      }

      /* "h5py/defs.pyx":3823
 * cdef herr_t H5Tconvert(hid_t src_id, hid_t dst_id, size_t nelmts, void *buf, void *background, hid_t plist_id) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Tconvert(src_id, dst_id, nelmts, buf, background, plist_id)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":3826
 *         set_default_error_handler()
 *         r = _hdf5.H5Tconvert(src_id, dst_id, nelmts, buf, background, plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3827
 *         r = _hdf5.H5Tconvert(src_id, dst_id, nelmts, buf, background, plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3827, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3828
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tconvert (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3827
 *         r = _hdf5.H5Tconvert(src_id, dst_id, nelmts, buf, background, plist_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3830
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tconvert (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__327, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3830, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3830, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3826
 *         set_default_error_handler()
 *         r = _hdf5.H5Tconvert(src_id, dst_id, nelmts, buf, background, plist_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3831
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tconvert (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3821
 *     return r
 * 
 * cdef herr_t H5Tconvert(hid_t src_id, hid_t dst_id, size_t nelmts, void *buf, void *background, hid_t plist_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tconvert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3833
 *     return r
 * 
 * cdef herr_t H5Tregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Tregister(H5T_pers_t __pyx_v_pers, char *__pyx_v_name, hid_t __pyx_v_src_id, hid_t __pyx_v_dst_id, H5T_conv_t __pyx_v_func) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tregister", 0);

  /* "h5py/defs.pyx":3835
 * cdef herr_t H5Tregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Tregister(pers, name, src_id, dst_id, func)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":3836
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Tregister(pers, name, src_id, dst_id, func)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":3837
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Tregister(pers, name, src_id, dst_id, func)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Tregister(__pyx_v_pers, __pyx_v_name, __pyx_v_src_id, __pyx_v_dst_id, __pyx_v_func);
      }

      /* "h5py/defs.pyx":3835
 * cdef herr_t H5Tregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Tregister(pers, name, src_id, dst_id, func)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":3838
 *         set_default_error_handler()
 *         r = _hdf5.H5Tregister(pers, name, src_id, dst_id, func)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3839
 *         r = _hdf5.H5Tregister(pers, name, src_id, dst_id, func)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3839, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3840
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tregister (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3839
 *         r = _hdf5.H5Tregister(pers, name, src_id, dst_id, func)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3842
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__328, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3842, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3842, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3838
 *         set_default_error_handler()
 *         r = _hdf5.H5Tregister(pers, name, src_id, dst_id, func)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3843
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tregister (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tunregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3833
 *     return r
 * 
 * cdef herr_t H5Tregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tregister", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3845
 *     return r
 * 
 * cdef herr_t H5Tunregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

static herr_t __pyx_f_4h5py_4defs_H5Tunregister(H5T_pers_t __pyx_v_pers, char *__pyx_v_name, hid_t __pyx_v_src_id, hid_t __pyx_v_dst_id, H5T_conv_t __pyx_v_func) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tunregister", 0);

  /* "h5py/defs.pyx":3847
 * cdef herr_t H5Tunregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Tunregister(pers, name, src_id, dst_id, func)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "h5py/defs.pyx":3848
 *     cdef herr_t r
 *     with nogil:
 *         set_default_error_handler()             # <<<<<<<<<<<<<<
 *         r = _hdf5.H5Tunregister(pers, name, src_id, dst_id, func)
 *     if r<0:
 */
        __pyx_f_4h5py_7_errors_set_default_error_handler();

        /* "h5py/defs.pyx":3849
 *     with nogil:
 *         set_default_error_handler()
 *         r = _hdf5.H5Tunregister(pers, name, src_id, dst_id, func)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
        __pyx_v_r = H5Tunregister(__pyx_v_pers, __pyx_v_name, __pyx_v_src_id, __pyx_v_dst_id, __pyx_v_func);
      }

      /* "h5py/defs.pyx":3847
 * cdef herr_t H5Tunregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:
 *     cdef herr_t r
 *     with nogil:             # <<<<<<<<<<<<<<
 *         set_default_error_handler()
 *         r = _hdf5.H5Tunregister(pers, name, src_id, dst_id, func)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "h5py/defs.pyx":3850
 *         set_default_error_handler()
 *         r = _hdf5.H5Tunregister(pers, name, src_id, dst_id, func)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3851
 *         r = _hdf5.H5Tunregister(pers, name, src_id, dst_id, func)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3851, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3852
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tunregister (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3851
 *         r = _hdf5.H5Tunregister(pers, name, src_id, dst_id, func)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3854
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tunregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__329, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3854, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3850
 *         set_default_error_handler()
 *         r = _hdf5.H5Tunregister(pers, name, src_id, dst_id, func)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3855
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tunregister (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_size(hid_t type_id, size_t size) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3845
 *     return r
 * 
 * cdef herr_t H5Tunregister(H5T_pers_t pers, char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     with nogil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tunregister", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3857
 *     return r
 * 
 * cdef herr_t H5Tset_size(hid_t type_id, size_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_size(hid_t __pyx_v_type_id, size_t __pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_size", 0);

  /* "h5py/defs.pyx":3859
 * cdef herr_t H5Tset_size(hid_t type_id, size_t size) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_size(type_id, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3860
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_size(type_id, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_size(__pyx_v_type_id, __pyx_v_size);

  /* "h5py/defs.pyx":3861
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_size(type_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3862
 *     r = _hdf5.H5Tset_size(type_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3862, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3863
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_size (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3862
 *     r = _hdf5.H5Tset_size(type_id, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3865
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__330, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3865, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3865, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3861
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_size(type_id, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3866
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_size (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_order_t H5Tget_order(hid_t type_id) except <H5T_order_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3857
 *     return r
 * 
 * cdef herr_t H5Tset_size(hid_t type_id, size_t size) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3868
 *     return r
 * 
 * cdef H5T_order_t H5Tget_order(hid_t type_id) except <H5T_order_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_order_t r
 *     set_default_error_handler()
 */

static H5T_order_t __pyx_f_4h5py_4defs_H5Tget_order(hid_t __pyx_v_type_id) {
  H5T_order_t __pyx_v_r;
  H5T_order_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_order", 0);

  /* "h5py/defs.pyx":3870
 * cdef H5T_order_t H5Tget_order(hid_t type_id) except <H5T_order_t>-1:
 *     cdef H5T_order_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_order(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3871
 *     cdef H5T_order_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_order(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_order(__pyx_v_type_id);

  /* "h5py/defs.pyx":3872
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_order(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_order_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3873
 *     r = _hdf5.H5Tget_order(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_order_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3873, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3874
 *     if r<0:
 *         if set_exception():
 *             return <H5T_order_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_order (return value <0)")
 */
      __pyx_r = ((H5T_order_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3873
 *     r = _hdf5.H5Tget_order(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_order_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3876
 *             return <H5T_order_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__331, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3876, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3876, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3872
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_order(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_order_t>-1
 */
  }

  /* "h5py/defs.pyx":3877
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_order (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_order(hid_t type_id, H5T_order_t order) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3868
 *     return r
 * 
 * cdef H5T_order_t H5Tget_order(hid_t type_id) except <H5T_order_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_order_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5T_order_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3879
 *     return r
 * 
 * cdef herr_t H5Tset_order(hid_t type_id, H5T_order_t order) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_order(hid_t __pyx_v_type_id, H5T_order_t __pyx_v_order) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_order", 0);

  /* "h5py/defs.pyx":3881
 * cdef herr_t H5Tset_order(hid_t type_id, H5T_order_t order) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_order(type_id, order)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3882
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_order(type_id, order)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_order(__pyx_v_type_id, __pyx_v_order);

  /* "h5py/defs.pyx":3883
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_order(type_id, order)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3884
 *     r = _hdf5.H5Tset_order(type_id, order)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3884, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3885
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_order (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3884
 *     r = _hdf5.H5Tset_order(type_id, order)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3887
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__332, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3887, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3887, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3883
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_order(type_id, order)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3888
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_order (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hsize_t H5Tget_precision(hid_t type_id) except <hsize_t>0:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3879
 *     return r
 * 
 * cdef herr_t H5Tset_order(hid_t type_id, H5T_order_t order) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3890
 *     return r
 * 
 * cdef hsize_t H5Tget_precision(hid_t type_id) except <hsize_t>0:             # <<<<<<<<<<<<<<
 *     cdef hsize_t r
 *     set_default_error_handler()
 */

static hsize_t __pyx_f_4h5py_4defs_H5Tget_precision(hid_t __pyx_v_type_id) {
  hsize_t __pyx_v_r;
  hsize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_precision", 0);

  /* "h5py/defs.pyx":3892
 * cdef hsize_t H5Tget_precision(hid_t type_id) except <hsize_t>0:
 *     cdef hsize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_precision(type_id)
 *     if r==0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3893
 *     cdef hsize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_precision(type_id)             # <<<<<<<<<<<<<<
 *     if r==0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_precision(__pyx_v_type_id);

  /* "h5py/defs.pyx":3894
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_precision(type_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hsize_t>0
 */
  __pyx_t_1 = ((__pyx_v_r == 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3895
 *     r = _hdf5.H5Tget_precision(type_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hsize_t>0
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3895, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3896
 *     if r==0:
 *         if set_exception():
 *             return <hsize_t>0             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_precision (return value ==0)")
 */
      __pyx_r = ((hsize_t)0);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3895
 *     r = _hdf5.H5Tget_precision(type_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hsize_t>0
 *         else:
 */
    }

    /* "h5py/defs.pyx":3898
 *             return <hsize_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_precision (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__333, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3898, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3898, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3894
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_precision(type_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hsize_t>0
 */
  }

  /* "h5py/defs.pyx":3899
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_precision (return value ==0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_precision(hid_t type_id, size_t prec) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3890
 *     return r
 * 
 * cdef hsize_t H5Tget_precision(hid_t type_id) except <hsize_t>0:             # <<<<<<<<<<<<<<
 *     cdef hsize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_precision", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hsize_t)0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3901
 *     return r
 * 
 * cdef herr_t H5Tset_precision(hid_t type_id, size_t prec) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_precision(hid_t __pyx_v_type_id, size_t __pyx_v_prec) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_precision", 0);

  /* "h5py/defs.pyx":3903
 * cdef herr_t H5Tset_precision(hid_t type_id, size_t prec) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_precision(type_id, prec)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3904
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_precision(type_id, prec)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_precision(__pyx_v_type_id, __pyx_v_prec);

  /* "h5py/defs.pyx":3905
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_precision(type_id, prec)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3906
 *     r = _hdf5.H5Tset_precision(type_id, prec)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3906, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3907
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_precision (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3906
 *     r = _hdf5.H5Tset_precision(type_id, prec)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3909
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_precision (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__334, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3909, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3905
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_precision(type_id, prec)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3910
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_precision (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Tget_offset(hid_t type_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3901
 *     return r
 * 
 * cdef herr_t H5Tset_precision(hid_t type_id, size_t prec) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_precision", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3912
 *     return r
 * 
 * cdef int H5Tget_offset(hid_t type_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Tget_offset(hid_t __pyx_v_type_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_offset", 0);

  /* "h5py/defs.pyx":3914
 * cdef int H5Tget_offset(hid_t type_id) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_offset(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3915
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_offset(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_offset(__pyx_v_type_id);

  /* "h5py/defs.pyx":3916
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_offset(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3917
 *     r = _hdf5.H5Tget_offset(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3917, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3918
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_offset (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3917
 *     r = _hdf5.H5Tget_offset(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3920
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__335, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3920, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3920, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3916
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_offset(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":3921
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_offset (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_offset(hid_t type_id, size_t offset) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3912
 *     return r
 * 
 * cdef int H5Tget_offset(hid_t type_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3923
 *     return r
 * 
 * cdef herr_t H5Tset_offset(hid_t type_id, size_t offset) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_offset(hid_t __pyx_v_type_id, size_t __pyx_v_offset) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_offset", 0);

  /* "h5py/defs.pyx":3925
 * cdef herr_t H5Tset_offset(hid_t type_id, size_t offset) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_offset(type_id, offset)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3926
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_offset(type_id, offset)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_offset(__pyx_v_type_id, __pyx_v_offset);

  /* "h5py/defs.pyx":3927
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_offset(type_id, offset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3928
 *     r = _hdf5.H5Tset_offset(type_id, offset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3928, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3929
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_offset (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3928
 *     r = _hdf5.H5Tset_offset(type_id, offset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3931
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__336, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3931, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3931, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3927
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_offset(type_id, offset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3932
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_offset (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tget_pad(hid_t type_id, H5T_pad_t * lsb, H5T_pad_t * msb ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3923
 *     return r
 * 
 * cdef herr_t H5Tset_offset(hid_t type_id, size_t offset) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3934
 *     return r
 * 
 * cdef herr_t H5Tget_pad(hid_t type_id, H5T_pad_t * lsb, H5T_pad_t * msb ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tget_pad(hid_t __pyx_v_type_id, H5T_pad_t *__pyx_v_lsb, H5T_pad_t *__pyx_v_msb) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_pad", 0);

  /* "h5py/defs.pyx":3936
 * cdef herr_t H5Tget_pad(hid_t type_id, H5T_pad_t * lsb, H5T_pad_t * msb ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_pad(type_id, lsb, msb)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3937
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_pad(type_id, lsb, msb)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_pad(__pyx_v_type_id, __pyx_v_lsb, __pyx_v_msb);

  /* "h5py/defs.pyx":3938
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_pad(type_id, lsb, msb)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3939
 *     r = _hdf5.H5Tget_pad(type_id, lsb, msb)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3939, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3940
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_pad (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3939
 *     r = _hdf5.H5Tget_pad(type_id, lsb, msb)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3942
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_pad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__337, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3942, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3942, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3938
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_pad(type_id, lsb, msb)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3943
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_pad (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_pad(hid_t type_id, H5T_pad_t lsb, H5T_pad_t msb ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3934
 *     return r
 * 
 * cdef herr_t H5Tget_pad(hid_t type_id, H5T_pad_t * lsb, H5T_pad_t * msb ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_pad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3945
 *     return r
 * 
 * cdef herr_t H5Tset_pad(hid_t type_id, H5T_pad_t lsb, H5T_pad_t msb ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_pad(hid_t __pyx_v_type_id, H5T_pad_t __pyx_v_lsb, H5T_pad_t __pyx_v_msb) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_pad", 0);

  /* "h5py/defs.pyx":3947
 * cdef herr_t H5Tset_pad(hid_t type_id, H5T_pad_t lsb, H5T_pad_t msb ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_pad(type_id, lsb, msb)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3948
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_pad(type_id, lsb, msb)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_pad(__pyx_v_type_id, __pyx_v_lsb, __pyx_v_msb);

  /* "h5py/defs.pyx":3949
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_pad(type_id, lsb, msb)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3950
 *     r = _hdf5.H5Tset_pad(type_id, lsb, msb)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3950, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3951
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_pad (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3950
 *     r = _hdf5.H5Tset_pad(type_id, lsb, msb)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3953
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_pad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__338, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3953, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3949
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_pad(type_id, lsb, msb)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3954
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_pad (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_sign_t H5Tget_sign(hid_t type_id) except <H5T_sign_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3945
 *     return r
 * 
 * cdef herr_t H5Tset_pad(hid_t type_id, H5T_pad_t lsb, H5T_pad_t msb ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_pad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3956
 *     return r
 * 
 * cdef H5T_sign_t H5Tget_sign(hid_t type_id) except <H5T_sign_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_sign_t r
 *     set_default_error_handler()
 */

static H5T_sign_t __pyx_f_4h5py_4defs_H5Tget_sign(hid_t __pyx_v_type_id) {
  H5T_sign_t __pyx_v_r;
  H5T_sign_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_sign", 0);

  /* "h5py/defs.pyx":3958
 * cdef H5T_sign_t H5Tget_sign(hid_t type_id) except <H5T_sign_t>-1:
 *     cdef H5T_sign_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_sign(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3959
 *     cdef H5T_sign_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_sign(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_sign(__pyx_v_type_id);

  /* "h5py/defs.pyx":3960
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_sign(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_sign_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3961
 *     r = _hdf5.H5Tget_sign(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_sign_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3961, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3962
 *     if r<0:
 *         if set_exception():
 *             return <H5T_sign_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_sign (return value <0)")
 */
      __pyx_r = ((H5T_sign_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3961
 *     r = _hdf5.H5Tget_sign(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_sign_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3964
 *             return <H5T_sign_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_sign (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__339, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3964, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3964, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3960
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_sign(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_sign_t>-1
 */
  }

  /* "h5py/defs.pyx":3965
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_sign (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_sign(hid_t type_id, H5T_sign_t sign) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3956
 *     return r
 * 
 * cdef H5T_sign_t H5Tget_sign(hid_t type_id) except <H5T_sign_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_sign_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_sign", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5T_sign_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3967
 *     return r
 * 
 * cdef herr_t H5Tset_sign(hid_t type_id, H5T_sign_t sign) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_sign(hid_t __pyx_v_type_id, H5T_sign_t __pyx_v_sign) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_sign", 0);

  /* "h5py/defs.pyx":3969
 * cdef herr_t H5Tset_sign(hid_t type_id, H5T_sign_t sign) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_sign(type_id, sign)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3970
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_sign(type_id, sign)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_sign(__pyx_v_type_id, __pyx_v_sign);

  /* "h5py/defs.pyx":3971
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_sign(type_id, sign)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3972
 *     r = _hdf5.H5Tset_sign(type_id, sign)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3972, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3973
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_sign (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3972
 *     r = _hdf5.H5Tset_sign(type_id, sign)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3975
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_sign (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__340, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3975, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3975, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3971
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_sign(type_id, sign)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3976
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_sign (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tget_fields(hid_t type_id, size_t *spos, size_t *epos, size_t *esize, size_t *mpos, size_t *msize ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3967
 *     return r
 * 
 * cdef herr_t H5Tset_sign(hid_t type_id, H5T_sign_t sign) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_sign", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3978
 *     return r
 * 
 * cdef herr_t H5Tget_fields(hid_t type_id, size_t *spos, size_t *epos, size_t *esize, size_t *mpos, size_t *msize ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tget_fields(hid_t __pyx_v_type_id, size_t *__pyx_v_spos, size_t *__pyx_v_epos, size_t *__pyx_v_esize, size_t *__pyx_v_mpos, size_t *__pyx_v_msize) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_fields", 0);

  /* "h5py/defs.pyx":3980
 * cdef herr_t H5Tget_fields(hid_t type_id, size_t *spos, size_t *epos, size_t *esize, size_t *mpos, size_t *msize ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3981
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_fields(type_id, spos, epos, esize, mpos, msize)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_fields(__pyx_v_type_id, __pyx_v_spos, __pyx_v_epos, __pyx_v_esize, __pyx_v_mpos, __pyx_v_msize);

  /* "h5py/defs.pyx":3982
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3983
 *     r = _hdf5.H5Tget_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3983, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3984
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_fields (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3983
 *     r = _hdf5.H5Tget_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3986
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_fields (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__341, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3986, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3986, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3982
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3987
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_fields (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_fields(hid_t type_id, size_t spos, size_t epos, size_t esize, size_t mpos, size_t msize ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3978
 *     return r
 * 
 * cdef herr_t H5Tget_fields(hid_t type_id, size_t *spos, size_t *epos, size_t *esize, size_t *mpos, size_t *msize ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":3989
 *     return r
 * 
 * cdef herr_t H5Tset_fields(hid_t type_id, size_t spos, size_t epos, size_t esize, size_t mpos, size_t msize ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_fields(hid_t __pyx_v_type_id, size_t __pyx_v_spos, size_t __pyx_v_epos, size_t __pyx_v_esize, size_t __pyx_v_mpos, size_t __pyx_v_msize) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_fields", 0);

  /* "h5py/defs.pyx":3991
 * cdef herr_t H5Tset_fields(hid_t type_id, size_t spos, size_t epos, size_t esize, size_t mpos, size_t msize ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":3992
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_fields(type_id, spos, epos, esize, mpos, msize)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_fields(__pyx_v_type_id, __pyx_v_spos, __pyx_v_epos, __pyx_v_esize, __pyx_v_mpos, __pyx_v_msize);

  /* "h5py/defs.pyx":3993
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":3994
 *     r = _hdf5.H5Tset_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3994, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":3995
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_fields (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":3994
 *     r = _hdf5.H5Tset_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":3997
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_fields (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__342, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3997, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 3997, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":3993
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_fields(type_id, spos, epos, esize, mpos, msize)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":3998
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_fields (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef size_t H5Tget_ebias(hid_t type_id) except <size_t>0:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":3989
 *     return r
 * 
 * cdef herr_t H5Tset_fields(hid_t type_id, size_t spos, size_t epos, size_t esize, size_t mpos, size_t msize ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4000
 *     return r
 * 
 * cdef size_t H5Tget_ebias(hid_t type_id) except <size_t>0:             # <<<<<<<<<<<<<<
 *     cdef size_t r
 *     set_default_error_handler()
 */

static size_t __pyx_f_4h5py_4defs_H5Tget_ebias(hid_t __pyx_v_type_id) {
  size_t __pyx_v_r;
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_ebias", 0);

  /* "h5py/defs.pyx":4002
 * cdef size_t H5Tget_ebias(hid_t type_id) except <size_t>0:
 *     cdef size_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_ebias(type_id)
 *     if r==0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4003
 *     cdef size_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_ebias(type_id)             # <<<<<<<<<<<<<<
 *     if r==0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_ebias(__pyx_v_type_id);

  /* "h5py/defs.pyx":4004
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_ebias(type_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <size_t>0
 */
  __pyx_t_1 = ((__pyx_v_r == 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4005
 *     r = _hdf5.H5Tget_ebias(type_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <size_t>0
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4005, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4006
 *     if r==0:
 *         if set_exception():
 *             return <size_t>0             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_ebias (return value ==0)")
 */
      __pyx_r = ((size_t)0);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4005
 *     r = _hdf5.H5Tget_ebias(type_id)
 *     if r==0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <size_t>0
 *         else:
 */
    }

    /* "h5py/defs.pyx":4008
 *             return <size_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_ebias (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__343, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4008, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4008, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4004
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_ebias(type_id)
 *     if r==0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <size_t>0
 */
  }

  /* "h5py/defs.pyx":4009
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_ebias (return value ==0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_ebias(hid_t type_id, size_t ebias) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4000
 *     return r
 * 
 * cdef size_t H5Tget_ebias(hid_t type_id) except <size_t>0:             # <<<<<<<<<<<<<<
 *     cdef size_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_ebias", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((size_t)0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4011
 *     return r
 * 
 * cdef herr_t H5Tset_ebias(hid_t type_id, size_t ebias) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_ebias(hid_t __pyx_v_type_id, size_t __pyx_v_ebias) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_ebias", 0);

  /* "h5py/defs.pyx":4013
 * cdef herr_t H5Tset_ebias(hid_t type_id, size_t ebias) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_ebias(type_id, ebias)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4014
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_ebias(type_id, ebias)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_ebias(__pyx_v_type_id, __pyx_v_ebias);

  /* "h5py/defs.pyx":4015
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_ebias(type_id, ebias)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4016
 *     r = _hdf5.H5Tset_ebias(type_id, ebias)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4016, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4017
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_ebias (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4016
 *     r = _hdf5.H5Tset_ebias(type_id, ebias)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4019
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_ebias (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__344, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4019, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4019, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4015
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_ebias(type_id, ebias)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4020
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_ebias (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_norm_t H5Tget_norm(hid_t type_id) except <H5T_norm_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4011
 *     return r
 * 
 * cdef herr_t H5Tset_ebias(hid_t type_id, size_t ebias) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_ebias", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4022
 *     return r
 * 
 * cdef H5T_norm_t H5Tget_norm(hid_t type_id) except <H5T_norm_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_norm_t r
 *     set_default_error_handler()
 */

static H5T_norm_t __pyx_f_4h5py_4defs_H5Tget_norm(hid_t __pyx_v_type_id) {
  H5T_norm_t __pyx_v_r;
  H5T_norm_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_norm", 0);

  /* "h5py/defs.pyx":4024
 * cdef H5T_norm_t H5Tget_norm(hid_t type_id) except <H5T_norm_t>-1:
 *     cdef H5T_norm_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_norm(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4025
 *     cdef H5T_norm_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_norm(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_norm(__pyx_v_type_id);

  /* "h5py/defs.pyx":4026
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_norm(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_norm_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4027
 *     r = _hdf5.H5Tget_norm(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_norm_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4027, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4028
 *     if r<0:
 *         if set_exception():
 *             return <H5T_norm_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_norm (return value <0)")
 */
      __pyx_r = ((H5T_norm_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4027
 *     r = _hdf5.H5Tget_norm(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_norm_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4030
 *             return <H5T_norm_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_norm (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__345, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4030, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4030, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4026
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_norm(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_norm_t>-1
 */
  }

  /* "h5py/defs.pyx":4031
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_norm (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_norm(hid_t type_id, H5T_norm_t norm) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4022
 *     return r
 * 
 * cdef H5T_norm_t H5Tget_norm(hid_t type_id) except <H5T_norm_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_norm_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5T_norm_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4033
 *     return r
 * 
 * cdef herr_t H5Tset_norm(hid_t type_id, H5T_norm_t norm) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_norm(hid_t __pyx_v_type_id, H5T_norm_t __pyx_v_norm) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_norm", 0);

  /* "h5py/defs.pyx":4035
 * cdef herr_t H5Tset_norm(hid_t type_id, H5T_norm_t norm) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_norm(type_id, norm)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4036
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_norm(type_id, norm)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_norm(__pyx_v_type_id, __pyx_v_norm);

  /* "h5py/defs.pyx":4037
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_norm(type_id, norm)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4038
 *     r = _hdf5.H5Tset_norm(type_id, norm)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4038, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4039
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_norm (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4038
 *     r = _hdf5.H5Tset_norm(type_id, norm)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4041
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_norm (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__346, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4041, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4037
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_norm(type_id, norm)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4042
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_norm (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_pad_t H5Tget_inpad(hid_t type_id) except <H5T_pad_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4033
 *     return r
 * 
 * cdef herr_t H5Tset_norm(hid_t type_id, H5T_norm_t norm) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4044
 *     return r
 * 
 * cdef H5T_pad_t H5Tget_inpad(hid_t type_id) except <H5T_pad_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_pad_t r
 *     set_default_error_handler()
 */

static H5T_pad_t __pyx_f_4h5py_4defs_H5Tget_inpad(hid_t __pyx_v_type_id) {
  H5T_pad_t __pyx_v_r;
  H5T_pad_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_inpad", 0);

  /* "h5py/defs.pyx":4046
 * cdef H5T_pad_t H5Tget_inpad(hid_t type_id) except <H5T_pad_t>-1:
 *     cdef H5T_pad_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_inpad(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4047
 *     cdef H5T_pad_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_inpad(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_inpad(__pyx_v_type_id);

  /* "h5py/defs.pyx":4048
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_inpad(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_pad_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4049
 *     r = _hdf5.H5Tget_inpad(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_pad_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4049, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4050
 *     if r<0:
 *         if set_exception():
 *             return <H5T_pad_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_inpad (return value <0)")
 */
      __pyx_r = ((H5T_pad_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4049
 *     r = _hdf5.H5Tget_inpad(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_pad_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4052
 *             return <H5T_pad_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_inpad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__347, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4052, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4052, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4048
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_inpad(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_pad_t>-1
 */
  }

  /* "h5py/defs.pyx":4053
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_inpad (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_inpad(hid_t type_id, H5T_pad_t inpad) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4044
 *     return r
 * 
 * cdef H5T_pad_t H5Tget_inpad(hid_t type_id) except <H5T_pad_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_pad_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_inpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5T_pad_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4055
 *     return r
 * 
 * cdef herr_t H5Tset_inpad(hid_t type_id, H5T_pad_t inpad) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_inpad(hid_t __pyx_v_type_id, H5T_pad_t __pyx_v_inpad) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_inpad", 0);

  /* "h5py/defs.pyx":4057
 * cdef herr_t H5Tset_inpad(hid_t type_id, H5T_pad_t inpad) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_inpad(type_id, inpad)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4058
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_inpad(type_id, inpad)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_inpad(__pyx_v_type_id, __pyx_v_inpad);

  /* "h5py/defs.pyx":4059
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_inpad(type_id, inpad)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4060
 *     r = _hdf5.H5Tset_inpad(type_id, inpad)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4060, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4061
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_inpad (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4060
 *     r = _hdf5.H5Tset_inpad(type_id, inpad)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4063
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_inpad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__348, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4063, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4063, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4059
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_inpad(type_id, inpad)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4064
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_inpad (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_cset_t H5Tget_cset(hid_t type_id) except <H5T_cset_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4055
 *     return r
 * 
 * cdef herr_t H5Tset_inpad(hid_t type_id, H5T_pad_t inpad) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_inpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4066
 *     return r
 * 
 * cdef H5T_cset_t H5Tget_cset(hid_t type_id) except <H5T_cset_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_cset_t r
 *     set_default_error_handler()
 */

static H5T_cset_t __pyx_f_4h5py_4defs_H5Tget_cset(hid_t __pyx_v_type_id) {
  H5T_cset_t __pyx_v_r;
  H5T_cset_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_cset", 0);

  /* "h5py/defs.pyx":4068
 * cdef H5T_cset_t H5Tget_cset(hid_t type_id) except <H5T_cset_t>-1:
 *     cdef H5T_cset_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_cset(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4069
 *     cdef H5T_cset_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_cset(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_cset(__pyx_v_type_id);

  /* "h5py/defs.pyx":4070
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_cset(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_cset_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4071
 *     r = _hdf5.H5Tget_cset(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_cset_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4071, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4072
 *     if r<0:
 *         if set_exception():
 *             return <H5T_cset_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_cset (return value <0)")
 */
      __pyx_r = ((H5T_cset_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4071
 *     r = _hdf5.H5Tget_cset(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_cset_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4074
 *             return <H5T_cset_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_cset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__349, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4074, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4074, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4070
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_cset(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_cset_t>-1
 */
  }

  /* "h5py/defs.pyx":4075
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_cset (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_cset(hid_t type_id, H5T_cset_t cset) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4066
 *     return r
 * 
 * cdef H5T_cset_t H5Tget_cset(hid_t type_id) except <H5T_cset_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_cset_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_cset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5T_cset_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4077
 *     return r
 * 
 * cdef herr_t H5Tset_cset(hid_t type_id, H5T_cset_t cset) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_cset(hid_t __pyx_v_type_id, H5T_cset_t __pyx_v_cset) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_cset", 0);

  /* "h5py/defs.pyx":4079
 * cdef herr_t H5Tset_cset(hid_t type_id, H5T_cset_t cset) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_cset(type_id, cset)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4080
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_cset(type_id, cset)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_cset(__pyx_v_type_id, __pyx_v_cset);

  /* "h5py/defs.pyx":4081
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_cset(type_id, cset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4082
 *     r = _hdf5.H5Tset_cset(type_id, cset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4082, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4083
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_cset (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4082
 *     r = _hdf5.H5Tset_cset(type_id, cset)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4085
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_cset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__350, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4085, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4085, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4081
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_cset(type_id, cset)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4086
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_cset (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_str_t H5Tget_strpad(hid_t type_id) except <H5T_str_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4077
 *     return r
 * 
 * cdef herr_t H5Tset_cset(hid_t type_id, H5T_cset_t cset) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_cset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4088
 *     return r
 * 
 * cdef H5T_str_t H5Tget_strpad(hid_t type_id) except <H5T_str_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_str_t r
 *     set_default_error_handler()
 */

static H5T_str_t __pyx_f_4h5py_4defs_H5Tget_strpad(hid_t __pyx_v_type_id) {
  H5T_str_t __pyx_v_r;
  H5T_str_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_strpad", 0);

  /* "h5py/defs.pyx":4090
 * cdef H5T_str_t H5Tget_strpad(hid_t type_id) except <H5T_str_t>-1:
 *     cdef H5T_str_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_strpad(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4091
 *     cdef H5T_str_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_strpad(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_strpad(__pyx_v_type_id);

  /* "h5py/defs.pyx":4092
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_strpad(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_str_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4093
 *     r = _hdf5.H5Tget_strpad(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_str_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4093, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4094
 *     if r<0:
 *         if set_exception():
 *             return <H5T_str_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_strpad (return value <0)")
 */
      __pyx_r = ((H5T_str_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4093
 *     r = _hdf5.H5Tget_strpad(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_str_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4096
 *             return <H5T_str_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_strpad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__351, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4096, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4096, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4092
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_strpad(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_str_t>-1
 */
  }

  /* "h5py/defs.pyx":4097
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_strpad (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_strpad(hid_t type_id, H5T_str_t strpad) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4088
 *     return r
 * 
 * cdef H5T_str_t H5Tget_strpad(hid_t type_id) except <H5T_str_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_str_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_strpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((H5T_str_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4099
 *     return r
 * 
 * cdef herr_t H5Tset_strpad(hid_t type_id, H5T_str_t strpad) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_strpad(hid_t __pyx_v_type_id, H5T_str_t __pyx_v_strpad) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_strpad", 0);

  /* "h5py/defs.pyx":4101
 * cdef herr_t H5Tset_strpad(hid_t type_id, H5T_str_t strpad) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_strpad(type_id, strpad)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4102
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_strpad(type_id, strpad)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_strpad(__pyx_v_type_id, __pyx_v_strpad);

  /* "h5py/defs.pyx":4103
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_strpad(type_id, strpad)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4104
 *     r = _hdf5.H5Tset_strpad(type_id, strpad)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4104, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4105
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_strpad (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4104
 *     r = _hdf5.H5Tset_strpad(type_id, strpad)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4107
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_strpad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__352, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4107, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4103
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_strpad(type_id, strpad)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4108
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_strpad (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tvlen_create(hid_t base_type_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4099
 *     return r
 * 
 * cdef herr_t H5Tset_strpad(hid_t type_id, H5T_str_t strpad) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_strpad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4110
 *     return r
 * 
 * cdef hid_t H5Tvlen_create(hid_t base_type_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tvlen_create(hid_t __pyx_v_base_type_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tvlen_create", 0);

  /* "h5py/defs.pyx":4112
 * cdef hid_t H5Tvlen_create(hid_t base_type_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tvlen_create(base_type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4113
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tvlen_create(base_type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tvlen_create(__pyx_v_base_type_id);

  /* "h5py/defs.pyx":4114
 *     set_default_error_handler()
 *     r = _hdf5.H5Tvlen_create(base_type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4115
 *     r = _hdf5.H5Tvlen_create(base_type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4115, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4116
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tvlen_create (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4115
 *     r = _hdf5.H5Tvlen_create(base_type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4118
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tvlen_create (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__353, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4118, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4118, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4114
 *     set_default_error_handler()
 *     r = _hdf5.H5Tvlen_create(base_type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":4119
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tvlen_create (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Tis_variable_str(hid_t dtype_id) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4110
 *     return r
 * 
 * cdef hid_t H5Tvlen_create(hid_t base_type_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tvlen_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4121
 *     return r
 * 
 * cdef htri_t H5Tis_variable_str(hid_t dtype_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Tis_variable_str(hid_t __pyx_v_dtype_id) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tis_variable_str", 0);

  /* "h5py/defs.pyx":4123
 * cdef htri_t H5Tis_variable_str(hid_t dtype_id) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tis_variable_str(dtype_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4124
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tis_variable_str(dtype_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tis_variable_str(__pyx_v_dtype_id);

  /* "h5py/defs.pyx":4125
 *     set_default_error_handler()
 *     r = _hdf5.H5Tis_variable_str(dtype_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4126
 *     r = _hdf5.H5Tis_variable_str(dtype_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4126, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4127
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tis_variable_str (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4126
 *     r = _hdf5.H5Tis_variable_str(dtype_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4129
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tis_variable_str (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__354, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4129, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4129, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4125
 *     set_default_error_handler()
 *     r = _hdf5.H5Tis_variable_str(dtype_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":4130
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tis_variable_str (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Tget_nmembers(hid_t type_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4121
 *     return r
 * 
 * cdef htri_t H5Tis_variable_str(hid_t dtype_id) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tis_variable_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4132
 *     return r
 * 
 * cdef int H5Tget_nmembers(hid_t type_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Tget_nmembers(hid_t __pyx_v_type_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_nmembers", 0);

  /* "h5py/defs.pyx":4134
 * cdef int H5Tget_nmembers(hid_t type_id) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_nmembers(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4135
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_nmembers(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_nmembers(__pyx_v_type_id);

  /* "h5py/defs.pyx":4136
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_nmembers(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4137
 *     r = _hdf5.H5Tget_nmembers(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4137, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4138
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_nmembers (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4137
 *     r = _hdf5.H5Tget_nmembers(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4140
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_nmembers (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__355, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4140, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4136
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_nmembers(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":4141
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_nmembers (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef H5T_class_t H5Tget_member_class(hid_t type_id, int member_no) except <H5T_class_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4132
 *     return r
 * 
 * cdef int H5Tget_nmembers(hid_t type_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_nmembers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4143
 *     return r
 * 
 * cdef H5T_class_t H5Tget_member_class(hid_t type_id, int member_no) except <H5T_class_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_class_t r
 *     set_default_error_handler()
 */

static enum H5T_class_t __pyx_f_4h5py_4defs_H5Tget_member_class(hid_t __pyx_v_type_id, int __pyx_v_member_no) {
  enum H5T_class_t __pyx_v_r;
  enum H5T_class_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_member_class", 0);

  /* "h5py/defs.pyx":4145
 * cdef H5T_class_t H5Tget_member_class(hid_t type_id, int member_no) except <H5T_class_t>-1:
 *     cdef H5T_class_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_member_class(type_id, member_no)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4146
 *     cdef H5T_class_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_class(type_id, member_no)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_member_class(__pyx_v_type_id, __pyx_v_member_no);

  /* "h5py/defs.pyx":4147
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_class(type_id, member_no)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_class_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4148
 *     r = _hdf5.H5Tget_member_class(type_id, member_no)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_class_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4148, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4149
 *     if r<0:
 *         if set_exception():
 *             return <H5T_class_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_class (return value <0)")
 */
      __pyx_r = ((enum H5T_class_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4148
 *     r = _hdf5.H5Tget_member_class(type_id, member_no)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <H5T_class_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4151
 *             return <H5T_class_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__356, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4151, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4147
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_class(type_id, member_no)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <H5T_class_t>-1
 */
  }

  /* "h5py/defs.pyx":4152
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_class (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef char* H5Tget_member_name(hid_t type_id, unsigned membno) except <char*>NULL:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4143
 *     return r
 * 
 * cdef H5T_class_t H5Tget_member_class(hid_t type_id, int member_no) except <H5T_class_t>-1:             # <<<<<<<<<<<<<<
 *     cdef H5T_class_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_member_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((enum H5T_class_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4154
 *     return r
 * 
 * cdef char* H5Tget_member_name(hid_t type_id, unsigned membno) except <char*>NULL:             # <<<<<<<<<<<<<<
 *     cdef char* r
 *     set_default_error_handler()
 */

static char *__pyx_f_4h5py_4defs_H5Tget_member_name(hid_t __pyx_v_type_id, unsigned int __pyx_v_membno) {
  char *__pyx_v_r;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_member_name", 0);

  /* "h5py/defs.pyx":4156
 * cdef char* H5Tget_member_name(hid_t type_id, unsigned membno) except <char*>NULL:
 *     cdef char* r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_member_name(type_id, membno)
 *     if r==NULL:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4157
 *     cdef char* r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_name(type_id, membno)             # <<<<<<<<<<<<<<
 *     if r==NULL:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_member_name(__pyx_v_type_id, __pyx_v_membno);

  /* "h5py/defs.pyx":4158
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_name(type_id, membno)
 *     if r==NULL:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <char*>NULL
 */
  __pyx_t_1 = ((__pyx_v_r == NULL) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4159
 *     r = _hdf5.H5Tget_member_name(type_id, membno)
 *     if r==NULL:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <char*>NULL
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4159, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4160
 *     if r==NULL:
 *         if set_exception():
 *             return <char*>NULL             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_name (return value ==NULL)")
 */
      __pyx_r = ((char *)NULL);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4159
 *     r = _hdf5.H5Tget_member_name(type_id, membno)
 *     if r==NULL:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <char*>NULL
 *         else:
 */
    }

    /* "h5py/defs.pyx":4162
 *             return <char*>NULL
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_name (return value ==NULL)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__357, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4162, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4162, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4158
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_name(type_id, membno)
 *     if r==NULL:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <char*>NULL
 */
  }

  /* "h5py/defs.pyx":4163
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_name (return value ==NULL)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tget_member_type(hid_t type_id, unsigned membno) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4154
 *     return r
 * 
 * cdef char* H5Tget_member_name(hid_t type_id, unsigned membno) except <char*>NULL:             # <<<<<<<<<<<<<<
 *     cdef char* r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_member_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((char *)NULL);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4165
 *     return r
 * 
 * cdef hid_t H5Tget_member_type(hid_t type_id, unsigned membno) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tget_member_type(hid_t __pyx_v_type_id, unsigned int __pyx_v_membno) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_member_type", 0);

  /* "h5py/defs.pyx":4167
 * cdef hid_t H5Tget_member_type(hid_t type_id, unsigned membno) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_member_type(type_id, membno)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4168
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_type(type_id, membno)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_member_type(__pyx_v_type_id, __pyx_v_membno);

  /* "h5py/defs.pyx":4169
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_type(type_id, membno)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4170
 *     r = _hdf5.H5Tget_member_type(type_id, membno)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4170, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4171
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_type (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4170
 *     r = _hdf5.H5Tget_member_type(type_id, membno)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4173
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__358, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4173, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4169
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_type(type_id, membno)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":4174
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_type (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Tget_member_offset(hid_t type_id, int membno) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4165
 *     return r
 * 
 * cdef hid_t H5Tget_member_type(hid_t type_id, unsigned membno) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_member_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4176
 *     return r
 * 
 * cdef int H5Tget_member_offset(hid_t type_id, int membno) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Tget_member_offset(hid_t __pyx_v_type_id, int __pyx_v_membno) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_member_offset", 0);

  /* "h5py/defs.pyx":4178
 * cdef int H5Tget_member_offset(hid_t type_id, int membno) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_member_offset(type_id, membno)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4179
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_offset(type_id, membno)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_member_offset(__pyx_v_type_id, __pyx_v_membno);

  /* "h5py/defs.pyx":4180
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_offset(type_id, membno)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4181
 *     r = _hdf5.H5Tget_member_offset(type_id, membno)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4181, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4182
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_offset (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4181
 *     r = _hdf5.H5Tget_member_offset(type_id, membno)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4184
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__359, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4184, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4180
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_offset(type_id, membno)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":4185
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_offset (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Tget_member_index(hid_t type_id, char* name) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4176
 *     return r
 * 
 * cdef int H5Tget_member_offset(hid_t type_id, int membno) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_member_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4187
 *     return r
 * 
 * cdef int H5Tget_member_index(hid_t type_id, char* name) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Tget_member_index(hid_t __pyx_v_type_id, char *__pyx_v_name) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_member_index", 0);

  /* "h5py/defs.pyx":4189
 * cdef int H5Tget_member_index(hid_t type_id, char* name) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_member_index(type_id, name)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4190
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_index(type_id, name)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_member_index(__pyx_v_type_id, __pyx_v_name);

  /* "h5py/defs.pyx":4191
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_index(type_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4192
 *     r = _hdf5.H5Tget_member_index(type_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4192, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4193
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_index (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4192
 *     r = _hdf5.H5Tget_member_index(type_id, name)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4195
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_index (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__360, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4195, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4191
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_index(type_id, name)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":4196
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_index (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tinsert(hid_t parent_id, char *name, size_t offset, hid_t member_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4187
 *     return r
 * 
 * cdef int H5Tget_member_index(hid_t type_id, char* name) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_member_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4198
 *     return r
 * 
 * cdef herr_t H5Tinsert(hid_t parent_id, char *name, size_t offset, hid_t member_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tinsert(hid_t __pyx_v_parent_id, char *__pyx_v_name, size_t __pyx_v_offset, hid_t __pyx_v_member_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tinsert", 0);

  /* "h5py/defs.pyx":4200
 * cdef herr_t H5Tinsert(hid_t parent_id, char *name, size_t offset, hid_t member_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tinsert(parent_id, name, offset, member_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4201
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tinsert(parent_id, name, offset, member_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tinsert(__pyx_v_parent_id, __pyx_v_name, __pyx_v_offset, __pyx_v_member_id);

  /* "h5py/defs.pyx":4202
 *     set_default_error_handler()
 *     r = _hdf5.H5Tinsert(parent_id, name, offset, member_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4203
 *     r = _hdf5.H5Tinsert(parent_id, name, offset, member_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4203, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4204
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tinsert (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4203
 *     r = _hdf5.H5Tinsert(parent_id, name, offset, member_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4206
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tinsert (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__361, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4206, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4202
 *     set_default_error_handler()
 *     r = _hdf5.H5Tinsert(parent_id, name, offset, member_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4207
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tinsert (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tpack(hid_t type_id) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4198
 *     return r
 * 
 * cdef herr_t H5Tinsert(hid_t parent_id, char *name, size_t offset, hid_t member_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tinsert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4209
 *     return r
 * 
 * cdef herr_t H5Tpack(hid_t type_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tpack(hid_t __pyx_v_type_id) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tpack", 0);

  /* "h5py/defs.pyx":4211
 * cdef herr_t H5Tpack(hid_t type_id) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tpack(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4212
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tpack(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tpack(__pyx_v_type_id);

  /* "h5py/defs.pyx":4213
 *     set_default_error_handler()
 *     r = _hdf5.H5Tpack(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4214
 *     r = _hdf5.H5Tpack(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4214, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4215
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tpack (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4214
 *     r = _hdf5.H5Tpack(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4217
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tpack (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__362, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4217, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4213
 *     set_default_error_handler()
 *     r = _hdf5.H5Tpack(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4218
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tpack (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tenum_create(hid_t base_id) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4209
 *     return r
 * 
 * cdef herr_t H5Tpack(hid_t type_id) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tpack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4220
 *     return r
 * 
 * cdef hid_t H5Tenum_create(hid_t base_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tenum_create(hid_t __pyx_v_base_id) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tenum_create", 0);

  /* "h5py/defs.pyx":4222
 * cdef hid_t H5Tenum_create(hid_t base_id) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tenum_create(base_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4223
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_create(base_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tenum_create(__pyx_v_base_id);

  /* "h5py/defs.pyx":4224
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_create(base_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4225
 *     r = _hdf5.H5Tenum_create(base_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4225, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4226
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_create (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4225
 *     r = _hdf5.H5Tenum_create(base_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4228
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_create (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__363, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4228, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4224
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_create(base_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":4229
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_create (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tenum_insert(hid_t type, char *name, void *value) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4220
 *     return r
 * 
 * cdef hid_t H5Tenum_create(hid_t base_id) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tenum_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4231
 *     return r
 * 
 * cdef herr_t H5Tenum_insert(hid_t type, char *name, void *value) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tenum_insert(hid_t __pyx_v_type, char *__pyx_v_name, void *__pyx_v_value) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tenum_insert", 0);

  /* "h5py/defs.pyx":4233
 * cdef herr_t H5Tenum_insert(hid_t type, char *name, void *value) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tenum_insert(type, name, value)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4234
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_insert(type, name, value)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tenum_insert(__pyx_v_type, __pyx_v_name, __pyx_v_value);

  /* "h5py/defs.pyx":4235
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_insert(type, name, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4236
 *     r = _hdf5.H5Tenum_insert(type, name, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4236, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4237
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_insert (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4236
 *     r = _hdf5.H5Tenum_insert(type, name, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4239
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_insert (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__364, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4239, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4235
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_insert(type, name, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4240
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_insert (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tenum_nameof( hid_t type, void *value, char *name, size_t size ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4231
 *     return r
 * 
 * cdef herr_t H5Tenum_insert(hid_t type, char *name, void *value) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tenum_insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4242
 *     return r
 * 
 * cdef herr_t H5Tenum_nameof( hid_t type, void *value, char *name, size_t size ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tenum_nameof(hid_t __pyx_v_type, void *__pyx_v_value, char *__pyx_v_name, size_t __pyx_v_size) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tenum_nameof", 0);

  /* "h5py/defs.pyx":4244
 * cdef herr_t H5Tenum_nameof( hid_t type, void *value, char *name, size_t size ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tenum_nameof(type, value, name, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4245
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_nameof(type, value, name, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tenum_nameof(__pyx_v_type, __pyx_v_value, __pyx_v_name, __pyx_v_size);

  /* "h5py/defs.pyx":4246
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_nameof(type, value, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4247
 *     r = _hdf5.H5Tenum_nameof(type, value, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4247, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4248
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_nameof (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4247
 *     r = _hdf5.H5Tenum_nameof(type, value, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4250
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_nameof (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__365, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4250, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4250, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4246
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_nameof(type, value, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4251
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_nameof (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tenum_valueof( hid_t type, char *name, void *value ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4242
 *     return r
 * 
 * cdef herr_t H5Tenum_nameof( hid_t type, void *value, char *name, size_t size ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tenum_nameof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4253
 *     return r
 * 
 * cdef herr_t H5Tenum_valueof( hid_t type, char *name, void *value ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tenum_valueof(hid_t __pyx_v_type, char *__pyx_v_name, void *__pyx_v_value) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tenum_valueof", 0);

  /* "h5py/defs.pyx":4255
 * cdef herr_t H5Tenum_valueof( hid_t type, char *name, void *value ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tenum_valueof(type, name, value)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4256
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_valueof(type, name, value)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tenum_valueof(__pyx_v_type, __pyx_v_name, __pyx_v_value);

  /* "h5py/defs.pyx":4257
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_valueof(type, name, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4258
 *     r = _hdf5.H5Tenum_valueof(type, name, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4258, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4259
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_valueof (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4258
 *     r = _hdf5.H5Tenum_valueof(type, name, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4261
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_valueof (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__366, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4261, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4261, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4257
 *     set_default_error_handler()
 *     r = _hdf5.H5Tenum_valueof(type, name, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4262
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_valueof (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tget_member_value(hid_t type,  unsigned int memb_no, void *value ) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4253
 *     return r
 * 
 * cdef herr_t H5Tenum_valueof( hid_t type, char *name, void *value ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tenum_valueof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4264
 *     return r
 * 
 * cdef herr_t H5Tget_member_value(hid_t type,  unsigned int memb_no, void *value ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tget_member_value(hid_t __pyx_v_type, unsigned int __pyx_v_memb_no, void *__pyx_v_value) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_member_value", 0);

  /* "h5py/defs.pyx":4266
 * cdef herr_t H5Tget_member_value(hid_t type,  unsigned int memb_no, void *value ) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_member_value(type, memb_no, value)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4267
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_value(type, memb_no, value)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_member_value(__pyx_v_type, __pyx_v_memb_no, __pyx_v_value);

  /* "h5py/defs.pyx":4268
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_value(type, memb_no, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4269
 *     r = _hdf5.H5Tget_member_value(type, memb_no, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4269, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4270
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_value (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4269
 *     r = _hdf5.H5Tget_member_value(type, memb_no, value)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4272
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_value (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__367, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4272, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4268
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_member_value(type, memb_no, value)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4273
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_value (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef hid_t H5Tarray_create(hid_t base_id, int ndims, hsize_t *dims) except <hid_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4264
 *     return r
 * 
 * cdef herr_t H5Tget_member_value(hid_t type,  unsigned int memb_no, void *value ) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_member_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4275
 *     return r
 * 
 * cdef hid_t H5Tarray_create(hid_t base_id, int ndims, hsize_t *dims) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

static hid_t __pyx_f_4h5py_4defs_H5Tarray_create(hid_t __pyx_v_base_id, int __pyx_v_ndims, hsize_t *__pyx_v_dims) {
  hid_t __pyx_v_r;
  hid_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tarray_create", 0);

  /* "h5py/defs.pyx":4277
 * cdef hid_t H5Tarray_create(hid_t base_id, int ndims, hsize_t *dims) except <hid_t>-1:
 *     cdef hid_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tarray_create(base_id, ndims, dims)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4278
 *     cdef hid_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tarray_create(base_id, ndims, dims)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tarray_create(__pyx_v_base_id, __pyx_v_ndims, __pyx_v_dims);

  /* "h5py/defs.pyx":4279
 *     set_default_error_handler()
 *     r = _hdf5.H5Tarray_create(base_id, ndims, dims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4280
 *     r = _hdf5.H5Tarray_create(base_id, ndims, dims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4280, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4281
 *     if r<0:
 *         if set_exception():
 *             return <hid_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tarray_create (return value <0)")
 */
      __pyx_r = ((hid_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4280
 *     r = _hdf5.H5Tarray_create(base_id, ndims, dims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <hid_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4283
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tarray_create (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__368, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4283, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4279
 *     set_default_error_handler()
 *     r = _hdf5.H5Tarray_create(base_id, ndims, dims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <hid_t>-1
 */
  }

  /* "h5py/defs.pyx":4284
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tarray_create (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Tget_array_ndims(hid_t type_id) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4275
 *     return r
 * 
 * cdef hid_t H5Tarray_create(hid_t base_id, int ndims, hsize_t *dims) except <hid_t>-1:             # <<<<<<<<<<<<<<
 *     cdef hid_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tarray_create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((hid_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4286
 *     return r
 * 
 * cdef int H5Tget_array_ndims(hid_t type_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Tget_array_ndims(hid_t __pyx_v_type_id) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_array_ndims", 0);

  /* "h5py/defs.pyx":4288
 * cdef int H5Tget_array_ndims(hid_t type_id) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_array_ndims(type_id)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4289
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_array_ndims(type_id)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_array_ndims(__pyx_v_type_id);

  /* "h5py/defs.pyx":4290
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_array_ndims(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4291
 *     r = _hdf5.H5Tget_array_ndims(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4291, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4292
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_array_ndims (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4291
 *     r = _hdf5.H5Tget_array_ndims(type_id)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4294
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_array_ndims (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__369, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4294, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4294, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4290
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_array_ndims(type_id)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":4295
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_array_ndims (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5Tget_array_dims(hid_t type_id, hsize_t *dims) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4286
 *     return r
 * 
 * cdef int H5Tget_array_ndims(hid_t type_id) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_array_ndims", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4297
 *     return r
 * 
 * cdef int H5Tget_array_dims(hid_t type_id, hsize_t *dims) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5Tget_array_dims(hid_t __pyx_v_type_id, hsize_t *__pyx_v_dims) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_array_dims", 0);

  /* "h5py/defs.pyx":4299
 * cdef int H5Tget_array_dims(hid_t type_id, hsize_t *dims) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_array_dims(type_id, dims)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4300
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_array_dims(type_id, dims)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_array_dims(__pyx_v_type_id, __pyx_v_dims);

  /* "h5py/defs.pyx":4301
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_array_dims(type_id, dims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4302
 *     r = _hdf5.H5Tget_array_dims(type_id, dims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4302, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4303
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_array_dims (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4302
 *     r = _hdf5.H5Tget_array_dims(type_id, dims)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4305
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_array_dims (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__370, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4305, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4305, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4301
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_array_dims(type_id, dims)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":4306
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_array_dims (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Tset_tag(hid_t type_id, char* tag) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4297
 *     return r
 * 
 * cdef int H5Tget_array_dims(hid_t type_id, hsize_t *dims) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_array_dims", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4308
 *     return r
 * 
 * cdef herr_t H5Tset_tag(hid_t type_id, char* tag) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Tset_tag(hid_t __pyx_v_type_id, char *__pyx_v_tag) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tset_tag", 0);

  /* "h5py/defs.pyx":4310
 * cdef herr_t H5Tset_tag(hid_t type_id, char* tag) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tset_tag(type_id, tag)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4311
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_tag(type_id, tag)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Tset_tag(__pyx_v_type_id, __pyx_v_tag);

  /* "h5py/defs.pyx":4312
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_tag(type_id, tag)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4313
 *     r = _hdf5.H5Tset_tag(type_id, tag)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4313, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4314
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_tag (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4313
 *     r = _hdf5.H5Tset_tag(type_id, tag)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4316
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_tag (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__371, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4316, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4312
 *     set_default_error_handler()
 *     r = _hdf5.H5Tset_tag(type_id, tag)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4317
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_tag (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef char* H5Tget_tag(hid_t type_id) except <char*>NULL:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4308
 *     return r
 * 
 * cdef herr_t H5Tset_tag(hid_t type_id, char* tag) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tset_tag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4319
 *     return r
 * 
 * cdef char* H5Tget_tag(hid_t type_id) except <char*>NULL:             # <<<<<<<<<<<<<<
 *     cdef char* r
 *     set_default_error_handler()
 */

static char *__pyx_f_4h5py_4defs_H5Tget_tag(hid_t __pyx_v_type_id) {
  char *__pyx_v_r;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Tget_tag", 0);

  /* "h5py/defs.pyx":4321
 * cdef char* H5Tget_tag(hid_t type_id) except <char*>NULL:
 *     cdef char* r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Tget_tag(type_id)
 *     if r==NULL:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4322
 *     cdef char* r
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_tag(type_id)             # <<<<<<<<<<<<<<
 *     if r==NULL:
 *         if set_exception():
 */
  __pyx_v_r = H5Tget_tag(__pyx_v_type_id);

  /* "h5py/defs.pyx":4323
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_tag(type_id)
 *     if r==NULL:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <char*>NULL
 */
  __pyx_t_1 = ((__pyx_v_r == NULL) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4324
 *     r = _hdf5.H5Tget_tag(type_id)
 *     if r==NULL:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <char*>NULL
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4324, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4325
 *     if r==NULL:
 *         if set_exception():
 *             return <char*>NULL             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_tag (return value ==NULL)")
 */
      __pyx_r = ((char *)NULL);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4324
 *     r = _hdf5.H5Tget_tag(type_id)
 *     if r==NULL:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <char*>NULL
 *         else:
 */
    }

    /* "h5py/defs.pyx":4327
 *             return <char*>NULL
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_tag (return value ==NULL)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__372, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4327, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4327, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4323
 *     set_default_error_handler()
 *     r = _hdf5.H5Tget_tag(type_id)
 *     if r==NULL:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <char*>NULL
 */
  }

  /* "h5py/defs.pyx":4328
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_tag (return value ==NULL)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5Zfilter_avail(H5Z_filter_t id_) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4319
 *     return r
 * 
 * cdef char* H5Tget_tag(hid_t type_id) except <char*>NULL:             # <<<<<<<<<<<<<<
 *     cdef char* r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Tget_tag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((char *)NULL);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4330
 *     return r
 * 
 * cdef htri_t H5Zfilter_avail(H5Z_filter_t id_) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5Zfilter_avail(H5Z_filter_t __pyx_v_id_) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Zfilter_avail", 0);

  /* "h5py/defs.pyx":4332
 * cdef htri_t H5Zfilter_avail(H5Z_filter_t id_) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Zfilter_avail(id_)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4333
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Zfilter_avail(id_)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Zfilter_avail(__pyx_v_id_);

  /* "h5py/defs.pyx":4334
 *     set_default_error_handler()
 *     r = _hdf5.H5Zfilter_avail(id_)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4335
 *     r = _hdf5.H5Zfilter_avail(id_)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4335, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4336
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zfilter_avail (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4335
 *     r = _hdf5.H5Zfilter_avail(id_)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4338
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zfilter_avail (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__373, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4338, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4334
 *     set_default_error_handler()
 *     r = _hdf5.H5Zfilter_avail(id_)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":4339
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zfilter_avail (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Zget_filter_info(H5Z_filter_t filter_, unsigned int *filter_config_flags) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4330
 *     return r
 * 
 * cdef htri_t H5Zfilter_avail(H5Z_filter_t id_) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Zfilter_avail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4341
 *     return r
 * 
 * cdef herr_t H5Zget_filter_info(H5Z_filter_t filter_, unsigned int *filter_config_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Zget_filter_info(H5Z_filter_t __pyx_v_filter_, unsigned int *__pyx_v_filter_config_flags) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Zget_filter_info", 0);

  /* "h5py/defs.pyx":4343
 * cdef herr_t H5Zget_filter_info(H5Z_filter_t filter_, unsigned int *filter_config_flags) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Zget_filter_info(filter_, filter_config_flags)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4344
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Zget_filter_info(filter_, filter_config_flags)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Zget_filter_info(__pyx_v_filter_, __pyx_v_filter_config_flags);

  /* "h5py/defs.pyx":4345
 *     set_default_error_handler()
 *     r = _hdf5.H5Zget_filter_info(filter_, filter_config_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4346
 *     r = _hdf5.H5Zget_filter_info(filter_, filter_config_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4346, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4347
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zget_filter_info (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4346
 *     r = _hdf5.H5Zget_filter_info(filter_, filter_config_flags)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4349
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zget_filter_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__374, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4349, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4345
 *     set_default_error_handler()
 *     r = _hdf5.H5Zget_filter_info(filter_, filter_config_flags)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4350
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zget_filter_info (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5Zunregister(H5Z_filter_t id_) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4341
 *     return r
 * 
 * cdef herr_t H5Zget_filter_info(H5Z_filter_t filter_, unsigned int *filter_config_flags) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Zget_filter_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4352
 *     return r
 * 
 * cdef herr_t H5Zunregister(H5Z_filter_t id_) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5Zunregister(H5Z_filter_t __pyx_v_id_) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5Zunregister", 0);

  /* "h5py/defs.pyx":4354
 * cdef herr_t H5Zunregister(H5Z_filter_t id_) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5Zunregister(id_)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4355
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5Zunregister(id_)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5Zunregister(__pyx_v_id_);

  /* "h5py/defs.pyx":4356
 *     set_default_error_handler()
 *     r = _hdf5.H5Zunregister(id_)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4357
 *     r = _hdf5.H5Zunregister(id_)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4357, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4358
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zunregister (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4357
 *     r = _hdf5.H5Zunregister(id_)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4360
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zunregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__375, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4360, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4360, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4356
 *     set_default_error_handler()
 *     r = _hdf5.H5Zunregister(id_)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4361
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zunregister (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5DSattach_scale(hid_t did, hid_t dsid, unsigned int idx) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4352
 *     return r
 * 
 * cdef herr_t H5Zunregister(H5Z_filter_t id_) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5Zunregister", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4363
 *     return r
 * 
 * cdef herr_t H5DSattach_scale(hid_t did, hid_t dsid, unsigned int idx) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5DSattach_scale(hid_t __pyx_v_did, hid_t __pyx_v_dsid, unsigned int __pyx_v_idx) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSattach_scale", 0);

  /* "h5py/defs.pyx":4365
 * cdef herr_t H5DSattach_scale(hid_t did, hid_t dsid, unsigned int idx) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSattach_scale(did, dsid, idx)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4366
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSattach_scale(did, dsid, idx)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSattach_scale(__pyx_v_did, __pyx_v_dsid, __pyx_v_idx);

  /* "h5py/defs.pyx":4367
 *     set_default_error_handler()
 *     r = _hdf5.H5DSattach_scale(did, dsid, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4368
 *     r = _hdf5.H5DSattach_scale(did, dsid, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4368, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4369
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSattach_scale (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4368
 *     r = _hdf5.H5DSattach_scale(did, dsid, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4371
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSattach_scale (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__376, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4371, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4367
 *     set_default_error_handler()
 *     r = _hdf5.H5DSattach_scale(did, dsid, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4372
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSattach_scale (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5DSdetach_scale(hid_t did, hid_t dsid, unsigned int idx) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4363
 *     return r
 * 
 * cdef herr_t H5DSattach_scale(hid_t did, hid_t dsid, unsigned int idx) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSattach_scale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4374
 *     return r
 * 
 * cdef herr_t H5DSdetach_scale(hid_t did, hid_t dsid, unsigned int idx) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5DSdetach_scale(hid_t __pyx_v_did, hid_t __pyx_v_dsid, unsigned int __pyx_v_idx) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSdetach_scale", 0);

  /* "h5py/defs.pyx":4376
 * cdef herr_t H5DSdetach_scale(hid_t did, hid_t dsid, unsigned int idx) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSdetach_scale(did, dsid, idx)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4377
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSdetach_scale(did, dsid, idx)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSdetach_scale(__pyx_v_did, __pyx_v_dsid, __pyx_v_idx);

  /* "h5py/defs.pyx":4378
 *     set_default_error_handler()
 *     r = _hdf5.H5DSdetach_scale(did, dsid, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4379
 *     r = _hdf5.H5DSdetach_scale(did, dsid, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4379, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4380
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSdetach_scale (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4379
 *     r = _hdf5.H5DSdetach_scale(did, dsid, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4382
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSdetach_scale (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__377, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4382, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4378
 *     set_default_error_handler()
 *     r = _hdf5.H5DSdetach_scale(did, dsid, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4383
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSdetach_scale (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5DSis_attached(hid_t did, hid_t dsid, unsigned int idx) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4374
 *     return r
 * 
 * cdef herr_t H5DSdetach_scale(hid_t did, hid_t dsid, unsigned int idx) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSdetach_scale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4385
 *     return r
 * 
 * cdef htri_t H5DSis_attached(hid_t did, hid_t dsid, unsigned int idx) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5DSis_attached(hid_t __pyx_v_did, hid_t __pyx_v_dsid, unsigned int __pyx_v_idx) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSis_attached", 0);

  /* "h5py/defs.pyx":4387
 * cdef htri_t H5DSis_attached(hid_t did, hid_t dsid, unsigned int idx) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSis_attached(did, dsid, idx)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4388
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSis_attached(did, dsid, idx)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSis_attached(__pyx_v_did, __pyx_v_dsid, __pyx_v_idx);

  /* "h5py/defs.pyx":4389
 *     set_default_error_handler()
 *     r = _hdf5.H5DSis_attached(did, dsid, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4390
 *     r = _hdf5.H5DSis_attached(did, dsid, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4390, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4391
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSis_attached (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4390
 *     r = _hdf5.H5DSis_attached(did, dsid, idx)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4393
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSis_attached (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__378, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4393, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4389
 *     set_default_error_handler()
 *     r = _hdf5.H5DSis_attached(did, dsid, idx)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":4394
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSis_attached (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5DSset_scale(hid_t dsid, char *dimname) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4385
 *     return r
 * 
 * cdef htri_t H5DSis_attached(hid_t did, hid_t dsid, unsigned int idx) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSis_attached", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4396
 *     return r
 * 
 * cdef herr_t H5DSset_scale(hid_t dsid, char *dimname) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5DSset_scale(hid_t __pyx_v_dsid, char *__pyx_v_dimname) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSset_scale", 0);

  /* "h5py/defs.pyx":4398
 * cdef herr_t H5DSset_scale(hid_t dsid, char *dimname) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSset_scale(dsid, dimname)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4399
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSset_scale(dsid, dimname)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSset_scale(__pyx_v_dsid, __pyx_v_dimname);

  /* "h5py/defs.pyx":4400
 *     set_default_error_handler()
 *     r = _hdf5.H5DSset_scale(dsid, dimname)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4401
 *     r = _hdf5.H5DSset_scale(dsid, dimname)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4401, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4402
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSset_scale (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4401
 *     r = _hdf5.H5DSset_scale(dsid, dimname)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4404
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSset_scale (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__379, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4404, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4404, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4400
 *     set_default_error_handler()
 *     r = _hdf5.H5DSset_scale(dsid, dimname)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4405
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSset_scale (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef int H5DSget_num_scales(hid_t did, unsigned int dim) except <int>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4396
 *     return r
 * 
 * cdef herr_t H5DSset_scale(hid_t dsid, char *dimname) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSset_scale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4407
 *     return r
 * 
 * cdef int H5DSget_num_scales(hid_t did, unsigned int dim) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

static int __pyx_f_4h5py_4defs_H5DSget_num_scales(hid_t __pyx_v_did, unsigned int __pyx_v_dim) {
  int __pyx_v_r;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSget_num_scales", 0);

  /* "h5py/defs.pyx":4409
 * cdef int H5DSget_num_scales(hid_t did, unsigned int dim) except <int>-1:
 *     cdef int r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSget_num_scales(did, dim)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4410
 *     cdef int r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_num_scales(did, dim)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSget_num_scales(__pyx_v_did, __pyx_v_dim);

  /* "h5py/defs.pyx":4411
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_num_scales(did, dim)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4412
 *     r = _hdf5.H5DSget_num_scales(did, dim)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4412, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4413
 *     if r<0:
 *         if set_exception():
 *             return <int>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_num_scales (return value <0)")
 */
      __pyx_r = ((int)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4412
 *     r = _hdf5.H5DSget_num_scales(did, dim)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <int>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4415
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_num_scales (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__380, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4415, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4411
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_num_scales(did, dim)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <int>-1
 */
  }

  /* "h5py/defs.pyx":4416
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_num_scales (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5DSset_label(hid_t did, unsigned int idx, char *label) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4407
 *     return r
 * 
 * cdef int H5DSget_num_scales(hid_t did, unsigned int dim) except <int>-1:             # <<<<<<<<<<<<<<
 *     cdef int r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSget_num_scales", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((int)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4418
 *     return r
 * 
 * cdef herr_t H5DSset_label(hid_t did, unsigned int idx, char *label) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5DSset_label(hid_t __pyx_v_did, unsigned int __pyx_v_idx, char *__pyx_v_label) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSset_label", 0);

  /* "h5py/defs.pyx":4420
 * cdef herr_t H5DSset_label(hid_t did, unsigned int idx, char *label) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSset_label(did, idx, label)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4421
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSset_label(did, idx, label)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSset_label(__pyx_v_did, __pyx_v_idx, __pyx_v_label);

  /* "h5py/defs.pyx":4422
 *     set_default_error_handler()
 *     r = _hdf5.H5DSset_label(did, idx, label)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4423
 *     r = _hdf5.H5DSset_label(did, idx, label)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4423, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4424
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSset_label (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4423
 *     r = _hdf5.H5DSset_label(did, idx, label)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4426
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSset_label (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__381, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4426, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4426, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4422
 *     set_default_error_handler()
 *     r = _hdf5.H5DSset_label(did, idx, label)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4427
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSset_label (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5DSget_label(hid_t did, unsigned int idx, char *label, size_t size) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4418
 *     return r
 * 
 * cdef herr_t H5DSset_label(hid_t did, unsigned int idx, char *label) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSset_label", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4429
 *     return r
 * 
 * cdef ssize_t H5DSget_label(hid_t did, unsigned int idx, char *label, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5DSget_label(hid_t __pyx_v_did, unsigned int __pyx_v_idx, char *__pyx_v_label, size_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSget_label", 0);

  /* "h5py/defs.pyx":4431
 * cdef ssize_t H5DSget_label(hid_t did, unsigned int idx, char *label, size_t size) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSget_label(did, idx, label, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4432
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_label(did, idx, label, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSget_label(__pyx_v_did, __pyx_v_idx, __pyx_v_label, __pyx_v_size);

  /* "h5py/defs.pyx":4433
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_label(did, idx, label, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4434
 *     r = _hdf5.H5DSget_label(did, idx, label, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4434, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4435
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_label (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4434
 *     r = _hdf5.H5DSget_label(did, idx, label, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4437
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_label (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__382, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4437, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4437, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4433
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_label(did, idx, label, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":4438
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_label (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef ssize_t H5DSget_scale_name(hid_t did, char *name, size_t size) except <ssize_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4429
 *     return r
 * 
 * cdef ssize_t H5DSget_label(hid_t did, unsigned int idx, char *label, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSget_label", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4440
 *     return r
 * 
 * cdef ssize_t H5DSget_scale_name(hid_t did, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

static Py_ssize_t __pyx_f_4h5py_4defs_H5DSget_scale_name(hid_t __pyx_v_did, char *__pyx_v_name, size_t __pyx_v_size) {
  Py_ssize_t __pyx_v_r;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSget_scale_name", 0);

  /* "h5py/defs.pyx":4442
 * cdef ssize_t H5DSget_scale_name(hid_t did, char *name, size_t size) except <ssize_t>-1:
 *     cdef ssize_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSget_scale_name(did, name, size)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4443
 *     cdef ssize_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_scale_name(did, name, size)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSget_scale_name(__pyx_v_did, __pyx_v_name, __pyx_v_size);

  /* "h5py/defs.pyx":4444
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_scale_name(did, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4445
 *     r = _hdf5.H5DSget_scale_name(did, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4445, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4446
 *     if r<0:
 *         if set_exception():
 *             return <ssize_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_scale_name (return value <0)")
 */
      __pyx_r = ((Py_ssize_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4445
 *     r = _hdf5.H5DSget_scale_name(did, name, size)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <ssize_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4448
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_scale_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__383, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4448, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4444
 *     set_default_error_handler()
 *     r = _hdf5.H5DSget_scale_name(did, name, size)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <ssize_t>-1
 */
  }

  /* "h5py/defs.pyx":4449
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_scale_name (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef htri_t H5DSis_scale(hid_t did) except <htri_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4440
 *     return r
 * 
 * cdef ssize_t H5DSget_scale_name(hid_t did, char *name, size_t size) except <ssize_t>-1:             # <<<<<<<<<<<<<<
 *     cdef ssize_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSget_scale_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((Py_ssize_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4451
 *     return r
 * 
 * cdef htri_t H5DSis_scale(hid_t did) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

static htri_t __pyx_f_4h5py_4defs_H5DSis_scale(hid_t __pyx_v_did) {
  htri_t __pyx_v_r;
  htri_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSis_scale", 0);

  /* "h5py/defs.pyx":4453
 * cdef htri_t H5DSis_scale(hid_t did) except <htri_t>-1:
 *     cdef htri_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSis_scale(did)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4454
 *     cdef htri_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSis_scale(did)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSis_scale(__pyx_v_did);

  /* "h5py/defs.pyx":4455
 *     set_default_error_handler()
 *     r = _hdf5.H5DSis_scale(did)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4456
 *     r = _hdf5.H5DSis_scale(did)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4456, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4457
 *     if r<0:
 *         if set_exception():
 *             return <htri_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSis_scale (return value <0)")
 */
      __pyx_r = ((htri_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4456
 *     r = _hdf5.H5DSis_scale(did)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <htri_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4459
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSis_scale (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__384, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4459, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4459, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4455
 *     set_default_error_handler()
 *     r = _hdf5.H5DSis_scale(did)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <htri_t>-1
 */
  }

  /* "h5py/defs.pyx":4460
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSis_scale (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 * cdef herr_t H5DSiterate_scales(hid_t did, unsigned int dim, int *idx, H5DS_iterate_t visitor, void *visitor_data) except <herr_t>-1:
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4451
 *     return r
 * 
 * cdef htri_t H5DSis_scale(hid_t did) except <htri_t>-1:             # <<<<<<<<<<<<<<
 *     cdef htri_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSis_scale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((htri_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/defs.pyx":4462
 *     return r
 * 
 * cdef herr_t H5DSiterate_scales(hid_t did, unsigned int dim, int *idx, H5DS_iterate_t visitor, void *visitor_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

static herr_t __pyx_f_4h5py_4defs_H5DSiterate_scales(hid_t __pyx_v_did, unsigned int __pyx_v_dim, int *__pyx_v_idx, H5DS_iterate_t __pyx_v_visitor, void *__pyx_v_visitor_data) {
  herr_t __pyx_v_r;
  herr_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("H5DSiterate_scales", 0);

  /* "h5py/defs.pyx":4464
 * cdef herr_t H5DSiterate_scales(hid_t did, unsigned int dim, int *idx, H5DS_iterate_t visitor, void *visitor_data) except <herr_t>-1:
 *     cdef herr_t r
 *     set_default_error_handler()             # <<<<<<<<<<<<<<
 *     r = _hdf5.H5DSiterate_scales(did, dim, idx, visitor, visitor_data)
 *     if r<0:
 */
  __pyx_f_4h5py_7_errors_set_default_error_handler();

  /* "h5py/defs.pyx":4465
 *     cdef herr_t r
 *     set_default_error_handler()
 *     r = _hdf5.H5DSiterate_scales(did, dim, idx, visitor, visitor_data)             # <<<<<<<<<<<<<<
 *     if r<0:
 *         if set_exception():
 */
  __pyx_v_r = H5DSiterate_scales(__pyx_v_did, __pyx_v_dim, __pyx_v_idx, __pyx_v_visitor, __pyx_v_visitor_data);

  /* "h5py/defs.pyx":4466
 *     set_default_error_handler()
 *     r = _hdf5.H5DSiterate_scales(did, dim, idx, visitor, visitor_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  __pyx_t_1 = ((__pyx_v_r < 0) != 0);
  if (__pyx_t_1) {

    /* "h5py/defs.pyx":4467
 *     r = _hdf5.H5DSiterate_scales(did, dim, idx, visitor, visitor_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    __pyx_t_2 = __pyx_f_4h5py_7_errors_set_exception(); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4467, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (likely(__pyx_t_1)) {

      /* "h5py/defs.pyx":4468
 *     if r<0:
 *         if set_exception():
 *             return <herr_t>-1             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSiterate_scales (return value <0)")
 */
      __pyx_r = ((herr_t)-1L);
      goto __pyx_L0;

      /* "h5py/defs.pyx":4467
 *     r = _hdf5.H5DSiterate_scales(did, dim, idx, visitor, visitor_data)
 *     if r<0:
 *         if set_exception():             # <<<<<<<<<<<<<<
 *             return <herr_t>-1
 *         else:
 */
    }

    /* "h5py/defs.pyx":4470
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSiterate_scales (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__385, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4470, __pyx_L1_error)
    }

    /* "h5py/defs.pyx":4466
 *     set_default_error_handler()
 *     r = _hdf5.H5DSiterate_scales(did, dim, idx, visitor, visitor_data)
 *     if r<0:             # <<<<<<<<<<<<<<
 *         if set_exception():
 *             return <herr_t>-1
 */
  }

  /* "h5py/defs.pyx":4471
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSiterate_scales (return value <0)")
 *     return r             # <<<<<<<<<<<<<<
 * 
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "h5py/defs.pyx":4462
 *     return r
 * 
 * cdef herr_t H5DSiterate_scales(hid_t did, unsigned int dim, int *idx, H5DS_iterate_t visitor, void *visitor_data) except <herr_t>-1:             # <<<<<<<<<<<<<<
 *     cdef herr_t r
 *     set_default_error_handler()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("h5py.defs.H5DSiterate_scales", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((herr_t)-1L);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":734
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":735
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":734
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":737
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":738
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":737
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":740
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":741
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":740
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":743
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":744
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":743
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":746
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":747
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":746
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":749
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":750
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = (PyDataType_HASSUBARRAY(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":751
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_d->subarray->shape));
    __pyx_r = ((PyObject*)__pyx_v_d->subarray->shape);
    goto __pyx_L0;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":750
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":753
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":749
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":928
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":929
 * 
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!             # <<<<<<<<<<<<<<
 *     PyArray_SetBaseObject(arr, base)
 * 
 */
  Py_INCREF(__pyx_v_base);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":930
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  (void)(PyArray_SetBaseObject(__pyx_v_arr, __pyx_v_base));

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":928
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":932
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_v_base;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":933
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)             # <<<<<<<<<<<<<<
 *     if base is NULL:
 *         return None
 */
  __pyx_v_base = PyArray_BASE(__pyx_v_arr);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":934
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  __pyx_t_1 = ((__pyx_v_base == NULL) != 0);
  if (__pyx_t_1) {

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":935
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return <object>base
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":934
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":936
 *     if base is NULL:
 *         return None
 *     return <object>base             # <<<<<<<<<<<<<<
 * 
 * # Versions of the import_* functions which are more suitable for
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_base));
  __pyx_r = ((PyObject *)__pyx_v_base);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":932
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":940
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_array", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":941
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":942
 * cdef inline int import_array() except -1:
 *     try:
 *         __pyx_import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 942, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":941
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":943
 *     try:
 *         __pyx_import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 943, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":944
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__386, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 944, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 944, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":941
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":940
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":946
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_umath", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":947
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":948
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 948, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":947
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":949
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 949, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":950
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__387, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 950, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 950, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":947
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":946
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":952
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_ufunc", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":953
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":954
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 954, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":953
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":955
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 955, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":956
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef extern from *:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__387, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 956, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 956, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":953
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":952
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":966
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_timedelta64_object", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":978
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":966
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":981
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_datetime64_object", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":993
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":981
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":996
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

static CYTHON_INLINE npy_datetime __pyx_f_5numpy_get_datetime64_value(PyObject *__pyx_v_obj) {
  npy_datetime __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1003
 *     also needed.  That can be found using `get_datetime64_unit`.
 *     """
 *     return (<PyDatetimeScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyDatetimeScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":996
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1006
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

static CYTHON_INLINE npy_timedelta __pyx_f_5numpy_get_timedelta64_value(PyObject *__pyx_v_obj) {
  npy_timedelta __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1010
 *     returns the int64 value underlying scalar numpy timedelta64 object
 *     """
 *     return (<PyTimedeltaScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyTimedeltaScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1006
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1013
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

static CYTHON_INLINE NPY_DATETIMEUNIT __pyx_f_5numpy_get_datetime64_unit(PyObject *__pyx_v_obj) {
  NPY_DATETIMEUNIT __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1017
 *     returns the unit part of the dtype for a numpy datetime64 object.
 *     """
 *     return <NPY_DATETIMEUNIT>(<PyDatetimeScalarObject*>obj).obmeta.base             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((NPY_DATETIMEUNIT)((PyDatetimeScalarObject *)__pyx_v_obj)->obmeta.base);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1013
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_defs(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_defs},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "defs",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_kp_u_Unspecified_error_in_H5Aclose_re, __pyx_k_Unspecified_error_in_H5Aclose_re, sizeof(__pyx_k_Unspecified_error_in_H5Aclose_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Acreate_b, __pyx_k_Unspecified_error_in_H5Acreate_b, sizeof(__pyx_k_Unspecified_error_in_H5Acreate_b), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Acreate_r, __pyx_k_Unspecified_error_in_H5Acreate_r, sizeof(__pyx_k_Unspecified_error_in_H5Acreate_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Adelete_b, __pyx_k_Unspecified_error_in_H5Adelete_b, sizeof(__pyx_k_Unspecified_error_in_H5Adelete_b), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Adelete_b_2, __pyx_k_Unspecified_error_in_H5Adelete_b_2, sizeof(__pyx_k_Unspecified_error_in_H5Adelete_b_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Adelete_r, __pyx_k_Unspecified_error_in_H5Adelete_r, sizeof(__pyx_k_Unspecified_error_in_H5Adelete_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aexists_b, __pyx_k_Unspecified_error_in_H5Aexists_b, sizeof(__pyx_k_Unspecified_error_in_H5Aexists_b), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aexists_r, __pyx_k_Unspecified_error_in_H5Aexists_r, sizeof(__pyx_k_Unspecified_error_in_H5Aexists_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aget_info, __pyx_k_Unspecified_error_in_H5Aget_info, sizeof(__pyx_k_Unspecified_error_in_H5Aget_info), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aget_info_2, __pyx_k_Unspecified_error_in_H5Aget_info_2, sizeof(__pyx_k_Unspecified_error_in_H5Aget_info_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aget_info_3, __pyx_k_Unspecified_error_in_H5Aget_info_3, sizeof(__pyx_k_Unspecified_error_in_H5Aget_info_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aget_name, __pyx_k_Unspecified_error_in_H5Aget_name, sizeof(__pyx_k_Unspecified_error_in_H5Aget_name), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aget_num, __pyx_k_Unspecified_error_in_H5Aget_num, sizeof(__pyx_k_Unspecified_error_in_H5Aget_num), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aget_spac, __pyx_k_Unspecified_error_in_H5Aget_spac, sizeof(__pyx_k_Unspecified_error_in_H5Aget_spac), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aget_stor, __pyx_k_Unspecified_error_in_H5Aget_stor, sizeof(__pyx_k_Unspecified_error_in_H5Aget_stor), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aget_type, __pyx_k_Unspecified_error_in_H5Aget_type, sizeof(__pyx_k_Unspecified_error_in_H5Aget_type), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aiterate, __pyx_k_Unspecified_error_in_H5Aiterate, sizeof(__pyx_k_Unspecified_error_in_H5Aiterate), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aopen_by, __pyx_k_Unspecified_error_in_H5Aopen_by, sizeof(__pyx_k_Unspecified_error_in_H5Aopen_by), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aopen_by_2, __pyx_k_Unspecified_error_in_H5Aopen_by_2, sizeof(__pyx_k_Unspecified_error_in_H5Aopen_by_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aopen_idx, __pyx_k_Unspecified_error_in_H5Aopen_idx, sizeof(__pyx_k_Unspecified_error_in_H5Aopen_idx), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aopen_nam, __pyx_k_Unspecified_error_in_H5Aopen_nam, sizeof(__pyx_k_Unspecified_error_in_H5Aopen_nam), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aopen_ret, __pyx_k_Unspecified_error_in_H5Aopen_ret, sizeof(__pyx_k_Unspecified_error_in_H5Aopen_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Aread_ret, __pyx_k_Unspecified_error_in_H5Aread_ret, sizeof(__pyx_k_Unspecified_error_in_H5Aread_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Arename_b, __pyx_k_Unspecified_error_in_H5Arename_b, sizeof(__pyx_k_Unspecified_error_in_H5Arename_b), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Arename_r, __pyx_k_Unspecified_error_in_H5Arename_r, sizeof(__pyx_k_Unspecified_error_in_H5Arename_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Awrite_re, __pyx_k_Unspecified_error_in_H5Awrite_re, sizeof(__pyx_k_Unspecified_error_in_H5Awrite_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DOread_ch, __pyx_k_Unspecified_error_in_H5DOread_ch, sizeof(__pyx_k_Unspecified_error_in_H5DOread_ch), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DOwrite_c, __pyx_k_Unspecified_error_in_H5DOwrite_c, sizeof(__pyx_k_Unspecified_error_in_H5DOwrite_c), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSattach, __pyx_k_Unspecified_error_in_H5DSattach, sizeof(__pyx_k_Unspecified_error_in_H5DSattach), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSdetach, __pyx_k_Unspecified_error_in_H5DSdetach, sizeof(__pyx_k_Unspecified_error_in_H5DSdetach), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSget_lab, __pyx_k_Unspecified_error_in_H5DSget_lab, sizeof(__pyx_k_Unspecified_error_in_H5DSget_lab), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSget_num, __pyx_k_Unspecified_error_in_H5DSget_num, sizeof(__pyx_k_Unspecified_error_in_H5DSget_num), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSget_sca, __pyx_k_Unspecified_error_in_H5DSget_sca, sizeof(__pyx_k_Unspecified_error_in_H5DSget_sca), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSis_atta, __pyx_k_Unspecified_error_in_H5DSis_atta, sizeof(__pyx_k_Unspecified_error_in_H5DSis_atta), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSis_scal, __pyx_k_Unspecified_error_in_H5DSis_scal, sizeof(__pyx_k_Unspecified_error_in_H5DSis_scal), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSiterate, __pyx_k_Unspecified_error_in_H5DSiterate, sizeof(__pyx_k_Unspecified_error_in_H5DSiterate), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSset_lab, __pyx_k_Unspecified_error_in_H5DSset_lab, sizeof(__pyx_k_Unspecified_error_in_H5DSset_lab), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5DSset_sca, __pyx_k_Unspecified_error_in_H5DSset_sca, sizeof(__pyx_k_Unspecified_error_in_H5DSset_sca), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dclose_re, __pyx_k_Unspecified_error_in_H5Dclose_re, sizeof(__pyx_k_Unspecified_error_in_H5Dclose_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dcreate_a, __pyx_k_Unspecified_error_in_H5Dcreate_a, sizeof(__pyx_k_Unspecified_error_in_H5Dcreate_a), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dcreate_r, __pyx_k_Unspecified_error_in_H5Dcreate_r, sizeof(__pyx_k_Unspecified_error_in_H5Dcreate_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dextend_r, __pyx_k_Unspecified_error_in_H5Dextend_r, sizeof(__pyx_k_Unspecified_error_in_H5Dextend_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dfill_ret, __pyx_k_Unspecified_error_in_H5Dfill_ret, sizeof(__pyx_k_Unspecified_error_in_H5Dfill_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dflush_re, __pyx_k_Unspecified_error_in_H5Dflush_re, sizeof(__pyx_k_Unspecified_error_in_H5Dflush_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_acce, __pyx_k_Unspecified_error_in_H5Dget_acce, sizeof(__pyx_k_Unspecified_error_in_H5Dget_acce), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_chun, __pyx_k_Unspecified_error_in_H5Dget_chun, sizeof(__pyx_k_Unspecified_error_in_H5Dget_chun), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_chun_2, __pyx_k_Unspecified_error_in_H5Dget_chun_2, sizeof(__pyx_k_Unspecified_error_in_H5Dget_chun_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_chun_3, __pyx_k_Unspecified_error_in_H5Dget_chun_3, sizeof(__pyx_k_Unspecified_error_in_H5Dget_chun_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_crea, __pyx_k_Unspecified_error_in_H5Dget_crea, sizeof(__pyx_k_Unspecified_error_in_H5Dget_crea), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_num, __pyx_k_Unspecified_error_in_H5Dget_num, sizeof(__pyx_k_Unspecified_error_in_H5Dget_num), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_offs, __pyx_k_Unspecified_error_in_H5Dget_offs, sizeof(__pyx_k_Unspecified_error_in_H5Dget_offs), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_spac, __pyx_k_Unspecified_error_in_H5Dget_spac, sizeof(__pyx_k_Unspecified_error_in_H5Dget_spac), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_spac_2, __pyx_k_Unspecified_error_in_H5Dget_spac_2, sizeof(__pyx_k_Unspecified_error_in_H5Dget_spac_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dget_type, __pyx_k_Unspecified_error_in_H5Dget_type, sizeof(__pyx_k_Unspecified_error_in_H5Dget_type), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Diterate, __pyx_k_Unspecified_error_in_H5Diterate, sizeof(__pyx_k_Unspecified_error_in_H5Diterate), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dopen_ret, __pyx_k_Unspecified_error_in_H5Dopen_ret, sizeof(__pyx_k_Unspecified_error_in_H5Dopen_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dread_chu, __pyx_k_Unspecified_error_in_H5Dread_chu, sizeof(__pyx_k_Unspecified_error_in_H5Dread_chu), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dread_ret, __pyx_k_Unspecified_error_in_H5Dread_ret, sizeof(__pyx_k_Unspecified_error_in_H5Dread_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Drefresh, __pyx_k_Unspecified_error_in_H5Drefresh, sizeof(__pyx_k_Unspecified_error_in_H5Drefresh), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dset_exte, __pyx_k_Unspecified_error_in_H5Dset_exte, sizeof(__pyx_k_Unspecified_error_in_H5Dset_exte), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dvlen_get, __pyx_k_Unspecified_error_in_H5Dvlen_get, sizeof(__pyx_k_Unspecified_error_in_H5Dvlen_get), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dvlen_rec, __pyx_k_Unspecified_error_in_H5Dvlen_rec, sizeof(__pyx_k_Unspecified_error_in_H5Dvlen_rec), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Dwrite_re, __pyx_k_Unspecified_error_in_H5Dwrite_re, sizeof(__pyx_k_Unspecified_error_in_H5Dwrite_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5FDregiste, __pyx_k_Unspecified_error_in_H5FDregiste, sizeof(__pyx_k_Unspecified_error_in_H5FDregiste), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5FDunregis, __pyx_k_Unspecified_error_in_H5FDunregis, sizeof(__pyx_k_Unspecified_error_in_H5FDunregis), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fclose_re, __pyx_k_Unspecified_error_in_H5Fclose_re, sizeof(__pyx_k_Unspecified_error_in_H5Fclose_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fcreate_r, __pyx_k_Unspecified_error_in_H5Fcreate_r, sizeof(__pyx_k_Unspecified_error_in_H5Fcreate_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fflush_re, __pyx_k_Unspecified_error_in_H5Fflush_re, sizeof(__pyx_k_Unspecified_error_in_H5Fflush_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_acce, __pyx_k_Unspecified_error_in_H5Fget_acce, sizeof(__pyx_k_Unspecified_error_in_H5Fget_acce), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_crea, __pyx_k_Unspecified_error_in_H5Fget_crea, sizeof(__pyx_k_Unspecified_error_in_H5Fget_crea), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_file, __pyx_k_Unspecified_error_in_H5Fget_file, sizeof(__pyx_k_Unspecified_error_in_H5Fget_file), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_file_2, __pyx_k_Unspecified_error_in_H5Fget_file_2, sizeof(__pyx_k_Unspecified_error_in_H5Fget_file_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_free, __pyx_k_Unspecified_error_in_H5Fget_free, sizeof(__pyx_k_Unspecified_error_in_H5Fget_free), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_inte, __pyx_k_Unspecified_error_in_H5Fget_inte, sizeof(__pyx_k_Unspecified_error_in_H5Fget_inte), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_mdc, __pyx_k_Unspecified_error_in_H5Fget_mdc, sizeof(__pyx_k_Unspecified_error_in_H5Fget_mdc), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_mdc_2, __pyx_k_Unspecified_error_in_H5Fget_mdc_2, sizeof(__pyx_k_Unspecified_error_in_H5Fget_mdc_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_mdc_3, __pyx_k_Unspecified_error_in_H5Fget_mdc_3, sizeof(__pyx_k_Unspecified_error_in_H5Fget_mdc_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_name, __pyx_k_Unspecified_error_in_H5Fget_name, sizeof(__pyx_k_Unspecified_error_in_H5Fget_name), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_obj, __pyx_k_Unspecified_error_in_H5Fget_obj, sizeof(__pyx_k_Unspecified_error_in_H5Fget_obj), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_obj_2, __pyx_k_Unspecified_error_in_H5Fget_obj_2, sizeof(__pyx_k_Unspecified_error_in_H5Fget_obj_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_page, __pyx_k_Unspecified_error_in_H5Fget_page, sizeof(__pyx_k_Unspecified_error_in_H5Fget_page), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fget_vfd, __pyx_k_Unspecified_error_in_H5Fget_vfd, sizeof(__pyx_k_Unspecified_error_in_H5Fget_vfd), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fis_hdf5, __pyx_k_Unspecified_error_in_H5Fis_hdf5, sizeof(__pyx_k_Unspecified_error_in_H5Fis_hdf5), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fmount_re, __pyx_k_Unspecified_error_in_H5Fmount_re, sizeof(__pyx_k_Unspecified_error_in_H5Fmount_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fopen_ret, __pyx_k_Unspecified_error_in_H5Fopen_ret, sizeof(__pyx_k_Unspecified_error_in_H5Fopen_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Freopen_r, __pyx_k_Unspecified_error_in_H5Freopen_r, sizeof(__pyx_k_Unspecified_error_in_H5Freopen_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Freset_md, __pyx_k_Unspecified_error_in_H5Freset_md, sizeof(__pyx_k_Unspecified_error_in_H5Freset_md), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Freset_pa, __pyx_k_Unspecified_error_in_H5Freset_pa, sizeof(__pyx_k_Unspecified_error_in_H5Freset_pa), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fset_mdc, __pyx_k_Unspecified_error_in_H5Fset_mdc, sizeof(__pyx_k_Unspecified_error_in_H5Fset_mdc), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Fstart_sw, __pyx_k_Unspecified_error_in_H5Fstart_sw, sizeof(__pyx_k_Unspecified_error_in_H5Fstart_sw), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Funmount, __pyx_k_Unspecified_error_in_H5Funmount, sizeof(__pyx_k_Unspecified_error_in_H5Funmount), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gclose_re, __pyx_k_Unspecified_error_in_H5Gclose_re, sizeof(__pyx_k_Unspecified_error_in_H5Gclose_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gcreate_a, __pyx_k_Unspecified_error_in_H5Gcreate_a, sizeof(__pyx_k_Unspecified_error_in_H5Gcreate_a), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gcreate_r, __pyx_k_Unspecified_error_in_H5Gcreate_r, sizeof(__pyx_k_Unspecified_error_in_H5Gcreate_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_comm, __pyx_k_Unspecified_error_in_H5Gget_comm, sizeof(__pyx_k_Unspecified_error_in_H5Gget_comm), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_crea, __pyx_k_Unspecified_error_in_H5Gget_crea, sizeof(__pyx_k_Unspecified_error_in_H5Gget_crea), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_info, __pyx_k_Unspecified_error_in_H5Gget_info, sizeof(__pyx_k_Unspecified_error_in_H5Gget_info), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_info_2, __pyx_k_Unspecified_error_in_H5Gget_info_2, sizeof(__pyx_k_Unspecified_error_in_H5Gget_info_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_link, __pyx_k_Unspecified_error_in_H5Gget_link, sizeof(__pyx_k_Unspecified_error_in_H5Gget_link), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_num, __pyx_k_Unspecified_error_in_H5Gget_num, sizeof(__pyx_k_Unspecified_error_in_H5Gget_num), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_obji, __pyx_k_Unspecified_error_in_H5Gget_obji, sizeof(__pyx_k_Unspecified_error_in_H5Gget_obji), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_objn, __pyx_k_Unspecified_error_in_H5Gget_objn, sizeof(__pyx_k_Unspecified_error_in_H5Gget_objn), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gget_objt, __pyx_k_Unspecified_error_in_H5Gget_objt, sizeof(__pyx_k_Unspecified_error_in_H5Gget_objt), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Giterate, __pyx_k_Unspecified_error_in_H5Giterate, sizeof(__pyx_k_Unspecified_error_in_H5Giterate), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Glink2_re, __pyx_k_Unspecified_error_in_H5Glink2_re, sizeof(__pyx_k_Unspecified_error_in_H5Glink2_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gmove2_re, __pyx_k_Unspecified_error_in_H5Gmove2_re, sizeof(__pyx_k_Unspecified_error_in_H5Gmove2_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gopen_ret, __pyx_k_Unspecified_error_in_H5Gopen_ret, sizeof(__pyx_k_Unspecified_error_in_H5Gopen_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gset_comm, __pyx_k_Unspecified_error_in_H5Gset_comm, sizeof(__pyx_k_Unspecified_error_in_H5Gset_comm), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Gunlink_r, __pyx_k_Unspecified_error_in_H5Gunlink_r, sizeof(__pyx_k_Unspecified_error_in_H5Gunlink_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Idec_ref, __pyx_k_Unspecified_error_in_H5Idec_ref, sizeof(__pyx_k_Unspecified_error_in_H5Idec_ref), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Iget_file, __pyx_k_Unspecified_error_in_H5Iget_file, sizeof(__pyx_k_Unspecified_error_in_H5Iget_file), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Iget_name, __pyx_k_Unspecified_error_in_H5Iget_name, sizeof(__pyx_k_Unspecified_error_in_H5Iget_name), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Iget_ref, __pyx_k_Unspecified_error_in_H5Iget_ref, sizeof(__pyx_k_Unspecified_error_in_H5Iget_ref), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Iget_type, __pyx_k_Unspecified_error_in_H5Iget_type, sizeof(__pyx_k_Unspecified_error_in_H5Iget_type), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Iinc_ref, __pyx_k_Unspecified_error_in_H5Iinc_ref, sizeof(__pyx_k_Unspecified_error_in_H5Iinc_ref), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Iis_valid, __pyx_k_Unspecified_error_in_H5Iis_valid, sizeof(__pyx_k_Unspecified_error_in_H5Iis_valid), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5LTopen_fi, __pyx_k_Unspecified_error_in_H5LTopen_fi, sizeof(__pyx_k_Unspecified_error_in_H5LTopen_fi), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lcopy_ret, __pyx_k_Unspecified_error_in_H5Lcopy_ret, sizeof(__pyx_k_Unspecified_error_in_H5Lcopy_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lcreate_e, __pyx_k_Unspecified_error_in_H5Lcreate_e, sizeof(__pyx_k_Unspecified_error_in_H5Lcreate_e), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lcreate_h, __pyx_k_Unspecified_error_in_H5Lcreate_h, sizeof(__pyx_k_Unspecified_error_in_H5Lcreate_h), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lcreate_s, __pyx_k_Unspecified_error_in_H5Lcreate_s, sizeof(__pyx_k_Unspecified_error_in_H5Lcreate_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Ldelete_b, __pyx_k_Unspecified_error_in_H5Ldelete_b, sizeof(__pyx_k_Unspecified_error_in_H5Ldelete_b), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Ldelete_r, __pyx_k_Unspecified_error_in_H5Ldelete_r, sizeof(__pyx_k_Unspecified_error_in_H5Ldelete_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lexists_r, __pyx_k_Unspecified_error_in_H5Lexists_r, sizeof(__pyx_k_Unspecified_error_in_H5Lexists_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lget_info, __pyx_k_Unspecified_error_in_H5Lget_info, sizeof(__pyx_k_Unspecified_error_in_H5Lget_info), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lget_info_2, __pyx_k_Unspecified_error_in_H5Lget_info_2, sizeof(__pyx_k_Unspecified_error_in_H5Lget_info_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lget_name, __pyx_k_Unspecified_error_in_H5Lget_name, sizeof(__pyx_k_Unspecified_error_in_H5Lget_name), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lget_val, __pyx_k_Unspecified_error_in_H5Lget_val, sizeof(__pyx_k_Unspecified_error_in_H5Lget_val), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lget_val_2, __pyx_k_Unspecified_error_in_H5Lget_val_2, sizeof(__pyx_k_Unspecified_error_in_H5Lget_val_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Literate, __pyx_k_Unspecified_error_in_H5Literate, sizeof(__pyx_k_Unspecified_error_in_H5Literate), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Literate_2, __pyx_k_Unspecified_error_in_H5Literate_2, sizeof(__pyx_k_Unspecified_error_in_H5Literate_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lmove_ret, __pyx_k_Unspecified_error_in_H5Lmove_ret, sizeof(__pyx_k_Unspecified_error_in_H5Lmove_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lunpack_e, __pyx_k_Unspecified_error_in_H5Lunpack_e, sizeof(__pyx_k_Unspecified_error_in_H5Lunpack_e), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lvisit_by, __pyx_k_Unspecified_error_in_H5Lvisit_by, sizeof(__pyx_k_Unspecified_error_in_H5Lvisit_by), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Lvisit_re, __pyx_k_Unspecified_error_in_H5Lvisit_re, sizeof(__pyx_k_Unspecified_error_in_H5Lvisit_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oclose_re, __pyx_k_Unspecified_error_in_H5Oclose_re, sizeof(__pyx_k_Unspecified_error_in_H5Oclose_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Ocopy_ret, __pyx_k_Unspecified_error_in_H5Ocopy_ret, sizeof(__pyx_k_Unspecified_error_in_H5Ocopy_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Odecr_ref, __pyx_k_Unspecified_error_in_H5Odecr_ref, sizeof(__pyx_k_Unspecified_error_in_H5Odecr_ref), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oexists_b, __pyx_k_Unspecified_error_in_H5Oexists_b, sizeof(__pyx_k_Unspecified_error_in_H5Oexists_b), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oget_comm, __pyx_k_Unspecified_error_in_H5Oget_comm, sizeof(__pyx_k_Unspecified_error_in_H5Oget_comm), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oget_comm_2, __pyx_k_Unspecified_error_in_H5Oget_comm_2, sizeof(__pyx_k_Unspecified_error_in_H5Oget_comm_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oget_info, __pyx_k_Unspecified_error_in_H5Oget_info, sizeof(__pyx_k_Unspecified_error_in_H5Oget_info), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oget_info_2, __pyx_k_Unspecified_error_in_H5Oget_info_2, sizeof(__pyx_k_Unspecified_error_in_H5Oget_info_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oget_info_3, __pyx_k_Unspecified_error_in_H5Oget_info_3, sizeof(__pyx_k_Unspecified_error_in_H5Oget_info_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oincr_ref, __pyx_k_Unspecified_error_in_H5Oincr_ref, sizeof(__pyx_k_Unspecified_error_in_H5Oincr_ref), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Olink_ret, __pyx_k_Unspecified_error_in_H5Olink_ret, sizeof(__pyx_k_Unspecified_error_in_H5Olink_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oopen_by, __pyx_k_Unspecified_error_in_H5Oopen_by, sizeof(__pyx_k_Unspecified_error_in_H5Oopen_by), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oopen_by_2, __pyx_k_Unspecified_error_in_H5Oopen_by_2, sizeof(__pyx_k_Unspecified_error_in_H5Oopen_by_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oopen_ret, __pyx_k_Unspecified_error_in_H5Oopen_ret, sizeof(__pyx_k_Unspecified_error_in_H5Oopen_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oset_comm, __pyx_k_Unspecified_error_in_H5Oset_comm, sizeof(__pyx_k_Unspecified_error_in_H5Oset_comm), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Oset_comm_2, __pyx_k_Unspecified_error_in_H5Oset_comm_2, sizeof(__pyx_k_Unspecified_error_in_H5Oset_comm_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Ovisit_by, __pyx_k_Unspecified_error_in_H5Ovisit_by, sizeof(__pyx_k_Unspecified_error_in_H5Ovisit_by), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Ovisit_re, __pyx_k_Unspecified_error_in_H5Ovisit_re, sizeof(__pyx_k_Unspecified_error_in_H5Ovisit_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5PLappend, __pyx_k_Unspecified_error_in_H5PLappend, sizeof(__pyx_k_Unspecified_error_in_H5PLappend), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5PLget_ret, __pyx_k_Unspecified_error_in_H5PLget_ret, sizeof(__pyx_k_Unspecified_error_in_H5PLget_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5PLinsert, __pyx_k_Unspecified_error_in_H5PLinsert, sizeof(__pyx_k_Unspecified_error_in_H5PLinsert), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5PLprepend, __pyx_k_Unspecified_error_in_H5PLprepend, sizeof(__pyx_k_Unspecified_error_in_H5PLprepend), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5PLremove, __pyx_k_Unspecified_error_in_H5PLremove, sizeof(__pyx_k_Unspecified_error_in_H5PLremove), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5PLreplace, __pyx_k_Unspecified_error_in_H5PLreplace, sizeof(__pyx_k_Unspecified_error_in_H5PLreplace), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5PLsize_re, __pyx_k_Unspecified_error_in_H5PLsize_re, sizeof(__pyx_k_Unspecified_error_in_H5PLsize_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pall_filt, __pyx_k_Unspecified_error_in_H5Pall_filt, sizeof(__pyx_k_Unspecified_error_in_H5Pall_filt), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pclose_cl, __pyx_k_Unspecified_error_in_H5Pclose_cl, sizeof(__pyx_k_Unspecified_error_in_H5Pclose_cl), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pclose_re, __pyx_k_Unspecified_error_in_H5Pclose_re, sizeof(__pyx_k_Unspecified_error_in_H5Pclose_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pcopy_ret, __pyx_k_Unspecified_error_in_H5Pcopy_ret, sizeof(__pyx_k_Unspecified_error_in_H5Pcopy_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pcreate_r, __pyx_k_Unspecified_error_in_H5Pcreate_r, sizeof(__pyx_k_Unspecified_error_in_H5Pcreate_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pequal_re, __pyx_k_Unspecified_error_in_H5Pequal_re, sizeof(__pyx_k_Unspecified_error_in_H5Pequal_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pfill_val, __pyx_k_Unspecified_error_in_H5Pfill_val, sizeof(__pyx_k_Unspecified_error_in_H5Pfill_val), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_alig, __pyx_k_Unspecified_error_in_H5Pget_alig, sizeof(__pyx_k_Unspecified_error_in_H5Pget_alig), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_allo, __pyx_k_Unspecified_error_in_H5Pget_allo, sizeof(__pyx_k_Unspecified_error_in_H5Pget_allo), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_attr, __pyx_k_Unspecified_error_in_H5Pget_attr, sizeof(__pyx_k_Unspecified_error_in_H5Pget_attr), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_attr_2, __pyx_k_Unspecified_error_in_H5Pget_attr_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_attr_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_cach, __pyx_k_Unspecified_error_in_H5Pget_cach, sizeof(__pyx_k_Unspecified_error_in_H5Pget_cach), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_char, __pyx_k_Unspecified_error_in_H5Pget_char, sizeof(__pyx_k_Unspecified_error_in_H5Pget_char), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_chun, __pyx_k_Unspecified_error_in_H5Pget_chun, sizeof(__pyx_k_Unspecified_error_in_H5Pget_chun), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_chun_2, __pyx_k_Unspecified_error_in_H5Pget_chun_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_chun_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_clas, __pyx_k_Unspecified_error_in_H5Pget_clas, sizeof(__pyx_k_Unspecified_error_in_H5Pget_clas), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_copy, __pyx_k_Unspecified_error_in_H5Pget_copy, sizeof(__pyx_k_Unspecified_error_in_H5Pget_copy), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_crea, __pyx_k_Unspecified_error_in_H5Pget_crea, sizeof(__pyx_k_Unspecified_error_in_H5Pget_crea), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_driv, __pyx_k_Unspecified_error_in_H5Pget_driv, sizeof(__pyx_k_Unspecified_error_in_H5Pget_driv), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_driv_2, __pyx_k_Unspecified_error_in_H5Pget_driv_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_driv_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_edc, __pyx_k_Unspecified_error_in_H5Pget_edc, sizeof(__pyx_k_Unspecified_error_in_H5Pget_edc), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_efil, __pyx_k_Unspecified_error_in_H5Pget_efil, sizeof(__pyx_k_Unspecified_error_in_H5Pget_efil), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_elin, __pyx_k_Unspecified_error_in_H5Pget_elin, sizeof(__pyx_k_Unspecified_error_in_H5Pget_elin), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_elin_2, __pyx_k_Unspecified_error_in_H5Pget_elin_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_elin_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_est, __pyx_k_Unspecified_error_in_H5Pget_est, sizeof(__pyx_k_Unspecified_error_in_H5Pget_est), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_exte, __pyx_k_Unspecified_error_in_H5Pget_exte, sizeof(__pyx_k_Unspecified_error_in_H5Pget_exte), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_exte_2, __pyx_k_Unspecified_error_in_H5Pget_exte_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_exte_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_fami, __pyx_k_Unspecified_error_in_H5Pget_fami, sizeof(__pyx_k_Unspecified_error_in_H5Pget_fami), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_fapl, __pyx_k_Unspecified_error_in_H5Pget_fapl, sizeof(__pyx_k_Unspecified_error_in_H5Pget_fapl), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_fapl_2, __pyx_k_Unspecified_error_in_H5Pget_fapl_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_fapl_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_fclo, __pyx_k_Unspecified_error_in_H5Pget_fclo, sizeof(__pyx_k_Unspecified_error_in_H5Pget_fclo), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_file, __pyx_k_Unspecified_error_in_H5Pget_file, sizeof(__pyx_k_Unspecified_error_in_H5Pget_file), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_file_2, __pyx_k_Unspecified_error_in_H5Pget_file_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_file_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_file_3, __pyx_k_Unspecified_error_in_H5Pget_file_3, sizeof(__pyx_k_Unspecified_error_in_H5Pget_file_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_fill, __pyx_k_Unspecified_error_in_H5Pget_fill, sizeof(__pyx_k_Unspecified_error_in_H5Pget_fill), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_fill_2, __pyx_k_Unspecified_error_in_H5Pget_fill_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_fill_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_filt, __pyx_k_Unspecified_error_in_H5Pget_filt, sizeof(__pyx_k_Unspecified_error_in_H5Pget_filt), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_filt_2, __pyx_k_Unspecified_error_in_H5Pget_filt_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_filt_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_isto, __pyx_k_Unspecified_error_in_H5Pget_isto, sizeof(__pyx_k_Unspecified_error_in_H5Pget_isto), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_layo, __pyx_k_Unspecified_error_in_H5Pget_layo, sizeof(__pyx_k_Unspecified_error_in_H5Pget_layo), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_libv, __pyx_k_Unspecified_error_in_H5Pget_libv, sizeof(__pyx_k_Unspecified_error_in_H5Pget_libv), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_link, __pyx_k_Unspecified_error_in_H5Pget_link, sizeof(__pyx_k_Unspecified_error_in_H5Pget_link), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_link_2, __pyx_k_Unspecified_error_in_H5Pget_link_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_link_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_loca, __pyx_k_Unspecified_error_in_H5Pget_loca, sizeof(__pyx_k_Unspecified_error_in_H5Pget_loca), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_mdc, __pyx_k_Unspecified_error_in_H5Pget_mdc, sizeof(__pyx_k_Unspecified_error_in_H5Pget_mdc), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_nfil, __pyx_k_Unspecified_error_in_H5Pget_nfil, sizeof(__pyx_k_Unspecified_error_in_H5Pget_nfil), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_nlin, __pyx_k_Unspecified_error_in_H5Pget_nlin, sizeof(__pyx_k_Unspecified_error_in_H5Pget_nlin), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_obj, __pyx_k_Unspecified_error_in_H5Pget_obj, sizeof(__pyx_k_Unspecified_error_in_H5Pget_obj), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_page, __pyx_k_Unspecified_error_in_H5Pget_page, sizeof(__pyx_k_Unspecified_error_in_H5Pget_page), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_siev, __pyx_k_Unspecified_error_in_H5Pget_siev, sizeof(__pyx_k_Unspecified_error_in_H5Pget_siev), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_size, __pyx_k_Unspecified_error_in_H5Pget_size, sizeof(__pyx_k_Unspecified_error_in_H5Pget_size), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_sym, __pyx_k_Unspecified_error_in_H5Pget_sym, sizeof(__pyx_k_Unspecified_error_in_H5Pget_sym), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_user, __pyx_k_Unspecified_error_in_H5Pget_user, sizeof(__pyx_k_Unspecified_error_in_H5Pget_user), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_vers, __pyx_k_Unspecified_error_in_H5Pget_vers, sizeof(__pyx_k_Unspecified_error_in_H5Pget_vers), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_virt, __pyx_k_Unspecified_error_in_H5Pget_virt, sizeof(__pyx_k_Unspecified_error_in_H5Pget_virt), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_virt_2, __pyx_k_Unspecified_error_in_H5Pget_virt_2, sizeof(__pyx_k_Unspecified_error_in_H5Pget_virt_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_virt_3, __pyx_k_Unspecified_error_in_H5Pget_virt_3, sizeof(__pyx_k_Unspecified_error_in_H5Pget_virt_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_virt_4, __pyx_k_Unspecified_error_in_H5Pget_virt_4, sizeof(__pyx_k_Unspecified_error_in_H5Pget_virt_4), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_virt_5, __pyx_k_Unspecified_error_in_H5Pget_virt_5, sizeof(__pyx_k_Unspecified_error_in_H5Pget_virt_5), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_virt_6, __pyx_k_Unspecified_error_in_H5Pget_virt_6, sizeof(__pyx_k_Unspecified_error_in_H5Pget_virt_6), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_virt_7, __pyx_k_Unspecified_error_in_H5Pget_virt_7, sizeof(__pyx_k_Unspecified_error_in_H5Pget_virt_7), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pget_virt_8, __pyx_k_Unspecified_error_in_H5Pget_virt_8, sizeof(__pyx_k_Unspecified_error_in_H5Pget_virt_8), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pmodify_f, __pyx_k_Unspecified_error_in_H5Pmodify_f, sizeof(__pyx_k_Unspecified_error_in_H5Pmodify_f), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Premove_f, __pyx_k_Unspecified_error_in_H5Premove_f, sizeof(__pyx_k_Unspecified_error_in_H5Premove_f), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_alig, __pyx_k_Unspecified_error_in_H5Pset_alig, sizeof(__pyx_k_Unspecified_error_in_H5Pset_alig), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_allo, __pyx_k_Unspecified_error_in_H5Pset_allo, sizeof(__pyx_k_Unspecified_error_in_H5Pset_allo), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_attr, __pyx_k_Unspecified_error_in_H5Pset_attr, sizeof(__pyx_k_Unspecified_error_in_H5Pset_attr), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_attr_2, __pyx_k_Unspecified_error_in_H5Pset_attr_2, sizeof(__pyx_k_Unspecified_error_in_H5Pset_attr_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_cach, __pyx_k_Unspecified_error_in_H5Pset_cach, sizeof(__pyx_k_Unspecified_error_in_H5Pset_cach), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_char, __pyx_k_Unspecified_error_in_H5Pset_char, sizeof(__pyx_k_Unspecified_error_in_H5Pset_char), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_chun, __pyx_k_Unspecified_error_in_H5Pset_chun, sizeof(__pyx_k_Unspecified_error_in_H5Pset_chun), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_chun_2, __pyx_k_Unspecified_error_in_H5Pset_chun_2, sizeof(__pyx_k_Unspecified_error_in_H5Pset_chun_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_copy, __pyx_k_Unspecified_error_in_H5Pset_copy, sizeof(__pyx_k_Unspecified_error_in_H5Pset_copy), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_crea, __pyx_k_Unspecified_error_in_H5Pset_crea, sizeof(__pyx_k_Unspecified_error_in_H5Pset_crea), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_defl, __pyx_k_Unspecified_error_in_H5Pset_defl, sizeof(__pyx_k_Unspecified_error_in_H5Pset_defl), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_driv, __pyx_k_Unspecified_error_in_H5Pset_driv, sizeof(__pyx_k_Unspecified_error_in_H5Pset_driv), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_edc, __pyx_k_Unspecified_error_in_H5Pset_edc, sizeof(__pyx_k_Unspecified_error_in_H5Pset_edc), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_efil, __pyx_k_Unspecified_error_in_H5Pset_efil, sizeof(__pyx_k_Unspecified_error_in_H5Pset_efil), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_elin, __pyx_k_Unspecified_error_in_H5Pset_elin, sizeof(__pyx_k_Unspecified_error_in_H5Pset_elin), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_elin_2, __pyx_k_Unspecified_error_in_H5Pset_elin_2, sizeof(__pyx_k_Unspecified_error_in_H5Pset_elin_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_est, __pyx_k_Unspecified_error_in_H5Pset_est, sizeof(__pyx_k_Unspecified_error_in_H5Pset_est), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_exte, __pyx_k_Unspecified_error_in_H5Pset_exte, sizeof(__pyx_k_Unspecified_error_in_H5Pset_exte), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fami, __pyx_k_Unspecified_error_in_H5Pset_fami, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fami), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fapl, __pyx_k_Unspecified_error_in_H5Pset_fapl, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fapl), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_2, __pyx_k_Unspecified_error_in_H5Pset_fapl_2, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fapl_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_3, __pyx_k_Unspecified_error_in_H5Pset_fapl_3, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fapl_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_4, __pyx_k_Unspecified_error_in_H5Pset_fapl_4, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fapl_4), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_5, __pyx_k_Unspecified_error_in_H5Pset_fapl_5, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fapl_5), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_6, __pyx_k_Unspecified_error_in_H5Pset_fapl_6, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fapl_6), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fapl_7, __pyx_k_Unspecified_error_in_H5Pset_fapl_7, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fapl_7), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fclo, __pyx_k_Unspecified_error_in_H5Pset_fclo, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fclo), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_file, __pyx_k_Unspecified_error_in_H5Pset_file, sizeof(__pyx_k_Unspecified_error_in_H5Pset_file), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_file_2, __pyx_k_Unspecified_error_in_H5Pset_file_2, sizeof(__pyx_k_Unspecified_error_in_H5Pset_file_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_file_3, __pyx_k_Unspecified_error_in_H5Pset_file_3, sizeof(__pyx_k_Unspecified_error_in_H5Pset_file_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_file_4, __pyx_k_Unspecified_error_in_H5Pset_file_4, sizeof(__pyx_k_Unspecified_error_in_H5Pset_file_4), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fill, __pyx_k_Unspecified_error_in_H5Pset_fill, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fill), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_fill_2, __pyx_k_Unspecified_error_in_H5Pset_fill_2, sizeof(__pyx_k_Unspecified_error_in_H5Pset_fill_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_filt, __pyx_k_Unspecified_error_in_H5Pset_filt, sizeof(__pyx_k_Unspecified_error_in_H5Pset_filt), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_flet, __pyx_k_Unspecified_error_in_H5Pset_flet, sizeof(__pyx_k_Unspecified_error_in_H5Pset_flet), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_isto, __pyx_k_Unspecified_error_in_H5Pset_isto, sizeof(__pyx_k_Unspecified_error_in_H5Pset_isto), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_layo, __pyx_k_Unspecified_error_in_H5Pset_layo, sizeof(__pyx_k_Unspecified_error_in_H5Pset_layo), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_libv, __pyx_k_Unspecified_error_in_H5Pset_libv, sizeof(__pyx_k_Unspecified_error_in_H5Pset_libv), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_link, __pyx_k_Unspecified_error_in_H5Pset_link, sizeof(__pyx_k_Unspecified_error_in_H5Pset_link), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_link_2, __pyx_k_Unspecified_error_in_H5Pset_link_2, sizeof(__pyx_k_Unspecified_error_in_H5Pset_link_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_loca, __pyx_k_Unspecified_error_in_H5Pset_loca, sizeof(__pyx_k_Unspecified_error_in_H5Pset_loca), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_mdc, __pyx_k_Unspecified_error_in_H5Pset_mdc, sizeof(__pyx_k_Unspecified_error_in_H5Pset_mdc), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_nlin, __pyx_k_Unspecified_error_in_H5Pset_nlin, sizeof(__pyx_k_Unspecified_error_in_H5Pset_nlin), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_obj, __pyx_k_Unspecified_error_in_H5Pset_obj, sizeof(__pyx_k_Unspecified_error_in_H5Pset_obj), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_page, __pyx_k_Unspecified_error_in_H5Pset_page, sizeof(__pyx_k_Unspecified_error_in_H5Pset_page), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_scal, __pyx_k_Unspecified_error_in_H5Pset_scal, sizeof(__pyx_k_Unspecified_error_in_H5Pset_scal), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_shuf, __pyx_k_Unspecified_error_in_H5Pset_shuf, sizeof(__pyx_k_Unspecified_error_in_H5Pset_shuf), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_siev, __pyx_k_Unspecified_error_in_H5Pset_siev, sizeof(__pyx_k_Unspecified_error_in_H5Pset_siev), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_size, __pyx_k_Unspecified_error_in_H5Pset_size, sizeof(__pyx_k_Unspecified_error_in_H5Pset_size), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_sym, __pyx_k_Unspecified_error_in_H5Pset_sym, sizeof(__pyx_k_Unspecified_error_in_H5Pset_sym), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_szip, __pyx_k_Unspecified_error_in_H5Pset_szip, sizeof(__pyx_k_Unspecified_error_in_H5Pset_szip), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_user, __pyx_k_Unspecified_error_in_H5Pset_user, sizeof(__pyx_k_Unspecified_error_in_H5Pset_user), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_virt, __pyx_k_Unspecified_error_in_H5Pset_virt, sizeof(__pyx_k_Unspecified_error_in_H5Pset_virt), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_virt_2, __pyx_k_Unspecified_error_in_H5Pset_virt_2, sizeof(__pyx_k_Unspecified_error_in_H5Pset_virt_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_virt_3, __pyx_k_Unspecified_error_in_H5Pset_virt_3, sizeof(__pyx_k_Unspecified_error_in_H5Pset_virt_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Pset_virt_4, __pyx_k_Unspecified_error_in_H5Pset_virt_4, sizeof(__pyx_k_Unspecified_error_in_H5Pset_virt_4), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Rcreate_r, __pyx_k_Unspecified_error_in_H5Rcreate_r, sizeof(__pyx_k_Unspecified_error_in_H5Rcreate_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Rderefere, __pyx_k_Unspecified_error_in_H5Rderefere, sizeof(__pyx_k_Unspecified_error_in_H5Rderefere), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Rget_name, __pyx_k_Unspecified_error_in_H5Rget_name, sizeof(__pyx_k_Unspecified_error_in_H5Rget_name), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Rget_obj, __pyx_k_Unspecified_error_in_H5Rget_obj, sizeof(__pyx_k_Unspecified_error_in_H5Rget_obj), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Rget_regi, __pyx_k_Unspecified_error_in_H5Rget_regi, sizeof(__pyx_k_Unspecified_error_in_H5Rget_regi), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sclose_re, __pyx_k_Unspecified_error_in_H5Sclose_re, sizeof(__pyx_k_Unspecified_error_in_H5Sclose_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Scopy_ret, __pyx_k_Unspecified_error_in_H5Scopy_ret, sizeof(__pyx_k_Unspecified_error_in_H5Scopy_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Screate_r, __pyx_k_Unspecified_error_in_H5Screate_r, sizeof(__pyx_k_Unspecified_error_in_H5Screate_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Screate_s, __pyx_k_Unspecified_error_in_H5Screate_s, sizeof(__pyx_k_Unspecified_error_in_H5Screate_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sdecode_r, __pyx_k_Unspecified_error_in_H5Sdecode_r, sizeof(__pyx_k_Unspecified_error_in_H5Sdecode_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sencode_r, __pyx_k_Unspecified_error_in_H5Sencode_r, sizeof(__pyx_k_Unspecified_error_in_H5Sencode_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sextent_c, __pyx_k_Unspecified_error_in_H5Sextent_c, sizeof(__pyx_k_Unspecified_error_in_H5Sextent_c), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_regu, __pyx_k_Unspecified_error_in_H5Sget_regu, sizeof(__pyx_k_Unspecified_error_in_H5Sget_regu), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_sele, __pyx_k_Unspecified_error_in_H5Sget_sele, sizeof(__pyx_k_Unspecified_error_in_H5Sget_sele), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_sele_2, __pyx_k_Unspecified_error_in_H5Sget_sele_2, sizeof(__pyx_k_Unspecified_error_in_H5Sget_sele_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_sele_3, __pyx_k_Unspecified_error_in_H5Sget_sele_3, sizeof(__pyx_k_Unspecified_error_in_H5Sget_sele_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_sele_4, __pyx_k_Unspecified_error_in_H5Sget_sele_4, sizeof(__pyx_k_Unspecified_error_in_H5Sget_sele_4), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_sele_5, __pyx_k_Unspecified_error_in_H5Sget_sele_5, sizeof(__pyx_k_Unspecified_error_in_H5Sget_sele_5), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_sele_6, __pyx_k_Unspecified_error_in_H5Sget_sele_6, sizeof(__pyx_k_Unspecified_error_in_H5Sget_sele_6), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_sele_7, __pyx_k_Unspecified_error_in_H5Sget_sele_7, sizeof(__pyx_k_Unspecified_error_in_H5Sget_sele_7), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_simp, __pyx_k_Unspecified_error_in_H5Sget_simp, sizeof(__pyx_k_Unspecified_error_in_H5Sget_simp), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_simp_2, __pyx_k_Unspecified_error_in_H5Sget_simp_2, sizeof(__pyx_k_Unspecified_error_in_H5Sget_simp_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_simp_3, __pyx_k_Unspecified_error_in_H5Sget_simp_3, sizeof(__pyx_k_Unspecified_error_in_H5Sget_simp_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sget_simp_4, __pyx_k_Unspecified_error_in_H5Sget_simp_4, sizeof(__pyx_k_Unspecified_error_in_H5Sget_simp_4), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sis_regul, __pyx_k_Unspecified_error_in_H5Sis_regul, sizeof(__pyx_k_Unspecified_error_in_H5Sis_regul), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sis_simpl, __pyx_k_Unspecified_error_in_H5Sis_simpl, sizeof(__pyx_k_Unspecified_error_in_H5Sis_simpl), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Soffset_s, __pyx_k_Unspecified_error_in_H5Soffset_s, sizeof(__pyx_k_Unspecified_error_in_H5Soffset_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sselect_a, __pyx_k_Unspecified_error_in_H5Sselect_a, sizeof(__pyx_k_Unspecified_error_in_H5Sselect_a), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sselect_e, __pyx_k_Unspecified_error_in_H5Sselect_e, sizeof(__pyx_k_Unspecified_error_in_H5Sselect_e), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sselect_h, __pyx_k_Unspecified_error_in_H5Sselect_h, sizeof(__pyx_k_Unspecified_error_in_H5Sselect_h), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sselect_n, __pyx_k_Unspecified_error_in_H5Sselect_n, sizeof(__pyx_k_Unspecified_error_in_H5Sselect_n), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sselect_v, __pyx_k_Unspecified_error_in_H5Sselect_v, sizeof(__pyx_k_Unspecified_error_in_H5Sselect_v), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sset_exte, __pyx_k_Unspecified_error_in_H5Sset_exte, sizeof(__pyx_k_Unspecified_error_in_H5Sset_exte), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Sset_exte_2, __pyx_k_Unspecified_error_in_H5Sset_exte_2, sizeof(__pyx_k_Unspecified_error_in_H5Sset_exte_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tarray_cr, __pyx_k_Unspecified_error_in_H5Tarray_cr, sizeof(__pyx_k_Unspecified_error_in_H5Tarray_cr), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tclose_re, __pyx_k_Unspecified_error_in_H5Tclose_re, sizeof(__pyx_k_Unspecified_error_in_H5Tclose_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tcommit_r, __pyx_k_Unspecified_error_in_H5Tcommit_r, sizeof(__pyx_k_Unspecified_error_in_H5Tcommit_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tcommitte, __pyx_k_Unspecified_error_in_H5Tcommitte, sizeof(__pyx_k_Unspecified_error_in_H5Tcommitte), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tconvert, __pyx_k_Unspecified_error_in_H5Tconvert, sizeof(__pyx_k_Unspecified_error_in_H5Tconvert), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tcopy_ret, __pyx_k_Unspecified_error_in_H5Tcopy_ret, sizeof(__pyx_k_Unspecified_error_in_H5Tcopy_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tcreate_r, __pyx_k_Unspecified_error_in_H5Tcreate_r, sizeof(__pyx_k_Unspecified_error_in_H5Tcreate_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tdecode_r, __pyx_k_Unspecified_error_in_H5Tdecode_r, sizeof(__pyx_k_Unspecified_error_in_H5Tdecode_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tdetect_c, __pyx_k_Unspecified_error_in_H5Tdetect_c, sizeof(__pyx_k_Unspecified_error_in_H5Tdetect_c), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tencode_r, __pyx_k_Unspecified_error_in_H5Tencode_r, sizeof(__pyx_k_Unspecified_error_in_H5Tencode_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tenum_cre, __pyx_k_Unspecified_error_in_H5Tenum_cre, sizeof(__pyx_k_Unspecified_error_in_H5Tenum_cre), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tenum_ins, __pyx_k_Unspecified_error_in_H5Tenum_ins, sizeof(__pyx_k_Unspecified_error_in_H5Tenum_ins), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tenum_nam, __pyx_k_Unspecified_error_in_H5Tenum_nam, sizeof(__pyx_k_Unspecified_error_in_H5Tenum_nam), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tenum_val, __pyx_k_Unspecified_error_in_H5Tenum_val, sizeof(__pyx_k_Unspecified_error_in_H5Tenum_val), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tequal_re, __pyx_k_Unspecified_error_in_H5Tequal_re, sizeof(__pyx_k_Unspecified_error_in_H5Tequal_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tfind_ret, __pyx_k_Unspecified_error_in_H5Tfind_ret, sizeof(__pyx_k_Unspecified_error_in_H5Tfind_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_arra, __pyx_k_Unspecified_error_in_H5Tget_arra, sizeof(__pyx_k_Unspecified_error_in_H5Tget_arra), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_arra_2, __pyx_k_Unspecified_error_in_H5Tget_arra_2, sizeof(__pyx_k_Unspecified_error_in_H5Tget_arra_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_clas, __pyx_k_Unspecified_error_in_H5Tget_clas, sizeof(__pyx_k_Unspecified_error_in_H5Tget_clas), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_crea, __pyx_k_Unspecified_error_in_H5Tget_crea, sizeof(__pyx_k_Unspecified_error_in_H5Tget_crea), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_cset, __pyx_k_Unspecified_error_in_H5Tget_cset, sizeof(__pyx_k_Unspecified_error_in_H5Tget_cset), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_ebia, __pyx_k_Unspecified_error_in_H5Tget_ebia, sizeof(__pyx_k_Unspecified_error_in_H5Tget_ebia), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_fiel, __pyx_k_Unspecified_error_in_H5Tget_fiel, sizeof(__pyx_k_Unspecified_error_in_H5Tget_fiel), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_inpa, __pyx_k_Unspecified_error_in_H5Tget_inpa, sizeof(__pyx_k_Unspecified_error_in_H5Tget_inpa), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_memb, __pyx_k_Unspecified_error_in_H5Tget_memb, sizeof(__pyx_k_Unspecified_error_in_H5Tget_memb), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_memb_2, __pyx_k_Unspecified_error_in_H5Tget_memb_2, sizeof(__pyx_k_Unspecified_error_in_H5Tget_memb_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_memb_3, __pyx_k_Unspecified_error_in_H5Tget_memb_3, sizeof(__pyx_k_Unspecified_error_in_H5Tget_memb_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_memb_4, __pyx_k_Unspecified_error_in_H5Tget_memb_4, sizeof(__pyx_k_Unspecified_error_in_H5Tget_memb_4), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_memb_5, __pyx_k_Unspecified_error_in_H5Tget_memb_5, sizeof(__pyx_k_Unspecified_error_in_H5Tget_memb_5), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_memb_6, __pyx_k_Unspecified_error_in_H5Tget_memb_6, sizeof(__pyx_k_Unspecified_error_in_H5Tget_memb_6), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_nati, __pyx_k_Unspecified_error_in_H5Tget_nati, sizeof(__pyx_k_Unspecified_error_in_H5Tget_nati), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_nmem, __pyx_k_Unspecified_error_in_H5Tget_nmem, sizeof(__pyx_k_Unspecified_error_in_H5Tget_nmem), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_norm, __pyx_k_Unspecified_error_in_H5Tget_norm, sizeof(__pyx_k_Unspecified_error_in_H5Tget_norm), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_offs, __pyx_k_Unspecified_error_in_H5Tget_offs, sizeof(__pyx_k_Unspecified_error_in_H5Tget_offs), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_orde, __pyx_k_Unspecified_error_in_H5Tget_orde, sizeof(__pyx_k_Unspecified_error_in_H5Tget_orde), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_pad, __pyx_k_Unspecified_error_in_H5Tget_pad, sizeof(__pyx_k_Unspecified_error_in_H5Tget_pad), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_prec, __pyx_k_Unspecified_error_in_H5Tget_prec, sizeof(__pyx_k_Unspecified_error_in_H5Tget_prec), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_sign, __pyx_k_Unspecified_error_in_H5Tget_sign, sizeof(__pyx_k_Unspecified_error_in_H5Tget_sign), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_size, __pyx_k_Unspecified_error_in_H5Tget_size, sizeof(__pyx_k_Unspecified_error_in_H5Tget_size), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_strp, __pyx_k_Unspecified_error_in_H5Tget_strp, sizeof(__pyx_k_Unspecified_error_in_H5Tget_strp), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_supe, __pyx_k_Unspecified_error_in_H5Tget_supe, sizeof(__pyx_k_Unspecified_error_in_H5Tget_supe), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tget_tag, __pyx_k_Unspecified_error_in_H5Tget_tag, sizeof(__pyx_k_Unspecified_error_in_H5Tget_tag), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tinsert_r, __pyx_k_Unspecified_error_in_H5Tinsert_r, sizeof(__pyx_k_Unspecified_error_in_H5Tinsert_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tis_varia, __pyx_k_Unspecified_error_in_H5Tis_varia, sizeof(__pyx_k_Unspecified_error_in_H5Tis_varia), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tlock_ret, __pyx_k_Unspecified_error_in_H5Tlock_ret, sizeof(__pyx_k_Unspecified_error_in_H5Tlock_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Topen_ret, __pyx_k_Unspecified_error_in_H5Topen_ret, sizeof(__pyx_k_Unspecified_error_in_H5Topen_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tpack_ret, __pyx_k_Unspecified_error_in_H5Tpack_ret, sizeof(__pyx_k_Unspecified_error_in_H5Tpack_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tregister, __pyx_k_Unspecified_error_in_H5Tregister, sizeof(__pyx_k_Unspecified_error_in_H5Tregister), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_cset, __pyx_k_Unspecified_error_in_H5Tset_cset, sizeof(__pyx_k_Unspecified_error_in_H5Tset_cset), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_ebia, __pyx_k_Unspecified_error_in_H5Tset_ebia, sizeof(__pyx_k_Unspecified_error_in_H5Tset_ebia), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_fiel, __pyx_k_Unspecified_error_in_H5Tset_fiel, sizeof(__pyx_k_Unspecified_error_in_H5Tset_fiel), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_inpa, __pyx_k_Unspecified_error_in_H5Tset_inpa, sizeof(__pyx_k_Unspecified_error_in_H5Tset_inpa), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_norm, __pyx_k_Unspecified_error_in_H5Tset_norm, sizeof(__pyx_k_Unspecified_error_in_H5Tset_norm), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_offs, __pyx_k_Unspecified_error_in_H5Tset_offs, sizeof(__pyx_k_Unspecified_error_in_H5Tset_offs), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_orde, __pyx_k_Unspecified_error_in_H5Tset_orde, sizeof(__pyx_k_Unspecified_error_in_H5Tset_orde), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_pad, __pyx_k_Unspecified_error_in_H5Tset_pad, sizeof(__pyx_k_Unspecified_error_in_H5Tset_pad), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_prec, __pyx_k_Unspecified_error_in_H5Tset_prec, sizeof(__pyx_k_Unspecified_error_in_H5Tset_prec), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_sign, __pyx_k_Unspecified_error_in_H5Tset_sign, sizeof(__pyx_k_Unspecified_error_in_H5Tset_sign), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_size, __pyx_k_Unspecified_error_in_H5Tset_size, sizeof(__pyx_k_Unspecified_error_in_H5Tset_size), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_strp, __pyx_k_Unspecified_error_in_H5Tset_strp, sizeof(__pyx_k_Unspecified_error_in_H5Tset_strp), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tset_tag, __pyx_k_Unspecified_error_in_H5Tset_tag, sizeof(__pyx_k_Unspecified_error_in_H5Tset_tag), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tunregist, __pyx_k_Unspecified_error_in_H5Tunregist, sizeof(__pyx_k_Unspecified_error_in_H5Tunregist), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Tvlen_cre, __pyx_k_Unspecified_error_in_H5Tvlen_cre, sizeof(__pyx_k_Unspecified_error_in_H5Tvlen_cre), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Zfilter_a, __pyx_k_Unspecified_error_in_H5Zfilter_a, sizeof(__pyx_k_Unspecified_error_in_H5Zfilter_a), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Zget_filt, __pyx_k_Unspecified_error_in_H5Zget_filt, sizeof(__pyx_k_Unspecified_error_in_H5Zget_filt), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5Zunregist, __pyx_k_Unspecified_error_in_H5Zunregist, sizeof(__pyx_k_Unspecified_error_in_H5Zunregist), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5check_ver, __pyx_k_Unspecified_error_in_H5check_ver, sizeof(__pyx_k_Unspecified_error_in_H5check_ver), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5close_ret, __pyx_k_Unspecified_error_in_H5close_ret, sizeof(__pyx_k_Unspecified_error_in_H5close_ret), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5free_memo, __pyx_k_Unspecified_error_in_H5free_memo, sizeof(__pyx_k_Unspecified_error_in_H5free_memo), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5get_libve, __pyx_k_Unspecified_error_in_H5get_libve, sizeof(__pyx_k_Unspecified_error_in_H5get_libve), 0, 1, 0, 0},
  {&__pyx_kp_u_Unspecified_error_in_H5open_retu, __pyx_k_Unspecified_error_in_H5open_retu, sizeof(__pyx_k_Unspecified_error_in_H5open_retu), 0, 1, 0, 0},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_kp_u_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 1, 0, 0},
  {&__pyx_kp_u_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 1, 0, 0},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(0, 22, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(1, 944, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "h5py/defs.pyx":22
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5open (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5open_retu); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "h5py/defs.pyx":33
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5close (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5close_ret); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "h5py/defs.pyx":44
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5get_libversion (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5get_libve); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "h5py/defs.pyx":55
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5check_version (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5check_ver); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "h5py/defs.pyx":67
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5free_memory (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5free_memo); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "h5py/defs.pyx":78
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Acreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Acreate_r); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "h5py/defs.pyx":89
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aopen_idx); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "h5py/defs.pyx":100
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aopen_nam); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "h5py/defs.pyx":111
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aclose_re); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "h5py/defs.pyx":122
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Adelete_r); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "h5py/defs.pyx":133
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aread (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aread_ret); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "h5py/defs.pyx":144
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Awrite (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Awrite_re); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "h5py/defs.pyx":155
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_num_attrs (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aget_num); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "h5py/defs.pyx":166
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aget_name); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "h5py/defs.pyx":177
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_space (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aget_spac); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "h5py/defs.pyx":188
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aget_type); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "h5py/defs.pyx":199
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Adelete_b); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "h5py/defs.pyx":210
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Adelete_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Adelete_b_2); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "h5py/defs.pyx":221
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Acreate_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Acreate_b); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "h5py/defs.pyx":232
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aopen_ret); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "h5py/defs.pyx":243
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aopen_by); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "h5py/defs.pyx":254
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aopen_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aopen_by_2); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "h5py/defs.pyx":265
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aexists_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aexists_b); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "h5py/defs.pyx":276
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aexists (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aexists_r); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "h5py/defs.pyx":287
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Arename (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Arename_r); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "h5py/defs.pyx":298
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Arename_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Arename_b); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "h5py/defs.pyx":309
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aget_info); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "h5py/defs.pyx":320
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aget_info_2); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "h5py/defs.pyx":331
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_info_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__29 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aget_info_3); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "h5py/defs.pyx":342
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aiterate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__30 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aiterate); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "h5py/defs.pyx":353
 *             return <hsize_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Aget_storage_size (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Aget_stor); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "h5py/defs.pyx":365
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dcreate_r); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "h5py/defs.pyx":377
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dcreate_anon (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__33 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dcreate_a); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "h5py/defs.pyx":388
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__34 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dopen_ret); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "h5py/defs.pyx":399
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__35 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dclose_re); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "h5py/defs.pyx":410
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_space (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__36 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_spac); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "h5py/defs.pyx":421
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_space_status (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__37 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_spac_2); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "h5py/defs.pyx":432
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__38 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_type); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "h5py/defs.pyx":443
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_create_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__39 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_crea); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "h5py/defs.pyx":454
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_access_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__40 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_acce); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);

  /* "h5py/defs.pyx":465
 *             return <haddr_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dget_offset (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__41 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_offs); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "h5py/defs.pyx":486
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dread (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__42 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dread_ret); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "h5py/defs.pyx":498
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dwrite (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__43 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dwrite_re); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "h5py/defs.pyx":510
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dextend (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dextend_r); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "h5py/defs.pyx":522
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dfill (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__45 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dfill_ret); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "h5py/defs.pyx":533
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dvlen_get_buf_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__46 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dvlen_get); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "h5py/defs.pyx":544
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dvlen_reclaim (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__47 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dvlen_rec); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "h5py/defs.pyx":556
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Diterate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__48 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Diterate); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "h5py/defs.pyx":568
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Dset_extent (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__49 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dset_exte); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "h5py/defs.pyx":581
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dflush (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__50 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dflush_re); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "h5py/defs.pyx":594
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Drefresh (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__51 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Drefresh); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "h5py/defs.pyx":607
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5DOwrite_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__52 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DOwrite_c); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "h5py/defs.pyx":620
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_storage_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__53 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_chun); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "h5py/defs.pyx":633
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5DOread_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__54 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DOread_ch); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "h5py/defs.pyx":646
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dread_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__55 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dread_chu); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "h5py/defs.pyx":658
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_num_chunks (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__56 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_num); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "h5py/defs.pyx":670
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_info (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__57 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_chun_2); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "h5py/defs.pyx":682
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Dget_chunk_info_by_coord (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__58 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Dget_chun_3); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "h5py/defs.pyx":693
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fcreate_r); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "h5py/defs.pyx":704
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__60 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fopen_ret); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "h5py/defs.pyx":715
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__61 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fclose_re); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "h5py/defs.pyx":726
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fis_hdf5 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__62 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fis_hdf5); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "h5py/defs.pyx":738
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fflush (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__63 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fflush_re); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "h5py/defs.pyx":749
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Freopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__64 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Freopen_r); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "h5py/defs.pyx":760
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fmount (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__65 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fmount_re); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "h5py/defs.pyx":771
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Funmount (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__66 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Funmount); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(0, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "h5py/defs.pyx":782
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_filesize (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__67 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_file); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);

  /* "h5py/defs.pyx":793
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_create_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__68 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_crea); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "h5py/defs.pyx":804
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_access_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__69 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_acce); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);

  /* "h5py/defs.pyx":815
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_freespace (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__70 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_free); if (unlikely(!__pyx_tuple__70)) __PYX_ERR(0, 815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);

  /* "h5py/defs.pyx":826
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__71 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_name); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);

  /* "h5py/defs.pyx":837
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_obj_count (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__72 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_obj); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "h5py/defs.pyx":848
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_obj_ids (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__73 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_obj_2); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);

  /* "h5py/defs.pyx":859
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_vfd_handle (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__74 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_vfd); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);

  /* "h5py/defs.pyx":870
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_intent (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__75 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_inte); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "h5py/defs.pyx":881
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_config (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__76 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_mdc); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "h5py/defs.pyx":892
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_hit_rate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__77 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_mdc_2); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "h5py/defs.pyx":903
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fget_mdc_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__78 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_mdc_3); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);

  /* "h5py/defs.pyx":914
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Freset_mdc_hit_rate_stats (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__79 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Freset_md); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(0, 914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);

  /* "h5py/defs.pyx":925
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Fset_mdc_config (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__80 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fset_mdc); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);

  /* "h5py/defs.pyx":937
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fget_file_image (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__81 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_file_2); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(0, 937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);

  /* "h5py/defs.pyx":949
 *                 return <hid_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5LTopen_file_image (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__82 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5LTopen_fi); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(0, 949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);

  /* "h5py/defs.pyx":987
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fstart_swmr_write (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__83 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fstart_sw); if (unlikely(!__pyx_tuple__83)) __PYX_ERR(0, 987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "h5py/defs.pyx":999
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Freset_page_buffering_stats (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__84 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Freset_pa); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);

  /* "h5py/defs.pyx":1011
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Fget_page_buffering_stats (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__85 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Fget_page); if (unlikely(!__pyx_tuple__85)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);

  /* "h5py/defs.pyx":1022
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5FDregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__86 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5FDregiste); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 1022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "h5py/defs.pyx":1033
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5FDunregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__87 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5FDunregis); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(0, 1033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);

  /* "h5py/defs.pyx":1044
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__88 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gclose_re); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);

  /* "h5py/defs.pyx":1055
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Glink2 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__89 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Glink2_re); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(0, 1055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);

  /* "h5py/defs.pyx":1066
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gunlink (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__90 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gunlink_r); if (unlikely(!__pyx_tuple__90)) __PYX_ERR(0, 1066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);

  /* "h5py/defs.pyx":1077
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gmove2 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__91 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gmove2_re); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 1077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);

  /* "h5py/defs.pyx":1088
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_num_objs (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__92 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_num); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(0, 1088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);

  /* "h5py/defs.pyx":1099
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objname_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__93 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_objn); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 1099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "h5py/defs.pyx":1110
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objtype_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__94 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_objt); if (unlikely(!__pyx_tuple__94)) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);

  /* "h5py/defs.pyx":1121
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Giterate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__95 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Giterate); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 1121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);

  /* "h5py/defs.pyx":1132
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_objinfo (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__96 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_obji); if (unlikely(!__pyx_tuple__96)) __PYX_ERR(0, 1132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__96);
  __Pyx_GIVEREF(__pyx_tuple__96);

  /* "h5py/defs.pyx":1143
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_linkval (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__97 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_link); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);

  /* "h5py/defs.pyx":1154
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gset_comment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__98 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gset_comm); if (unlikely(!__pyx_tuple__98)) __PYX_ERR(0, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__98);
  __Pyx_GIVEREF(__pyx_tuple__98);

  /* "h5py/defs.pyx":1165
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_comment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__99 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_comm); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 1165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);

  /* "h5py/defs.pyx":1176
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gcreate_anon (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__100 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gcreate_a); if (unlikely(!__pyx_tuple__100)) __PYX_ERR(0, 1176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);

  /* "h5py/defs.pyx":1187
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__101 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gcreate_r); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 1187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "h5py/defs.pyx":1198
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__102 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gopen_ret); if (unlikely(!__pyx_tuple__102)) __PYX_ERR(0, 1198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);

  /* "h5py/defs.pyx":1209
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__103 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_info); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 1209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);

  /* "h5py/defs.pyx":1220
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_info_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__104 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_info_2); if (unlikely(!__pyx_tuple__104)) __PYX_ERR(0, 1220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);

  /* "h5py/defs.pyx":1231
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Gget_create_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__105 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Gget_crea); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(0, 1231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);

  /* "h5py/defs.pyx":1242
 *             return <H5I_type_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__106 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Iget_type); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(0, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "h5py/defs.pyx":1253
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__107 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Iget_name); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);

  /* "h5py/defs.pyx":1264
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_file_id (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__108 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Iget_file); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);

  /* "h5py/defs.pyx":1276
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Idec_ref (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__109 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Idec_ref); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);

  /* "h5py/defs.pyx":1287
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iget_ref (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__110 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Iget_ref); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);

  /* "h5py/defs.pyx":1298
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iinc_ref (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__111 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Iinc_ref); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(0, 1298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);

  /* "h5py/defs.pyx":1309
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Iis_valid (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__112 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Iis_valid); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);

  /* "h5py/defs.pyx":1320
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lmove (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__113 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lmove_ret); if (unlikely(!__pyx_tuple__113)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__113);
  __Pyx_GIVEREF(__pyx_tuple__113);

  /* "h5py/defs.pyx":1331
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__114 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lcopy_ret); if (unlikely(!__pyx_tuple__114)) __PYX_ERR(0, 1331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__114);
  __Pyx_GIVEREF(__pyx_tuple__114);

  /* "h5py/defs.pyx":1342
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_hard (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__115 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lcreate_h); if (unlikely(!__pyx_tuple__115)) __PYX_ERR(0, 1342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);

  /* "h5py/defs.pyx":1353
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_soft (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__116 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lcreate_s); if (unlikely(!__pyx_tuple__116)) __PYX_ERR(0, 1353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__116);
  __Pyx_GIVEREF(__pyx_tuple__116);

  /* "h5py/defs.pyx":1364
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ldelete (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__117 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Ldelete_r); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(0, 1364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);

  /* "h5py/defs.pyx":1375
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ldelete_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__118 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Ldelete_b); if (unlikely(!__pyx_tuple__118)) __PYX_ERR(0, 1375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__118);
  __Pyx_GIVEREF(__pyx_tuple__118);

  /* "h5py/defs.pyx":1386
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_val (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__119 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lget_val); if (unlikely(!__pyx_tuple__119)) __PYX_ERR(0, 1386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__119);
  __Pyx_GIVEREF(__pyx_tuple__119);

  /* "h5py/defs.pyx":1397
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_val_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__120 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lget_val_2); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);

  /* "h5py/defs.pyx":1408
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lexists (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__121 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lexists_r); if (unlikely(!__pyx_tuple__121)) __PYX_ERR(0, 1408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);

  /* "h5py/defs.pyx":1419
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__122 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lget_info); if (unlikely(!__pyx_tuple__122)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__122);
  __Pyx_GIVEREF(__pyx_tuple__122);

  /* "h5py/defs.pyx":1430
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_info_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__123 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lget_info_2); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 1430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);

  /* "h5py/defs.pyx":1441
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lget_name_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__124 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lget_name); if (unlikely(!__pyx_tuple__124)) __PYX_ERR(0, 1441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__124);
  __Pyx_GIVEREF(__pyx_tuple__124);

  /* "h5py/defs.pyx":1452
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Literate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__125 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Literate); if (unlikely(!__pyx_tuple__125)) __PYX_ERR(0, 1452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);

  /* "h5py/defs.pyx":1463
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Literate_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__126 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Literate_2); if (unlikely(!__pyx_tuple__126)) __PYX_ERR(0, 1463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__126);
  __Pyx_GIVEREF(__pyx_tuple__126);

  /* "h5py/defs.pyx":1474
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lvisit (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__127 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lvisit_re); if (unlikely(!__pyx_tuple__127)) __PYX_ERR(0, 1474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);

  /* "h5py/defs.pyx":1485
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lvisit_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__128 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lvisit_by); if (unlikely(!__pyx_tuple__128)) __PYX_ERR(0, 1485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__128);
  __Pyx_GIVEREF(__pyx_tuple__128);

  /* "h5py/defs.pyx":1496
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lunpack_elink_val (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__129 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lunpack_e); if (unlikely(!__pyx_tuple__129)) __PYX_ERR(0, 1496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__129);
  __Pyx_GIVEREF(__pyx_tuple__129);

  /* "h5py/defs.pyx":1507
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Lcreate_external (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__130 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Lcreate_e); if (unlikely(!__pyx_tuple__130)) __PYX_ERR(0, 1507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__130);
  __Pyx_GIVEREF(__pyx_tuple__130);

  /* "h5py/defs.pyx":1518
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__131 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oopen_ret); if (unlikely(!__pyx_tuple__131)) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__131);
  __Pyx_GIVEREF(__pyx_tuple__131);

  /* "h5py/defs.pyx":1529
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen_by_addr (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__132 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oopen_by); if (unlikely(!__pyx_tuple__132)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__132);
  __Pyx_GIVEREF(__pyx_tuple__132);

  /* "h5py/defs.pyx":1540
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oopen_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__133 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oopen_by_2); if (unlikely(!__pyx_tuple__133)) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__133);
  __Pyx_GIVEREF(__pyx_tuple__133);

  /* "h5py/defs.pyx":1551
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__134 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oget_info); if (unlikely(!__pyx_tuple__134)) __PYX_ERR(0, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__134);
  __Pyx_GIVEREF(__pyx_tuple__134);

  /* "h5py/defs.pyx":1562
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__135 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oget_info_2); if (unlikely(!__pyx_tuple__135)) __PYX_ERR(0, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__135);
  __Pyx_GIVEREF(__pyx_tuple__135);

  /* "h5py/defs.pyx":1573
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_info_by_idx (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__136 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oget_info_3); if (unlikely(!__pyx_tuple__136)) __PYX_ERR(0, 1573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__136);
  __Pyx_GIVEREF(__pyx_tuple__136);

  /* "h5py/defs.pyx":1584
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Olink (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__137 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Olink_ret); if (unlikely(!__pyx_tuple__137)) __PYX_ERR(0, 1584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__137);
  __Pyx_GIVEREF(__pyx_tuple__137);

  /* "h5py/defs.pyx":1595
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ocopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__138 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Ocopy_ret); if (unlikely(!__pyx_tuple__138)) __PYX_ERR(0, 1595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__138);
  __Pyx_GIVEREF(__pyx_tuple__138);

  /* "h5py/defs.pyx":1606
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oincr_refcount (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__139 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oincr_ref); if (unlikely(!__pyx_tuple__139)) __PYX_ERR(0, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__139);
  __Pyx_GIVEREF(__pyx_tuple__139);

  /* "h5py/defs.pyx":1617
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Odecr_refcount (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__140 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Odecr_ref); if (unlikely(!__pyx_tuple__140)) __PYX_ERR(0, 1617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__140);
  __Pyx_GIVEREF(__pyx_tuple__140);

  /* "h5py/defs.pyx":1628
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oset_comment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__141 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oset_comm); if (unlikely(!__pyx_tuple__141)) __PYX_ERR(0, 1628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__141);
  __Pyx_GIVEREF(__pyx_tuple__141);

  /* "h5py/defs.pyx":1639
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oset_comment_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__142 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oset_comm_2); if (unlikely(!__pyx_tuple__142)) __PYX_ERR(0, 1639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__142);
  __Pyx_GIVEREF(__pyx_tuple__142);

  /* "h5py/defs.pyx":1650
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_comment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__143 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oget_comm); if (unlikely(!__pyx_tuple__143)) __PYX_ERR(0, 1650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__143);
  __Pyx_GIVEREF(__pyx_tuple__143);

  /* "h5py/defs.pyx":1661
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oget_comment_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__144 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oget_comm_2); if (unlikely(!__pyx_tuple__144)) __PYX_ERR(0, 1661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__144);
  __Pyx_GIVEREF(__pyx_tuple__144);

  /* "h5py/defs.pyx":1672
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ovisit (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__145 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Ovisit_re); if (unlikely(!__pyx_tuple__145)) __PYX_ERR(0, 1672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__145);
  __Pyx_GIVEREF(__pyx_tuple__145);

  /* "h5py/defs.pyx":1683
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Ovisit_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__146 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Ovisit_by); if (unlikely(!__pyx_tuple__146)) __PYX_ERR(0, 1683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__146);
  __Pyx_GIVEREF(__pyx_tuple__146);

  /* "h5py/defs.pyx":1694
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Oclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__147 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oclose_re); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(0, 1694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);

  /* "h5py/defs.pyx":1706
 *                 return <htri_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Oexists_by_name (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__148 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Oexists_b); if (unlikely(!__pyx_tuple__148)) __PYX_ERR(0, 1706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__148);
  __Pyx_GIVEREF(__pyx_tuple__148);

  /* "h5py/defs.pyx":1717
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__149 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pcreate_r); if (unlikely(!__pyx_tuple__149)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__149);
  __Pyx_GIVEREF(__pyx_tuple__149);

  /* "h5py/defs.pyx":1728
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pcopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__150 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pcopy_ret); if (unlikely(!__pyx_tuple__150)) __PYX_ERR(0, 1728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__150);
  __Pyx_GIVEREF(__pyx_tuple__150);

  /* "h5py/defs.pyx":1739
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__151 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_clas); if (unlikely(!__pyx_tuple__151)) __PYX_ERR(0, 1739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__151);
  __Pyx_GIVEREF(__pyx_tuple__151);

  /* "h5py/defs.pyx":1750
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__152 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pclose_re); if (unlikely(!__pyx_tuple__152)) __PYX_ERR(0, 1750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__152);
  __Pyx_GIVEREF(__pyx_tuple__152);

  /* "h5py/defs.pyx":1761
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pequal (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__153 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pequal_re); if (unlikely(!__pyx_tuple__153)) __PYX_ERR(0, 1761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__153);
  __Pyx_GIVEREF(__pyx_tuple__153);

  /* "h5py/defs.pyx":1772
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pclose_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__154 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pclose_cl); if (unlikely(!__pyx_tuple__154)) __PYX_ERR(0, 1772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__154);
  __Pyx_GIVEREF(__pyx_tuple__154);

  /* "h5py/defs.pyx":1783
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_version (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__155 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_vers); if (unlikely(!__pyx_tuple__155)) __PYX_ERR(0, 1783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__155);
  __Pyx_GIVEREF(__pyx_tuple__155);

  /* "h5py/defs.pyx":1794
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_userblock (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__156 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_user); if (unlikely(!__pyx_tuple__156)) __PYX_ERR(0, 1794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__156);
  __Pyx_GIVEREF(__pyx_tuple__156);

  /* "h5py/defs.pyx":1805
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_userblock (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__157 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_user); if (unlikely(!__pyx_tuple__157)) __PYX_ERR(0, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__157);
  __Pyx_GIVEREF(__pyx_tuple__157);

  /* "h5py/defs.pyx":1816
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sizes (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__158 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_size); if (unlikely(!__pyx_tuple__158)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__158);
  __Pyx_GIVEREF(__pyx_tuple__158);

  /* "h5py/defs.pyx":1827
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sizes (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__159 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_size); if (unlikely(!__pyx_tuple__159)) __PYX_ERR(0, 1827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__159);
  __Pyx_GIVEREF(__pyx_tuple__159);

  /* "h5py/defs.pyx":1838
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sym_k (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__160 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_sym); if (unlikely(!__pyx_tuple__160)) __PYX_ERR(0, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__160);
  __Pyx_GIVEREF(__pyx_tuple__160);

  /* "h5py/defs.pyx":1849
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sym_k (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__161 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_sym); if (unlikely(!__pyx_tuple__161)) __PYX_ERR(0, 1849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__161);
  __Pyx_GIVEREF(__pyx_tuple__161);

  /* "h5py/defs.pyx":1860
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_istore_k (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__162 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_isto); if (unlikely(!__pyx_tuple__162)) __PYX_ERR(0, 1860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__162);
  __Pyx_GIVEREF(__pyx_tuple__162);

  /* "h5py/defs.pyx":1871
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_istore_k (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__163 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_isto); if (unlikely(!__pyx_tuple__163)) __PYX_ERR(0, 1871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__163);
  __Pyx_GIVEREF(__pyx_tuple__163);

  /* "h5py/defs.pyx":1883
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_space_strategy (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__164 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_file); if (unlikely(!__pyx_tuple__164)) __PYX_ERR(0, 1883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__164);
  __Pyx_GIVEREF(__pyx_tuple__164);

  /* "h5py/defs.pyx":1895
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_space_strategy (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__165 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_file); if (unlikely(!__pyx_tuple__165)) __PYX_ERR(0, 1895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__165);
  __Pyx_GIVEREF(__pyx_tuple__165);

  /* "h5py/defs.pyx":1907
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_space_page_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__166 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_file_2); if (unlikely(!__pyx_tuple__166)) __PYX_ERR(0, 1907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__166);
  __Pyx_GIVEREF(__pyx_tuple__166);

  /* "h5py/defs.pyx":1919
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_space_page_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__167 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_file_2); if (unlikely(!__pyx_tuple__167)) __PYX_ERR(0, 1919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__167);
  __Pyx_GIVEREF(__pyx_tuple__167);

  /* "h5py/defs.pyx":1930
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fclose_degree (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__168 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fclo); if (unlikely(!__pyx_tuple__168)) __PYX_ERR(0, 1930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__168);
  __Pyx_GIVEREF(__pyx_tuple__168);

  /* "h5py/defs.pyx":1941
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fclose_degree (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__169 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_fclo); if (unlikely(!__pyx_tuple__169)) __PYX_ERR(0, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__169);
  __Pyx_GIVEREF(__pyx_tuple__169);

  /* "h5py/defs.pyx":1952
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_core (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__170 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fapl); if (unlikely(!__pyx_tuple__170)) __PYX_ERR(0, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__170);
  __Pyx_GIVEREF(__pyx_tuple__170);

  /* "h5py/defs.pyx":1963
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fapl_core (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__171 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_fapl); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(0, 1963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);

  /* "h5py/defs.pyx":1974
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_family (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__172 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fapl_2); if (unlikely(!__pyx_tuple__172)) __PYX_ERR(0, 1974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__172);
  __Pyx_GIVEREF(__pyx_tuple__172);

  /* "h5py/defs.pyx":1985
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fapl_family (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__173 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_fapl_2); if (unlikely(!__pyx_tuple__173)) __PYX_ERR(0, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__173);
  __Pyx_GIVEREF(__pyx_tuple__173);

  /* "h5py/defs.pyx":1996
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_family_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__174 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fami); if (unlikely(!__pyx_tuple__174)) __PYX_ERR(0, 1996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__174);
  __Pyx_GIVEREF(__pyx_tuple__174);

  /* "h5py/defs.pyx":2007
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_family_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__175 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_fami); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(0, 2007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);

  /* "h5py/defs.pyx":2068
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_log (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__176 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fapl_3); if (unlikely(!__pyx_tuple__176)) __PYX_ERR(0, 2068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__176);
  __Pyx_GIVEREF(__pyx_tuple__176);

  /* "h5py/defs.pyx":2079
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_multi (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__177 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fapl_4); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(0, 2079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);

  /* "h5py/defs.pyx":2090
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_cache (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__178 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_cach); if (unlikely(!__pyx_tuple__178)) __PYX_ERR(0, 2090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__178);
  __Pyx_GIVEREF(__pyx_tuple__178);

  /* "h5py/defs.pyx":2101
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_cache (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__179 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_cach); if (unlikely(!__pyx_tuple__179)) __PYX_ERR(0, 2101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__179);
  __Pyx_GIVEREF(__pyx_tuple__179);

  /* "h5py/defs.pyx":2112
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_sec2 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__180 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fapl_5); if (unlikely(!__pyx_tuple__180)) __PYX_ERR(0, 2112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__180);
  __Pyx_GIVEREF(__pyx_tuple__180);

  /* "h5py/defs.pyx":2123
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_stdio (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__181 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fapl_6); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(0, 2123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);

  /* "h5py/defs.pyx":2134
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fapl_split (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__182 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fapl_7); if (unlikely(!__pyx_tuple__182)) __PYX_ERR(0, 2134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__182);
  __Pyx_GIVEREF(__pyx_tuple__182);

  /* "h5py/defs.pyx":2145
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_driver (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__183 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_driv); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(0, 2145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);

  /* "h5py/defs.pyx":2156
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_driver (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__184 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_driv); if (unlikely(!__pyx_tuple__184)) __PYX_ERR(0, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__184);
  __Pyx_GIVEREF(__pyx_tuple__184);

  /* "h5py/defs.pyx":2167
 *             return <void*>NULL
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_driver_info (return value ==NULL)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__185 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_driv_2); if (unlikely(!__pyx_tuple__185)) __PYX_ERR(0, 2167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__185);
  __Pyx_GIVEREF(__pyx_tuple__185);

  /* "h5py/defs.pyx":2178
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_mdc_config (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__186 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_mdc); if (unlikely(!__pyx_tuple__186)) __PYX_ERR(0, 2178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__186);
  __Pyx_GIVEREF(__pyx_tuple__186);

  /* "h5py/defs.pyx":2189
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_mdc_config (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__187 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_mdc); if (unlikely(!__pyx_tuple__187)) __PYX_ERR(0, 2189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__187);
  __Pyx_GIVEREF(__pyx_tuple__187);

  /* "h5py/defs.pyx":2201
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_image (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__188 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_file_3); if (unlikely(!__pyx_tuple__188)) __PYX_ERR(0, 2201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__188);
  __Pyx_GIVEREF(__pyx_tuple__188);

  /* "h5py/defs.pyx":2213
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_page_buffer_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__189 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_page); if (unlikely(!__pyx_tuple__189)) __PYX_ERR(0, 2213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__189);
  __Pyx_GIVEREF(__pyx_tuple__189);

  /* "h5py/defs.pyx":2225
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_page_buffer_size (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__190 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_page); if (unlikely(!__pyx_tuple__190)) __PYX_ERR(0, 2225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__190);
  __Pyx_GIVEREF(__pyx_tuple__190);

  /* "h5py/defs.pyx":2249
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_file_locking (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__191 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_file_3); if (unlikely(!__pyx_tuple__191)) __PYX_ERR(0, 2249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__191);
  __Pyx_GIVEREF(__pyx_tuple__191);

  /* "h5py/defs.pyx":2273
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_file_locking (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__192 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_file_4); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(0, 2273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);

  /* "h5py/defs.pyx":2284
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_layout (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__193 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_layo); if (unlikely(!__pyx_tuple__193)) __PYX_ERR(0, 2284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__193);
  __Pyx_GIVEREF(__pyx_tuple__193);

  /* "h5py/defs.pyx":2295
 *             return <H5D_layout_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_layout (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__194 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_layo); if (unlikely(!__pyx_tuple__194)) __PYX_ERR(0, 2295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__194);
  __Pyx_GIVEREF(__pyx_tuple__194);

  /* "h5py/defs.pyx":2306
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__195 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_chun); if (unlikely(!__pyx_tuple__195)) __PYX_ERR(0, 2306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__195);
  __Pyx_GIVEREF(__pyx_tuple__195);

  /* "h5py/defs.pyx":2317
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_chunk (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__196 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_chun); if (unlikely(!__pyx_tuple__196)) __PYX_ERR(0, 2317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__196);
  __Pyx_GIVEREF(__pyx_tuple__196);

  /* "h5py/defs.pyx":2328
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_deflate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__197 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_defl); if (unlikely(!__pyx_tuple__197)) __PYX_ERR(0, 2328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__197);
  __Pyx_GIVEREF(__pyx_tuple__197);

  /* "h5py/defs.pyx":2339
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fill_value (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__198 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fill); if (unlikely(!__pyx_tuple__198)) __PYX_ERR(0, 2339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__198);
  __Pyx_GIVEREF(__pyx_tuple__198);

  /* "h5py/defs.pyx":2350
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fill_value (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__199 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_fill); if (unlikely(!__pyx_tuple__199)) __PYX_ERR(0, 2350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__199);
  __Pyx_GIVEREF(__pyx_tuple__199);

  /* "h5py/defs.pyx":2361
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pfill_value_defined (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__200 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pfill_val); if (unlikely(!__pyx_tuple__200)) __PYX_ERR(0, 2361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__200);
  __Pyx_GIVEREF(__pyx_tuple__200);

  /* "h5py/defs.pyx":2372
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fill_time (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__201 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_fill_2); if (unlikely(!__pyx_tuple__201)) __PYX_ERR(0, 2372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__201);
  __Pyx_GIVEREF(__pyx_tuple__201);

  /* "h5py/defs.pyx":2383
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_fill_time (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__202 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_fill_2); if (unlikely(!__pyx_tuple__202)) __PYX_ERR(0, 2383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__202);
  __Pyx_GIVEREF(__pyx_tuple__202);

  /* "h5py/defs.pyx":2394
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_alloc_time (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__203 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_allo); if (unlikely(!__pyx_tuple__203)) __PYX_ERR(0, 2394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__203);
  __Pyx_GIVEREF(__pyx_tuple__203);

  /* "h5py/defs.pyx":2405
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_alloc_time (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__204 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_allo); if (unlikely(!__pyx_tuple__204)) __PYX_ERR(0, 2405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__204);
  __Pyx_GIVEREF(__pyx_tuple__204);

  /* "h5py/defs.pyx":2416
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_filter (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__205 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_filt); if (unlikely(!__pyx_tuple__205)) __PYX_ERR(0, 2416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__205);
  __Pyx_GIVEREF(__pyx_tuple__205);

  /* "h5py/defs.pyx":2427
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pall_filters_avail (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__206 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pall_filt); if (unlikely(!__pyx_tuple__206)) __PYX_ERR(0, 2427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__206);
  __Pyx_GIVEREF(__pyx_tuple__206);

  /* "h5py/defs.pyx":2438
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_nfilters (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__207 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_nfil); if (unlikely(!__pyx_tuple__207)) __PYX_ERR(0, 2438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__207);
  __Pyx_GIVEREF(__pyx_tuple__207);

  /* "h5py/defs.pyx":2449
 *             return <H5Z_filter_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_filter (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__208 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_filt); if (unlikely(!__pyx_tuple__208)) __PYX_ERR(0, 2449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__208);
  __Pyx_GIVEREF(__pyx_tuple__208);

  /* "h5py/defs.pyx":2460
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_filter_by_id (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__209 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_filt_2); if (unlikely(!__pyx_tuple__209)) __PYX_ERR(0, 2460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__209);
  __Pyx_GIVEREF(__pyx_tuple__209);

  /* "h5py/defs.pyx":2471
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pmodify_filter (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__210 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pmodify_f); if (unlikely(!__pyx_tuple__210)) __PYX_ERR(0, 2471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__210);
  __Pyx_GIVEREF(__pyx_tuple__210);

  /* "h5py/defs.pyx":2482
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Premove_filter (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__211 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Premove_f); if (unlikely(!__pyx_tuple__211)) __PYX_ERR(0, 2482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__211);
  __Pyx_GIVEREF(__pyx_tuple__211);

  /* "h5py/defs.pyx":2493
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_fletcher32 (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__212 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_flet); if (unlikely(!__pyx_tuple__212)) __PYX_ERR(0, 2493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__212);
  __Pyx_GIVEREF(__pyx_tuple__212);

  /* "h5py/defs.pyx":2504
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_shuffle (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__213 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_shuf); if (unlikely(!__pyx_tuple__213)) __PYX_ERR(0, 2504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__213);
  __Pyx_GIVEREF(__pyx_tuple__213);

  /* "h5py/defs.pyx":2515
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_szip (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__214 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_szip); if (unlikely(!__pyx_tuple__214)) __PYX_ERR(0, 2515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__214);
  __Pyx_GIVEREF(__pyx_tuple__214);

  /* "h5py/defs.pyx":2526
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_scaleoffset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__215 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_scal); if (unlikely(!__pyx_tuple__215)) __PYX_ERR(0, 2526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__215);
  __Pyx_GIVEREF(__pyx_tuple__215);

  /* "h5py/defs.pyx":2537
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_external (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__216 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_exte); if (unlikely(!__pyx_tuple__216)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__216);
  __Pyx_GIVEREF(__pyx_tuple__216);

  /* "h5py/defs.pyx":2548
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_external_count (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__217 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_exte); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(0, 2548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);

  /* "h5py/defs.pyx":2559
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_external (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__218 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_exte_2); if (unlikely(!__pyx_tuple__218)) __PYX_ERR(0, 2559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__218);
  __Pyx_GIVEREF(__pyx_tuple__218);

  /* "h5py/defs.pyx":2571
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_dsetname (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__219 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_virt); if (unlikely(!__pyx_tuple__219)) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__219);
  __Pyx_GIVEREF(__pyx_tuple__219);

  /* "h5py/defs.pyx":2583
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_filename (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__220 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_virt_2); if (unlikely(!__pyx_tuple__220)) __PYX_ERR(0, 2583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__220);
  __Pyx_GIVEREF(__pyx_tuple__220);

  /* "h5py/defs.pyx":2595
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_count (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__221 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_virt_3); if (unlikely(!__pyx_tuple__221)) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__221);
  __Pyx_GIVEREF(__pyx_tuple__221);

  /* "h5py/defs.pyx":2607
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__222 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_virt); if (unlikely(!__pyx_tuple__222)) __PYX_ERR(0, 2607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__222);
  __Pyx_GIVEREF(__pyx_tuple__222);

  /* "h5py/defs.pyx":2619
 *                 return <hid_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_vspace (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__223 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_virt_4); if (unlikely(!__pyx_tuple__223)) __PYX_ERR(0, 2619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__223);
  __Pyx_GIVEREF(__pyx_tuple__223);

  /* "h5py/defs.pyx":2631
 *                 return <hid_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_srcspace (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__224 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_virt_5); if (unlikely(!__pyx_tuple__224)) __PYX_ERR(0, 2631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__224);
  __Pyx_GIVEREF(__pyx_tuple__224);

  /* "h5py/defs.pyx":2642
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_edc_check (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__225 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_edc); if (unlikely(!__pyx_tuple__225)) __PYX_ERR(0, 2642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__225);
  __Pyx_GIVEREF(__pyx_tuple__225);

  /* "h5py/defs.pyx":2653
 *             return <H5Z_EDC_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_edc_check (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__226 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_edc); if (unlikely(!__pyx_tuple__226)) __PYX_ERR(0, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__226);
  __Pyx_GIVEREF(__pyx_tuple__226);

  /* "h5py/defs.pyx":2664
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_chunk_cache (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__227 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_chun_2); if (unlikely(!__pyx_tuple__227)) __PYX_ERR(0, 2664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__227);
  __Pyx_GIVEREF(__pyx_tuple__227);

  /* "h5py/defs.pyx":2675
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_chunk_cache (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__228 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_chun_2); if (unlikely(!__pyx_tuple__228)) __PYX_ERR(0, 2675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__228);
  __Pyx_GIVEREF(__pyx_tuple__228);

  /* "h5py/defs.pyx":2687
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_efile_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__229 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_efil); if (unlikely(!__pyx_tuple__229)) __PYX_ERR(0, 2687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__229);
  __Pyx_GIVEREF(__pyx_tuple__229);

  /* "h5py/defs.pyx":2699
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_efile_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__230 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_efil); if (unlikely(!__pyx_tuple__230)) __PYX_ERR(0, 2699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__230);
  __Pyx_GIVEREF(__pyx_tuple__230);

  /* "h5py/defs.pyx":2711
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_view (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__231 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_virt_2); if (unlikely(!__pyx_tuple__231)) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__231);
  __Pyx_GIVEREF(__pyx_tuple__231);

  /* "h5py/defs.pyx":2723
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_view (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__232 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_virt_6); if (unlikely(!__pyx_tuple__232)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__232);
  __Pyx_GIVEREF(__pyx_tuple__232);

  /* "h5py/defs.pyx":2735
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_printf_gap (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__233 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_virt_3); if (unlikely(!__pyx_tuple__233)) __PYX_ERR(0, 2735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__233);
  __Pyx_GIVEREF(__pyx_tuple__233);

  /* "h5py/defs.pyx":2747
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_printf_gap (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__234 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_virt_7); if (unlikely(!__pyx_tuple__234)) __PYX_ERR(0, 2747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__234);
  __Pyx_GIVEREF(__pyx_tuple__234);

  /* "h5py/defs.pyx":2759
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pget_virtual_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__235 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_virt_8); if (unlikely(!__pyx_tuple__235)) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__235);
  __Pyx_GIVEREF(__pyx_tuple__235);

  /* "h5py/defs.pyx":2771
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Pset_virtual_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__236 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_virt_4); if (unlikely(!__pyx_tuple__236)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__236);
  __Pyx_GIVEREF(__pyx_tuple__236);

  /* "h5py/defs.pyx":2806
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_sieve_buf_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__237 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_siev); if (unlikely(!__pyx_tuple__237)) __PYX_ERR(0, 2806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__237);
  __Pyx_GIVEREF(__pyx_tuple__237);

  /* "h5py/defs.pyx":2817
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_sieve_buf_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__238 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_siev); if (unlikely(!__pyx_tuple__238)) __PYX_ERR(0, 2817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__238);
  __Pyx_GIVEREF(__pyx_tuple__238);

  /* "h5py/defs.pyx":2828
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_nlinks (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__239 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_nlin); if (unlikely(!__pyx_tuple__239)) __PYX_ERR(0, 2828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__239);
  __Pyx_GIVEREF(__pyx_tuple__239);

  /* "h5py/defs.pyx":2839
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_nlinks (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__240 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_nlin); if (unlikely(!__pyx_tuple__240)) __PYX_ERR(0, 2839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__240);
  __Pyx_GIVEREF(__pyx_tuple__240);

  /* "h5py/defs.pyx":2850
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_elink_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__241 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_elin); if (unlikely(!__pyx_tuple__241)) __PYX_ERR(0, 2850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__241);
  __Pyx_GIVEREF(__pyx_tuple__241);

  /* "h5py/defs.pyx":2861
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_elink_prefix (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__242 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_elin); if (unlikely(!__pyx_tuple__242)) __PYX_ERR(0, 2861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__242);
  __Pyx_GIVEREF(__pyx_tuple__242);

  /* "h5py/defs.pyx":2872
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_elink_fapl (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__243 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_elin_2); if (unlikely(!__pyx_tuple__243)) __PYX_ERR(0, 2872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__243);
  __Pyx_GIVEREF(__pyx_tuple__243);

  /* "h5py/defs.pyx":2883
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_elink_fapl (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__244 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_elin_2); if (unlikely(!__pyx_tuple__244)) __PYX_ERR(0, 2883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__244);
  __Pyx_GIVEREF(__pyx_tuple__244);

  /* "h5py/defs.pyx":2894
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_create_intermediate_group (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__245 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_crea); if (unlikely(!__pyx_tuple__245)) __PYX_ERR(0, 2894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__245);
  __Pyx_GIVEREF(__pyx_tuple__245);

  /* "h5py/defs.pyx":2905
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_create_intermediate_group (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__246 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_crea); if (unlikely(!__pyx_tuple__246)) __PYX_ERR(0, 2905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__246);
  __Pyx_GIVEREF(__pyx_tuple__246);

  /* "h5py/defs.pyx":2916
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_copy_object (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__247 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_copy); if (unlikely(!__pyx_tuple__247)) __PYX_ERR(0, 2916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__247);
  __Pyx_GIVEREF(__pyx_tuple__247);

  /* "h5py/defs.pyx":2927
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_copy_object (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__248 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_copy); if (unlikely(!__pyx_tuple__248)) __PYX_ERR(0, 2927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__248);
  __Pyx_GIVEREF(__pyx_tuple__248);

  /* "h5py/defs.pyx":2938
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_char_encoding (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__249 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_char); if (unlikely(!__pyx_tuple__249)) __PYX_ERR(0, 2938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__249);
  __Pyx_GIVEREF(__pyx_tuple__249);

  /* "h5py/defs.pyx":2949
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_char_encoding (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__250 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_char); if (unlikely(!__pyx_tuple__250)) __PYX_ERR(0, 2949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__250);
  __Pyx_GIVEREF(__pyx_tuple__250);

  /* "h5py/defs.pyx":2960
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_attr_creation_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__251 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_attr); if (unlikely(!__pyx_tuple__251)) __PYX_ERR(0, 2960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__251);
  __Pyx_GIVEREF(__pyx_tuple__251);

  /* "h5py/defs.pyx":2971
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_attr_creation_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__252 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_attr); if (unlikely(!__pyx_tuple__252)) __PYX_ERR(0, 2971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__252);
  __Pyx_GIVEREF(__pyx_tuple__252);

  /* "h5py/defs.pyx":2982
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_obj_track_times (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__253 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_obj); if (unlikely(!__pyx_tuple__253)) __PYX_ERR(0, 2982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__253);
  __Pyx_GIVEREF(__pyx_tuple__253);

  /* "h5py/defs.pyx":2993
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_obj_track_times (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__254 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_obj); if (unlikely(!__pyx_tuple__254)) __PYX_ERR(0, 2993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__254);
  __Pyx_GIVEREF(__pyx_tuple__254);

  /* "h5py/defs.pyx":3004
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_local_heap_size_hint (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__255 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_loca); if (unlikely(!__pyx_tuple__255)) __PYX_ERR(0, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__255);
  __Pyx_GIVEREF(__pyx_tuple__255);

  /* "h5py/defs.pyx":3015
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_local_heap_size_hint (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__256 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_loca); if (unlikely(!__pyx_tuple__256)) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__256);
  __Pyx_GIVEREF(__pyx_tuple__256);

  /* "h5py/defs.pyx":3026
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_link_phase_change (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__257 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_link); if (unlikely(!__pyx_tuple__257)) __PYX_ERR(0, 3026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__257);
  __Pyx_GIVEREF(__pyx_tuple__257);

  /* "h5py/defs.pyx":3037
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_link_phase_change (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__258 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_link); if (unlikely(!__pyx_tuple__258)) __PYX_ERR(0, 3037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__258);
  __Pyx_GIVEREF(__pyx_tuple__258);

  /* "h5py/defs.pyx":3048
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_attr_phase_change (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__259 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_attr_2); if (unlikely(!__pyx_tuple__259)) __PYX_ERR(0, 3048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__259);
  __Pyx_GIVEREF(__pyx_tuple__259);

  /* "h5py/defs.pyx":3059
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_attr_phase_change (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__260 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_attr_2); if (unlikely(!__pyx_tuple__260)) __PYX_ERR(0, 3059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__260);
  __Pyx_GIVEREF(__pyx_tuple__260);

  /* "h5py/defs.pyx":3070
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_est_link_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__261 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_est); if (unlikely(!__pyx_tuple__261)) __PYX_ERR(0, 3070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__261);
  __Pyx_GIVEREF(__pyx_tuple__261);

  /* "h5py/defs.pyx":3081
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_est_link_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__262 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_est); if (unlikely(!__pyx_tuple__262)) __PYX_ERR(0, 3081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__262);
  __Pyx_GIVEREF(__pyx_tuple__262);

  /* "h5py/defs.pyx":3092
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_link_creation_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__263 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_link_2); if (unlikely(!__pyx_tuple__263)) __PYX_ERR(0, 3092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__263);
  __Pyx_GIVEREF(__pyx_tuple__263);

  /* "h5py/defs.pyx":3103
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_link_creation_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__264 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_link_2); if (unlikely(!__pyx_tuple__264)) __PYX_ERR(0, 3103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__264);
  __Pyx_GIVEREF(__pyx_tuple__264);

  /* "h5py/defs.pyx":3114
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_libver_bounds (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__265 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_libv); if (unlikely(!__pyx_tuple__265)) __PYX_ERR(0, 3114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__265);
  __Pyx_GIVEREF(__pyx_tuple__265);

  /* "h5py/defs.pyx":3125
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_libver_bounds (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__266 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_libv); if (unlikely(!__pyx_tuple__266)) __PYX_ERR(0, 3125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__266);
  __Pyx_GIVEREF(__pyx_tuple__266);

  /* "h5py/defs.pyx":3136
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pset_alignment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__267 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pset_alig); if (unlikely(!__pyx_tuple__267)) __PYX_ERR(0, 3136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__267);
  __Pyx_GIVEREF(__pyx_tuple__267);

  /* "h5py/defs.pyx":3147
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Pget_alignment (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__268 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Pget_alig); if (unlikely(!__pyx_tuple__268)) __PYX_ERR(0, 3147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__268);
  __Pyx_GIVEREF(__pyx_tuple__268);

  /* "h5py/defs.pyx":3183
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLappend (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__269 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5PLappend); if (unlikely(!__pyx_tuple__269)) __PYX_ERR(0, 3183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__269);
  __Pyx_GIVEREF(__pyx_tuple__269);

  /* "h5py/defs.pyx":3195
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLprepend (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__270 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5PLprepend); if (unlikely(!__pyx_tuple__270)) __PYX_ERR(0, 3195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__270);
  __Pyx_GIVEREF(__pyx_tuple__270);

  /* "h5py/defs.pyx":3207
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLreplace (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__271 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5PLreplace); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);

  /* "h5py/defs.pyx":3219
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLinsert (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__272 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5PLinsert); if (unlikely(!__pyx_tuple__272)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__272);
  __Pyx_GIVEREF(__pyx_tuple__272);

  /* "h5py/defs.pyx":3231
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLremove (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__273 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5PLremove); if (unlikely(!__pyx_tuple__273)) __PYX_ERR(0, 3231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__273);
  __Pyx_GIVEREF(__pyx_tuple__273);

  /* "h5py/defs.pyx":3243
 *                 return <ssize_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLget (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__274 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5PLget_ret); if (unlikely(!__pyx_tuple__274)) __PYX_ERR(0, 3243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__274);
  __Pyx_GIVEREF(__pyx_tuple__274);

  /* "h5py/defs.pyx":3255
 *                 return <herr_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5PLsize (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__275 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5PLsize_re); if (unlikely(!__pyx_tuple__275)) __PYX_ERR(0, 3255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__275);
  __Pyx_GIVEREF(__pyx_tuple__275);

  /* "h5py/defs.pyx":3266
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__276 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Rcreate_r); if (unlikely(!__pyx_tuple__276)) __PYX_ERR(0, 3266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__276);
  __Pyx_GIVEREF(__pyx_tuple__276);

  /* "h5py/defs.pyx":3277
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rdereference (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__277 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Rderefere); if (unlikely(!__pyx_tuple__277)) __PYX_ERR(0, 3277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__277);
  __Pyx_GIVEREF(__pyx_tuple__277);

  /* "h5py/defs.pyx":3288
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_region (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__278 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Rget_regi); if (unlikely(!__pyx_tuple__278)) __PYX_ERR(0, 3288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__278);
  __Pyx_GIVEREF(__pyx_tuple__278);

  /* "h5py/defs.pyx":3299
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_obj_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__279 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Rget_obj); if (unlikely(!__pyx_tuple__279)) __PYX_ERR(0, 3299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__279);
  __Pyx_GIVEREF(__pyx_tuple__279);

  /* "h5py/defs.pyx":3310
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Rget_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__280 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Rget_name); if (unlikely(!__pyx_tuple__280)) __PYX_ERR(0, 3310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__280);
  __Pyx_GIVEREF(__pyx_tuple__280);

  /* "h5py/defs.pyx":3321
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Screate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__281 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Screate_r); if (unlikely(!__pyx_tuple__281)) __PYX_ERR(0, 3321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__281);
  __Pyx_GIVEREF(__pyx_tuple__281);

  /* "h5py/defs.pyx":3332
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Scopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__282 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Scopy_ret); if (unlikely(!__pyx_tuple__282)) __PYX_ERR(0, 3332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__282);
  __Pyx_GIVEREF(__pyx_tuple__282);

  /* "h5py/defs.pyx":3343
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__283 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sclose_re); if (unlikely(!__pyx_tuple__283)) __PYX_ERR(0, 3343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__283);
  __Pyx_GIVEREF(__pyx_tuple__283);

  /* "h5py/defs.pyx":3354
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Screate_simple (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__284 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Screate_s); if (unlikely(!__pyx_tuple__284)) __PYX_ERR(0, 3354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__284);
  __Pyx_GIVEREF(__pyx_tuple__284);

  /* "h5py/defs.pyx":3365
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sis_simple (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__285 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sis_simpl); if (unlikely(!__pyx_tuple__285)) __PYX_ERR(0, 3365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__285);
  __Pyx_GIVEREF(__pyx_tuple__285);

  /* "h5py/defs.pyx":3376
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Soffset_simple (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__286 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Soffset_s); if (unlikely(!__pyx_tuple__286)) __PYX_ERR(0, 3376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__286);
  __Pyx_GIVEREF(__pyx_tuple__286);

  /* "h5py/defs.pyx":3387
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_ndims (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__287 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_simp); if (unlikely(!__pyx_tuple__287)) __PYX_ERR(0, 3387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__287);
  __Pyx_GIVEREF(__pyx_tuple__287);

  /* "h5py/defs.pyx":3398
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_dims (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__288 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_simp_2); if (unlikely(!__pyx_tuple__288)) __PYX_ERR(0, 3398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__288);
  __Pyx_GIVEREF(__pyx_tuple__288);

  /* "h5py/defs.pyx":3409
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_npoints (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__289 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_simp_3); if (unlikely(!__pyx_tuple__289)) __PYX_ERR(0, 3409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__289);
  __Pyx_GIVEREF(__pyx_tuple__289);

  /* "h5py/defs.pyx":3420
 *             return <H5S_class_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_simple_extent_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__290 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_simp_4); if (unlikely(!__pyx_tuple__290)) __PYX_ERR(0, 3420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__290);
  __Pyx_GIVEREF(__pyx_tuple__290);

  /* "h5py/defs.pyx":3431
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sextent_copy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__291 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sextent_c); if (unlikely(!__pyx_tuple__291)) __PYX_ERR(0, 3431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__291);
  __Pyx_GIVEREF(__pyx_tuple__291);

  /* "h5py/defs.pyx":3442
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sset_extent_simple (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__292 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sset_exte); if (unlikely(!__pyx_tuple__292)) __PYX_ERR(0, 3442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__292);
  __Pyx_GIVEREF(__pyx_tuple__292);

  /* "h5py/defs.pyx":3453
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sset_extent_none (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__293 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sset_exte_2); if (unlikely(!__pyx_tuple__293)) __PYX_ERR(0, 3453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__293);
  __Pyx_GIVEREF(__pyx_tuple__293);

  /* "h5py/defs.pyx":3464
 *             return <H5S_sel_type>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__294 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_sele); if (unlikely(!__pyx_tuple__294)) __PYX_ERR(0, 3464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__294);
  __Pyx_GIVEREF(__pyx_tuple__294);

  /* "h5py/defs.pyx":3475
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_npoints (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__295 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_sele_2); if (unlikely(!__pyx_tuple__295)) __PYX_ERR(0, 3475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__295);
  __Pyx_GIVEREF(__pyx_tuple__295);

  /* "h5py/defs.pyx":3486
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_bounds (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__296 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_sele_3); if (unlikely(!__pyx_tuple__296)) __PYX_ERR(0, 3486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__296);
  __Pyx_GIVEREF(__pyx_tuple__296);

  /* "h5py/defs.pyx":3497
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_all (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__297 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sselect_a); if (unlikely(!__pyx_tuple__297)) __PYX_ERR(0, 3497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__297);
  __Pyx_GIVEREF(__pyx_tuple__297);

  /* "h5py/defs.pyx":3508
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_none (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__298 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sselect_n); if (unlikely(!__pyx_tuple__298)) __PYX_ERR(0, 3508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__298);
  __Pyx_GIVEREF(__pyx_tuple__298);

  /* "h5py/defs.pyx":3519
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_valid (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__299 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sselect_v); if (unlikely(!__pyx_tuple__299)) __PYX_ERR(0, 3519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__299);
  __Pyx_GIVEREF(__pyx_tuple__299);

  /* "h5py/defs.pyx":3530
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_elem_npoints (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__300 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_sele_4); if (unlikely(!__pyx_tuple__300)) __PYX_ERR(0, 3530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__300);
  __Pyx_GIVEREF(__pyx_tuple__300);

  /* "h5py/defs.pyx":3541
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_elem_pointlist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__301 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_sele_5); if (unlikely(!__pyx_tuple__301)) __PYX_ERR(0, 3541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__301);
  __Pyx_GIVEREF(__pyx_tuple__301);

  /* "h5py/defs.pyx":3552
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_elements (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__302 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sselect_e); if (unlikely(!__pyx_tuple__302)) __PYX_ERR(0, 3552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__302);
  __Pyx_GIVEREF(__pyx_tuple__302);

  /* "h5py/defs.pyx":3563
 *             return <hssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_hyper_nblocks (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__303 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_sele_6); if (unlikely(!__pyx_tuple__303)) __PYX_ERR(0, 3563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__303);
  __Pyx_GIVEREF(__pyx_tuple__303);

  /* "h5py/defs.pyx":3574
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sget_select_hyper_blocklist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__304 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_sele_7); if (unlikely(!__pyx_tuple__304)) __PYX_ERR(0, 3574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__304);
  __Pyx_GIVEREF(__pyx_tuple__304);

  /* "h5py/defs.pyx":3585
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sselect_hyperslab (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__305 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sselect_h); if (unlikely(!__pyx_tuple__305)) __PYX_ERR(0, 3585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__305);
  __Pyx_GIVEREF(__pyx_tuple__305);

  /* "h5py/defs.pyx":3596
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sencode (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__306 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sencode_r); if (unlikely(!__pyx_tuple__306)) __PYX_ERR(0, 3596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__306);
  __Pyx_GIVEREF(__pyx_tuple__306);

  /* "h5py/defs.pyx":3607
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Sdecode (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__307 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sdecode_r); if (unlikely(!__pyx_tuple__307)) __PYX_ERR(0, 3607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__307);
  __Pyx_GIVEREF(__pyx_tuple__307);

  /* "h5py/defs.pyx":3619
 *                 return <htri_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Sis_regular_hyperslab (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__308 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sis_regul); if (unlikely(!__pyx_tuple__308)) __PYX_ERR(0, 3619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__308);
  __Pyx_GIVEREF(__pyx_tuple__308);

  /* "h5py/defs.pyx":3631
 *                 return <htri_t>-1
 *             else:
 *                 raise RuntimeError("Unspecified error in H5Sget_regular_hyperslab (return value <0)")             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_tuple__309 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Sget_regu); if (unlikely(!__pyx_tuple__309)) __PYX_ERR(0, 3631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__309);
  __Pyx_GIVEREF(__pyx_tuple__309);

  /* "h5py/defs.pyx":3642
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcreate (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__310 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tcreate_r); if (unlikely(!__pyx_tuple__310)) __PYX_ERR(0, 3642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__310);
  __Pyx_GIVEREF(__pyx_tuple__310);

  /* "h5py/defs.pyx":3653
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Topen (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__311 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Topen_ret); if (unlikely(!__pyx_tuple__311)) __PYX_ERR(0, 3653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__311);
  __Pyx_GIVEREF(__pyx_tuple__311);

  /* "h5py/defs.pyx":3664
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcommitted (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__312 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tcommitte); if (unlikely(!__pyx_tuple__312)) __PYX_ERR(0, 3664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__312);
  __Pyx_GIVEREF(__pyx_tuple__312);

  /* "h5py/defs.pyx":3675
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcopy (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__313 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tcopy_ret); if (unlikely(!__pyx_tuple__313)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__313);
  __Pyx_GIVEREF(__pyx_tuple__313);

  /* "h5py/defs.pyx":3686
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tequal (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__314 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tequal_re); if (unlikely(!__pyx_tuple__314)) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__314);
  __Pyx_GIVEREF(__pyx_tuple__314);

  /* "h5py/defs.pyx":3697
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tlock (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__315 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tlock_ret); if (unlikely(!__pyx_tuple__315)) __PYX_ERR(0, 3697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__315);
  __Pyx_GIVEREF(__pyx_tuple__315);

  /* "h5py/defs.pyx":3708
 *             return <H5T_class_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__316 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_clas); if (unlikely(!__pyx_tuple__316)) __PYX_ERR(0, 3708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__316);
  __Pyx_GIVEREF(__pyx_tuple__316);

  /* "h5py/defs.pyx":3719
 *             return <size_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_size (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__317 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_size); if (unlikely(!__pyx_tuple__317)) __PYX_ERR(0, 3719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__317);
  __Pyx_GIVEREF(__pyx_tuple__317);

  /* "h5py/defs.pyx":3730
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_super (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__318 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_supe); if (unlikely(!__pyx_tuple__318)) __PYX_ERR(0, 3730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__318);
  __Pyx_GIVEREF(__pyx_tuple__318);

  /* "h5py/defs.pyx":3741
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tdetect_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__319 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tdetect_c); if (unlikely(!__pyx_tuple__319)) __PYX_ERR(0, 3741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__319);
  __Pyx_GIVEREF(__pyx_tuple__319);

  /* "h5py/defs.pyx":3752
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tclose (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__320 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tclose_re); if (unlikely(!__pyx_tuple__320)) __PYX_ERR(0, 3752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__320);
  __Pyx_GIVEREF(__pyx_tuple__320);

  /* "h5py/defs.pyx":3763
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_native_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__321 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_nati); if (unlikely(!__pyx_tuple__321)) __PYX_ERR(0, 3763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__321);
  __Pyx_GIVEREF(__pyx_tuple__321);

  /* "h5py/defs.pyx":3774
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tcommit (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__322 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tcommit_r); if (unlikely(!__pyx_tuple__322)) __PYX_ERR(0, 3774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__322);
  __Pyx_GIVEREF(__pyx_tuple__322);

  /* "h5py/defs.pyx":3785
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_create_plist (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__323 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_crea); if (unlikely(!__pyx_tuple__323)) __PYX_ERR(0, 3785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__323);
  __Pyx_GIVEREF(__pyx_tuple__323);

  /* "h5py/defs.pyx":3796
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tdecode (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__324 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tdecode_r); if (unlikely(!__pyx_tuple__324)) __PYX_ERR(0, 3796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__324);
  __Pyx_GIVEREF(__pyx_tuple__324);

  /* "h5py/defs.pyx":3807
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tencode (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__325 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tencode_r); if (unlikely(!__pyx_tuple__325)) __PYX_ERR(0, 3807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__325);
  __Pyx_GIVEREF(__pyx_tuple__325);

  /* "h5py/defs.pyx":3818
 *             return <H5T_conv_t>NULL
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tfind (return value ==NULL)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__326 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tfind_ret); if (unlikely(!__pyx_tuple__326)) __PYX_ERR(0, 3818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__326);
  __Pyx_GIVEREF(__pyx_tuple__326);

  /* "h5py/defs.pyx":3830
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tconvert (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__327 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tconvert); if (unlikely(!__pyx_tuple__327)) __PYX_ERR(0, 3830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__327);
  __Pyx_GIVEREF(__pyx_tuple__327);

  /* "h5py/defs.pyx":3842
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__328 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tregister); if (unlikely(!__pyx_tuple__328)) __PYX_ERR(0, 3842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__328);
  __Pyx_GIVEREF(__pyx_tuple__328);

  /* "h5py/defs.pyx":3854
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tunregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__329 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tunregist); if (unlikely(!__pyx_tuple__329)) __PYX_ERR(0, 3854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__329);
  __Pyx_GIVEREF(__pyx_tuple__329);

  /* "h5py/defs.pyx":3865
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_size (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__330 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_size); if (unlikely(!__pyx_tuple__330)) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__330);
  __Pyx_GIVEREF(__pyx_tuple__330);

  /* "h5py/defs.pyx":3876
 *             return <H5T_order_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__331 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_orde); if (unlikely(!__pyx_tuple__331)) __PYX_ERR(0, 3876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__331);
  __Pyx_GIVEREF(__pyx_tuple__331);

  /* "h5py/defs.pyx":3887
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_order (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__332 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_orde); if (unlikely(!__pyx_tuple__332)) __PYX_ERR(0, 3887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__332);
  __Pyx_GIVEREF(__pyx_tuple__332);

  /* "h5py/defs.pyx":3898
 *             return <hsize_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_precision (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__333 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_prec); if (unlikely(!__pyx_tuple__333)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__333);
  __Pyx_GIVEREF(__pyx_tuple__333);

  /* "h5py/defs.pyx":3909
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_precision (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__334 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_prec); if (unlikely(!__pyx_tuple__334)) __PYX_ERR(0, 3909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__334);
  __Pyx_GIVEREF(__pyx_tuple__334);

  /* "h5py/defs.pyx":3920
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__335 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_offs); if (unlikely(!__pyx_tuple__335)) __PYX_ERR(0, 3920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__335);
  __Pyx_GIVEREF(__pyx_tuple__335);

  /* "h5py/defs.pyx":3931
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__336 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_offs); if (unlikely(!__pyx_tuple__336)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__336);
  __Pyx_GIVEREF(__pyx_tuple__336);

  /* "h5py/defs.pyx":3942
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_pad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__337 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_pad); if (unlikely(!__pyx_tuple__337)) __PYX_ERR(0, 3942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__337);
  __Pyx_GIVEREF(__pyx_tuple__337);

  /* "h5py/defs.pyx":3953
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_pad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__338 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_pad); if (unlikely(!__pyx_tuple__338)) __PYX_ERR(0, 3953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__338);
  __Pyx_GIVEREF(__pyx_tuple__338);

  /* "h5py/defs.pyx":3964
 *             return <H5T_sign_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_sign (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__339 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_sign); if (unlikely(!__pyx_tuple__339)) __PYX_ERR(0, 3964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__339);
  __Pyx_GIVEREF(__pyx_tuple__339);

  /* "h5py/defs.pyx":3975
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_sign (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__340 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_sign); if (unlikely(!__pyx_tuple__340)) __PYX_ERR(0, 3975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__340);
  __Pyx_GIVEREF(__pyx_tuple__340);

  /* "h5py/defs.pyx":3986
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_fields (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__341 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_fiel); if (unlikely(!__pyx_tuple__341)) __PYX_ERR(0, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__341);
  __Pyx_GIVEREF(__pyx_tuple__341);

  /* "h5py/defs.pyx":3997
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_fields (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__342 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_fiel); if (unlikely(!__pyx_tuple__342)) __PYX_ERR(0, 3997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__342);
  __Pyx_GIVEREF(__pyx_tuple__342);

  /* "h5py/defs.pyx":4008
 *             return <size_t>0
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_ebias (return value ==0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__343 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_ebia); if (unlikely(!__pyx_tuple__343)) __PYX_ERR(0, 4008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__343);
  __Pyx_GIVEREF(__pyx_tuple__343);

  /* "h5py/defs.pyx":4019
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_ebias (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__344 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_ebia); if (unlikely(!__pyx_tuple__344)) __PYX_ERR(0, 4019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__344);
  __Pyx_GIVEREF(__pyx_tuple__344);

  /* "h5py/defs.pyx":4030
 *             return <H5T_norm_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_norm (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__345 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_norm); if (unlikely(!__pyx_tuple__345)) __PYX_ERR(0, 4030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__345);
  __Pyx_GIVEREF(__pyx_tuple__345);

  /* "h5py/defs.pyx":4041
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_norm (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__346 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_norm); if (unlikely(!__pyx_tuple__346)) __PYX_ERR(0, 4041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__346);
  __Pyx_GIVEREF(__pyx_tuple__346);

  /* "h5py/defs.pyx":4052
 *             return <H5T_pad_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_inpad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__347 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_inpa); if (unlikely(!__pyx_tuple__347)) __PYX_ERR(0, 4052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__347);
  __Pyx_GIVEREF(__pyx_tuple__347);

  /* "h5py/defs.pyx":4063
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_inpad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__348 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_inpa); if (unlikely(!__pyx_tuple__348)) __PYX_ERR(0, 4063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__348);
  __Pyx_GIVEREF(__pyx_tuple__348);

  /* "h5py/defs.pyx":4074
 *             return <H5T_cset_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_cset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__349 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_cset); if (unlikely(!__pyx_tuple__349)) __PYX_ERR(0, 4074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__349);
  __Pyx_GIVEREF(__pyx_tuple__349);

  /* "h5py/defs.pyx":4085
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_cset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__350 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_cset); if (unlikely(!__pyx_tuple__350)) __PYX_ERR(0, 4085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__350);
  __Pyx_GIVEREF(__pyx_tuple__350);

  /* "h5py/defs.pyx":4096
 *             return <H5T_str_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_strpad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__351 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_strp); if (unlikely(!__pyx_tuple__351)) __PYX_ERR(0, 4096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__351);
  __Pyx_GIVEREF(__pyx_tuple__351);

  /* "h5py/defs.pyx":4107
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_strpad (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__352 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_strp); if (unlikely(!__pyx_tuple__352)) __PYX_ERR(0, 4107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__352);
  __Pyx_GIVEREF(__pyx_tuple__352);

  /* "h5py/defs.pyx":4118
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tvlen_create (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__353 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tvlen_cre); if (unlikely(!__pyx_tuple__353)) __PYX_ERR(0, 4118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__353);
  __Pyx_GIVEREF(__pyx_tuple__353);

  /* "h5py/defs.pyx":4129
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tis_variable_str (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__354 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tis_varia); if (unlikely(!__pyx_tuple__354)) __PYX_ERR(0, 4129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__354);
  __Pyx_GIVEREF(__pyx_tuple__354);

  /* "h5py/defs.pyx":4140
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_nmembers (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__355 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_nmem); if (unlikely(!__pyx_tuple__355)) __PYX_ERR(0, 4140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__355);
  __Pyx_GIVEREF(__pyx_tuple__355);

  /* "h5py/defs.pyx":4151
 *             return <H5T_class_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_class (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__356 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_memb); if (unlikely(!__pyx_tuple__356)) __PYX_ERR(0, 4151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__356);
  __Pyx_GIVEREF(__pyx_tuple__356);

  /* "h5py/defs.pyx":4162
 *             return <char*>NULL
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_name (return value ==NULL)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__357 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_memb_2); if (unlikely(!__pyx_tuple__357)) __PYX_ERR(0, 4162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__357);
  __Pyx_GIVEREF(__pyx_tuple__357);

  /* "h5py/defs.pyx":4173
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_type (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__358 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_memb_3); if (unlikely(!__pyx_tuple__358)) __PYX_ERR(0, 4173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__358);
  __Pyx_GIVEREF(__pyx_tuple__358);

  /* "h5py/defs.pyx":4184
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_offset (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__359 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_memb_4); if (unlikely(!__pyx_tuple__359)) __PYX_ERR(0, 4184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__359);
  __Pyx_GIVEREF(__pyx_tuple__359);

  /* "h5py/defs.pyx":4195
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_index (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__360 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_memb_5); if (unlikely(!__pyx_tuple__360)) __PYX_ERR(0, 4195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__360);
  __Pyx_GIVEREF(__pyx_tuple__360);

  /* "h5py/defs.pyx":4206
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tinsert (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__361 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tinsert_r); if (unlikely(!__pyx_tuple__361)) __PYX_ERR(0, 4206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__361);
  __Pyx_GIVEREF(__pyx_tuple__361);

  /* "h5py/defs.pyx":4217
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tpack (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__362 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tpack_ret); if (unlikely(!__pyx_tuple__362)) __PYX_ERR(0, 4217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__362);
  __Pyx_GIVEREF(__pyx_tuple__362);

  /* "h5py/defs.pyx":4228
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_create (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__363 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tenum_cre); if (unlikely(!__pyx_tuple__363)) __PYX_ERR(0, 4228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__363);
  __Pyx_GIVEREF(__pyx_tuple__363);

  /* "h5py/defs.pyx":4239
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_insert (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__364 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tenum_ins); if (unlikely(!__pyx_tuple__364)) __PYX_ERR(0, 4239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__364);
  __Pyx_GIVEREF(__pyx_tuple__364);

  /* "h5py/defs.pyx":4250
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_nameof (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__365 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tenum_nam); if (unlikely(!__pyx_tuple__365)) __PYX_ERR(0, 4250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__365);
  __Pyx_GIVEREF(__pyx_tuple__365);

  /* "h5py/defs.pyx":4261
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tenum_valueof (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__366 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tenum_val); if (unlikely(!__pyx_tuple__366)) __PYX_ERR(0, 4261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__366);
  __Pyx_GIVEREF(__pyx_tuple__366);

  /* "h5py/defs.pyx":4272
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_member_value (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__367 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_memb_6); if (unlikely(!__pyx_tuple__367)) __PYX_ERR(0, 4272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__367);
  __Pyx_GIVEREF(__pyx_tuple__367);

  /* "h5py/defs.pyx":4283
 *             return <hid_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tarray_create (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__368 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tarray_cr); if (unlikely(!__pyx_tuple__368)) __PYX_ERR(0, 4283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__368);
  __Pyx_GIVEREF(__pyx_tuple__368);

  /* "h5py/defs.pyx":4294
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_array_ndims (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__369 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_arra); if (unlikely(!__pyx_tuple__369)) __PYX_ERR(0, 4294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__369);
  __Pyx_GIVEREF(__pyx_tuple__369);

  /* "h5py/defs.pyx":4305
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_array_dims (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__370 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_arra_2); if (unlikely(!__pyx_tuple__370)) __PYX_ERR(0, 4305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__370);
  __Pyx_GIVEREF(__pyx_tuple__370);

  /* "h5py/defs.pyx":4316
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tset_tag (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__371 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tset_tag); if (unlikely(!__pyx_tuple__371)) __PYX_ERR(0, 4316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__371);
  __Pyx_GIVEREF(__pyx_tuple__371);

  /* "h5py/defs.pyx":4327
 *             return <char*>NULL
 *         else:
 *             raise RuntimeError("Unspecified error in H5Tget_tag (return value ==NULL)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__372 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Tget_tag); if (unlikely(!__pyx_tuple__372)) __PYX_ERR(0, 4327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__372);
  __Pyx_GIVEREF(__pyx_tuple__372);

  /* "h5py/defs.pyx":4338
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zfilter_avail (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__373 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Zfilter_a); if (unlikely(!__pyx_tuple__373)) __PYX_ERR(0, 4338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__373);
  __Pyx_GIVEREF(__pyx_tuple__373);

  /* "h5py/defs.pyx":4349
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zget_filter_info (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__374 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Zget_filt); if (unlikely(!__pyx_tuple__374)) __PYX_ERR(0, 4349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__374);
  __Pyx_GIVEREF(__pyx_tuple__374);

  /* "h5py/defs.pyx":4360
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5Zunregister (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__375 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5Zunregist); if (unlikely(!__pyx_tuple__375)) __PYX_ERR(0, 4360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__375);
  __Pyx_GIVEREF(__pyx_tuple__375);

  /* "h5py/defs.pyx":4371
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSattach_scale (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__376 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSattach); if (unlikely(!__pyx_tuple__376)) __PYX_ERR(0, 4371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__376);
  __Pyx_GIVEREF(__pyx_tuple__376);

  /* "h5py/defs.pyx":4382
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSdetach_scale (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__377 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSdetach); if (unlikely(!__pyx_tuple__377)) __PYX_ERR(0, 4382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__377);
  __Pyx_GIVEREF(__pyx_tuple__377);

  /* "h5py/defs.pyx":4393
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSis_attached (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__378 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSis_atta); if (unlikely(!__pyx_tuple__378)) __PYX_ERR(0, 4393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__378);
  __Pyx_GIVEREF(__pyx_tuple__378);

  /* "h5py/defs.pyx":4404
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSset_scale (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__379 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSset_sca); if (unlikely(!__pyx_tuple__379)) __PYX_ERR(0, 4404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__379);
  __Pyx_GIVEREF(__pyx_tuple__379);

  /* "h5py/defs.pyx":4415
 *             return <int>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_num_scales (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__380 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSget_num); if (unlikely(!__pyx_tuple__380)) __PYX_ERR(0, 4415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__380);
  __Pyx_GIVEREF(__pyx_tuple__380);

  /* "h5py/defs.pyx":4426
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSset_label (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__381 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSset_lab); if (unlikely(!__pyx_tuple__381)) __PYX_ERR(0, 4426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__381);
  __Pyx_GIVEREF(__pyx_tuple__381);

  /* "h5py/defs.pyx":4437
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_label (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__382 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSget_lab); if (unlikely(!__pyx_tuple__382)) __PYX_ERR(0, 4437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__382);
  __Pyx_GIVEREF(__pyx_tuple__382);

  /* "h5py/defs.pyx":4448
 *             return <ssize_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSget_scale_name (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__383 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSget_sca); if (unlikely(!__pyx_tuple__383)) __PYX_ERR(0, 4448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__383);
  __Pyx_GIVEREF(__pyx_tuple__383);

  /* "h5py/defs.pyx":4459
 *             return <htri_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSis_scale (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__384 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSis_scal); if (unlikely(!__pyx_tuple__384)) __PYX_ERR(0, 4459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__384);
  __Pyx_GIVEREF(__pyx_tuple__384);

  /* "h5py/defs.pyx":4470
 *             return <herr_t>-1
 *         else:
 *             raise RuntimeError("Unspecified error in H5DSiterate_scales (return value <0)")             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_tuple__385 = PyTuple_Pack(1, __pyx_kp_u_Unspecified_error_in_H5DSiterate); if (unlikely(!__pyx_tuple__385)) __PYX_ERR(0, 4470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__385);
  __Pyx_GIVEREF(__pyx_tuple__385);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":944
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__386 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple__386)) __PYX_ERR(1, 944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__386);
  __Pyx_GIVEREF(__pyx_tuple__386);

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":950
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__387 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__387)) __PYX_ERR(1, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__387);
  __Pyx_GIVEREF(__pyx_tuple__387);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("H5open", (void (*)(void))__pyx_f_4h5py_4defs_H5open, "herr_t (void)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5close", (void (*)(void))__pyx_f_4h5py_4defs_H5close, "herr_t (void)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5get_libversion", (void (*)(void))__pyx_f_4h5py_4defs_H5get_libversion, "herr_t (unsigned int *, unsigned int *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5check_version", (void (*)(void))__pyx_f_4h5py_4defs_H5check_version, "herr_t (unsigned int, unsigned int, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5free_memory", (void (*)(void))__pyx_f_4h5py_4defs_H5free_memory, "herr_t (void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Acreate", (void (*)(void))__pyx_f_4h5py_4defs_H5Acreate, "hid_t (hid_t, char *, hid_t, hid_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aopen_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Aopen_idx, "hid_t (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aopen_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Aopen_name, "hid_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aclose", (void (*)(void))__pyx_f_4h5py_4defs_H5Aclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Adelete", (void (*)(void))__pyx_f_4h5py_4defs_H5Adelete, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aread", (void (*)(void))__pyx_f_4h5py_4defs_H5Aread, "herr_t (hid_t, hid_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Awrite", (void (*)(void))__pyx_f_4h5py_4defs_H5Awrite, "herr_t (hid_t, hid_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aget_num_attrs", (void (*)(void))__pyx_f_4h5py_4defs_H5Aget_num_attrs, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aget_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Aget_name, "Py_ssize_t (hid_t, size_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aget_space", (void (*)(void))__pyx_f_4h5py_4defs_H5Aget_space, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aget_type", (void (*)(void))__pyx_f_4h5py_4defs_H5Aget_type, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Adelete_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Adelete_by_name, "herr_t (hid_t, char *, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Adelete_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Adelete_by_idx, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Acreate_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Acreate_by_name, "hid_t (hid_t, char *, char *, hid_t, hid_t, hid_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aopen", (void (*)(void))__pyx_f_4h5py_4defs_H5Aopen, "hid_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aopen_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Aopen_by_name, "hid_t (hid_t, char *, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aopen_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Aopen_by_idx, "hid_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aexists_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Aexists_by_name, "htri_t (hid_t, char *, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aexists", (void (*)(void))__pyx_f_4h5py_4defs_H5Aexists, "htri_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Arename", (void (*)(void))__pyx_f_4h5py_4defs_H5Arename, "herr_t (hid_t, char *, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Arename_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Arename_by_name, "herr_t (hid_t, char *, char *, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aget_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Aget_info, "herr_t (hid_t, H5A_info_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aget_info_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Aget_info_by_name, "herr_t (hid_t, char *, char *, H5A_info_t *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aget_info_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Aget_info_by_idx, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, H5A_info_t *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aiterate", (void (*)(void))__pyx_f_4h5py_4defs_H5Aiterate, "herr_t (hid_t, H5_index_t, H5_iter_order_t, hsize_t *, H5A_operator2_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Aget_storage_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Aget_storage_size, "hsize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dcreate", (void (*)(void))__pyx_f_4h5py_4defs_H5Dcreate, "hid_t (hid_t, char *, hid_t, hid_t, hid_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dcreate_anon", (void (*)(void))__pyx_f_4h5py_4defs_H5Dcreate_anon, "hid_t (hid_t, hid_t, hid_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dopen", (void (*)(void))__pyx_f_4h5py_4defs_H5Dopen, "hid_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dclose", (void (*)(void))__pyx_f_4h5py_4defs_H5Dclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_space", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_space, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_space_status", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_space_status, "herr_t (hid_t, H5D_space_status_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_type", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_type, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_create_plist", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_create_plist, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_access_plist", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_access_plist, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_offset", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_offset, "haddr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_storage_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_storage_size, "hsize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dread", (void (*)(void))__pyx_f_4h5py_4defs_H5Dread, "herr_t (hid_t, hid_t, hid_t, hid_t, hid_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dwrite", (void (*)(void))__pyx_f_4h5py_4defs_H5Dwrite, "herr_t (hid_t, hid_t, hid_t, hid_t, hid_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dextend", (void (*)(void))__pyx_f_4h5py_4defs_H5Dextend, "herr_t (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dfill", (void (*)(void))__pyx_f_4h5py_4defs_H5Dfill, "herr_t (void *, hid_t, void *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dvlen_get_buf_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Dvlen_get_buf_size, "herr_t (hid_t, hid_t, hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dvlen_reclaim", (void (*)(void))__pyx_f_4h5py_4defs_H5Dvlen_reclaim, "herr_t (hid_t, hid_t, hid_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Diterate", (void (*)(void))__pyx_f_4h5py_4defs_H5Diterate, "herr_t (void *, hid_t, hid_t, H5D_operator_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dset_extent", (void (*)(void))__pyx_f_4h5py_4defs_H5Dset_extent, "herr_t (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dflush", (void (*)(void))__pyx_f_4h5py_4defs_H5Dflush, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Drefresh", (void (*)(void))__pyx_f_4h5py_4defs_H5Drefresh, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DOwrite_chunk", (void (*)(void))__pyx_f_4h5py_4defs_H5DOwrite_chunk, "herr_t (hid_t, hid_t, __pyx_t_5numpy_uint32_t, hsize_t const *, size_t, void const *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_chunk_storage_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_chunk_storage_size, "herr_t (hid_t, hsize_t const *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DOread_chunk", (void (*)(void))__pyx_f_4h5py_4defs_H5DOread_chunk, "herr_t (hid_t, hid_t, hsize_t const *, __pyx_t_5numpy_uint32_t *, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dread_chunk", (void (*)(void))__pyx_f_4h5py_4defs_H5Dread_chunk, "herr_t (hid_t, hid_t, hsize_t const *, __pyx_t_5numpy_uint32_t *, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_num_chunks", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_num_chunks, "herr_t (hid_t, hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_chunk_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_chunk_info, "herr_t (hid_t, hid_t, hsize_t, hsize_t *, unsigned int *, haddr_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Dget_chunk_info_by_coord", (void (*)(void))__pyx_f_4h5py_4defs_H5Dget_chunk_info_by_coord, "herr_t (hid_t, hsize_t const *, unsigned int *, haddr_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fcreate", (void (*)(void))__pyx_f_4h5py_4defs_H5Fcreate, "hid_t (char *, unsigned int, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fopen", (void (*)(void))__pyx_f_4h5py_4defs_H5Fopen, "hid_t (char *, unsigned int, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fclose", (void (*)(void))__pyx_f_4h5py_4defs_H5Fclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fis_hdf5", (void (*)(void))__pyx_f_4h5py_4defs_H5Fis_hdf5, "htri_t (char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fflush", (void (*)(void))__pyx_f_4h5py_4defs_H5Fflush, "herr_t (hid_t, enum H5F_scope_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Freopen", (void (*)(void))__pyx_f_4h5py_4defs_H5Freopen, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fmount", (void (*)(void))__pyx_f_4h5py_4defs_H5Fmount, "herr_t (hid_t, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Funmount", (void (*)(void))__pyx_f_4h5py_4defs_H5Funmount, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_filesize", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_filesize, "herr_t (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_create_plist", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_create_plist, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_access_plist", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_access_plist, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_freespace", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_freespace, "hssize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_name, "Py_ssize_t (hid_t, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_obj_count", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_obj_count, "int (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_obj_ids", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_obj_ids, "int (hid_t, unsigned int, int, hid_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_vfd_handle", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_vfd_handle, "herr_t (hid_t, hid_t, void **)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_intent", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_intent, "herr_t (hid_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_mdc_config", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_mdc_config, "herr_t (hid_t, H5AC_cache_config_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_mdc_hit_rate", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_mdc_hit_rate, "herr_t (hid_t, double *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_mdc_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_mdc_size, "herr_t (hid_t, size_t *, size_t *, size_t *, int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Freset_mdc_hit_rate_stats", (void (*)(void))__pyx_f_4h5py_4defs_H5Freset_mdc_hit_rate_stats, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fset_mdc_config", (void (*)(void))__pyx_f_4h5py_4defs_H5Fset_mdc_config, "herr_t (hid_t, H5AC_cache_config_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_file_image", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_file_image, "Py_ssize_t (hid_t, void *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5LTopen_file_image", (void (*)(void))__pyx_f_4h5py_4defs_H5LTopen_file_image, "hid_t (void *, size_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fstart_swmr_write", (void (*)(void))__pyx_f_4h5py_4defs_H5Fstart_swmr_write, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Freset_page_buffering_stats", (void (*)(void))__pyx_f_4h5py_4defs_H5Freset_page_buffering_stats, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Fget_page_buffering_stats", (void (*)(void))__pyx_f_4h5py_4defs_H5Fget_page_buffering_stats, "herr_t (hid_t, unsigned int *, unsigned int *, unsigned int *, unsigned int *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5FDregister", (void (*)(void))__pyx_f_4h5py_4defs_H5FDregister, "hid_t (H5FD_class_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5FDunregister", (void (*)(void))__pyx_f_4h5py_4defs_H5FDunregister, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gclose", (void (*)(void))__pyx_f_4h5py_4defs_H5Gclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Glink2", (void (*)(void))__pyx_f_4h5py_4defs_H5Glink2, "herr_t (hid_t, char *, H5G_link_t, hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gunlink", (void (*)(void))__pyx_f_4h5py_4defs_H5Gunlink, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gmove2", (void (*)(void))__pyx_f_4h5py_4defs_H5Gmove2, "herr_t (hid_t, char *, hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_num_objs", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_num_objs, "herr_t (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_objname_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_objname_by_idx, "int (hid_t, hsize_t, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_objtype_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_objtype_by_idx, "int (hid_t, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Giterate", (void (*)(void))__pyx_f_4h5py_4defs_H5Giterate, "herr_t (hid_t, char *, int *, H5G_iterate_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_objinfo", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_objinfo, "herr_t (hid_t, char *, int, H5G_stat_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_linkval", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_linkval, "herr_t (hid_t, char *, size_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gset_comment", (void (*)(void))__pyx_f_4h5py_4defs_H5Gset_comment, "herr_t (hid_t, char *, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_comment", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_comment, "int (hid_t, char *, size_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gcreate_anon", (void (*)(void))__pyx_f_4h5py_4defs_H5Gcreate_anon, "hid_t (hid_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gcreate", (void (*)(void))__pyx_f_4h5py_4defs_H5Gcreate, "hid_t (hid_t, char *, hid_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gopen", (void (*)(void))__pyx_f_4h5py_4defs_H5Gopen, "hid_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_info, "herr_t (hid_t, H5G_info_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_info_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_info_by_name, "herr_t (hid_t, char *, H5G_info_t *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Gget_create_plist", (void (*)(void))__pyx_f_4h5py_4defs_H5Gget_create_plist, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Iget_type", (void (*)(void))__pyx_f_4h5py_4defs_H5Iget_type, "H5I_type_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Iget_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Iget_name, "Py_ssize_t (hid_t, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Iget_file_id", (void (*)(void))__pyx_f_4h5py_4defs_H5Iget_file_id, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Idec_ref", (void (*)(void))__pyx_f_4h5py_4defs_H5Idec_ref, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Iget_ref", (void (*)(void))__pyx_f_4h5py_4defs_H5Iget_ref, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Iinc_ref", (void (*)(void))__pyx_f_4h5py_4defs_H5Iinc_ref, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Iis_valid", (void (*)(void))__pyx_f_4h5py_4defs_H5Iis_valid, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lmove", (void (*)(void))__pyx_f_4h5py_4defs_H5Lmove, "herr_t (hid_t, char *, hid_t, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lcopy", (void (*)(void))__pyx_f_4h5py_4defs_H5Lcopy, "herr_t (hid_t, char *, hid_t, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lcreate_hard", (void (*)(void))__pyx_f_4h5py_4defs_H5Lcreate_hard, "herr_t (hid_t, char *, hid_t, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lcreate_soft", (void (*)(void))__pyx_f_4h5py_4defs_H5Lcreate_soft, "herr_t (char *, hid_t, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Ldelete", (void (*)(void))__pyx_f_4h5py_4defs_H5Ldelete, "herr_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Ldelete_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Ldelete_by_idx, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lget_val", (void (*)(void))__pyx_f_4h5py_4defs_H5Lget_val, "herr_t (hid_t, char *, void *, size_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lget_val_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Lget_val_by_idx, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, void *, size_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lexists", (void (*)(void))__pyx_f_4h5py_4defs_H5Lexists, "htri_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lget_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Lget_info, "herr_t (hid_t, char *, H5L_info_t *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lget_info_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Lget_info_by_idx, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, H5L_info_t *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lget_name_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Lget_name_by_idx, "Py_ssize_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, char *, size_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Literate", (void (*)(void))__pyx_f_4h5py_4defs_H5Literate, "herr_t (hid_t, H5_index_t, H5_iter_order_t, hsize_t *, H5L_iterate_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Literate_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Literate_by_name, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t *, H5L_iterate_t, void *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lvisit", (void (*)(void))__pyx_f_4h5py_4defs_H5Lvisit, "herr_t (hid_t, H5_index_t, H5_iter_order_t, H5L_iterate_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lvisit_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Lvisit_by_name, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, H5L_iterate_t, void *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lunpack_elink_val", (void (*)(void))__pyx_f_4h5py_4defs_H5Lunpack_elink_val, "herr_t (void *, size_t, unsigned int *, char const **, char const **)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Lcreate_external", (void (*)(void))__pyx_f_4h5py_4defs_H5Lcreate_external, "herr_t (char *, char *, hid_t, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oopen", (void (*)(void))__pyx_f_4h5py_4defs_H5Oopen, "hid_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oopen_by_addr", (void (*)(void))__pyx_f_4h5py_4defs_H5Oopen_by_addr, "hid_t (hid_t, haddr_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oopen_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Oopen_by_idx, "hid_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oget_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Oget_info, "herr_t (hid_t, H5O_info_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oget_info_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Oget_info_by_name, "herr_t (hid_t, char *, H5O_info_t *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oget_info_by_idx", (void (*)(void))__pyx_f_4h5py_4defs_H5Oget_info_by_idx, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, hsize_t, H5O_info_t *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Olink", (void (*)(void))__pyx_f_4h5py_4defs_H5Olink, "herr_t (hid_t, hid_t, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Ocopy", (void (*)(void))__pyx_f_4h5py_4defs_H5Ocopy, "herr_t (hid_t, char *, hid_t, char *, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oincr_refcount", (void (*)(void))__pyx_f_4h5py_4defs_H5Oincr_refcount, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Odecr_refcount", (void (*)(void))__pyx_f_4h5py_4defs_H5Odecr_refcount, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oset_comment", (void (*)(void))__pyx_f_4h5py_4defs_H5Oset_comment, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oset_comment_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Oset_comment_by_name, "herr_t (hid_t, char *, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oget_comment", (void (*)(void))__pyx_f_4h5py_4defs_H5Oget_comment, "Py_ssize_t (hid_t, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oget_comment_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Oget_comment_by_name, "Py_ssize_t (hid_t, char *, char *, size_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Ovisit", (void (*)(void))__pyx_f_4h5py_4defs_H5Ovisit, "herr_t (hid_t, H5_index_t, H5_iter_order_t, H5O_iterate_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Ovisit_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Ovisit_by_name, "herr_t (hid_t, char *, H5_index_t, H5_iter_order_t, H5O_iterate_t, void *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oclose", (void (*)(void))__pyx_f_4h5py_4defs_H5Oclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Oexists_by_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Oexists_by_name, "htri_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pcreate", (void (*)(void))__pyx_f_4h5py_4defs_H5Pcreate, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pcopy", (void (*)(void))__pyx_f_4h5py_4defs_H5Pcopy, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_class", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_class, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pclose", (void (*)(void))__pyx_f_4h5py_4defs_H5Pclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pequal", (void (*)(void))__pyx_f_4h5py_4defs_H5Pequal, "htri_t (hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pclose_class", (void (*)(void))__pyx_f_4h5py_4defs_H5Pclose_class, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_version", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_version, "herr_t (hid_t, unsigned int *, unsigned int *, unsigned int *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_userblock", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_userblock, "herr_t (hid_t, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_userblock", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_userblock, "herr_t (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_sizes", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_sizes, "herr_t (hid_t, size_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_sizes", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_sizes, "herr_t (hid_t, size_t *, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_sym_k", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_sym_k, "herr_t (hid_t, unsigned int, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_sym_k", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_sym_k, "herr_t (hid_t, unsigned int *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_istore_k", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_istore_k, "herr_t (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_istore_k", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_istore_k, "herr_t (hid_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_file_space_strategy", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_file_space_strategy, "herr_t (hid_t, enum H5F_fspace_strategy_t, hbool_t, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_file_space_strategy", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_file_space_strategy, "herr_t (hid_t, enum H5F_fspace_strategy_t *, hbool_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_file_space_page_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_file_space_page_size, "herr_t (hid_t, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_file_space_page_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_file_space_page_size, "herr_t (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fclose_degree", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fclose_degree, "herr_t (hid_t, enum H5F_close_degree_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_fclose_degree", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_fclose_degree, "herr_t (hid_t, enum H5F_close_degree_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fapl_core", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fapl_core, "herr_t (hid_t, size_t, hbool_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_fapl_core", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_fapl_core, "herr_t (hid_t, size_t *, hbool_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fapl_family", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fapl_family, "herr_t (hid_t, hsize_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_fapl_family", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_fapl_family, "herr_t (hid_t, hsize_t *, hid_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_family_offset", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_family_offset, "herr_t (hid_t, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_family_offset", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_family_offset, "herr_t (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fapl_log", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fapl_log, "herr_t (hid_t, char *, unsigned int, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fapl_multi", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fapl_multi, "herr_t (hid_t, H5FD_mem_t *, hid_t *, char const *const *, haddr_t *, hbool_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_cache", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_cache, "herr_t (hid_t, int, int, size_t, double)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_cache", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_cache, "herr_t (hid_t, int *, size_t *, size_t *, double *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fapl_sec2", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fapl_sec2, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fapl_stdio", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fapl_stdio, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fapl_split", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fapl_split, "herr_t (hid_t, char const *, hid_t, char const *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_driver", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_driver, "herr_t (hid_t, hid_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_driver", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_driver, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_driver_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_driver_info, "void *(hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_mdc_config", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_mdc_config, "herr_t (hid_t, H5AC_cache_config_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_mdc_config", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_mdc_config, "herr_t (hid_t, H5AC_cache_config_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_file_image", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_file_image, "herr_t (hid_t, void *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_page_buffer_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_page_buffer_size, "herr_t (hid_t, size_t, unsigned int, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_page_buffer_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_page_buffer_size, "herr_t (hid_t, size_t *, unsigned int *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_file_locking", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_file_locking, "herr_t (hid_t, hbool_t *, hbool_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_file_locking", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_file_locking, "herr_t (hid_t, hbool_t, hbool_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_layout", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_layout, "herr_t (hid_t, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_layout", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_layout, "H5D_layout_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_chunk", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_chunk, "herr_t (hid_t, int, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_chunk", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_chunk, "int (hid_t, int, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_deflate", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_deflate, "herr_t (hid_t, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fill_value", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fill_value, "herr_t (hid_t, hid_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_fill_value", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_fill_value, "herr_t (hid_t, hid_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pfill_value_defined", (void (*)(void))__pyx_f_4h5py_4defs_H5Pfill_value_defined, "herr_t (hid_t, H5D_fill_value_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fill_time", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fill_time, "herr_t (hid_t, H5D_fill_time_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_fill_time", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_fill_time, "herr_t (hid_t, H5D_fill_time_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_alloc_time", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_alloc_time, "herr_t (hid_t, H5D_alloc_time_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_alloc_time", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_alloc_time, "herr_t (hid_t, H5D_alloc_time_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_filter", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_filter, "herr_t (hid_t, H5Z_filter_t, unsigned int, size_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pall_filters_avail", (void (*)(void))__pyx_f_4h5py_4defs_H5Pall_filters_avail, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_nfilters", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_nfilters, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_filter", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_filter, "H5Z_filter_t (hid_t, unsigned int, unsigned int *, size_t *, unsigned int *, size_t, char *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_filter_by_id", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_filter_by_id, "herr_t (hid_t, H5Z_filter_t, unsigned int *, size_t *, unsigned int *, size_t, char *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pmodify_filter", (void (*)(void))__pyx_f_4h5py_4defs_H5Pmodify_filter, "herr_t (hid_t, H5Z_filter_t, unsigned int, size_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Premove_filter", (void (*)(void))__pyx_f_4h5py_4defs_H5Premove_filter, "herr_t (hid_t, H5Z_filter_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_fletcher32", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_fletcher32, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_shuffle", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_shuffle, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_szip", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_szip, "herr_t (hid_t, unsigned int, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_scaleoffset", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_scaleoffset, "herr_t (hid_t, enum H5Z_SO_scale_type_t, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_external", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_external, "herr_t (hid_t, char const *, off_t, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_external_count", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_external_count, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_external", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_external, "herr_t (hid_t, unsigned int, size_t, char *, off_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_virtual_dsetname", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_virtual_dsetname, "Py_ssize_t (hid_t, size_t, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_virtual_filename", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_virtual_filename, "Py_ssize_t (hid_t, size_t, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_virtual_count", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_virtual_count, "herr_t (hid_t, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_virtual", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_virtual, "herr_t (hid_t, hid_t, char const *, char const *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_virtual_vspace", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_virtual_vspace, "hid_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_virtual_srcspace", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_virtual_srcspace, "hid_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_edc_check", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_edc_check, "herr_t (hid_t, enum H5Z_EDC_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_edc_check", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_edc_check, "enum H5Z_EDC_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_chunk_cache", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_chunk_cache, "herr_t (hid_t, size_t, size_t, double)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_chunk_cache", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_chunk_cache, "herr_t (hid_t, size_t *, size_t *, double *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_efile_prefix", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_efile_prefix, "herr_t (hid_t, char *, Py_ssize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_efile_prefix", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_efile_prefix, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_virtual_view", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_virtual_view, "herr_t (hid_t, H5D_vds_view_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_virtual_view", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_virtual_view, "herr_t (hid_t, H5D_vds_view_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_virtual_printf_gap", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_virtual_printf_gap, "herr_t (hid_t, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_virtual_printf_gap", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_virtual_printf_gap, "herr_t (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_virtual_prefix", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_virtual_prefix, "Py_ssize_t (hid_t, char *, Py_ssize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_virtual_prefix", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_virtual_prefix, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_sieve_buf_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_sieve_buf_size, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_sieve_buf_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_sieve_buf_size, "herr_t (hid_t, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_nlinks", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_nlinks, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_nlinks", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_nlinks, "herr_t (hid_t, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_elink_prefix", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_elink_prefix, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_elink_prefix", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_elink_prefix, "Py_ssize_t (hid_t, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_elink_fapl", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_elink_fapl, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_elink_fapl", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_elink_fapl, "herr_t (hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_create_intermediate_group", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_create_intermediate_group, "herr_t (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_create_intermediate_group", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_create_intermediate_group, "herr_t (hid_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_copy_object", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_copy_object, "herr_t (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_copy_object", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_copy_object, "herr_t (hid_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_char_encoding", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_char_encoding, "herr_t (hid_t, H5T_cset_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_char_encoding", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_char_encoding, "herr_t (hid_t, H5T_cset_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_attr_creation_order", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_attr_creation_order, "herr_t (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_attr_creation_order", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_attr_creation_order, "herr_t (hid_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_obj_track_times", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_obj_track_times, "herr_t (hid_t, hbool_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_obj_track_times", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_obj_track_times, "herr_t (hid_t, hbool_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_local_heap_size_hint", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_local_heap_size_hint, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_local_heap_size_hint", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_local_heap_size_hint, "herr_t (hid_t, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_link_phase_change", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_link_phase_change, "herr_t (hid_t, unsigned int, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_link_phase_change", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_link_phase_change, "herr_t (hid_t, unsigned int *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_attr_phase_change", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_attr_phase_change, "herr_t (hid_t, unsigned int, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_attr_phase_change", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_attr_phase_change, "herr_t (hid_t, unsigned int *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_est_link_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_est_link_info, "herr_t (hid_t, unsigned int, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_est_link_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_est_link_info, "herr_t (hid_t, unsigned int *, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_link_creation_order", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_link_creation_order, "herr_t (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_link_creation_order", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_link_creation_order, "herr_t (hid_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_libver_bounds", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_libver_bounds, "herr_t (hid_t, H5F_libver_t, H5F_libver_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_libver_bounds", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_libver_bounds, "herr_t (hid_t, H5F_libver_t *, H5F_libver_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pset_alignment", (void (*)(void))__pyx_f_4h5py_4defs_H5Pset_alignment, "herr_t (hid_t, hsize_t, hsize_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Pget_alignment", (void (*)(void))__pyx_f_4h5py_4defs_H5Pget_alignment, "herr_t (hid_t, hsize_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5PLappend", (void (*)(void))__pyx_f_4h5py_4defs_H5PLappend, "herr_t (char const *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5PLprepend", (void (*)(void))__pyx_f_4h5py_4defs_H5PLprepend, "herr_t (char const *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5PLreplace", (void (*)(void))__pyx_f_4h5py_4defs_H5PLreplace, "herr_t (char const *, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5PLinsert", (void (*)(void))__pyx_f_4h5py_4defs_H5PLinsert, "herr_t (char const *, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5PLremove", (void (*)(void))__pyx_f_4h5py_4defs_H5PLremove, "herr_t (unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5PLget", (void (*)(void))__pyx_f_4h5py_4defs_H5PLget, "Py_ssize_t (unsigned int, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5PLsize", (void (*)(void))__pyx_f_4h5py_4defs_H5PLsize, "herr_t (unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Rcreate", (void (*)(void))__pyx_f_4h5py_4defs_H5Rcreate, "herr_t (void *, hid_t, char *, H5R_type_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Rdereference", (void (*)(void))__pyx_f_4h5py_4defs_H5Rdereference, "hid_t (hid_t, H5R_type_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Rget_region", (void (*)(void))__pyx_f_4h5py_4defs_H5Rget_region, "hid_t (hid_t, H5R_type_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Rget_obj_type", (void (*)(void))__pyx_f_4h5py_4defs_H5Rget_obj_type, "herr_t (hid_t, H5R_type_t, void *, H5O_type_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Rget_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Rget_name, "Py_ssize_t (hid_t, H5R_type_t, void *, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Screate", (void (*)(void))__pyx_f_4h5py_4defs_H5Screate, "hid_t (H5S_class_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Scopy", (void (*)(void))__pyx_f_4h5py_4defs_H5Scopy, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sclose", (void (*)(void))__pyx_f_4h5py_4defs_H5Sclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Screate_simple", (void (*)(void))__pyx_f_4h5py_4defs_H5Screate_simple, "hid_t (int, hsize_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sis_simple", (void (*)(void))__pyx_f_4h5py_4defs_H5Sis_simple, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Soffset_simple", (void (*)(void))__pyx_f_4h5py_4defs_H5Soffset_simple, "herr_t (hid_t, hssize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_simple_extent_ndims", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_simple_extent_ndims, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_simple_extent_dims", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_simple_extent_dims, "int (hid_t, hsize_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_simple_extent_npoints", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_simple_extent_npoints, "hssize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_simple_extent_type", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_simple_extent_type, "H5S_class_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sextent_copy", (void (*)(void))__pyx_f_4h5py_4defs_H5Sextent_copy, "herr_t (hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sset_extent_simple", (void (*)(void))__pyx_f_4h5py_4defs_H5Sset_extent_simple, "herr_t (hid_t, int, hsize_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sset_extent_none", (void (*)(void))__pyx_f_4h5py_4defs_H5Sset_extent_none, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_select_type", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_select_type, "H5S_sel_type (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_select_npoints", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_select_npoints, "hssize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_select_bounds", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_select_bounds, "herr_t (hid_t, hsize_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sselect_all", (void (*)(void))__pyx_f_4h5py_4defs_H5Sselect_all, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sselect_none", (void (*)(void))__pyx_f_4h5py_4defs_H5Sselect_none, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sselect_valid", (void (*)(void))__pyx_f_4h5py_4defs_H5Sselect_valid, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_select_elem_npoints", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_select_elem_npoints, "hssize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_select_elem_pointlist", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_select_elem_pointlist, "herr_t (hid_t, hsize_t, hsize_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sselect_elements", (void (*)(void))__pyx_f_4h5py_4defs_H5Sselect_elements, "herr_t (hid_t, H5S_seloper_t, size_t, hsize_t const *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_select_hyper_nblocks", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_select_hyper_nblocks, "hssize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_select_hyper_blocklist", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_select_hyper_blocklist, "herr_t (hid_t, hsize_t, hsize_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sselect_hyperslab", (void (*)(void))__pyx_f_4h5py_4defs_H5Sselect_hyperslab, "herr_t (hid_t, H5S_seloper_t, hsize_t *, hsize_t *, hsize_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sencode", (void (*)(void))__pyx_f_4h5py_4defs_H5Sencode, "herr_t (hid_t, void *, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sdecode", (void (*)(void))__pyx_f_4h5py_4defs_H5Sdecode, "hid_t (void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sis_regular_hyperslab", (void (*)(void))__pyx_f_4h5py_4defs_H5Sis_regular_hyperslab, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Sget_regular_hyperslab", (void (*)(void))__pyx_f_4h5py_4defs_H5Sget_regular_hyperslab, "htri_t (hid_t, hsize_t *, hsize_t *, hsize_t *, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tcreate", (void (*)(void))__pyx_f_4h5py_4defs_H5Tcreate, "hid_t (enum H5T_class_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Topen", (void (*)(void))__pyx_f_4h5py_4defs_H5Topen, "hid_t (hid_t, char *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tcommitted", (void (*)(void))__pyx_f_4h5py_4defs_H5Tcommitted, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tcopy", (void (*)(void))__pyx_f_4h5py_4defs_H5Tcopy, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tequal", (void (*)(void))__pyx_f_4h5py_4defs_H5Tequal, "htri_t (hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tlock", (void (*)(void))__pyx_f_4h5py_4defs_H5Tlock, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_class", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_class, "enum H5T_class_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_size, "size_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_super", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_super, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tdetect_class", (void (*)(void))__pyx_f_4h5py_4defs_H5Tdetect_class, "htri_t (hid_t, enum H5T_class_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tclose", (void (*)(void))__pyx_f_4h5py_4defs_H5Tclose, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_native_type", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_native_type, "hid_t (hid_t, enum H5T_direction_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tcommit", (void (*)(void))__pyx_f_4h5py_4defs_H5Tcommit, "herr_t (hid_t, char *, hid_t, hid_t, hid_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_create_plist", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_create_plist, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tdecode", (void (*)(void))__pyx_f_4h5py_4defs_H5Tdecode, "hid_t (unsigned char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tencode", (void (*)(void))__pyx_f_4h5py_4defs_H5Tencode, "herr_t (hid_t, unsigned char *, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tfind", (void (*)(void))__pyx_f_4h5py_4defs_H5Tfind, "H5T_conv_t (hid_t, hid_t, H5T_cdata_t **)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tconvert", (void (*)(void))__pyx_f_4h5py_4defs_H5Tconvert, "herr_t (hid_t, hid_t, size_t, void *, void *, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tregister", (void (*)(void))__pyx_f_4h5py_4defs_H5Tregister, "herr_t (H5T_pers_t, char *, hid_t, hid_t, H5T_conv_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tunregister", (void (*)(void))__pyx_f_4h5py_4defs_H5Tunregister, "herr_t (H5T_pers_t, char *, hid_t, hid_t, H5T_conv_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_size", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_size, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_order", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_order, "H5T_order_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_order", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_order, "herr_t (hid_t, H5T_order_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_precision", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_precision, "hsize_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_precision", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_precision, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_offset", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_offset, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_offset", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_offset, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_pad", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_pad, "herr_t (hid_t, H5T_pad_t *, H5T_pad_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_pad", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_pad, "herr_t (hid_t, H5T_pad_t, H5T_pad_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_sign", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_sign, "H5T_sign_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_sign", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_sign, "herr_t (hid_t, H5T_sign_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_fields", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_fields, "herr_t (hid_t, size_t *, size_t *, size_t *, size_t *, size_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_fields", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_fields, "herr_t (hid_t, size_t, size_t, size_t, size_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_ebias", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_ebias, "size_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_ebias", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_ebias, "herr_t (hid_t, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_norm", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_norm, "H5T_norm_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_norm", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_norm, "herr_t (hid_t, H5T_norm_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_inpad", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_inpad, "H5T_pad_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_inpad", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_inpad, "herr_t (hid_t, H5T_pad_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_cset", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_cset, "H5T_cset_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_cset", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_cset, "herr_t (hid_t, H5T_cset_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_strpad", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_strpad, "H5T_str_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_strpad", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_strpad, "herr_t (hid_t, H5T_str_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tvlen_create", (void (*)(void))__pyx_f_4h5py_4defs_H5Tvlen_create, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tis_variable_str", (void (*)(void))__pyx_f_4h5py_4defs_H5Tis_variable_str, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_nmembers", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_nmembers, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_member_class", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_member_class, "enum H5T_class_t (hid_t, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_member_name", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_member_name, "char *(hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_member_type", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_member_type, "hid_t (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_member_offset", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_member_offset, "int (hid_t, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_member_index", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_member_index, "int (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tinsert", (void (*)(void))__pyx_f_4h5py_4defs_H5Tinsert, "herr_t (hid_t, char *, size_t, hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tpack", (void (*)(void))__pyx_f_4h5py_4defs_H5Tpack, "herr_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tenum_create", (void (*)(void))__pyx_f_4h5py_4defs_H5Tenum_create, "hid_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tenum_insert", (void (*)(void))__pyx_f_4h5py_4defs_H5Tenum_insert, "herr_t (hid_t, char *, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tenum_nameof", (void (*)(void))__pyx_f_4h5py_4defs_H5Tenum_nameof, "herr_t (hid_t, void *, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tenum_valueof", (void (*)(void))__pyx_f_4h5py_4defs_H5Tenum_valueof, "herr_t (hid_t, char *, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_member_value", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_member_value, "herr_t (hid_t, unsigned int, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tarray_create", (void (*)(void))__pyx_f_4h5py_4defs_H5Tarray_create, "hid_t (hid_t, int, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_array_ndims", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_array_ndims, "int (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_array_dims", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_array_dims, "int (hid_t, hsize_t *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tset_tag", (void (*)(void))__pyx_f_4h5py_4defs_H5Tset_tag, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Tget_tag", (void (*)(void))__pyx_f_4h5py_4defs_H5Tget_tag, "char *(hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Zfilter_avail", (void (*)(void))__pyx_f_4h5py_4defs_H5Zfilter_avail, "htri_t (H5Z_filter_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Zget_filter_info", (void (*)(void))__pyx_f_4h5py_4defs_H5Zget_filter_info, "herr_t (H5Z_filter_t, unsigned int *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5Zunregister", (void (*)(void))__pyx_f_4h5py_4defs_H5Zunregister, "herr_t (H5Z_filter_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSattach_scale", (void (*)(void))__pyx_f_4h5py_4defs_H5DSattach_scale, "herr_t (hid_t, hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSdetach_scale", (void (*)(void))__pyx_f_4h5py_4defs_H5DSdetach_scale, "herr_t (hid_t, hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSis_attached", (void (*)(void))__pyx_f_4h5py_4defs_H5DSis_attached, "htri_t (hid_t, hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSset_scale", (void (*)(void))__pyx_f_4h5py_4defs_H5DSset_scale, "herr_t (hid_t, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSget_num_scales", (void (*)(void))__pyx_f_4h5py_4defs_H5DSget_num_scales, "int (hid_t, unsigned int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSset_label", (void (*)(void))__pyx_f_4h5py_4defs_H5DSset_label, "herr_t (hid_t, unsigned int, char *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSget_label", (void (*)(void))__pyx_f_4h5py_4defs_H5DSget_label, "Py_ssize_t (hid_t, unsigned int, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSget_scale_name", (void (*)(void))__pyx_f_4h5py_4defs_H5DSget_scale_name, "Py_ssize_t (hid_t, char *, size_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSis_scale", (void (*)(void))__pyx_f_4h5py_4defs_H5DSis_scale, "htri_t (hid_t)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("H5DSiterate_scales", (void (*)(void))__pyx_f_4h5py_4defs_H5DSiterate_scales, "herr_t (hid_t, unsigned int, int *, H5DS_iterate_t, void *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(2, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("numpy"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType(__pyx_t_1, "numpy", "dtype", sizeof(PyArray_Descr), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_dtype) __PYX_ERR(1, 199, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType(__pyx_t_1, "numpy", "flatiter", sizeof(PyArrayIterObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_flatiter) __PYX_ERR(1, 222, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType(__pyx_t_1, "numpy", "broadcast", sizeof(PyArrayMultiIterObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_broadcast) __PYX_ERR(1, 226, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType(__pyx_t_1, "numpy", "ndarray", sizeof(PyArrayObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_ndarray) __PYX_ERR(1, 238, __pyx_L1_error)
  __pyx_ptype_5numpy_generic = __Pyx_ImportType(__pyx_t_1, "numpy", "generic", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_generic) __PYX_ERR(1, 770, __pyx_L1_error)
  __pyx_ptype_5numpy_number = __Pyx_ImportType(__pyx_t_1, "numpy", "number", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_number) __PYX_ERR(1, 772, __pyx_L1_error)
  __pyx_ptype_5numpy_integer = __Pyx_ImportType(__pyx_t_1, "numpy", "integer", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_integer) __PYX_ERR(1, 774, __pyx_L1_error)
  __pyx_ptype_5numpy_signedinteger = __Pyx_ImportType(__pyx_t_1, "numpy", "signedinteger", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_signedinteger) __PYX_ERR(1, 776, __pyx_L1_error)
  __pyx_ptype_5numpy_unsignedinteger = __Pyx_ImportType(__pyx_t_1, "numpy", "unsignedinteger", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_unsignedinteger) __PYX_ERR(1, 778, __pyx_L1_error)
  __pyx_ptype_5numpy_inexact = __Pyx_ImportType(__pyx_t_1, "numpy", "inexact", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_inexact) __PYX_ERR(1, 780, __pyx_L1_error)
  __pyx_ptype_5numpy_floating = __Pyx_ImportType(__pyx_t_1, "numpy", "floating", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_floating) __PYX_ERR(1, 782, __pyx_L1_error)
  __pyx_ptype_5numpy_complexfloating = __Pyx_ImportType(__pyx_t_1, "numpy", "complexfloating", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_complexfloating) __PYX_ERR(1, 784, __pyx_L1_error)
  __pyx_ptype_5numpy_flexible = __Pyx_ImportType(__pyx_t_1, "numpy", "flexible", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_flexible) __PYX_ERR(1, 786, __pyx_L1_error)
  __pyx_ptype_5numpy_character = __Pyx_ImportType(__pyx_t_1, "numpy", "character", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_character) __PYX_ERR(1, 788, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType(__pyx_t_1, "numpy", "ufunc", sizeof(PyUFuncObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_ufunc) __PYX_ERR(1, 826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __pyx_t_1 = PyImport_ImportModule("h5py._errors"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction(__pyx_t_1, "set_exception", (void (**)(void))&__pyx_f_4h5py_7_errors_set_exception, "int (void)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "set_default_error_handler", (void (**)(void))&__pyx_f_4h5py_7_errors_set_default_error_handler, "void (void)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initdefs(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initdefs(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_defs(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_defs(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_defs(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'defs' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_defs(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("defs", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_h5py__defs) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "h5py.defs")) {
      if (unlikely(PyDict_SetItemString(modules, "h5py.defs", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  if (unlikely(__Pyx_modinit_function_export_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_init_code();
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  if (unlikely(__Pyx_modinit_function_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "h5py/defs.pyx":1
 * # cython: language_level=3             # <<<<<<<<<<<<<<
 * #
 * # Warning: this file is auto-generated from api_gen.py. DO NOT EDIT!
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "../recipe-sysroot-native/usr/lib/python3.10/site-packages/numpy/__init__.pxd":1013
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init h5py.defs", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init h5py.defs");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* Declarations */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = (float)(1.0) / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = (float)(1.0) / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = (double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = (double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[5];
    int same=1, i, found_dot;
    const char* rt_from_call = Py_GetVersion();
    PyOS_snprintf(ctversion, 5, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    found_dot = 0;
    for (i = 0; i < 4; i++) {
        if (!ctversion[i]) {
            same = (rt_from_call[i] < '0' || rt_from_call[i] > '9');
            break;
        }
        if (rt_from_call[i] != ctversion[i]) {
            same = 0;
            break;
        }
    }
    if (!same) {
        char rtversion[5] = {'\0'};
        char message[200];
        for (i=0; i<4; ++i) {
            if (rt_from_call[i] == '.') {
                if (found_dot) break;
                found_dot = 1;
            } else if (rt_from_call[i] < '0' || rt_from_call[i] > '9') {
                break;
            }
            rtversion[i] = rt_from_call[i];
        }
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* FunctionExport */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
#if PY_VERSION_HEX >= 0x02070000
    cobj = PyCapsule_New(tmp.p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(tmp.p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction
#define __PYX_HAVE_RT_ImportFunction
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, funcname);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C function %.200s",
                PyModule_GetName(module), funcname);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    tmp.p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, desc);
        goto bad;
    }
    tmp.p = PyCObject_AsVoidPtr(cobj);}
#endif
    *f = tmp.fp;
    if (!(*f))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
